{% extends "one_column.html" %}

{% block title %}Page Not Found{% endblock %}

{% block page_header %}
<h1>Sorry, we can't find that page.</h1>
{% endblock %}

{% block content %}
  	<p>We encourage you to <a href="/contact-us/">contact us</a> if you need assistance, or continue to browse the site.</p>
  	
{% endblock content %}

