{% load static %}
<div class="col-sm-7 h1"><a href="{{ homepage_url }}">{% block brand_title %}<img src="{% static 'img/FarmDropLogoBWG.png' %}"></a><small> {{ shop_tagline }}</small>{% endblock %}</div>
