@mixin ppoi {
  div.ppoi-point {
    background-color: map_get($materialize-red, lighten-3);
    background-color: rgba(map_get($materialize-red, lighten-3), .5);
    border-radius: 50%;
    box-shadow: 0 0 5px 0 rgba(0,0,0,.5);
    height: 50px;
    width: 50px;
  }
}

.point-stage {
  @include ppoi;
}
