@mixin select2 {
  margin-bottom: 15px;

  &--default, &--default.select2-container--focus {
    .select2-selection--multiple {
      background: transparent;
      border: none;
      border-bottom: 1px solid $input-border-color;
      border-radius: 0;
      line-height: calc(3rem - 1px);

      .select2-selection__rendered {
        padding: 0;
        vertical-align: middle;
      }

      .select2-selection__choice {
        background-color: map_get($blue, lighten-4);
        border-color: map-get($blue, lighten-3);
        border-radius: 2px;
        line-height: 1.5;
        margin-top: 10px;

        &__remove {
          @extend .mdi-navigation-close;
          font-size: 0;

          &:before {
            display: inline-block;
            font-family: $font-mdi;
            font-size: 12px;
          }
        }
      }
    }

    .select2-search--inline {
      .select2-search__field {
        background: transparent;
        height: auto;
        margin: 0;
        padding-left: 0;

        &:focus {
          border-bottom: none;
          box-shadow: none;
        }
      }
    }
  }

  &--default.select2-container--open {
    @extend .z-depth-1;

    .select2-selection__rendered {
      background-color: white;
    }
  }

  .select2-dropdown {
    @extend .z-depth-1;
    border: none;
  }
}

.select2-container {
  @include select2;
}
