@import "../components/bootstrap/less/bootstrap";
@import "../components/zocial-less/css/zocial";
@icon-font-path: "../fonts/";
@zocialPath: "../fonts/";

.navbar {
	margin-bottom: 50px;
}

.price {
	&.undiscounted {
		text-decoration: line-through;
	}
}

.address-details {
	border-bottom: 1px dashed;
	color: #3a87ad;
	cursor: pointer;
}

.popover {
	min-width: 200px;
}

.product-gallery {
	margin-top: @grid-gutter-width;
}

.product-related {
	.active {
		border: 1px solid @btn-primary-border;
		box-shadow: 0 0 5px @btn-primary-border;
	}
}

.product-form {
	.btn-group {
		display: block;
		overflow: hidden;

		.btn-default.active {
			.btn-primary;
		}
	}
}

.form-group.required .control-label:after{
    content: '*';
}
