@mixin card {
  & &-content {
    .card-title {
      display: block;
      line-height: 28px;
      margin-bottom: 10px;
    }

    &--no-data {
      padding-top: 6px;
    }
  }
}

.card {
  @include card;
}
