@mixin tabs {
  li {
    a {
      span {
        display: none;

        @media (min-width: $small-screen-up) {
          display: inline;
        }
      }

      i {
        font-size: 24px;

        @media (min-width: $small-screen-up) {
          display: none;
        }
      }
    }
  }
}

.tabs {
  @include tabs;
}
