!function(e){function t(i){if(n[i])return n[i].exports;var r=n[i]={exports:{},id:i,loaded:!1};return e[i].call(r.exports,r,r.exports,t),r.loaded=!0,r.exports}var n={};return t.m=e,t.c=n,t.p="",t(0)}([function(e,t,n){"use strict";function i(){r("select:not(.browser-default):not([multiple])").material_select(),r("select[multiple]").addClass("browser-default").select2()}var r=n(1),o=n(2),a=n(4);n(5),n(7),n(8),n(12),r(document).ready(function(){function e(){return!r(".hide-on-med-only").is(":visible")}i(),r(".button-collapse").sideNav(),r(".modal-trigger").leanModal(),e()&&r(".equal-height-on-med").matchHeight();var t=r("ul.tabs");t.length&&(t.find(".tab").on("click",function(e){window.history.pushState(null,null,e.target.hash);var t=r(this).find("a").attr("href");r(".btn-fab").addClass("btn-fab-hidden"),r(t+"-btn").removeClass("btn-fab-hidden")}),t.find("a.active").parent().click()),r(".modal-trigger-custom").on("click",function(e){var t=this;r.ajax({url:r(this).data("href"),method:"get",success:function(e){var n=r(r(t).attr("href"));n.html(e),i(),n.openModal()}}),e.preventDefault()});var n=r(".message"),o=0,a=100,s=250;setTimeout(function(){n.each(function(){var e=this;setTimeout(function(){r(e).removeClass("toast--hidden")},o+a),o+=3e3,setTimeout(function(){r(e).addClass("toast--hidden")},o-a)})},s),r(document).on("submit",".form-async",function(e){var t=this;r.ajax({url:r(t).attr("action"),method:"post",data:r(t).serialize(),complete:function(e){400===e.status?(r(t).parent().html(e.responseText),i()):r(".modal-close").click()},success:function(e){e.redirectUrl?window.location.href=e.redirectUrl:location.reload()}}),e.preventDefault()}).on("click",".modal-close",function(){r(".modal").closeModal()})}),o.options.productImageForm={paramName:"image",maxFilesize:20,previewsContainer:".product-gallery",thumbnailWidth:400,thumbnailHeight:250,previewTemplate:r("#template").html(),clickable:!1,init:function(){var e=r(".dropzone-ghost"),t=r(".product-gallery");this.on("complete",function(){e.remove().appendTo(t)}).on("success",function(e,t){r(e.previewElement).find(".product-gallery-item-desc").html(e.name),r(e.previewElement).attr("data-id",t.id);var n=r(e.previewElement).find(".card-action-edit").attr("href");n=n.split("/"),n[n.length-2]=t.id,r(e.previewElement).find(".card-action-edit").attr("href",n.join("/")),r(e.previewElement).find(".card-action-edit").show();var i=r(e.previewElement).find(".card-action-delete").attr("href");i=i.split("/"),i[i.length-3]=t.id,r(e.previewElement).find(".card-action-delete").attr("href",i.join("/")),r(e.previewElement).find(".card-action-delete").show()})}};var s=document.getElementById("product-gallery");s&&a.create(s,{handle:".card-image",onUpdate:function(){r.ajax({dataType:"json",contentType:"application/json",data:JSON.stringify({order:function(){var e=[];return r(s).find(".product-gallery-item[data-id]").each(function(){e.push(r(this).data("id"))}),e}()}),headers:{"X-CSRFToken":r("[name=csrfmiddlewaretoken]").val()},method:"post",url:r(s).data("post-url")})}}),r(".select-all").on("change",function(){var e=r(this).parents("form").find(".switch-actions");this.checked?e.prop("checked",!0):e.prop("checked",!1)}),r(".switch-actions").on("change",function(){var e=r(this).parents("form").find(".btn-show-when-checked"),t=r(this).parents("form").find(".btn-show-when-unchecked");r(this).parents("form").find(".switch-actions:checked").length?(e.show(),t.hide()):(t.show(),e.hide())}),r(".datepicker").pickadate({format:"d mmmm yyyy",formatSubmit:"yyyy-mm-dd",selectMonths:!0,hiddenName:!0}),r(document).ready(function(){var e=r('.body-vouchers [name="type"]');e.length&&!function(){var t=r('[name="discount_value_type"]'),n=r(".voucher-form"),i=r('[name="product-apply_to"]').parents(".input"),o=r('[name="category-apply_to"]').parents(".input"),a=function(){var a=t.val(),s=e.val(),l="percentage"===a;i.toggleClass("hide",l),o.toggleClass("hide",l),n.each(function(e,t){var n=r(t),i=n.data("type")!==s;n.toggleClass("hide",i)})};t.on("change",a),e.on("change",a),e.trigger("change")}()})},function(e,t,n){var i,r;/*!
	 * jQuery JavaScript Library v2.2.4
	 * http://jquery.com/
	 *
	 * Includes Sizzle.js
	 * http://sizzlejs.com/
	 *
	 * Copyright jQuery Foundation and other contributors
	 * Released under the MIT license
	 * http://jquery.org/license
	 *
	 * Date: 2016-05-20T17:23Z
	 */
!function(t,n){"object"==typeof e&&"object"==typeof e.exports?e.exports=t.document?n(t,!0):function(e){if(!e.document)throw new Error("jQuery requires a window with a document");return n(e)}:n(t)}("undefined"!=typeof window?window:this,function(n,o){function a(e){var t=!!e&&"length"in e&&e.length,n=ue.type(e);return"function"===n||ue.isWindow(e)?!1:"array"===n||0===t||"number"==typeof t&&t>0&&t-1 in e}function s(e,t,n){if(ue.isFunction(t))return ue.grep(e,function(e,i){return!!t.call(e,i,e)!==n});if(t.nodeType)return ue.grep(e,function(e){return e===t!==n});if("string"==typeof t){if(be.test(t))return ue.filter(t,e,n);t=ue.filter(t,e)}return ue.grep(e,function(e){return ie.call(t,e)>-1!==n})}function l(e,t){for(;(e=e[t])&&1!==e.nodeType;);return e}function u(e){var t={};return ue.each(e.match(Te)||[],function(e,n){t[n]=!0}),t}function c(){J.removeEventListener("DOMContentLoaded",c),n.removeEventListener("load",c),ue.ready()}function d(){this.expando=ue.expando+d.uid++}function p(e,t,n){var i;if(void 0===n&&1===e.nodeType)if(i="data-"+t.replace(Ie,"-$&").toLowerCase(),n=e.getAttribute(i),"string"==typeof n){try{n="true"===n?!0:"false"===n?!1:"null"===n?null:+n+""===n?+n:Oe.test(n)?ue.parseJSON(n):n}catch(r){}Me.set(e,t,n)}else n=void 0;return n}function h(e,t,n,i){var r,o=1,a=20,s=i?function(){return i.cur()}:function(){return ue.css(e,t,"")},l=s(),u=n&&n[3]||(ue.cssNumber[t]?"":"px"),c=(ue.cssNumber[t]||"px"!==u&&+l)&&Fe.exec(ue.css(e,t));if(c&&c[3]!==u){u=u||c[3],n=n||[],c=+l||1;do o=o||".5",c/=o,ue.style(e,t,c+u);while(o!==(o=s()/l)&&1!==o&&--a)}return n&&(c=+c||+l||0,r=n[1]?c+(n[1]+1)*n[2]:+n[2],i&&(i.unit=u,i.start=c,i.end=r)),r}function f(e,t){var n="undefined"!=typeof e.getElementsByTagName?e.getElementsByTagName(t||"*"):"undefined"!=typeof e.querySelectorAll?e.querySelectorAll(t||"*"):[];return void 0===t||t&&ue.nodeName(e,t)?ue.merge([e],n):n}function g(e,t){for(var n=0,i=e.length;i>n;n++)Ae.set(e[n],"globalEval",!t||Ae.get(t[n],"globalEval"))}function v(e,t,n,i,r){for(var o,a,s,l,u,c,d=t.createDocumentFragment(),p=[],h=0,v=e.length;v>h;h++)if(o=e[h],o||0===o)if("object"===ue.type(o))ue.merge(p,o.nodeType?[o]:o);else if(ze.test(o)){for(a=a||d.appendChild(t.createElement("div")),s=(qe.exec(o)||["",""])[1].toLowerCase(),l=Re[s]||Re._default,a.innerHTML=l[1]+ue.htmlPrefilter(o)+l[2],c=l[0];c--;)a=a.lastChild;ue.merge(p,a.childNodes),a=d.firstChild,a.textContent=""}else p.push(t.createTextNode(o));for(d.textContent="",h=0;o=p[h++];)if(i&&ue.inArray(o,i)>-1)r&&r.push(o);else if(u=ue.contains(o.ownerDocument,o),a=f(d.appendChild(o),"script"),u&&g(a),n)for(c=0;o=a[c++];)je.test(o.type||"")&&n.push(o);return d}function m(){return!0}function y(){return!1}function b(){try{return J.activeElement}catch(e){}}function w(e,t,n,i,r,o){var a,s;if("object"==typeof t){"string"!=typeof n&&(i=i||n,n=void 0);for(s in t)w(e,s,n,i,t[s],o);return e}if(null==i&&null==r?(r=n,i=n=void 0):null==r&&("string"==typeof n?(r=i,i=void 0):(r=i,i=n,n=void 0)),r===!1)r=y;else if(!r)return e;return 1===o&&(a=r,r=function(e){return ue().off(e),a.apply(this,arguments)},r.guid=a.guid||(a.guid=ue.guid++)),e.each(function(){ue.event.add(this,t,r,i,n)})}function x(e,t){return ue.nodeName(e,"table")&&ue.nodeName(11!==t.nodeType?t:t.firstChild,"tr")?e.getElementsByTagName("tbody")[0]||e.appendChild(e.ownerDocument.createElement("tbody")):e}function _(e){return e.type=(null!==e.getAttribute("type"))+"/"+e.type,e}function k(e){var t=Xe.exec(e.type);return t?e.type=t[1]:e.removeAttribute("type"),e}function C(e,t){var n,i,r,o,a,s,l,u;if(1===t.nodeType){if(Ae.hasData(e)&&(o=Ae.access(e),a=Ae.set(t,o),u=o.events)){delete a.handle,a.events={};for(r in u)for(n=0,i=u[r].length;i>n;n++)ue.event.add(t,r,u[r][n])}Me.hasData(e)&&(s=Me.access(e),l=ue.extend({},s),Me.set(t,l))}}function T(e,t){var n=t.nodeName.toLowerCase();"input"===n&&Le.test(e.type)?t.checked=e.checked:"input"!==n&&"textarea"!==n||(t.defaultValue=e.defaultValue)}function D(e,t,n,i){t=te.apply([],t);var r,o,a,s,l,u,c=0,d=e.length,p=d-1,h=t[0],g=ue.isFunction(h);if(g||d>1&&"string"==typeof h&&!se.checkClone&&Ve.test(h))return e.each(function(r){var o=e.eq(r);g&&(t[0]=h.call(this,r,o.html())),D(o,t,n,i)});if(d&&(r=v(t,e[0].ownerDocument,!1,e,i),o=r.firstChild,1===r.childNodes.length&&(r=o),o||i)){for(a=ue.map(f(r,"script"),_),s=a.length;d>c;c++)l=r,c!==p&&(l=ue.clone(l,!0,!0),s&&ue.merge(a,f(l,"script"))),n.call(e[c],l,c);if(s)for(u=a[a.length-1].ownerDocument,ue.map(a,k),c=0;s>c;c++)l=a[c],je.test(l.type||"")&&!Ae.access(l,"globalEval")&&ue.contains(u,l)&&(l.src?ue._evalUrl&&ue._evalUrl(l.src):ue.globalEval(l.textContent.replace(Qe,"")))}return e}function S(e,t,n){for(var i,r=t?ue.filter(t,e):e,o=0;null!=(i=r[o]);o++)n||1!==i.nodeType||ue.cleanData(f(i)),i.parentNode&&(n&&ue.contains(i.ownerDocument,i)&&g(f(i,"script")),i.parentNode.removeChild(i));return e}function E(e,t){var n=ue(t.createElement(e)).appendTo(t.body),i=ue.css(n[0],"display");return n.detach(),i}function A(e){var t=J,n=Ke[e];return n||(n=E(e,t),"none"!==n&&n||(Ge=(Ge||ue("<iframe frameborder='0' width='0' height='0'/>")).appendTo(t.documentElement),t=Ge[0].contentDocument,t.write(),t.close(),n=E(e,t),Ge.detach()),Ke[e]=n),n}function M(e,t,n){var i,r,o,a,s=e.style;return n=n||et(e),a=n?n.getPropertyValue(t)||n[t]:void 0,""!==a&&void 0!==a||ue.contains(e.ownerDocument,e)||(a=ue.style(e,t)),n&&!se.pixelMarginRight()&&Je.test(a)&&Ze.test(t)&&(i=s.width,r=s.minWidth,o=s.maxWidth,s.minWidth=s.maxWidth=s.width=a,a=n.width,s.width=i,s.minWidth=r,s.maxWidth=o),void 0!==a?a+"":a}function O(e,t){return{get:function(){return e()?void delete this.get:(this.get=t).apply(this,arguments)}}}function I(e){if(e in st)return e;for(var t=e[0].toUpperCase()+e.slice(1),n=at.length;n--;)if(e=at[n]+t,e in st)return e}function N(e,t,n){var i=Fe.exec(t);return i?Math.max(0,i[2]-(n||0))+(i[3]||"px"):t}function F(e,t,n,i,r){for(var o=n===(i?"border":"content")?4:"width"===t?1:0,a=0;4>o;o+=2)"margin"===n&&(a+=ue.css(e,n+Pe[o],!0,r)),i?("content"===n&&(a-=ue.css(e,"padding"+Pe[o],!0,r)),"margin"!==n&&(a-=ue.css(e,"border"+Pe[o]+"Width",!0,r))):(a+=ue.css(e,"padding"+Pe[o],!0,r),"padding"!==n&&(a+=ue.css(e,"border"+Pe[o]+"Width",!0,r)));return a}function P(e,t,n){var i=!0,r="width"===t?e.offsetWidth:e.offsetHeight,o=et(e),a="border-box"===ue.css(e,"boxSizing",!1,o);if(0>=r||null==r){if(r=M(e,t,o),(0>r||null==r)&&(r=e.style[t]),Je.test(r))return r;i=a&&(se.boxSizingReliable()||r===e.style[t]),r=parseFloat(r)||0}return r+F(e,t,n||(a?"border":"content"),i,o)+"px"}function $(e,t){for(var n,i,r,o=[],a=0,s=e.length;s>a;a++)i=e[a],i.style&&(o[a]=Ae.get(i,"olddisplay"),n=i.style.display,t?(o[a]||"none"!==n||(i.style.display=""),""===i.style.display&&$e(i)&&(o[a]=Ae.access(i,"olddisplay",A(i.nodeName)))):(r=$e(i),"none"===n&&r||Ae.set(i,"olddisplay",r?n:ue.css(i,"display"))));for(a=0;s>a;a++)i=e[a],i.style&&(t&&"none"!==i.style.display&&""!==i.style.display||(i.style.display=t?o[a]||"":"none"));return e}function L(e,t,n,i,r){return new L.prototype.init(e,t,n,i,r)}function q(){return n.setTimeout(function(){lt=void 0}),lt=ue.now()}function j(e,t){var n,i=0,r={height:e};for(t=t?1:0;4>i;i+=2-t)n=Pe[i],r["margin"+n]=r["padding"+n]=e;return t&&(r.opacity=r.width=e),r}function R(e,t,n){for(var i,r=(W.tweeners[t]||[]).concat(W.tweeners["*"]),o=0,a=r.length;a>o;o++)if(i=r[o].call(n,t,e))return i}function z(e,t,n){var i,r,o,a,s,l,u,c,d=this,p={},h=e.style,f=e.nodeType&&$e(e),g=Ae.get(e,"fxshow");n.queue||(s=ue._queueHooks(e,"fx"),null==s.unqueued&&(s.unqueued=0,l=s.empty.fire,s.empty.fire=function(){s.unqueued||l()}),s.unqueued++,d.always(function(){d.always(function(){s.unqueued--,ue.queue(e,"fx").length||s.empty.fire()})})),1===e.nodeType&&("height"in t||"width"in t)&&(n.overflow=[h.overflow,h.overflowX,h.overflowY],u=ue.css(e,"display"),c="none"===u?Ae.get(e,"olddisplay")||A(e.nodeName):u,"inline"===c&&"none"===ue.css(e,"float")&&(h.display="inline-block")),n.overflow&&(h.overflow="hidden",d.always(function(){h.overflow=n.overflow[0],h.overflowX=n.overflow[1],h.overflowY=n.overflow[2]}));for(i in t)if(r=t[i],ct.exec(r)){if(delete t[i],o=o||"toggle"===r,r===(f?"hide":"show")){if("show"!==r||!g||void 0===g[i])continue;f=!0}p[i]=g&&g[i]||ue.style(e,i)}else u=void 0;if(ue.isEmptyObject(p))"inline"===("none"===u?A(e.nodeName):u)&&(h.display=u);else{g?"hidden"in g&&(f=g.hidden):g=Ae.access(e,"fxshow",{}),o&&(g.hidden=!f),f?ue(e).show():d.done(function(){ue(e).hide()}),d.done(function(){var t;Ae.remove(e,"fxshow");for(t in p)ue.style(e,t,p[t])});for(i in p)a=R(f?g[i]:0,i,d),i in g||(g[i]=a.start,f&&(a.end=a.start,a.start="width"===i||"height"===i?1:0))}}function H(e,t){var n,i,r,o,a;for(n in e)if(i=ue.camelCase(n),r=t[i],o=e[n],ue.isArray(o)&&(r=o[1],o=e[n]=o[0]),n!==i&&(e[i]=o,delete e[n]),a=ue.cssHooks[i],a&&"expand"in a){o=a.expand(o),delete e[i];for(n in o)n in e||(e[n]=o[n],t[n]=r)}else t[i]=r}function W(e,t,n){var i,r,o=0,a=W.prefilters.length,s=ue.Deferred().always(function(){delete l.elem}),l=function(){if(r)return!1;for(var t=lt||q(),n=Math.max(0,u.startTime+u.duration-t),i=n/u.duration||0,o=1-i,a=0,l=u.tweens.length;l>a;a++)u.tweens[a].run(o);return s.notifyWith(e,[u,o,n]),1>o&&l?n:(s.resolveWith(e,[u]),!1)},u=s.promise({elem:e,props:ue.extend({},t),opts:ue.extend(!0,{specialEasing:{},easing:ue.easing._default},n),originalProperties:t,originalOptions:n,startTime:lt||q(),duration:n.duration,tweens:[],createTween:function(t,n){var i=ue.Tween(e,u.opts,t,n,u.opts.specialEasing[t]||u.opts.easing);return u.tweens.push(i),i},stop:function(t){var n=0,i=t?u.tweens.length:0;if(r)return this;for(r=!0;i>n;n++)u.tweens[n].run(1);return t?(s.notifyWith(e,[u,1,0]),s.resolveWith(e,[u,t])):s.rejectWith(e,[u,t]),this}}),c=u.props;for(H(c,u.opts.specialEasing);a>o;o++)if(i=W.prefilters[o].call(u,e,c,u.opts))return ue.isFunction(i.stop)&&(ue._queueHooks(u.elem,u.opts.queue).stop=ue.proxy(i.stop,i)),i;return ue.map(c,R,u),ue.isFunction(u.opts.start)&&u.opts.start.call(e,u),ue.fx.timer(ue.extend(l,{elem:e,anim:u,queue:u.opts.queue})),u.progress(u.opts.progress).done(u.opts.done,u.opts.complete).fail(u.opts.fail).always(u.opts.always)}function Y(e){return e.getAttribute&&e.getAttribute("class")||""}function B(e){return function(t,n){"string"!=typeof t&&(n=t,t="*");var i,r=0,o=t.toLowerCase().match(Te)||[];if(ue.isFunction(n))for(;i=o[r++];)"+"===i[0]?(i=i.slice(1)||"*",(e[i]=e[i]||[]).unshift(n)):(e[i]=e[i]||[]).push(n)}}function U(e,t,n,i){function r(s){var l;return o[s]=!0,ue.each(e[s]||[],function(e,s){var u=s(t,n,i);return"string"!=typeof u||a||o[u]?a?!(l=u):void 0:(t.dataTypes.unshift(u),r(u),!1)}),l}var o={},a=e===Mt;return r(t.dataTypes[0])||!o["*"]&&r("*")}function V(e,t){var n,i,r=ue.ajaxSettings.flatOptions||{};for(n in t)void 0!==t[n]&&((r[n]?e:i||(i={}))[n]=t[n]);return i&&ue.extend(!0,e,i),e}function X(e,t,n){for(var i,r,o,a,s=e.contents,l=e.dataTypes;"*"===l[0];)l.shift(),void 0===i&&(i=e.mimeType||t.getResponseHeader("Content-Type"));if(i)for(r in s)if(s[r]&&s[r].test(i)){l.unshift(r);break}if(l[0]in n)o=l[0];else{for(r in n){if(!l[0]||e.converters[r+" "+l[0]]){o=r;break}a||(a=r)}o=o||a}return o?(o!==l[0]&&l.unshift(o),n[o]):void 0}function Q(e,t,n,i){var r,o,a,s,l,u={},c=e.dataTypes.slice();if(c[1])for(a in e.converters)u[a.toLowerCase()]=e.converters[a];for(o=c.shift();o;)if(e.responseFields[o]&&(n[e.responseFields[o]]=t),!l&&i&&e.dataFilter&&(t=e.dataFilter(t,e.dataType)),l=o,o=c.shift())if("*"===o)o=l;else if("*"!==l&&l!==o){if(a=u[l+" "+o]||u["* "+o],!a)for(r in u)if(s=r.split(" "),s[1]===o&&(a=u[l+" "+s[0]]||u["* "+s[0]])){a===!0?a=u[r]:u[r]!==!0&&(o=s[0],c.unshift(s[1]));break}if(a!==!0)if(a&&e["throws"])t=a(t);else try{t=a(t)}catch(d){return{state:"parsererror",error:a?d:"No conversion from "+l+" to "+o}}}return{state:"success",data:t}}function G(e,t,n,i){var r;if(ue.isArray(t))ue.each(t,function(t,r){n||Ft.test(e)?i(e,r):G(e+"["+("object"==typeof r&&null!=r?t:"")+"]",r,n,i)});else if(n||"object"!==ue.type(t))i(e,t);else for(r in t)G(e+"["+r+"]",t[r],n,i)}function K(e){return ue.isWindow(e)?e:9===e.nodeType&&e.defaultView}var Z=[],J=n.document,ee=Z.slice,te=Z.concat,ne=Z.push,ie=Z.indexOf,re={},oe=re.toString,ae=re.hasOwnProperty,se={},le="2.2.4",ue=function(e,t){return new ue.fn.init(e,t)},ce=/^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g,de=/^-ms-/,pe=/-([\da-z])/gi,he=function(e,t){return t.toUpperCase()};ue.fn=ue.prototype={jquery:le,constructor:ue,selector:"",length:0,toArray:function(){return ee.call(this)},get:function(e){return null!=e?0>e?this[e+this.length]:this[e]:ee.call(this)},pushStack:function(e){var t=ue.merge(this.constructor(),e);return t.prevObject=this,t.context=this.context,t},each:function(e){return ue.each(this,e)},map:function(e){return this.pushStack(ue.map(this,function(t,n){return e.call(t,n,t)}))},slice:function(){return this.pushStack(ee.apply(this,arguments))},first:function(){return this.eq(0)},last:function(){return this.eq(-1)},eq:function(e){var t=this.length,n=+e+(0>e?t:0);return this.pushStack(n>=0&&t>n?[this[n]]:[])},end:function(){return this.prevObject||this.constructor()},push:ne,sort:Z.sort,splice:Z.splice},ue.extend=ue.fn.extend=function(){var e,t,n,i,r,o,a=arguments[0]||{},s=1,l=arguments.length,u=!1;for("boolean"==typeof a&&(u=a,a=arguments[s]||{},s++),"object"==typeof a||ue.isFunction(a)||(a={}),s===l&&(a=this,s--);l>s;s++)if(null!=(e=arguments[s]))for(t in e)n=a[t],i=e[t],a!==i&&(u&&i&&(ue.isPlainObject(i)||(r=ue.isArray(i)))?(r?(r=!1,o=n&&ue.isArray(n)?n:[]):o=n&&ue.isPlainObject(n)?n:{},a[t]=ue.extend(u,o,i)):void 0!==i&&(a[t]=i));return a},ue.extend({expando:"jQuery"+(le+Math.random()).replace(/\D/g,""),isReady:!0,error:function(e){throw new Error(e)},noop:function(){},isFunction:function(e){return"function"===ue.type(e)},isArray:Array.isArray,isWindow:function(e){return null!=e&&e===e.window},isNumeric:function(e){var t=e&&e.toString();return!ue.isArray(e)&&t-parseFloat(t)+1>=0},isPlainObject:function(e){var t;if("object"!==ue.type(e)||e.nodeType||ue.isWindow(e))return!1;if(e.constructor&&!ae.call(e,"constructor")&&!ae.call(e.constructor.prototype||{},"isPrototypeOf"))return!1;for(t in e);return void 0===t||ae.call(e,t)},isEmptyObject:function(e){var t;for(t in e)return!1;return!0},type:function(e){return null==e?e+"":"object"==typeof e||"function"==typeof e?re[oe.call(e)]||"object":typeof e},globalEval:function(e){var t,n=eval;e=ue.trim(e),e&&(1===e.indexOf("use strict")?(t=J.createElement("script"),t.text=e,J.head.appendChild(t).parentNode.removeChild(t)):n(e))},camelCase:function(e){return e.replace(de,"ms-").replace(pe,he)},nodeName:function(e,t){return e.nodeName&&e.nodeName.toLowerCase()===t.toLowerCase()},each:function(e,t){var n,i=0;if(a(e))for(n=e.length;n>i&&t.call(e[i],i,e[i])!==!1;i++);else for(i in e)if(t.call(e[i],i,e[i])===!1)break;return e},trim:function(e){return null==e?"":(e+"").replace(ce,"")},makeArray:function(e,t){var n=t||[];return null!=e&&(a(Object(e))?ue.merge(n,"string"==typeof e?[e]:e):ne.call(n,e)),n},inArray:function(e,t,n){return null==t?-1:ie.call(t,e,n)},merge:function(e,t){for(var n=+t.length,i=0,r=e.length;n>i;i++)e[r++]=t[i];return e.length=r,e},grep:function(e,t,n){for(var i,r=[],o=0,a=e.length,s=!n;a>o;o++)i=!t(e[o],o),i!==s&&r.push(e[o]);return r},map:function(e,t,n){var i,r,o=0,s=[];if(a(e))for(i=e.length;i>o;o++)r=t(e[o],o,n),null!=r&&s.push(r);else for(o in e)r=t(e[o],o,n),null!=r&&s.push(r);return te.apply([],s)},guid:1,proxy:function(e,t){var n,i,r;return"string"==typeof t&&(n=e[t],t=e,e=n),ue.isFunction(e)?(i=ee.call(arguments,2),r=function(){return e.apply(t||this,i.concat(ee.call(arguments)))},r.guid=e.guid=e.guid||ue.guid++,r):void 0},now:Date.now,support:se}),"function"==typeof Symbol&&(ue.fn[Symbol.iterator]=Z[Symbol.iterator]),ue.each("Boolean Number String Function Array Date RegExp Object Error Symbol".split(" "),function(e,t){re["[object "+t+"]"]=t.toLowerCase()});var fe=/*!
	 * Sizzle CSS Selector Engine v2.2.1
	 * http://sizzlejs.com/
	 *
	 * Copyright jQuery Foundation and other contributors
	 * Released under the MIT license
	 * http://jquery.org/license
	 *
	 * Date: 2015-10-17
	 */
function(e){function t(e,t,n,i){var r,o,a,s,l,u,d,h,f=t&&t.ownerDocument,g=t?t.nodeType:9;if(n=n||[],"string"!=typeof e||!e||1!==g&&9!==g&&11!==g)return n;if(!i&&((t?t.ownerDocument||t:R)!==I&&O(t),t=t||I,F)){if(11!==g&&(u=me.exec(e)))if(r=u[1]){if(9===g){if(!(a=t.getElementById(r)))return n;if(a.id===r)return n.push(a),n}else if(f&&(a=f.getElementById(r))&&q(t,a)&&a.id===r)return n.push(a),n}else{if(u[2])return Z.apply(n,t.getElementsByTagName(e)),n;if((r=u[3])&&x.getElementsByClassName&&t.getElementsByClassName)return Z.apply(n,t.getElementsByClassName(r)),n}if(x.qsa&&!B[e+" "]&&(!P||!P.test(e))){if(1!==g)f=t,h=e;else if("object"!==t.nodeName.toLowerCase()){for((s=t.getAttribute("id"))?s=s.replace(be,"\\$&"):t.setAttribute("id",s=j),d=T(e),o=d.length,l=pe.test(s)?"#"+s:"[id='"+s+"']";o--;)d[o]=l+" "+p(d[o]);h=d.join(","),f=ye.test(e)&&c(t.parentNode)||t}if(h)try{return Z.apply(n,f.querySelectorAll(h)),n}catch(v){}finally{s===j&&t.removeAttribute("id")}}}return S(e.replace(se,"$1"),t,n,i)}function n(){function e(n,i){return t.push(n+" ")>_.cacheLength&&delete e[t.shift()],e[n+" "]=i}var t=[];return e}function i(e){return e[j]=!0,e}function r(e){var t=I.createElement("div");try{return!!e(t)}catch(n){return!1}finally{t.parentNode&&t.parentNode.removeChild(t),t=null}}function o(e,t){for(var n=e.split("|"),i=n.length;i--;)_.attrHandle[n[i]]=t}function a(e,t){var n=t&&e,i=n&&1===e.nodeType&&1===t.nodeType&&(~t.sourceIndex||V)-(~e.sourceIndex||V);if(i)return i;if(n)for(;n=n.nextSibling;)if(n===t)return-1;return e?1:-1}function s(e){return function(t){var n=t.nodeName.toLowerCase();return"input"===n&&t.type===e}}function l(e){return function(t){var n=t.nodeName.toLowerCase();return("input"===n||"button"===n)&&t.type===e}}function u(e){return i(function(t){return t=+t,i(function(n,i){for(var r,o=e([],n.length,t),a=o.length;a--;)n[r=o[a]]&&(n[r]=!(i[r]=n[r]))})})}function c(e){return e&&"undefined"!=typeof e.getElementsByTagName&&e}function d(){}function p(e){for(var t=0,n=e.length,i="";n>t;t++)i+=e[t].value;return i}function h(e,t,n){var i=t.dir,r=n&&"parentNode"===i,o=H++;return t.first?function(t,n,o){for(;t=t[i];)if(1===t.nodeType||r)return e(t,n,o)}:function(t,n,a){var s,l,u,c=[z,o];if(a){for(;t=t[i];)if((1===t.nodeType||r)&&e(t,n,a))return!0}else for(;t=t[i];)if(1===t.nodeType||r){if(u=t[j]||(t[j]={}),l=u[t.uniqueID]||(u[t.uniqueID]={}),(s=l[i])&&s[0]===z&&s[1]===o)return c[2]=s[2];if(l[i]=c,c[2]=e(t,n,a))return!0}}}function f(e){return e.length>1?function(t,n,i){for(var r=e.length;r--;)if(!e[r](t,n,i))return!1;return!0}:e[0]}function g(e,n,i){for(var r=0,o=n.length;o>r;r++)t(e,n[r],i);return i}function v(e,t,n,i,r){for(var o,a=[],s=0,l=e.length,u=null!=t;l>s;s++)(o=e[s])&&(n&&!n(o,i,r)||(a.push(o),u&&t.push(s)));return a}function m(e,t,n,r,o,a){return r&&!r[j]&&(r=m(r)),o&&!o[j]&&(o=m(o,a)),i(function(i,a,s,l){var u,c,d,p=[],h=[],f=a.length,m=i||g(t||"*",s.nodeType?[s]:s,[]),y=!e||!i&&t?m:v(m,p,e,s,l),b=n?o||(i?e:f||r)?[]:a:y;if(n&&n(y,b,s,l),r)for(u=v(b,h),r(u,[],s,l),c=u.length;c--;)(d=u[c])&&(b[h[c]]=!(y[h[c]]=d));if(i){if(o||e){if(o){for(u=[],c=b.length;c--;)(d=b[c])&&u.push(y[c]=d);o(null,b=[],u,l)}for(c=b.length;c--;)(d=b[c])&&(u=o?ee(i,d):p[c])>-1&&(i[u]=!(a[u]=d))}}else b=v(b===a?b.splice(f,b.length):b),o?o(null,a,b,l):Z.apply(a,b)})}function y(e){for(var t,n,i,r=e.length,o=_.relative[e[0].type],a=o||_.relative[" "],s=o?1:0,l=h(function(e){return e===t},a,!0),u=h(function(e){return ee(t,e)>-1},a,!0),c=[function(e,n,i){var r=!o&&(i||n!==E)||((t=n).nodeType?l(e,n,i):u(e,n,i));return t=null,r}];r>s;s++)if(n=_.relative[e[s].type])c=[h(f(c),n)];else{if(n=_.filter[e[s].type].apply(null,e[s].matches),n[j]){for(i=++s;r>i&&!_.relative[e[i].type];i++);return m(s>1&&f(c),s>1&&p(e.slice(0,s-1).concat({value:" "===e[s-2].type?"*":""})).replace(se,"$1"),n,i>s&&y(e.slice(s,i)),r>i&&y(e=e.slice(i)),r>i&&p(e))}c.push(n)}return f(c)}function b(e,n){var r=n.length>0,o=e.length>0,a=function(i,a,s,l,u){var c,d,p,h=0,f="0",g=i&&[],m=[],y=E,b=i||o&&_.find.TAG("*",u),w=z+=null==y?1:Math.random()||.1,x=b.length;for(u&&(E=a===I||a||u);f!==x&&null!=(c=b[f]);f++){if(o&&c){for(d=0,a||c.ownerDocument===I||(O(c),s=!F);p=e[d++];)if(p(c,a||I,s)){l.push(c);break}u&&(z=w)}r&&((c=!p&&c)&&h--,i&&g.push(c))}if(h+=f,r&&f!==h){for(d=0;p=n[d++];)p(g,m,a,s);if(i){if(h>0)for(;f--;)g[f]||m[f]||(m[f]=G.call(l));m=v(m)}Z.apply(l,m),u&&!i&&m.length>0&&h+n.length>1&&t.uniqueSort(l)}return u&&(z=w,E=y),g};return r?i(a):a}var w,x,_,k,C,T,D,S,E,A,M,O,I,N,F,P,$,L,q,j="sizzle"+1*new Date,R=e.document,z=0,H=0,W=n(),Y=n(),B=n(),U=function(e,t){return e===t&&(M=!0),0},V=1<<31,X={}.hasOwnProperty,Q=[],G=Q.pop,K=Q.push,Z=Q.push,J=Q.slice,ee=function(e,t){for(var n=0,i=e.length;i>n;n++)if(e[n]===t)return n;return-1},te="checked|selected|async|autofocus|autoplay|controls|defer|disabled|hidden|ismap|loop|multiple|open|readonly|required|scoped",ne="[\\x20\\t\\r\\n\\f]",ie="(?:\\\\.|[\\w-]|[^\\x00-\\xa0])+",re="\\["+ne+"*("+ie+")(?:"+ne+"*([*^$|!~]?=)"+ne+"*(?:'((?:\\\\.|[^\\\\'])*)'|\"((?:\\\\.|[^\\\\\"])*)\"|("+ie+"))|)"+ne+"*\\]",oe=":("+ie+")(?:\\((('((?:\\\\.|[^\\\\'])*)'|\"((?:\\\\.|[^\\\\\"])*)\")|((?:\\\\.|[^\\\\()[\\]]|"+re+")*)|.*)\\)|)",ae=new RegExp(ne+"+","g"),se=new RegExp("^"+ne+"+|((?:^|[^\\\\])(?:\\\\.)*)"+ne+"+$","g"),le=new RegExp("^"+ne+"*,"+ne+"*"),ue=new RegExp("^"+ne+"*([>+~]|"+ne+")"+ne+"*"),ce=new RegExp("="+ne+"*([^\\]'\"]*?)"+ne+"*\\]","g"),de=new RegExp(oe),pe=new RegExp("^"+ie+"$"),he={ID:new RegExp("^#("+ie+")"),CLASS:new RegExp("^\\.("+ie+")"),TAG:new RegExp("^("+ie+"|[*])"),ATTR:new RegExp("^"+re),PSEUDO:new RegExp("^"+oe),CHILD:new RegExp("^:(only|first|last|nth|nth-last)-(child|of-type)(?:\\("+ne+"*(even|odd|(([+-]|)(\\d*)n|)"+ne+"*(?:([+-]|)"+ne+"*(\\d+)|))"+ne+"*\\)|)","i"),bool:new RegExp("^(?:"+te+")$","i"),needsContext:new RegExp("^"+ne+"*[>+~]|:(even|odd|eq|gt|lt|nth|first|last)(?:\\("+ne+"*((?:-\\d)?\\d*)"+ne+"*\\)|)(?=[^-]|$)","i")},fe=/^(?:input|select|textarea|button)$/i,ge=/^h\d$/i,ve=/^[^{]+\{\s*\[native \w/,me=/^(?:#([\w-]+)|(\w+)|\.([\w-]+))$/,ye=/[+~]/,be=/'|\\/g,we=new RegExp("\\\\([\\da-f]{1,6}"+ne+"?|("+ne+")|.)","ig"),xe=function(e,t,n){var i="0x"+t-65536;return i!==i||n?t:0>i?String.fromCharCode(i+65536):String.fromCharCode(i>>10|55296,1023&i|56320)},_e=function(){O()};try{Z.apply(Q=J.call(R.childNodes),R.childNodes),Q[R.childNodes.length].nodeType}catch(ke){Z={apply:Q.length?function(e,t){K.apply(e,J.call(t))}:function(e,t){for(var n=e.length,i=0;e[n++]=t[i++];);e.length=n-1}}}x=t.support={},C=t.isXML=function(e){var t=e&&(e.ownerDocument||e).documentElement;return t?"HTML"!==t.nodeName:!1},O=t.setDocument=function(e){var t,n,i=e?e.ownerDocument||e:R;return i!==I&&9===i.nodeType&&i.documentElement?(I=i,N=I.documentElement,F=!C(I),(n=I.defaultView)&&n.top!==n&&(n.addEventListener?n.addEventListener("unload",_e,!1):n.attachEvent&&n.attachEvent("onunload",_e)),x.attributes=r(function(e){return e.className="i",!e.getAttribute("className")}),x.getElementsByTagName=r(function(e){return e.appendChild(I.createComment("")),!e.getElementsByTagName("*").length}),x.getElementsByClassName=ve.test(I.getElementsByClassName),x.getById=r(function(e){return N.appendChild(e).id=j,!I.getElementsByName||!I.getElementsByName(j).length}),x.getById?(_.find.ID=function(e,t){if("undefined"!=typeof t.getElementById&&F){var n=t.getElementById(e);return n?[n]:[]}},_.filter.ID=function(e){var t=e.replace(we,xe);return function(e){return e.getAttribute("id")===t}}):(delete _.find.ID,_.filter.ID=function(e){var t=e.replace(we,xe);return function(e){var n="undefined"!=typeof e.getAttributeNode&&e.getAttributeNode("id");return n&&n.value===t}}),_.find.TAG=x.getElementsByTagName?function(e,t){return"undefined"!=typeof t.getElementsByTagName?t.getElementsByTagName(e):x.qsa?t.querySelectorAll(e):void 0}:function(e,t){var n,i=[],r=0,o=t.getElementsByTagName(e);if("*"===e){for(;n=o[r++];)1===n.nodeType&&i.push(n);return i}return o},_.find.CLASS=x.getElementsByClassName&&function(e,t){return"undefined"!=typeof t.getElementsByClassName&&F?t.getElementsByClassName(e):void 0},$=[],P=[],(x.qsa=ve.test(I.querySelectorAll))&&(r(function(e){N.appendChild(e).innerHTML="<a id='"+j+"'></a><select id='"+j+"-\r\\' msallowcapture=''><option selected=''></option></select>",e.querySelectorAll("[msallowcapture^='']").length&&P.push("[*^$]="+ne+"*(?:''|\"\")"),e.querySelectorAll("[selected]").length||P.push("\\["+ne+"*(?:value|"+te+")"),e.querySelectorAll("[id~="+j+"-]").length||P.push("~="),e.querySelectorAll(":checked").length||P.push(":checked"),e.querySelectorAll("a#"+j+"+*").length||P.push(".#.+[+~]")}),r(function(e){var t=I.createElement("input");t.setAttribute("type","hidden"),e.appendChild(t).setAttribute("name","D"),e.querySelectorAll("[name=d]").length&&P.push("name"+ne+"*[*^$|!~]?="),e.querySelectorAll(":enabled").length||P.push(":enabled",":disabled"),e.querySelectorAll("*,:x"),P.push(",.*:")})),(x.matchesSelector=ve.test(L=N.matches||N.webkitMatchesSelector||N.mozMatchesSelector||N.oMatchesSelector||N.msMatchesSelector))&&r(function(e){x.disconnectedMatch=L.call(e,"div"),L.call(e,"[s!='']:x"),$.push("!=",oe)}),P=P.length&&new RegExp(P.join("|")),$=$.length&&new RegExp($.join("|")),t=ve.test(N.compareDocumentPosition),q=t||ve.test(N.contains)?function(e,t){var n=9===e.nodeType?e.documentElement:e,i=t&&t.parentNode;return e===i||!(!i||1!==i.nodeType||!(n.contains?n.contains(i):e.compareDocumentPosition&&16&e.compareDocumentPosition(i)))}:function(e,t){if(t)for(;t=t.parentNode;)if(t===e)return!0;return!1},U=t?function(e,t){if(e===t)return M=!0,0;var n=!e.compareDocumentPosition-!t.compareDocumentPosition;return n?n:(n=(e.ownerDocument||e)===(t.ownerDocument||t)?e.compareDocumentPosition(t):1,1&n||!x.sortDetached&&t.compareDocumentPosition(e)===n?e===I||e.ownerDocument===R&&q(R,e)?-1:t===I||t.ownerDocument===R&&q(R,t)?1:A?ee(A,e)-ee(A,t):0:4&n?-1:1)}:function(e,t){if(e===t)return M=!0,0;var n,i=0,r=e.parentNode,o=t.parentNode,s=[e],l=[t];if(!r||!o)return e===I?-1:t===I?1:r?-1:o?1:A?ee(A,e)-ee(A,t):0;if(r===o)return a(e,t);for(n=e;n=n.parentNode;)s.unshift(n);for(n=t;n=n.parentNode;)l.unshift(n);for(;s[i]===l[i];)i++;return i?a(s[i],l[i]):s[i]===R?-1:l[i]===R?1:0},I):I},t.matches=function(e,n){return t(e,null,null,n)},t.matchesSelector=function(e,n){if((e.ownerDocument||e)!==I&&O(e),n=n.replace(ce,"='$1']"),x.matchesSelector&&F&&!B[n+" "]&&(!$||!$.test(n))&&(!P||!P.test(n)))try{var i=L.call(e,n);if(i||x.disconnectedMatch||e.document&&11!==e.document.nodeType)return i}catch(r){}return t(n,I,null,[e]).length>0},t.contains=function(e,t){return(e.ownerDocument||e)!==I&&O(e),q(e,t)},t.attr=function(e,t){(e.ownerDocument||e)!==I&&O(e);var n=_.attrHandle[t.toLowerCase()],i=n&&X.call(_.attrHandle,t.toLowerCase())?n(e,t,!F):void 0;return void 0!==i?i:x.attributes||!F?e.getAttribute(t):(i=e.getAttributeNode(t))&&i.specified?i.value:null},t.error=function(e){throw new Error("Syntax error, unrecognized expression: "+e)},t.uniqueSort=function(e){var t,n=[],i=0,r=0;if(M=!x.detectDuplicates,A=!x.sortStable&&e.slice(0),e.sort(U),M){for(;t=e[r++];)t===e[r]&&(i=n.push(r));for(;i--;)e.splice(n[i],1)}return A=null,e},k=t.getText=function(e){var t,n="",i=0,r=e.nodeType;if(r){if(1===r||9===r||11===r){if("string"==typeof e.textContent)return e.textContent;for(e=e.firstChild;e;e=e.nextSibling)n+=k(e)}else if(3===r||4===r)return e.nodeValue}else for(;t=e[i++];)n+=k(t);return n},_=t.selectors={cacheLength:50,createPseudo:i,match:he,attrHandle:{},find:{},relative:{">":{dir:"parentNode",first:!0}," ":{dir:"parentNode"},"+":{dir:"previousSibling",first:!0},"~":{dir:"previousSibling"}},preFilter:{ATTR:function(e){return e[1]=e[1].replace(we,xe),e[3]=(e[3]||e[4]||e[5]||"").replace(we,xe),"~="===e[2]&&(e[3]=" "+e[3]+" "),e.slice(0,4)},CHILD:function(e){return e[1]=e[1].toLowerCase(),"nth"===e[1].slice(0,3)?(e[3]||t.error(e[0]),e[4]=+(e[4]?e[5]+(e[6]||1):2*("even"===e[3]||"odd"===e[3])),e[5]=+(e[7]+e[8]||"odd"===e[3])):e[3]&&t.error(e[0]),e},PSEUDO:function(e){var t,n=!e[6]&&e[2];return he.CHILD.test(e[0])?null:(e[3]?e[2]=e[4]||e[5]||"":n&&de.test(n)&&(t=T(n,!0))&&(t=n.indexOf(")",n.length-t)-n.length)&&(e[0]=e[0].slice(0,t),e[2]=n.slice(0,t)),e.slice(0,3))}},filter:{TAG:function(e){var t=e.replace(we,xe).toLowerCase();return"*"===e?function(){return!0}:function(e){return e.nodeName&&e.nodeName.toLowerCase()===t}},CLASS:function(e){var t=W[e+" "];return t||(t=new RegExp("(^|"+ne+")"+e+"("+ne+"|$)"))&&W(e,function(e){return t.test("string"==typeof e.className&&e.className||"undefined"!=typeof e.getAttribute&&e.getAttribute("class")||"")})},ATTR:function(e,n,i){return function(r){var o=t.attr(r,e);return null==o?"!="===n:n?(o+="","="===n?o===i:"!="===n?o!==i:"^="===n?i&&0===o.indexOf(i):"*="===n?i&&o.indexOf(i)>-1:"$="===n?i&&o.slice(-i.length)===i:"~="===n?(" "+o.replace(ae," ")+" ").indexOf(i)>-1:"|="===n?o===i||o.slice(0,i.length+1)===i+"-":!1):!0}},CHILD:function(e,t,n,i,r){var o="nth"!==e.slice(0,3),a="last"!==e.slice(-4),s="of-type"===t;return 1===i&&0===r?function(e){return!!e.parentNode}:function(t,n,l){var u,c,d,p,h,f,g=o!==a?"nextSibling":"previousSibling",v=t.parentNode,m=s&&t.nodeName.toLowerCase(),y=!l&&!s,b=!1;if(v){if(o){for(;g;){for(p=t;p=p[g];)if(s?p.nodeName.toLowerCase()===m:1===p.nodeType)return!1;f=g="only"===e&&!f&&"nextSibling"}return!0}if(f=[a?v.firstChild:v.lastChild],a&&y){for(p=v,d=p[j]||(p[j]={}),c=d[p.uniqueID]||(d[p.uniqueID]={}),u=c[e]||[],h=u[0]===z&&u[1],b=h&&u[2],p=h&&v.childNodes[h];p=++h&&p&&p[g]||(b=h=0)||f.pop();)if(1===p.nodeType&&++b&&p===t){c[e]=[z,h,b];break}}else if(y&&(p=t,d=p[j]||(p[j]={}),c=d[p.uniqueID]||(d[p.uniqueID]={}),u=c[e]||[],h=u[0]===z&&u[1],b=h),b===!1)for(;(p=++h&&p&&p[g]||(b=h=0)||f.pop())&&((s?p.nodeName.toLowerCase()!==m:1!==p.nodeType)||!++b||(y&&(d=p[j]||(p[j]={}),c=d[p.uniqueID]||(d[p.uniqueID]={}),c[e]=[z,b]),p!==t)););return b-=r,b===i||b%i===0&&b/i>=0}}},PSEUDO:function(e,n){var r,o=_.pseudos[e]||_.setFilters[e.toLowerCase()]||t.error("unsupported pseudo: "+e);return o[j]?o(n):o.length>1?(r=[e,e,"",n],_.setFilters.hasOwnProperty(e.toLowerCase())?i(function(e,t){for(var i,r=o(e,n),a=r.length;a--;)i=ee(e,r[a]),e[i]=!(t[i]=r[a])}):function(e){return o(e,0,r)}):o}},pseudos:{not:i(function(e){var t=[],n=[],r=D(e.replace(se,"$1"));return r[j]?i(function(e,t,n,i){for(var o,a=r(e,null,i,[]),s=e.length;s--;)(o=a[s])&&(e[s]=!(t[s]=o))}):function(e,i,o){return t[0]=e,r(t,null,o,n),t[0]=null,!n.pop()}}),has:i(function(e){return function(n){return t(e,n).length>0}}),contains:i(function(e){return e=e.replace(we,xe),function(t){return(t.textContent||t.innerText||k(t)).indexOf(e)>-1}}),lang:i(function(e){return pe.test(e||"")||t.error("unsupported lang: "+e),e=e.replace(we,xe).toLowerCase(),function(t){var n;do if(n=F?t.lang:t.getAttribute("xml:lang")||t.getAttribute("lang"))return n=n.toLowerCase(),n===e||0===n.indexOf(e+"-");while((t=t.parentNode)&&1===t.nodeType);return!1}}),target:function(t){var n=e.location&&e.location.hash;return n&&n.slice(1)===t.id},root:function(e){return e===N},focus:function(e){return e===I.activeElement&&(!I.hasFocus||I.hasFocus())&&!!(e.type||e.href||~e.tabIndex)},enabled:function(e){return e.disabled===!1},disabled:function(e){return e.disabled===!0},checked:function(e){var t=e.nodeName.toLowerCase();return"input"===t&&!!e.checked||"option"===t&&!!e.selected},selected:function(e){return e.parentNode&&e.parentNode.selectedIndex,e.selected===!0},empty:function(e){for(e=e.firstChild;e;e=e.nextSibling)if(e.nodeType<6)return!1;return!0},parent:function(e){return!_.pseudos.empty(e)},header:function(e){return ge.test(e.nodeName)},input:function(e){return fe.test(e.nodeName)},button:function(e){var t=e.nodeName.toLowerCase();return"input"===t&&"button"===e.type||"button"===t},text:function(e){var t;return"input"===e.nodeName.toLowerCase()&&"text"===e.type&&(null==(t=e.getAttribute("type"))||"text"===t.toLowerCase())},first:u(function(){return[0]}),last:u(function(e,t){return[t-1]}),eq:u(function(e,t,n){return[0>n?n+t:n]}),even:u(function(e,t){for(var n=0;t>n;n+=2)e.push(n);return e}),odd:u(function(e,t){for(var n=1;t>n;n+=2)e.push(n);return e}),lt:u(function(e,t,n){for(var i=0>n?n+t:n;--i>=0;)e.push(i);return e}),gt:u(function(e,t,n){for(var i=0>n?n+t:n;++i<t;)e.push(i);return e})}},_.pseudos.nth=_.pseudos.eq;for(w in{radio:!0,checkbox:!0,file:!0,password:!0,image:!0})_.pseudos[w]=s(w);for(w in{submit:!0,reset:!0})_.pseudos[w]=l(w);return d.prototype=_.filters=_.pseudos,_.setFilters=new d,T=t.tokenize=function(e,n){var i,r,o,a,s,l,u,c=Y[e+" "];if(c)return n?0:c.slice(0);for(s=e,l=[],u=_.preFilter;s;){i&&!(r=le.exec(s))||(r&&(s=s.slice(r[0].length)||s),l.push(o=[])),i=!1,(r=ue.exec(s))&&(i=r.shift(),o.push({value:i,type:r[0].replace(se," ")}),s=s.slice(i.length));for(a in _.filter)!(r=he[a].exec(s))||u[a]&&!(r=u[a](r))||(i=r.shift(),o.push({value:i,type:a,matches:r}),s=s.slice(i.length));if(!i)break}return n?s.length:s?t.error(e):Y(e,l).slice(0)},D=t.compile=function(e,t){var n,i=[],r=[],o=B[e+" "];if(!o){for(t||(t=T(e)),n=t.length;n--;)o=y(t[n]),o[j]?i.push(o):r.push(o);o=B(e,b(r,i)),o.selector=e}return o},S=t.select=function(e,t,n,i){var r,o,a,s,l,u="function"==typeof e&&e,d=!i&&T(e=u.selector||e);if(n=n||[],1===d.length){if(o=d[0]=d[0].slice(0),o.length>2&&"ID"===(a=o[0]).type&&x.getById&&9===t.nodeType&&F&&_.relative[o[1].type]){if(t=(_.find.ID(a.matches[0].replace(we,xe),t)||[])[0],!t)return n;u&&(t=t.parentNode),e=e.slice(o.shift().value.length)}for(r=he.needsContext.test(e)?0:o.length;r--&&(a=o[r],!_.relative[s=a.type]);)if((l=_.find[s])&&(i=l(a.matches[0].replace(we,xe),ye.test(o[0].type)&&c(t.parentNode)||t))){if(o.splice(r,1),e=i.length&&p(o),!e)return Z.apply(n,i),n;break}}return(u||D(e,d))(i,t,!F,n,!t||ye.test(e)&&c(t.parentNode)||t),n},x.sortStable=j.split("").sort(U).join("")===j,x.detectDuplicates=!!M,O(),x.sortDetached=r(function(e){return 1&e.compareDocumentPosition(I.createElement("div"))}),r(function(e){return e.innerHTML="<a href='#'></a>","#"===e.firstChild.getAttribute("href")})||o("type|href|height|width",function(e,t,n){return n?void 0:e.getAttribute(t,"type"===t.toLowerCase()?1:2)}),x.attributes&&r(function(e){return e.innerHTML="<input/>",e.firstChild.setAttribute("value",""),""===e.firstChild.getAttribute("value")})||o("value",function(e,t,n){return n||"input"!==e.nodeName.toLowerCase()?void 0:e.defaultValue}),r(function(e){return null==e.getAttribute("disabled")})||o(te,function(e,t,n){var i;return n?void 0:e[t]===!0?t.toLowerCase():(i=e.getAttributeNode(t))&&i.specified?i.value:null}),t}(n);ue.find=fe,ue.expr=fe.selectors,ue.expr[":"]=ue.expr.pseudos,ue.uniqueSort=ue.unique=fe.uniqueSort,ue.text=fe.getText,ue.isXMLDoc=fe.isXML,ue.contains=fe.contains;var ge=function(e,t,n){for(var i=[],r=void 0!==n;(e=e[t])&&9!==e.nodeType;)if(1===e.nodeType){if(r&&ue(e).is(n))break;i.push(e)}return i},ve=function(e,t){for(var n=[];e;e=e.nextSibling)1===e.nodeType&&e!==t&&n.push(e);return n},me=ue.expr.match.needsContext,ye=/^<([\w-]+)\s*\/?>(?:<\/\1>|)$/,be=/^.[^:#\[\.,]*$/;ue.filter=function(e,t,n){var i=t[0];return n&&(e=":not("+e+")"),1===t.length&&1===i.nodeType?ue.find.matchesSelector(i,e)?[i]:[]:ue.find.matches(e,ue.grep(t,function(e){return 1===e.nodeType}))},ue.fn.extend({find:function(e){var t,n=this.length,i=[],r=this;if("string"!=typeof e)return this.pushStack(ue(e).filter(function(){for(t=0;n>t;t++)if(ue.contains(r[t],this))return!0}));for(t=0;n>t;t++)ue.find(e,r[t],i);return i=this.pushStack(n>1?ue.unique(i):i),i.selector=this.selector?this.selector+" "+e:e,i},filter:function(e){return this.pushStack(s(this,e||[],!1))},not:function(e){return this.pushStack(s(this,e||[],!0))},is:function(e){return!!s(this,"string"==typeof e&&me.test(e)?ue(e):e||[],!1).length}});var we,xe=/^(?:\s*(<[\w\W]+>)[^>]*|#([\w-]*))$/,_e=ue.fn.init=function(e,t,n){var i,r;if(!e)return this;if(n=n||we,"string"==typeof e){if(i="<"===e[0]&&">"===e[e.length-1]&&e.length>=3?[null,e,null]:xe.exec(e),!i||!i[1]&&t)return!t||t.jquery?(t||n).find(e):this.constructor(t).find(e);if(i[1]){if(t=t instanceof ue?t[0]:t,ue.merge(this,ue.parseHTML(i[1],t&&t.nodeType?t.ownerDocument||t:J,!0)),ye.test(i[1])&&ue.isPlainObject(t))for(i in t)ue.isFunction(this[i])?this[i](t[i]):this.attr(i,t[i]);return this}return r=J.getElementById(i[2]),r&&r.parentNode&&(this.length=1,this[0]=r),this.context=J,this.selector=e,this}return e.nodeType?(this.context=this[0]=e,this.length=1,this):ue.isFunction(e)?void 0!==n.ready?n.ready(e):e(ue):(void 0!==e.selector&&(this.selector=e.selector,this.context=e.context),ue.makeArray(e,this))};_e.prototype=ue.fn,we=ue(J);var ke=/^(?:parents|prev(?:Until|All))/,Ce={children:!0,contents:!0,next:!0,prev:!0};ue.fn.extend({has:function(e){var t=ue(e,this),n=t.length;return this.filter(function(){for(var e=0;n>e;e++)if(ue.contains(this,t[e]))return!0})},closest:function(e,t){for(var n,i=0,r=this.length,o=[],a=me.test(e)||"string"!=typeof e?ue(e,t||this.context):0;r>i;i++)for(n=this[i];n&&n!==t;n=n.parentNode)if(n.nodeType<11&&(a?a.index(n)>-1:1===n.nodeType&&ue.find.matchesSelector(n,e))){o.push(n);break}return this.pushStack(o.length>1?ue.uniqueSort(o):o)},index:function(e){return e?"string"==typeof e?ie.call(ue(e),this[0]):ie.call(this,e.jquery?e[0]:e):this[0]&&this[0].parentNode?this.first().prevAll().length:-1},add:function(e,t){return this.pushStack(ue.uniqueSort(ue.merge(this.get(),ue(e,t))))},addBack:function(e){return this.add(null==e?this.prevObject:this.prevObject.filter(e))}}),ue.each({parent:function(e){var t=e.parentNode;return t&&11!==t.nodeType?t:null},parents:function(e){return ge(e,"parentNode")},parentsUntil:function(e,t,n){return ge(e,"parentNode",n)},next:function(e){return l(e,"nextSibling")},prev:function(e){return l(e,"previousSibling")},nextAll:function(e){return ge(e,"nextSibling")},prevAll:function(e){return ge(e,"previousSibling")},nextUntil:function(e,t,n){return ge(e,"nextSibling",n)},prevUntil:function(e,t,n){return ge(e,"previousSibling",n)},siblings:function(e){return ve((e.parentNode||{}).firstChild,e)},children:function(e){return ve(e.firstChild)},contents:function(e){return e.contentDocument||ue.merge([],e.childNodes)}},function(e,t){ue.fn[e]=function(n,i){var r=ue.map(this,t,n);return"Until"!==e.slice(-5)&&(i=n),i&&"string"==typeof i&&(r=ue.filter(i,r)),this.length>1&&(Ce[e]||ue.uniqueSort(r),ke.test(e)&&r.reverse()),this.pushStack(r)}});var Te=/\S+/g;ue.Callbacks=function(e){e="string"==typeof e?u(e):ue.extend({},e);var t,n,i,r,o=[],a=[],s=-1,l=function(){for(r=e.once,i=t=!0;a.length;s=-1)for(n=a.shift();++s<o.length;)o[s].apply(n[0],n[1])===!1&&e.stopOnFalse&&(s=o.length,n=!1);e.memory||(n=!1),t=!1,r&&(o=n?[]:"")},c={add:function(){return o&&(n&&!t&&(s=o.length-1,a.push(n)),function i(t){ue.each(t,function(t,n){ue.isFunction(n)?e.unique&&c.has(n)||o.push(n):n&&n.length&&"string"!==ue.type(n)&&i(n)})}(arguments),n&&!t&&l()),this},remove:function(){return ue.each(arguments,function(e,t){for(var n;(n=ue.inArray(t,o,n))>-1;)o.splice(n,1),s>=n&&s--}),this},has:function(e){return e?ue.inArray(e,o)>-1:o.length>0},empty:function(){return o&&(o=[]),this},disable:function(){return r=a=[],o=n="",this},disabled:function(){return!o},lock:function(){return r=a=[],n||(o=n=""),this},locked:function(){return!!r},fireWith:function(e,n){return r||(n=n||[],n=[e,n.slice?n.slice():n],a.push(n),t||l()),this},fire:function(){return c.fireWith(this,arguments),this},fired:function(){return!!i}};return c},ue.extend({Deferred:function(e){var t=[["resolve","done",ue.Callbacks("once memory"),"resolved"],["reject","fail",ue.Callbacks("once memory"),"rejected"],["notify","progress",ue.Callbacks("memory")]],n="pending",i={state:function(){return n},always:function(){return r.done(arguments).fail(arguments),this},then:function(){var e=arguments;return ue.Deferred(function(n){ue.each(t,function(t,o){var a=ue.isFunction(e[t])&&e[t];r[o[1]](function(){var e=a&&a.apply(this,arguments);e&&ue.isFunction(e.promise)?e.promise().progress(n.notify).done(n.resolve).fail(n.reject):n[o[0]+"With"](this===i?n.promise():this,a?[e]:arguments)})}),e=null}).promise()},promise:function(e){return null!=e?ue.extend(e,i):i}},r={};return i.pipe=i.then,ue.each(t,function(e,o){var a=o[2],s=o[3];i[o[1]]=a.add,s&&a.add(function(){n=s},t[1^e][2].disable,t[2][2].lock),r[o[0]]=function(){return r[o[0]+"With"](this===r?i:this,arguments),this},r[o[0]+"With"]=a.fireWith}),i.promise(r),e&&e.call(r,r),r},when:function(e){var t,n,i,r=0,o=ee.call(arguments),a=o.length,s=1!==a||e&&ue.isFunction(e.promise)?a:0,l=1===s?e:ue.Deferred(),u=function(e,n,i){return function(r){n[e]=this,i[e]=arguments.length>1?ee.call(arguments):r,i===t?l.notifyWith(n,i):--s||l.resolveWith(n,i)}};if(a>1)for(t=new Array(a),n=new Array(a),i=new Array(a);a>r;r++)o[r]&&ue.isFunction(o[r].promise)?o[r].promise().progress(u(r,n,t)).done(u(r,i,o)).fail(l.reject):--s;return s||l.resolveWith(i,o),l.promise()}});var De;ue.fn.ready=function(e){return ue.ready.promise().done(e),this},ue.extend({isReady:!1,readyWait:1,holdReady:function(e){e?ue.readyWait++:ue.ready(!0)},ready:function(e){(e===!0?--ue.readyWait:ue.isReady)||(ue.isReady=!0,e!==!0&&--ue.readyWait>0||(De.resolveWith(J,[ue]),ue.fn.triggerHandler&&(ue(J).triggerHandler("ready"),ue(J).off("ready"))))}}),ue.ready.promise=function(e){return De||(De=ue.Deferred(),"complete"===J.readyState||"loading"!==J.readyState&&!J.documentElement.doScroll?n.setTimeout(ue.ready):(J.addEventListener("DOMContentLoaded",c),n.addEventListener("load",c))),De.promise(e)},ue.ready.promise();var Se=function(e,t,n,i,r,o,a){var s=0,l=e.length,u=null==n;if("object"===ue.type(n)){r=!0;for(s in n)Se(e,t,s,n[s],!0,o,a)}else if(void 0!==i&&(r=!0,ue.isFunction(i)||(a=!0),u&&(a?(t.call(e,i),t=null):(u=t,t=function(e,t,n){return u.call(ue(e),n)})),t))for(;l>s;s++)t(e[s],n,a?i:i.call(e[s],s,t(e[s],n)));return r?e:u?t.call(e):l?t(e[0],n):o},Ee=function(e){return 1===e.nodeType||9===e.nodeType||!+e.nodeType};d.uid=1,d.prototype={register:function(e,t){var n=t||{};return e.nodeType?e[this.expando]=n:Object.defineProperty(e,this.expando,{value:n,writable:!0,configurable:!0}),e[this.expando]},cache:function(e){if(!Ee(e))return{};var t=e[this.expando];return t||(t={},Ee(e)&&(e.nodeType?e[this.expando]=t:Object.defineProperty(e,this.expando,{value:t,configurable:!0}))),t},set:function(e,t,n){var i,r=this.cache(e);if("string"==typeof t)r[t]=n;else for(i in t)r[i]=t[i];return r},get:function(e,t){return void 0===t?this.cache(e):e[this.expando]&&e[this.expando][t]},access:function(e,t,n){var i;return void 0===t||t&&"string"==typeof t&&void 0===n?(i=this.get(e,t),void 0!==i?i:this.get(e,ue.camelCase(t))):(this.set(e,t,n),void 0!==n?n:t)},remove:function(e,t){var n,i,r,o=e[this.expando];if(void 0!==o){if(void 0===t)this.register(e);else{ue.isArray(t)?i=t.concat(t.map(ue.camelCase)):(r=ue.camelCase(t),t in o?i=[t,r]:(i=r,i=i in o?[i]:i.match(Te)||[])),n=i.length;for(;n--;)delete o[i[n]]}(void 0===t||ue.isEmptyObject(o))&&(e.nodeType?e[this.expando]=void 0:delete e[this.expando])}},hasData:function(e){var t=e[this.expando];return void 0!==t&&!ue.isEmptyObject(t)}};var Ae=new d,Me=new d,Oe=/^(?:\{[\w\W]*\}|\[[\w\W]*\])$/,Ie=/[A-Z]/g;ue.extend({hasData:function(e){return Me.hasData(e)||Ae.hasData(e)},data:function(e,t,n){return Me.access(e,t,n)},removeData:function(e,t){Me.remove(e,t)},_data:function(e,t,n){return Ae.access(e,t,n)},_removeData:function(e,t){Ae.remove(e,t)}}),ue.fn.extend({data:function(e,t){var n,i,r,o=this[0],a=o&&o.attributes;if(void 0===e){if(this.length&&(r=Me.get(o),1===o.nodeType&&!Ae.get(o,"hasDataAttrs"))){for(n=a.length;n--;)a[n]&&(i=a[n].name,0===i.indexOf("data-")&&(i=ue.camelCase(i.slice(5)),p(o,i,r[i])));Ae.set(o,"hasDataAttrs",!0)}return r}return"object"==typeof e?this.each(function(){Me.set(this,e)}):Se(this,function(t){var n,i;if(o&&void 0===t){if(n=Me.get(o,e)||Me.get(o,e.replace(Ie,"-$&").toLowerCase()),void 0!==n)return n;if(i=ue.camelCase(e),n=Me.get(o,i),void 0!==n)return n;if(n=p(o,i,void 0),void 0!==n)return n}else i=ue.camelCase(e),this.each(function(){var n=Me.get(this,i);Me.set(this,i,t),e.indexOf("-")>-1&&void 0!==n&&Me.set(this,e,t)})},null,t,arguments.length>1,null,!0)},removeData:function(e){return this.each(function(){Me.remove(this,e)})}}),ue.extend({queue:function(e,t,n){var i;return e?(t=(t||"fx")+"queue",i=Ae.get(e,t),n&&(!i||ue.isArray(n)?i=Ae.access(e,t,ue.makeArray(n)):i.push(n)),i||[]):void 0},dequeue:function(e,t){t=t||"fx";var n=ue.queue(e,t),i=n.length,r=n.shift(),o=ue._queueHooks(e,t),a=function(){ue.dequeue(e,t)};"inprogress"===r&&(r=n.shift(),i--),r&&("fx"===t&&n.unshift("inprogress"),delete o.stop,r.call(e,a,o)),!i&&o&&o.empty.fire()},_queueHooks:function(e,t){var n=t+"queueHooks";return Ae.get(e,n)||Ae.access(e,n,{empty:ue.Callbacks("once memory").add(function(){Ae.remove(e,[t+"queue",n])})})}}),ue.fn.extend({queue:function(e,t){var n=2;return"string"!=typeof e&&(t=e,e="fx",n--),arguments.length<n?ue.queue(this[0],e):void 0===t?this:this.each(function(){var n=ue.queue(this,e,t);ue._queueHooks(this,e),"fx"===e&&"inprogress"!==n[0]&&ue.dequeue(this,e)})},dequeue:function(e){return this.each(function(){ue.dequeue(this,e)})},clearQueue:function(e){return this.queue(e||"fx",[])},promise:function(e,t){var n,i=1,r=ue.Deferred(),o=this,a=this.length,s=function(){--i||r.resolveWith(o,[o])};for("string"!=typeof e&&(t=e,e=void 0),e=e||"fx";a--;)n=Ae.get(o[a],e+"queueHooks"),n&&n.empty&&(i++,n.empty.add(s));return s(),r.promise(t)}});var Ne=/[+-]?(?:\d*\.|)\d+(?:[eE][+-]?\d+|)/.source,Fe=new RegExp("^(?:([+-])=|)("+Ne+")([a-z%]*)$","i"),Pe=["Top","Right","Bottom","Left"],$e=function(e,t){return e=t||e,"none"===ue.css(e,"display")||!ue.contains(e.ownerDocument,e)},Le=/^(?:checkbox|radio)$/i,qe=/<([\w:-]+)/,je=/^$|\/(?:java|ecma)script/i,Re={option:[1,"<select multiple='multiple'>","</select>"],thead:[1,"<table>","</table>"],col:[2,"<table><colgroup>","</colgroup></table>"],tr:[2,"<table><tbody>","</tbody></table>"],td:[3,"<table><tbody><tr>","</tr></tbody></table>"],_default:[0,"",""]};Re.optgroup=Re.option,Re.tbody=Re.tfoot=Re.colgroup=Re.caption=Re.thead,Re.th=Re.td;var ze=/<|&#?\w+;/;!function(){var e=J.createDocumentFragment(),t=e.appendChild(J.createElement("div")),n=J.createElement("input");n.setAttribute("type","radio"),n.setAttribute("checked","checked"),n.setAttribute("name","t"),t.appendChild(n),se.checkClone=t.cloneNode(!0).cloneNode(!0).lastChild.checked,t.innerHTML="<textarea>x</textarea>",se.noCloneChecked=!!t.cloneNode(!0).lastChild.defaultValue}();var He=/^key/,We=/^(?:mouse|pointer|contextmenu|drag|drop)|click/,Ye=/^([^.]*)(?:\.(.+)|)/;ue.event={global:{},add:function(e,t,n,i,r){var o,a,s,l,u,c,d,p,h,f,g,v=Ae.get(e);if(v)for(n.handler&&(o=n,n=o.handler,r=o.selector),n.guid||(n.guid=ue.guid++),(l=v.events)||(l=v.events={}),(a=v.handle)||(a=v.handle=function(t){return"undefined"!=typeof ue&&ue.event.triggered!==t.type?ue.event.dispatch.apply(e,arguments):void 0}),t=(t||"").match(Te)||[""],u=t.length;u--;)s=Ye.exec(t[u])||[],h=g=s[1],f=(s[2]||"").split(".").sort(),h&&(d=ue.event.special[h]||{},h=(r?d.delegateType:d.bindType)||h,d=ue.event.special[h]||{},c=ue.extend({type:h,origType:g,data:i,handler:n,guid:n.guid,selector:r,needsContext:r&&ue.expr.match.needsContext.test(r),namespace:f.join(".")},o),(p=l[h])||(p=l[h]=[],p.delegateCount=0,d.setup&&d.setup.call(e,i,f,a)!==!1||e.addEventListener&&e.addEventListener(h,a)),d.add&&(d.add.call(e,c),c.handler.guid||(c.handler.guid=n.guid)),r?p.splice(p.delegateCount++,0,c):p.push(c),ue.event.global[h]=!0)},remove:function(e,t,n,i,r){var o,a,s,l,u,c,d,p,h,f,g,v=Ae.hasData(e)&&Ae.get(e);if(v&&(l=v.events)){for(t=(t||"").match(Te)||[""],u=t.length;u--;)if(s=Ye.exec(t[u])||[],h=g=s[1],f=(s[2]||"").split(".").sort(),h){for(d=ue.event.special[h]||{},h=(i?d.delegateType:d.bindType)||h,p=l[h]||[],s=s[2]&&new RegExp("(^|\\.)"+f.join("\\.(?:.*\\.|)")+"(\\.|$)"),a=o=p.length;o--;)c=p[o],!r&&g!==c.origType||n&&n.guid!==c.guid||s&&!s.test(c.namespace)||i&&i!==c.selector&&("**"!==i||!c.selector)||(p.splice(o,1),
c.selector&&p.delegateCount--,d.remove&&d.remove.call(e,c));a&&!p.length&&(d.teardown&&d.teardown.call(e,f,v.handle)!==!1||ue.removeEvent(e,h,v.handle),delete l[h])}else for(h in l)ue.event.remove(e,h+t[u],n,i,!0);ue.isEmptyObject(l)&&Ae.remove(e,"handle events")}},dispatch:function(e){e=ue.event.fix(e);var t,n,i,r,o,a=[],s=ee.call(arguments),l=(Ae.get(this,"events")||{})[e.type]||[],u=ue.event.special[e.type]||{};if(s[0]=e,e.delegateTarget=this,!u.preDispatch||u.preDispatch.call(this,e)!==!1){for(a=ue.event.handlers.call(this,e,l),t=0;(r=a[t++])&&!e.isPropagationStopped();)for(e.currentTarget=r.elem,n=0;(o=r.handlers[n++])&&!e.isImmediatePropagationStopped();)e.rnamespace&&!e.rnamespace.test(o.namespace)||(e.handleObj=o,e.data=o.data,i=((ue.event.special[o.origType]||{}).handle||o.handler).apply(r.elem,s),void 0!==i&&(e.result=i)===!1&&(e.preventDefault(),e.stopPropagation()));return u.postDispatch&&u.postDispatch.call(this,e),e.result}},handlers:function(e,t){var n,i,r,o,a=[],s=t.delegateCount,l=e.target;if(s&&l.nodeType&&("click"!==e.type||isNaN(e.button)||e.button<1))for(;l!==this;l=l.parentNode||this)if(1===l.nodeType&&(l.disabled!==!0||"click"!==e.type)){for(i=[],n=0;s>n;n++)o=t[n],r=o.selector+" ",void 0===i[r]&&(i[r]=o.needsContext?ue(r,this).index(l)>-1:ue.find(r,this,null,[l]).length),i[r]&&i.push(o);i.length&&a.push({elem:l,handlers:i})}return s<t.length&&a.push({elem:this,handlers:t.slice(s)}),a},props:"altKey bubbles cancelable ctrlKey currentTarget detail eventPhase metaKey relatedTarget shiftKey target timeStamp view which".split(" "),fixHooks:{},keyHooks:{props:"char charCode key keyCode".split(" "),filter:function(e,t){return null==e.which&&(e.which=null!=t.charCode?t.charCode:t.keyCode),e}},mouseHooks:{props:"button buttons clientX clientY offsetX offsetY pageX pageY screenX screenY toElement".split(" "),filter:function(e,t){var n,i,r,o=t.button;return null==e.pageX&&null!=t.clientX&&(n=e.target.ownerDocument||J,i=n.documentElement,r=n.body,e.pageX=t.clientX+(i&&i.scrollLeft||r&&r.scrollLeft||0)-(i&&i.clientLeft||r&&r.clientLeft||0),e.pageY=t.clientY+(i&&i.scrollTop||r&&r.scrollTop||0)-(i&&i.clientTop||r&&r.clientTop||0)),e.which||void 0===o||(e.which=1&o?1:2&o?3:4&o?2:0),e}},fix:function(e){if(e[ue.expando])return e;var t,n,i,r=e.type,o=e,a=this.fixHooks[r];for(a||(this.fixHooks[r]=a=We.test(r)?this.mouseHooks:He.test(r)?this.keyHooks:{}),i=a.props?this.props.concat(a.props):this.props,e=new ue.Event(o),t=i.length;t--;)n=i[t],e[n]=o[n];return e.target||(e.target=J),3===e.target.nodeType&&(e.target=e.target.parentNode),a.filter?a.filter(e,o):e},special:{load:{noBubble:!0},focus:{trigger:function(){return this!==b()&&this.focus?(this.focus(),!1):void 0},delegateType:"focusin"},blur:{trigger:function(){return this===b()&&this.blur?(this.blur(),!1):void 0},delegateType:"focusout"},click:{trigger:function(){return"checkbox"===this.type&&this.click&&ue.nodeName(this,"input")?(this.click(),!1):void 0},_default:function(e){return ue.nodeName(e.target,"a")}},beforeunload:{postDispatch:function(e){void 0!==e.result&&e.originalEvent&&(e.originalEvent.returnValue=e.result)}}}},ue.removeEvent=function(e,t,n){e.removeEventListener&&e.removeEventListener(t,n)},ue.Event=function(e,t){return this instanceof ue.Event?(e&&e.type?(this.originalEvent=e,this.type=e.type,this.isDefaultPrevented=e.defaultPrevented||void 0===e.defaultPrevented&&e.returnValue===!1?m:y):this.type=e,t&&ue.extend(this,t),this.timeStamp=e&&e.timeStamp||ue.now(),void(this[ue.expando]=!0)):new ue.Event(e,t)},ue.Event.prototype={constructor:ue.Event,isDefaultPrevented:y,isPropagationStopped:y,isImmediatePropagationStopped:y,isSimulated:!1,preventDefault:function(){var e=this.originalEvent;this.isDefaultPrevented=m,e&&!this.isSimulated&&e.preventDefault()},stopPropagation:function(){var e=this.originalEvent;this.isPropagationStopped=m,e&&!this.isSimulated&&e.stopPropagation()},stopImmediatePropagation:function(){var e=this.originalEvent;this.isImmediatePropagationStopped=m,e&&!this.isSimulated&&e.stopImmediatePropagation(),this.stopPropagation()}},ue.each({mouseenter:"mouseover",mouseleave:"mouseout",pointerenter:"pointerover",pointerleave:"pointerout"},function(e,t){ue.event.special[e]={delegateType:t,bindType:t,handle:function(e){var n,i=this,r=e.relatedTarget,o=e.handleObj;return r&&(r===i||ue.contains(i,r))||(e.type=o.origType,n=o.handler.apply(this,arguments),e.type=t),n}}}),ue.fn.extend({on:function(e,t,n,i){return w(this,e,t,n,i)},one:function(e,t,n,i){return w(this,e,t,n,i,1)},off:function(e,t,n){var i,r;if(e&&e.preventDefault&&e.handleObj)return i=e.handleObj,ue(e.delegateTarget).off(i.namespace?i.origType+"."+i.namespace:i.origType,i.selector,i.handler),this;if("object"==typeof e){for(r in e)this.off(r,t,e[r]);return this}return t!==!1&&"function"!=typeof t||(n=t,t=void 0),n===!1&&(n=y),this.each(function(){ue.event.remove(this,e,n,t)})}});var Be=/<(?!area|br|col|embed|hr|img|input|link|meta|param)(([\w:-]+)[^>]*)\/>/gi,Ue=/<script|<style|<link/i,Ve=/checked\s*(?:[^=]|=\s*.checked.)/i,Xe=/^true\/(.*)/,Qe=/^\s*<!(?:\[CDATA\[|--)|(?:\]\]|--)>\s*$/g;ue.extend({htmlPrefilter:function(e){return e.replace(Be,"<$1></$2>")},clone:function(e,t,n){var i,r,o,a,s=e.cloneNode(!0),l=ue.contains(e.ownerDocument,e);if(!(se.noCloneChecked||1!==e.nodeType&&11!==e.nodeType||ue.isXMLDoc(e)))for(a=f(s),o=f(e),i=0,r=o.length;r>i;i++)T(o[i],a[i]);if(t)if(n)for(o=o||f(e),a=a||f(s),i=0,r=o.length;r>i;i++)C(o[i],a[i]);else C(e,s);return a=f(s,"script"),a.length>0&&g(a,!l&&f(e,"script")),s},cleanData:function(e){for(var t,n,i,r=ue.event.special,o=0;void 0!==(n=e[o]);o++)if(Ee(n)){if(t=n[Ae.expando]){if(t.events)for(i in t.events)r[i]?ue.event.remove(n,i):ue.removeEvent(n,i,t.handle);n[Ae.expando]=void 0}n[Me.expando]&&(n[Me.expando]=void 0)}}}),ue.fn.extend({domManip:D,detach:function(e){return S(this,e,!0)},remove:function(e){return S(this,e)},text:function(e){return Se(this,function(e){return void 0===e?ue.text(this):this.empty().each(function(){1!==this.nodeType&&11!==this.nodeType&&9!==this.nodeType||(this.textContent=e)})},null,e,arguments.length)},append:function(){return D(this,arguments,function(e){if(1===this.nodeType||11===this.nodeType||9===this.nodeType){var t=x(this,e);t.appendChild(e)}})},prepend:function(){return D(this,arguments,function(e){if(1===this.nodeType||11===this.nodeType||9===this.nodeType){var t=x(this,e);t.insertBefore(e,t.firstChild)}})},before:function(){return D(this,arguments,function(e){this.parentNode&&this.parentNode.insertBefore(e,this)})},after:function(){return D(this,arguments,function(e){this.parentNode&&this.parentNode.insertBefore(e,this.nextSibling)})},empty:function(){for(var e,t=0;null!=(e=this[t]);t++)1===e.nodeType&&(ue.cleanData(f(e,!1)),e.textContent="");return this},clone:function(e,t){return e=null==e?!1:e,t=null==t?e:t,this.map(function(){return ue.clone(this,e,t)})},html:function(e){return Se(this,function(e){var t=this[0]||{},n=0,i=this.length;if(void 0===e&&1===t.nodeType)return t.innerHTML;if("string"==typeof e&&!Ue.test(e)&&!Re[(qe.exec(e)||["",""])[1].toLowerCase()]){e=ue.htmlPrefilter(e);try{for(;i>n;n++)t=this[n]||{},1===t.nodeType&&(ue.cleanData(f(t,!1)),t.innerHTML=e);t=0}catch(r){}}t&&this.empty().append(e)},null,e,arguments.length)},replaceWith:function(){var e=[];return D(this,arguments,function(t){var n=this.parentNode;ue.inArray(this,e)<0&&(ue.cleanData(f(this)),n&&n.replaceChild(t,this))},e)}}),ue.each({appendTo:"append",prependTo:"prepend",insertBefore:"before",insertAfter:"after",replaceAll:"replaceWith"},function(e,t){ue.fn[e]=function(e){for(var n,i=[],r=ue(e),o=r.length-1,a=0;o>=a;a++)n=a===o?this:this.clone(!0),ue(r[a])[t](n),ne.apply(i,n.get());return this.pushStack(i)}});var Ge,Ke={HTML:"block",BODY:"block"},Ze=/^margin/,Je=new RegExp("^("+Ne+")(?!px)[a-z%]+$","i"),et=function(e){var t=e.ownerDocument.defaultView;return t&&t.opener||(t=n),t.getComputedStyle(e)},tt=function(e,t,n,i){var r,o,a={};for(o in t)a[o]=e.style[o],e.style[o]=t[o];r=n.apply(e,i||[]);for(o in t)e.style[o]=a[o];return r},nt=J.documentElement;!function(){function e(){s.style.cssText="-webkit-box-sizing:border-box;-moz-box-sizing:border-box;box-sizing:border-box;position:relative;display:block;margin:auto;border:1px;padding:1px;top:1%;width:50%",s.innerHTML="",nt.appendChild(a);var e=n.getComputedStyle(s);t="1%"!==e.top,o="2px"===e.marginLeft,i="4px"===e.width,s.style.marginRight="50%",r="4px"===e.marginRight,nt.removeChild(a)}var t,i,r,o,a=J.createElement("div"),s=J.createElement("div");s.style&&(s.style.backgroundClip="content-box",s.cloneNode(!0).style.backgroundClip="",se.clearCloneStyle="content-box"===s.style.backgroundClip,a.style.cssText="border:0;width:8px;height:0;top:0;left:-9999px;padding:0;margin-top:1px;position:absolute",a.appendChild(s),ue.extend(se,{pixelPosition:function(){return e(),t},boxSizingReliable:function(){return null==i&&e(),i},pixelMarginRight:function(){return null==i&&e(),r},reliableMarginLeft:function(){return null==i&&e(),o},reliableMarginRight:function(){var e,t=s.appendChild(J.createElement("div"));return t.style.cssText=s.style.cssText="-webkit-box-sizing:content-box;box-sizing:content-box;display:block;margin:0;border:0;padding:0",t.style.marginRight=t.style.width="0",s.style.width="1px",nt.appendChild(a),e=!parseFloat(n.getComputedStyle(t).marginRight),nt.removeChild(a),s.removeChild(t),e}}))}();var it=/^(none|table(?!-c[ea]).+)/,rt={position:"absolute",visibility:"hidden",display:"block"},ot={letterSpacing:"0",fontWeight:"400"},at=["Webkit","O","Moz","ms"],st=J.createElement("div").style;ue.extend({cssHooks:{opacity:{get:function(e,t){if(t){var n=M(e,"opacity");return""===n?"1":n}}}},cssNumber:{animationIterationCount:!0,columnCount:!0,fillOpacity:!0,flexGrow:!0,flexShrink:!0,fontWeight:!0,lineHeight:!0,opacity:!0,order:!0,orphans:!0,widows:!0,zIndex:!0,zoom:!0},cssProps:{"float":"cssFloat"},style:function(e,t,n,i){if(e&&3!==e.nodeType&&8!==e.nodeType&&e.style){var r,o,a,s=ue.camelCase(t),l=e.style;return t=ue.cssProps[s]||(ue.cssProps[s]=I(s)||s),a=ue.cssHooks[t]||ue.cssHooks[s],void 0===n?a&&"get"in a&&void 0!==(r=a.get(e,!1,i))?r:l[t]:(o=typeof n,"string"===o&&(r=Fe.exec(n))&&r[1]&&(n=h(e,t,r),o="number"),null!=n&&n===n&&("number"===o&&(n+=r&&r[3]||(ue.cssNumber[s]?"":"px")),se.clearCloneStyle||""!==n||0!==t.indexOf("background")||(l[t]="inherit"),a&&"set"in a&&void 0===(n=a.set(e,n,i))||(l[t]=n)),void 0)}},css:function(e,t,n,i){var r,o,a,s=ue.camelCase(t);return t=ue.cssProps[s]||(ue.cssProps[s]=I(s)||s),a=ue.cssHooks[t]||ue.cssHooks[s],a&&"get"in a&&(r=a.get(e,!0,n)),void 0===r&&(r=M(e,t,i)),"normal"===r&&t in ot&&(r=ot[t]),""===n||n?(o=parseFloat(r),n===!0||isFinite(o)?o||0:r):r}}),ue.each(["height","width"],function(e,t){ue.cssHooks[t]={get:function(e,n,i){return n?it.test(ue.css(e,"display"))&&0===e.offsetWidth?tt(e,rt,function(){return P(e,t,i)}):P(e,t,i):void 0},set:function(e,n,i){var r,o=i&&et(e),a=i&&F(e,t,i,"border-box"===ue.css(e,"boxSizing",!1,o),o);return a&&(r=Fe.exec(n))&&"px"!==(r[3]||"px")&&(e.style[t]=n,n=ue.css(e,t)),N(e,n,a)}}}),ue.cssHooks.marginLeft=O(se.reliableMarginLeft,function(e,t){return t?(parseFloat(M(e,"marginLeft"))||e.getBoundingClientRect().left-tt(e,{marginLeft:0},function(){return e.getBoundingClientRect().left}))+"px":void 0}),ue.cssHooks.marginRight=O(se.reliableMarginRight,function(e,t){return t?tt(e,{display:"inline-block"},M,[e,"marginRight"]):void 0}),ue.each({margin:"",padding:"",border:"Width"},function(e,t){ue.cssHooks[e+t]={expand:function(n){for(var i=0,r={},o="string"==typeof n?n.split(" "):[n];4>i;i++)r[e+Pe[i]+t]=o[i]||o[i-2]||o[0];return r}},Ze.test(e)||(ue.cssHooks[e+t].set=N)}),ue.fn.extend({css:function(e,t){return Se(this,function(e,t,n){var i,r,o={},a=0;if(ue.isArray(t)){for(i=et(e),r=t.length;r>a;a++)o[t[a]]=ue.css(e,t[a],!1,i);return o}return void 0!==n?ue.style(e,t,n):ue.css(e,t)},e,t,arguments.length>1)},show:function(){return $(this,!0)},hide:function(){return $(this)},toggle:function(e){return"boolean"==typeof e?e?this.show():this.hide():this.each(function(){$e(this)?ue(this).show():ue(this).hide()})}}),ue.Tween=L,L.prototype={constructor:L,init:function(e,t,n,i,r,o){this.elem=e,this.prop=n,this.easing=r||ue.easing._default,this.options=t,this.start=this.now=this.cur(),this.end=i,this.unit=o||(ue.cssNumber[n]?"":"px")},cur:function(){var e=L.propHooks[this.prop];return e&&e.get?e.get(this):L.propHooks._default.get(this)},run:function(e){var t,n=L.propHooks[this.prop];return this.options.duration?this.pos=t=ue.easing[this.easing](e,this.options.duration*e,0,1,this.options.duration):this.pos=t=e,this.now=(this.end-this.start)*t+this.start,this.options.step&&this.options.step.call(this.elem,this.now,this),n&&n.set?n.set(this):L.propHooks._default.set(this),this}},L.prototype.init.prototype=L.prototype,L.propHooks={_default:{get:function(e){var t;return 1!==e.elem.nodeType||null!=e.elem[e.prop]&&null==e.elem.style[e.prop]?e.elem[e.prop]:(t=ue.css(e.elem,e.prop,""),t&&"auto"!==t?t:0)},set:function(e){ue.fx.step[e.prop]?ue.fx.step[e.prop](e):1!==e.elem.nodeType||null==e.elem.style[ue.cssProps[e.prop]]&&!ue.cssHooks[e.prop]?e.elem[e.prop]=e.now:ue.style(e.elem,e.prop,e.now+e.unit)}}},L.propHooks.scrollTop=L.propHooks.scrollLeft={set:function(e){e.elem.nodeType&&e.elem.parentNode&&(e.elem[e.prop]=e.now)}},ue.easing={linear:function(e){return e},swing:function(e){return.5-Math.cos(e*Math.PI)/2},_default:"swing"},ue.fx=L.prototype.init,ue.fx.step={};var lt,ut,ct=/^(?:toggle|show|hide)$/,dt=/queueHooks$/;ue.Animation=ue.extend(W,{tweeners:{"*":[function(e,t){var n=this.createTween(e,t);return h(n.elem,e,Fe.exec(t),n),n}]},tweener:function(e,t){ue.isFunction(e)?(t=e,e=["*"]):e=e.match(Te);for(var n,i=0,r=e.length;r>i;i++)n=e[i],W.tweeners[n]=W.tweeners[n]||[],W.tweeners[n].unshift(t)},prefilters:[z],prefilter:function(e,t){t?W.prefilters.unshift(e):W.prefilters.push(e)}}),ue.speed=function(e,t,n){var i=e&&"object"==typeof e?ue.extend({},e):{complete:n||!n&&t||ue.isFunction(e)&&e,duration:e,easing:n&&t||t&&!ue.isFunction(t)&&t};return i.duration=ue.fx.off?0:"number"==typeof i.duration?i.duration:i.duration in ue.fx.speeds?ue.fx.speeds[i.duration]:ue.fx.speeds._default,null!=i.queue&&i.queue!==!0||(i.queue="fx"),i.old=i.complete,i.complete=function(){ue.isFunction(i.old)&&i.old.call(this),i.queue&&ue.dequeue(this,i.queue)},i},ue.fn.extend({fadeTo:function(e,t,n,i){return this.filter($e).css("opacity",0).show().end().animate({opacity:t},e,n,i)},animate:function(e,t,n,i){var r=ue.isEmptyObject(e),o=ue.speed(t,n,i),a=function(){var t=W(this,ue.extend({},e),o);(r||Ae.get(this,"finish"))&&t.stop(!0)};return a.finish=a,r||o.queue===!1?this.each(a):this.queue(o.queue,a)},stop:function(e,t,n){var i=function(e){var t=e.stop;delete e.stop,t(n)};return"string"!=typeof e&&(n=t,t=e,e=void 0),t&&e!==!1&&this.queue(e||"fx",[]),this.each(function(){var t=!0,r=null!=e&&e+"queueHooks",o=ue.timers,a=Ae.get(this);if(r)a[r]&&a[r].stop&&i(a[r]);else for(r in a)a[r]&&a[r].stop&&dt.test(r)&&i(a[r]);for(r=o.length;r--;)o[r].elem!==this||null!=e&&o[r].queue!==e||(o[r].anim.stop(n),t=!1,o.splice(r,1));!t&&n||ue.dequeue(this,e)})},finish:function(e){return e!==!1&&(e=e||"fx"),this.each(function(){var t,n=Ae.get(this),i=n[e+"queue"],r=n[e+"queueHooks"],o=ue.timers,a=i?i.length:0;for(n.finish=!0,ue.queue(this,e,[]),r&&r.stop&&r.stop.call(this,!0),t=o.length;t--;)o[t].elem===this&&o[t].queue===e&&(o[t].anim.stop(!0),o.splice(t,1));for(t=0;a>t;t++)i[t]&&i[t].finish&&i[t].finish.call(this);delete n.finish})}}),ue.each(["toggle","show","hide"],function(e,t){var n=ue.fn[t];ue.fn[t]=function(e,i,r){return null==e||"boolean"==typeof e?n.apply(this,arguments):this.animate(j(t,!0),e,i,r)}}),ue.each({slideDown:j("show"),slideUp:j("hide"),slideToggle:j("toggle"),fadeIn:{opacity:"show"},fadeOut:{opacity:"hide"},fadeToggle:{opacity:"toggle"}},function(e,t){ue.fn[e]=function(e,n,i){return this.animate(t,e,n,i)}}),ue.timers=[],ue.fx.tick=function(){var e,t=0,n=ue.timers;for(lt=ue.now();t<n.length;t++)e=n[t],e()||n[t]!==e||n.splice(t--,1);n.length||ue.fx.stop(),lt=void 0},ue.fx.timer=function(e){ue.timers.push(e),e()?ue.fx.start():ue.timers.pop()},ue.fx.interval=13,ue.fx.start=function(){ut||(ut=n.setInterval(ue.fx.tick,ue.fx.interval))},ue.fx.stop=function(){n.clearInterval(ut),ut=null},ue.fx.speeds={slow:600,fast:200,_default:400},ue.fn.delay=function(e,t){return e=ue.fx?ue.fx.speeds[e]||e:e,t=t||"fx",this.queue(t,function(t,i){var r=n.setTimeout(t,e);i.stop=function(){n.clearTimeout(r)}})},function(){var e=J.createElement("input"),t=J.createElement("select"),n=t.appendChild(J.createElement("option"));e.type="checkbox",se.checkOn=""!==e.value,se.optSelected=n.selected,t.disabled=!0,se.optDisabled=!n.disabled,e=J.createElement("input"),e.value="t",e.type="radio",se.radioValue="t"===e.value}();var pt,ht=ue.expr.attrHandle;ue.fn.extend({attr:function(e,t){return Se(this,ue.attr,e,t,arguments.length>1)},removeAttr:function(e){return this.each(function(){ue.removeAttr(this,e)})}}),ue.extend({attr:function(e,t,n){var i,r,o=e.nodeType;if(3!==o&&8!==o&&2!==o)return"undefined"==typeof e.getAttribute?ue.prop(e,t,n):(1===o&&ue.isXMLDoc(e)||(t=t.toLowerCase(),r=ue.attrHooks[t]||(ue.expr.match.bool.test(t)?pt:void 0)),void 0!==n?null===n?void ue.removeAttr(e,t):r&&"set"in r&&void 0!==(i=r.set(e,n,t))?i:(e.setAttribute(t,n+""),n):r&&"get"in r&&null!==(i=r.get(e,t))?i:(i=ue.find.attr(e,t),null==i?void 0:i))},attrHooks:{type:{set:function(e,t){if(!se.radioValue&&"radio"===t&&ue.nodeName(e,"input")){var n=e.value;return e.setAttribute("type",t),n&&(e.value=n),t}}}},removeAttr:function(e,t){var n,i,r=0,o=t&&t.match(Te);if(o&&1===e.nodeType)for(;n=o[r++];)i=ue.propFix[n]||n,ue.expr.match.bool.test(n)&&(e[i]=!1),e.removeAttribute(n)}}),pt={set:function(e,t,n){return t===!1?ue.removeAttr(e,n):e.setAttribute(n,n),n}},ue.each(ue.expr.match.bool.source.match(/\w+/g),function(e,t){var n=ht[t]||ue.find.attr;ht[t]=function(e,t,i){var r,o;return i||(o=ht[t],ht[t]=r,r=null!=n(e,t,i)?t.toLowerCase():null,ht[t]=o),r}});var ft=/^(?:input|select|textarea|button)$/i,gt=/^(?:a|area)$/i;ue.fn.extend({prop:function(e,t){return Se(this,ue.prop,e,t,arguments.length>1)},removeProp:function(e){return this.each(function(){delete this[ue.propFix[e]||e]})}}),ue.extend({prop:function(e,t,n){var i,r,o=e.nodeType;if(3!==o&&8!==o&&2!==o)return 1===o&&ue.isXMLDoc(e)||(t=ue.propFix[t]||t,r=ue.propHooks[t]),void 0!==n?r&&"set"in r&&void 0!==(i=r.set(e,n,t))?i:e[t]=n:r&&"get"in r&&null!==(i=r.get(e,t))?i:e[t]},propHooks:{tabIndex:{get:function(e){var t=ue.find.attr(e,"tabindex");return t?parseInt(t,10):ft.test(e.nodeName)||gt.test(e.nodeName)&&e.href?0:-1}}},propFix:{"for":"htmlFor","class":"className"}}),se.optSelected||(ue.propHooks.selected={get:function(e){var t=e.parentNode;return t&&t.parentNode&&t.parentNode.selectedIndex,null},set:function(e){var t=e.parentNode;t&&(t.selectedIndex,t.parentNode&&t.parentNode.selectedIndex)}}),ue.each(["tabIndex","readOnly","maxLength","cellSpacing","cellPadding","rowSpan","colSpan","useMap","frameBorder","contentEditable"],function(){ue.propFix[this.toLowerCase()]=this});var vt=/[\t\r\n\f]/g;ue.fn.extend({addClass:function(e){var t,n,i,r,o,a,s,l=0;if(ue.isFunction(e))return this.each(function(t){ue(this).addClass(e.call(this,t,Y(this)))});if("string"==typeof e&&e)for(t=e.match(Te)||[];n=this[l++];)if(r=Y(n),i=1===n.nodeType&&(" "+r+" ").replace(vt," ")){for(a=0;o=t[a++];)i.indexOf(" "+o+" ")<0&&(i+=o+" ");s=ue.trim(i),r!==s&&n.setAttribute("class",s)}return this},removeClass:function(e){var t,n,i,r,o,a,s,l=0;if(ue.isFunction(e))return this.each(function(t){ue(this).removeClass(e.call(this,t,Y(this)))});if(!arguments.length)return this.attr("class","");if("string"==typeof e&&e)for(t=e.match(Te)||[];n=this[l++];)if(r=Y(n),i=1===n.nodeType&&(" "+r+" ").replace(vt," ")){for(a=0;o=t[a++];)for(;i.indexOf(" "+o+" ")>-1;)i=i.replace(" "+o+" "," ");s=ue.trim(i),r!==s&&n.setAttribute("class",s)}return this},toggleClass:function(e,t){var n=typeof e;return"boolean"==typeof t&&"string"===n?t?this.addClass(e):this.removeClass(e):ue.isFunction(e)?this.each(function(n){ue(this).toggleClass(e.call(this,n,Y(this),t),t)}):this.each(function(){var t,i,r,o;if("string"===n)for(i=0,r=ue(this),o=e.match(Te)||[];t=o[i++];)r.hasClass(t)?r.removeClass(t):r.addClass(t);else void 0!==e&&"boolean"!==n||(t=Y(this),t&&Ae.set(this,"__className__",t),this.setAttribute&&this.setAttribute("class",t||e===!1?"":Ae.get(this,"__className__")||""))})},hasClass:function(e){var t,n,i=0;for(t=" "+e+" ";n=this[i++];)if(1===n.nodeType&&(" "+Y(n)+" ").replace(vt," ").indexOf(t)>-1)return!0;return!1}});var mt=/\r/g,yt=/[\x20\t\r\n\f]+/g;ue.fn.extend({val:function(e){var t,n,i,r=this[0];{if(arguments.length)return i=ue.isFunction(e),this.each(function(n){var r;1===this.nodeType&&(r=i?e.call(this,n,ue(this).val()):e,null==r?r="":"number"==typeof r?r+="":ue.isArray(r)&&(r=ue.map(r,function(e){return null==e?"":e+""})),t=ue.valHooks[this.type]||ue.valHooks[this.nodeName.toLowerCase()],t&&"set"in t&&void 0!==t.set(this,r,"value")||(this.value=r))});if(r)return t=ue.valHooks[r.type]||ue.valHooks[r.nodeName.toLowerCase()],t&&"get"in t&&void 0!==(n=t.get(r,"value"))?n:(n=r.value,"string"==typeof n?n.replace(mt,""):null==n?"":n)}}}),ue.extend({valHooks:{option:{get:function(e){var t=ue.find.attr(e,"value");return null!=t?t:ue.trim(ue.text(e)).replace(yt," ")}},select:{get:function(e){for(var t,n,i=e.options,r=e.selectedIndex,o="select-one"===e.type||0>r,a=o?null:[],s=o?r+1:i.length,l=0>r?s:o?r:0;s>l;l++)if(n=i[l],(n.selected||l===r)&&(se.optDisabled?!n.disabled:null===n.getAttribute("disabled"))&&(!n.parentNode.disabled||!ue.nodeName(n.parentNode,"optgroup"))){if(t=ue(n).val(),o)return t;a.push(t)}return a},set:function(e,t){for(var n,i,r=e.options,o=ue.makeArray(t),a=r.length;a--;)i=r[a],(i.selected=ue.inArray(ue.valHooks.option.get(i),o)>-1)&&(n=!0);return n||(e.selectedIndex=-1),o}}}}),ue.each(["radio","checkbox"],function(){ue.valHooks[this]={set:function(e,t){return ue.isArray(t)?e.checked=ue.inArray(ue(e).val(),t)>-1:void 0}},se.checkOn||(ue.valHooks[this].get=function(e){return null===e.getAttribute("value")?"on":e.value})});var bt=/^(?:focusinfocus|focusoutblur)$/;ue.extend(ue.event,{trigger:function(e,t,i,r){var o,a,s,l,u,c,d,p=[i||J],h=ae.call(e,"type")?e.type:e,f=ae.call(e,"namespace")?e.namespace.split("."):[];if(a=s=i=i||J,3!==i.nodeType&&8!==i.nodeType&&!bt.test(h+ue.event.triggered)&&(h.indexOf(".")>-1&&(f=h.split("."),h=f.shift(),f.sort()),u=h.indexOf(":")<0&&"on"+h,e=e[ue.expando]?e:new ue.Event(h,"object"==typeof e&&e),e.isTrigger=r?2:3,e.namespace=f.join("."),e.rnamespace=e.namespace?new RegExp("(^|\\.)"+f.join("\\.(?:.*\\.|)")+"(\\.|$)"):null,e.result=void 0,e.target||(e.target=i),t=null==t?[e]:ue.makeArray(t,[e]),d=ue.event.special[h]||{},r||!d.trigger||d.trigger.apply(i,t)!==!1)){if(!r&&!d.noBubble&&!ue.isWindow(i)){for(l=d.delegateType||h,bt.test(l+h)||(a=a.parentNode);a;a=a.parentNode)p.push(a),s=a;s===(i.ownerDocument||J)&&p.push(s.defaultView||s.parentWindow||n)}for(o=0;(a=p[o++])&&!e.isPropagationStopped();)e.type=o>1?l:d.bindType||h,c=(Ae.get(a,"events")||{})[e.type]&&Ae.get(a,"handle"),c&&c.apply(a,t),c=u&&a[u],c&&c.apply&&Ee(a)&&(e.result=c.apply(a,t),e.result===!1&&e.preventDefault());return e.type=h,r||e.isDefaultPrevented()||d._default&&d._default.apply(p.pop(),t)!==!1||!Ee(i)||u&&ue.isFunction(i[h])&&!ue.isWindow(i)&&(s=i[u],s&&(i[u]=null),ue.event.triggered=h,i[h](),ue.event.triggered=void 0,s&&(i[u]=s)),e.result}},simulate:function(e,t,n){var i=ue.extend(new ue.Event,n,{type:e,isSimulated:!0});ue.event.trigger(i,null,t)}}),ue.fn.extend({trigger:function(e,t){return this.each(function(){ue.event.trigger(e,t,this)})},triggerHandler:function(e,t){var n=this[0];return n?ue.event.trigger(e,t,n,!0):void 0}}),ue.each("blur focus focusin focusout load resize scroll unload click dblclick mousedown mouseup mousemove mouseover mouseout mouseenter mouseleave change select submit keydown keypress keyup error contextmenu".split(" "),function(e,t){ue.fn[t]=function(e,n){return arguments.length>0?this.on(t,null,e,n):this.trigger(t)}}),ue.fn.extend({hover:function(e,t){return this.mouseenter(e).mouseleave(t||e)}}),se.focusin="onfocusin"in n,se.focusin||ue.each({focus:"focusin",blur:"focusout"},function(e,t){var n=function(e){ue.event.simulate(t,e.target,ue.event.fix(e))};ue.event.special[t]={setup:function(){var i=this.ownerDocument||this,r=Ae.access(i,t);r||i.addEventListener(e,n,!0),Ae.access(i,t,(r||0)+1)},teardown:function(){var i=this.ownerDocument||this,r=Ae.access(i,t)-1;r?Ae.access(i,t,r):(i.removeEventListener(e,n,!0),Ae.remove(i,t))}}});var wt=n.location,xt=ue.now(),_t=/\?/;ue.parseJSON=function(e){return JSON.parse(e+"")},ue.parseXML=function(e){var t;if(!e||"string"!=typeof e)return null;try{t=(new n.DOMParser).parseFromString(e,"text/xml")}catch(i){t=void 0}return t&&!t.getElementsByTagName("parsererror").length||ue.error("Invalid XML: "+e),t};var kt=/#.*$/,Ct=/([?&])_=[^&]*/,Tt=/^(.*?):[ \t]*([^\r\n]*)$/gm,Dt=/^(?:about|app|app-storage|.+-extension|file|res|widget):$/,St=/^(?:GET|HEAD)$/,Et=/^\/\//,At={},Mt={},Ot="*/".concat("*"),It=J.createElement("a");It.href=wt.href,ue.extend({active:0,lastModified:{},etag:{},ajaxSettings:{url:wt.href,type:"GET",isLocal:Dt.test(wt.protocol),global:!0,processData:!0,async:!0,contentType:"application/x-www-form-urlencoded; charset=UTF-8",accepts:{"*":Ot,text:"text/plain",html:"text/html",xml:"application/xml, text/xml",json:"application/json, text/javascript"},contents:{xml:/\bxml\b/,html:/\bhtml/,json:/\bjson\b/},responseFields:{xml:"responseXML",text:"responseText",json:"responseJSON"},converters:{"* text":String,"text html":!0,"text json":ue.parseJSON,"text xml":ue.parseXML},flatOptions:{url:!0,context:!0}},ajaxSetup:function(e,t){return t?V(V(e,ue.ajaxSettings),t):V(ue.ajaxSettings,e)},ajaxPrefilter:B(At),ajaxTransport:B(Mt),ajax:function(e,t){function i(e,t,i,s){var u,d,y,b,x,k=t;2!==w&&(w=2,l&&n.clearTimeout(l),r=void 0,a=s||"",_.readyState=e>0?4:0,u=e>=200&&300>e||304===e,i&&(b=X(p,_,i)),b=Q(p,b,_,u),u?(p.ifModified&&(x=_.getResponseHeader("Last-Modified"),x&&(ue.lastModified[o]=x),x=_.getResponseHeader("etag"),x&&(ue.etag[o]=x)),204===e||"HEAD"===p.type?k="nocontent":304===e?k="notmodified":(k=b.state,d=b.data,y=b.error,u=!y)):(y=k,!e&&k||(k="error",0>e&&(e=0))),_.status=e,_.statusText=(t||k)+"",u?g.resolveWith(h,[d,k,_]):g.rejectWith(h,[_,k,y]),_.statusCode(m),m=void 0,c&&f.trigger(u?"ajaxSuccess":"ajaxError",[_,p,u?d:y]),v.fireWith(h,[_,k]),c&&(f.trigger("ajaxComplete",[_,p]),--ue.active||ue.event.trigger("ajaxStop")))}"object"==typeof e&&(t=e,e=void 0),t=t||{};var r,o,a,s,l,u,c,d,p=ue.ajaxSetup({},t),h=p.context||p,f=p.context&&(h.nodeType||h.jquery)?ue(h):ue.event,g=ue.Deferred(),v=ue.Callbacks("once memory"),m=p.statusCode||{},y={},b={},w=0,x="canceled",_={readyState:0,getResponseHeader:function(e){var t;if(2===w){if(!s)for(s={};t=Tt.exec(a);)s[t[1].toLowerCase()]=t[2];t=s[e.toLowerCase()]}return null==t?null:t},getAllResponseHeaders:function(){return 2===w?a:null},setRequestHeader:function(e,t){var n=e.toLowerCase();return w||(e=b[n]=b[n]||e,y[e]=t),this},overrideMimeType:function(e){return w||(p.mimeType=e),this},statusCode:function(e){var t;if(e)if(2>w)for(t in e)m[t]=[m[t],e[t]];else _.always(e[_.status]);return this},abort:function(e){var t=e||x;return r&&r.abort(t),i(0,t),this}};if(g.promise(_).complete=v.add,_.success=_.done,_.error=_.fail,p.url=((e||p.url||wt.href)+"").replace(kt,"").replace(Et,wt.protocol+"//"),p.type=t.method||t.type||p.method||p.type,p.dataTypes=ue.trim(p.dataType||"*").toLowerCase().match(Te)||[""],null==p.crossDomain){u=J.createElement("a");try{u.href=p.url,u.href=u.href,p.crossDomain=It.protocol+"//"+It.host!=u.protocol+"//"+u.host}catch(k){p.crossDomain=!0}}if(p.data&&p.processData&&"string"!=typeof p.data&&(p.data=ue.param(p.data,p.traditional)),U(At,p,t,_),2===w)return _;c=ue.event&&p.global,c&&0===ue.active++&&ue.event.trigger("ajaxStart"),p.type=p.type.toUpperCase(),p.hasContent=!St.test(p.type),o=p.url,p.hasContent||(p.data&&(o=p.url+=(_t.test(o)?"&":"?")+p.data,delete p.data),p.cache===!1&&(p.url=Ct.test(o)?o.replace(Ct,"$1_="+xt++):o+(_t.test(o)?"&":"?")+"_="+xt++)),p.ifModified&&(ue.lastModified[o]&&_.setRequestHeader("If-Modified-Since",ue.lastModified[o]),ue.etag[o]&&_.setRequestHeader("If-None-Match",ue.etag[o])),(p.data&&p.hasContent&&p.contentType!==!1||t.contentType)&&_.setRequestHeader("Content-Type",p.contentType),_.setRequestHeader("Accept",p.dataTypes[0]&&p.accepts[p.dataTypes[0]]?p.accepts[p.dataTypes[0]]+("*"!==p.dataTypes[0]?", "+Ot+"; q=0.01":""):p.accepts["*"]);for(d in p.headers)_.setRequestHeader(d,p.headers[d]);if(p.beforeSend&&(p.beforeSend.call(h,_,p)===!1||2===w))return _.abort();x="abort";for(d in{success:1,error:1,complete:1})_[d](p[d]);if(r=U(Mt,p,t,_)){if(_.readyState=1,c&&f.trigger("ajaxSend",[_,p]),2===w)return _;p.async&&p.timeout>0&&(l=n.setTimeout(function(){_.abort("timeout")},p.timeout));try{w=1,r.send(y,i)}catch(k){if(!(2>w))throw k;i(-1,k)}}else i(-1,"No Transport");return _},getJSON:function(e,t,n){return ue.get(e,t,n,"json")},getScript:function(e,t){return ue.get(e,void 0,t,"script")}}),ue.each(["get","post"],function(e,t){ue[t]=function(e,n,i,r){return ue.isFunction(n)&&(r=r||i,i=n,n=void 0),ue.ajax(ue.extend({url:e,type:t,dataType:r,data:n,success:i},ue.isPlainObject(e)&&e))}}),ue._evalUrl=function(e){return ue.ajax({url:e,type:"GET",dataType:"script",async:!1,global:!1,"throws":!0})},ue.fn.extend({wrapAll:function(e){var t;return ue.isFunction(e)?this.each(function(t){ue(this).wrapAll(e.call(this,t))}):(this[0]&&(t=ue(e,this[0].ownerDocument).eq(0).clone(!0),this[0].parentNode&&t.insertBefore(this[0]),t.map(function(){for(var e=this;e.firstElementChild;)e=e.firstElementChild;return e}).append(this)),this)},wrapInner:function(e){return ue.isFunction(e)?this.each(function(t){ue(this).wrapInner(e.call(this,t))}):this.each(function(){var t=ue(this),n=t.contents();n.length?n.wrapAll(e):t.append(e)})},wrap:function(e){var t=ue.isFunction(e);return this.each(function(n){ue(this).wrapAll(t?e.call(this,n):e)})},unwrap:function(){return this.parent().each(function(){ue.nodeName(this,"body")||ue(this).replaceWith(this.childNodes)}).end()}}),ue.expr.filters.hidden=function(e){return!ue.expr.filters.visible(e)},ue.expr.filters.visible=function(e){return e.offsetWidth>0||e.offsetHeight>0||e.getClientRects().length>0};var Nt=/%20/g,Ft=/\[\]$/,Pt=/\r?\n/g,$t=/^(?:submit|button|image|reset|file)$/i,Lt=/^(?:input|select|textarea|keygen)/i;ue.param=function(e,t){var n,i=[],r=function(e,t){t=ue.isFunction(t)?t():null==t?"":t,i[i.length]=encodeURIComponent(e)+"="+encodeURIComponent(t)};if(void 0===t&&(t=ue.ajaxSettings&&ue.ajaxSettings.traditional),ue.isArray(e)||e.jquery&&!ue.isPlainObject(e))ue.each(e,function(){r(this.name,this.value)});else for(n in e)G(n,e[n],t,r);return i.join("&").replace(Nt,"+")},ue.fn.extend({serialize:function(){return ue.param(this.serializeArray())},serializeArray:function(){return this.map(function(){var e=ue.prop(this,"elements");return e?ue.makeArray(e):this}).filter(function(){var e=this.type;return this.name&&!ue(this).is(":disabled")&&Lt.test(this.nodeName)&&!$t.test(e)&&(this.checked||!Le.test(e))}).map(function(e,t){var n=ue(this).val();return null==n?null:ue.isArray(n)?ue.map(n,function(e){return{name:t.name,value:e.replace(Pt,"\r\n")}}):{name:t.name,value:n.replace(Pt,"\r\n")}}).get()}}),ue.ajaxSettings.xhr=function(){try{return new n.XMLHttpRequest}catch(e){}};var qt={0:200,1223:204},jt=ue.ajaxSettings.xhr();se.cors=!!jt&&"withCredentials"in jt,se.ajax=jt=!!jt,ue.ajaxTransport(function(e){var t,i;return se.cors||jt&&!e.crossDomain?{send:function(r,o){var a,s=e.xhr();if(s.open(e.type,e.url,e.async,e.username,e.password),e.xhrFields)for(a in e.xhrFields)s[a]=e.xhrFields[a];e.mimeType&&s.overrideMimeType&&s.overrideMimeType(e.mimeType),
e.crossDomain||r["X-Requested-With"]||(r["X-Requested-With"]="XMLHttpRequest");for(a in r)s.setRequestHeader(a,r[a]);t=function(e){return function(){t&&(t=i=s.onload=s.onerror=s.onabort=s.onreadystatechange=null,"abort"===e?s.abort():"error"===e?"number"!=typeof s.status?o(0,"error"):o(s.status,s.statusText):o(qt[s.status]||s.status,s.statusText,"text"!==(s.responseType||"text")||"string"!=typeof s.responseText?{binary:s.response}:{text:s.responseText},s.getAllResponseHeaders()))}},s.onload=t(),i=s.onerror=t("error"),void 0!==s.onabort?s.onabort=i:s.onreadystatechange=function(){4===s.readyState&&n.setTimeout(function(){t&&i()})},t=t("abort");try{s.send(e.hasContent&&e.data||null)}catch(l){if(t)throw l}},abort:function(){t&&t()}}:void 0}),ue.ajaxSetup({accepts:{script:"text/javascript, application/javascript, application/ecmascript, application/x-ecmascript"},contents:{script:/\b(?:java|ecma)script\b/},converters:{"text script":function(e){return ue.globalEval(e),e}}}),ue.ajaxPrefilter("script",function(e){void 0===e.cache&&(e.cache=!1),e.crossDomain&&(e.type="GET")}),ue.ajaxTransport("script",function(e){if(e.crossDomain){var t,n;return{send:function(i,r){t=ue("<script>").prop({charset:e.scriptCharset,src:e.url}).on("load error",n=function(e){t.remove(),n=null,e&&r("error"===e.type?404:200,e.type)}),J.head.appendChild(t[0])},abort:function(){n&&n()}}}});var Rt=[],zt=/(=)\?(?=&|$)|\?\?/;ue.ajaxSetup({jsonp:"callback",jsonpCallback:function(){var e=Rt.pop()||ue.expando+"_"+xt++;return this[e]=!0,e}}),ue.ajaxPrefilter("json jsonp",function(e,t,i){var r,o,a,s=e.jsonp!==!1&&(zt.test(e.url)?"url":"string"==typeof e.data&&0===(e.contentType||"").indexOf("application/x-www-form-urlencoded")&&zt.test(e.data)&&"data");return s||"jsonp"===e.dataTypes[0]?(r=e.jsonpCallback=ue.isFunction(e.jsonpCallback)?e.jsonpCallback():e.jsonpCallback,s?e[s]=e[s].replace(zt,"$1"+r):e.jsonp!==!1&&(e.url+=(_t.test(e.url)?"&":"?")+e.jsonp+"="+r),e.converters["script json"]=function(){return a||ue.error(r+" was not called"),a[0]},e.dataTypes[0]="json",o=n[r],n[r]=function(){a=arguments},i.always(function(){void 0===o?ue(n).removeProp(r):n[r]=o,e[r]&&(e.jsonpCallback=t.jsonpCallback,Rt.push(r)),a&&ue.isFunction(o)&&o(a[0]),a=o=void 0}),"script"):void 0}),ue.parseHTML=function(e,t,n){if(!e||"string"!=typeof e)return null;"boolean"==typeof t&&(n=t,t=!1),t=t||J;var i=ye.exec(e),r=!n&&[];return i?[t.createElement(i[1])]:(i=v([e],t,r),r&&r.length&&ue(r).remove(),ue.merge([],i.childNodes))};var Ht=ue.fn.load;ue.fn.load=function(e,t,n){if("string"!=typeof e&&Ht)return Ht.apply(this,arguments);var i,r,o,a=this,s=e.indexOf(" ");return s>-1&&(i=ue.trim(e.slice(s)),e=e.slice(0,s)),ue.isFunction(t)?(n=t,t=void 0):t&&"object"==typeof t&&(r="POST"),a.length>0&&ue.ajax({url:e,type:r||"GET",dataType:"html",data:t}).done(function(e){o=arguments,a.html(i?ue("<div>").append(ue.parseHTML(e)).find(i):e)}).always(n&&function(e,t){a.each(function(){n.apply(this,o||[e.responseText,t,e])})}),this},ue.each(["ajaxStart","ajaxStop","ajaxComplete","ajaxError","ajaxSuccess","ajaxSend"],function(e,t){ue.fn[t]=function(e){return this.on(t,e)}}),ue.expr.filters.animated=function(e){return ue.grep(ue.timers,function(t){return e===t.elem}).length},ue.offset={setOffset:function(e,t,n){var i,r,o,a,s,l,u,c=ue.css(e,"position"),d=ue(e),p={};"static"===c&&(e.style.position="relative"),s=d.offset(),o=ue.css(e,"top"),l=ue.css(e,"left"),u=("absolute"===c||"fixed"===c)&&(o+l).indexOf("auto")>-1,u?(i=d.position(),a=i.top,r=i.left):(a=parseFloat(o)||0,r=parseFloat(l)||0),ue.isFunction(t)&&(t=t.call(e,n,ue.extend({},s))),null!=t.top&&(p.top=t.top-s.top+a),null!=t.left&&(p.left=t.left-s.left+r),"using"in t?t.using.call(e,p):d.css(p)}},ue.fn.extend({offset:function(e){if(arguments.length)return void 0===e?this:this.each(function(t){ue.offset.setOffset(this,e,t)});var t,n,i=this[0],r={top:0,left:0},o=i&&i.ownerDocument;if(o)return t=o.documentElement,ue.contains(t,i)?(r=i.getBoundingClientRect(),n=K(o),{top:r.top+n.pageYOffset-t.clientTop,left:r.left+n.pageXOffset-t.clientLeft}):r},position:function(){if(this[0]){var e,t,n=this[0],i={top:0,left:0};return"fixed"===ue.css(n,"position")?t=n.getBoundingClientRect():(e=this.offsetParent(),t=this.offset(),ue.nodeName(e[0],"html")||(i=e.offset()),i.top+=ue.css(e[0],"borderTopWidth",!0),i.left+=ue.css(e[0],"borderLeftWidth",!0)),{top:t.top-i.top-ue.css(n,"marginTop",!0),left:t.left-i.left-ue.css(n,"marginLeft",!0)}}},offsetParent:function(){return this.map(function(){for(var e=this.offsetParent;e&&"static"===ue.css(e,"position");)e=e.offsetParent;return e||nt})}}),ue.each({scrollLeft:"pageXOffset",scrollTop:"pageYOffset"},function(e,t){var n="pageYOffset"===t;ue.fn[e]=function(i){return Se(this,function(e,i,r){var o=K(e);return void 0===r?o?o[t]:e[i]:void(o?o.scrollTo(n?o.pageXOffset:r,n?r:o.pageYOffset):e[i]=r)},e,i,arguments.length)}}),ue.each(["top","left"],function(e,t){ue.cssHooks[t]=O(se.pixelPosition,function(e,n){return n?(n=M(e,t),Je.test(n)?ue(e).position()[t]+"px":n):void 0})}),ue.each({Height:"height",Width:"width"},function(e,t){ue.each({padding:"inner"+e,content:t,"":"outer"+e},function(n,i){ue.fn[i]=function(i,r){var o=arguments.length&&(n||"boolean"!=typeof i),a=n||(i===!0||r===!0?"margin":"border");return Se(this,function(t,n,i){var r;return ue.isWindow(t)?t.document.documentElement["client"+e]:9===t.nodeType?(r=t.documentElement,Math.max(t.body["scroll"+e],r["scroll"+e],t.body["offset"+e],r["offset"+e],r["client"+e])):void 0===i?ue.css(t,n,a):ue.style(t,n,i,a)},t,o?i:void 0,o,null)}})}),ue.fn.extend({bind:function(e,t,n){return this.on(e,null,t,n)},unbind:function(e,t){return this.off(e,null,t)},delegate:function(e,t,n,i){return this.on(t,e,n,i)},undelegate:function(e,t,n){return 1===arguments.length?this.off(e,"**"):this.off(t,e||"**",n)},size:function(){return this.length}}),ue.fn.andSelf=ue.fn.addBack,i=[],r=function(){return ue}.apply(t,i),!(void 0!==r&&(e.exports=r));var Wt=n.jQuery,Yt=n.$;return ue.noConflict=function(e){return n.$===ue&&(n.$=Yt),e&&n.jQuery===ue&&(n.jQuery=Wt),ue},o||(n.jQuery=n.$=ue),ue})},function(e,t,n){(function(e,t){(function(){var n,i,r,o,a,s,l,u,c=[].slice,d={}.hasOwnProperty,p=function(e,t){function n(){this.constructor=e}for(var i in t)d.call(t,i)&&(e[i]=t[i]);return n.prototype=t.prototype,e.prototype=new n,e.__super__=t.prototype,e};l=function(){},i=function(){function e(){}return e.prototype.addEventListener=e.prototype.on,e.prototype.on=function(e,t){return this._callbacks=this._callbacks||{},this._callbacks[e]||(this._callbacks[e]=[]),this._callbacks[e].push(t),this},e.prototype.emit=function(){var e,t,n,i,r,o;if(i=arguments[0],e=2<=arguments.length?c.call(arguments,1):[],this._callbacks=this._callbacks||{},n=this._callbacks[i])for(r=0,o=n.length;o>r;r++)t=n[r],t.apply(this,e);return this},e.prototype.removeListener=e.prototype.off,e.prototype.removeAllListeners=e.prototype.off,e.prototype.removeEventListener=e.prototype.off,e.prototype.off=function(e,t){var n,i,r,o,a;if(!this._callbacks||0===arguments.length)return this._callbacks={},this;if(i=this._callbacks[e],!i)return this;if(1===arguments.length)return delete this._callbacks[e],this;for(r=o=0,a=i.length;a>o;r=++o)if(n=i[r],n===t){i.splice(r,1);break}return this},e}(),n=function(e){function t(e,i){var r,o,a;if(this.element=e,this.version=t.version,this.defaultOptions.previewTemplate=this.defaultOptions.previewTemplate.replace(/\n*/g,""),this.clickableElements=[],this.listeners=[],this.files=[],"string"==typeof this.element&&(this.element=document.querySelector(this.element)),!this.element||null==this.element.nodeType)throw new Error("Invalid dropzone element.");if(this.element.dropzone)throw new Error("Dropzone already attached.");if(t.instances.push(this),this.element.dropzone=this,r=null!=(a=t.optionsForElement(this.element))?a:{},this.options=n({},this.defaultOptions,r,null!=i?i:{}),this.options.forceFallback||!t.isBrowserSupported())return this.options.fallback.call(this);if(null==this.options.url&&(this.options.url=this.element.getAttribute("action")),!this.options.url)throw new Error("No URL provided.");if(this.options.acceptedFiles&&this.options.acceptedMimeTypes)throw new Error("You can't provide both 'acceptedFiles' and 'acceptedMimeTypes'. 'acceptedMimeTypes' is deprecated.");this.options.acceptedMimeTypes&&(this.options.acceptedFiles=this.options.acceptedMimeTypes,delete this.options.acceptedMimeTypes),this.options.method=this.options.method.toUpperCase(),(o=this.getExistingFallback())&&o.parentNode&&o.parentNode.removeChild(o),this.options.previewsContainer!==!1&&(this.options.previewsContainer?this.previewsContainer=t.getElement(this.options.previewsContainer,"previewsContainer"):this.previewsContainer=this.element),this.options.clickable&&(this.options.clickable===!0?this.clickableElements=[this.element]:this.clickableElements=t.getElements(this.options.clickable,"clickable")),this.init()}var n,r;return p(t,e),t.prototype.Emitter=i,t.prototype.events=["drop","dragstart","dragend","dragenter","dragover","dragleave","addedfile","addedfiles","removedfile","thumbnail","error","errormultiple","processing","processingmultiple","uploadprogress","totaluploadprogress","sending","sendingmultiple","success","successmultiple","canceled","canceledmultiple","complete","completemultiple","reset","maxfilesexceeded","maxfilesreached","queuecomplete"],t.prototype.defaultOptions={url:null,method:"post",withCredentials:!1,parallelUploads:2,uploadMultiple:!1,maxFilesize:256,paramName:"file",createImageThumbnails:!0,maxThumbnailFilesize:10,thumbnailWidth:120,thumbnailHeight:120,filesizeBase:1e3,maxFiles:null,params:{},clickable:!0,ignoreHiddenFiles:!0,acceptedFiles:null,acceptedMimeTypes:null,autoProcessQueue:!0,autoQueue:!0,addRemoveLinks:!1,previewsContainer:null,hiddenInputContainer:"body",capture:null,renameFilename:null,dictDefaultMessage:"Drop files here to upload",dictFallbackMessage:"Your browser does not support drag'n'drop file uploads.",dictFallbackText:"Please use the fallback form below to upload your files like in the olden days.",dictFileTooBig:"File is too big ({{filesize}}MiB). Max filesize: {{maxFilesize}}MiB.",dictInvalidFileType:"You can't upload files of this type.",dictResponseError:"Server responded with {{statusCode}} code.",dictCancelUpload:"Cancel upload",dictCancelUploadConfirmation:"Are you sure you want to cancel this upload?",dictRemoveFile:"Remove file",dictRemoveFileConfirmation:null,dictMaxFilesExceeded:"You can not upload any more files.",accept:function(e,t){return t()},init:function(){return l},forceFallback:!1,fallback:function(){var e,n,i,r,o,a;for(this.element.className=""+this.element.className+" dz-browser-not-supported",a=this.element.getElementsByTagName("div"),r=0,o=a.length;o>r;r++)e=a[r],/(^| )dz-message($| )/.test(e.className)&&(n=e,e.className="dz-message");return n||(n=t.createElement('<div class="dz-message"><span></span></div>'),this.element.appendChild(n)),i=n.getElementsByTagName("span")[0],i&&(null!=i.textContent?i.textContent=this.options.dictFallbackMessage:null!=i.innerText&&(i.innerText=this.options.dictFallbackMessage)),this.element.appendChild(this.getFallbackForm())},resize:function(e){var t,n,i;return t={srcX:0,srcY:0,srcWidth:e.width,srcHeight:e.height},n=e.width/e.height,t.optWidth=this.options.thumbnailWidth,t.optHeight=this.options.thumbnailHeight,null==t.optWidth&&null==t.optHeight?(t.optWidth=t.srcWidth,t.optHeight=t.srcHeight):null==t.optWidth?t.optWidth=n*t.optHeight:null==t.optHeight&&(t.optHeight=1/n*t.optWidth),i=t.optWidth/t.optHeight,e.height<t.optHeight||e.width<t.optWidth?(t.trgHeight=t.srcHeight,t.trgWidth=t.srcWidth):n>i?(t.srcHeight=e.height,t.srcWidth=t.srcHeight*i):(t.srcWidth=e.width,t.srcHeight=t.srcWidth/i),t.srcX=(e.width-t.srcWidth)/2,t.srcY=(e.height-t.srcHeight)/2,t},drop:function(e){return this.element.classList.remove("dz-drag-hover")},dragstart:l,dragend:function(e){return this.element.classList.remove("dz-drag-hover")},dragenter:function(e){return this.element.classList.add("dz-drag-hover")},dragover:function(e){return this.element.classList.add("dz-drag-hover")},dragleave:function(e){return this.element.classList.remove("dz-drag-hover")},paste:l,reset:function(){return this.element.classList.remove("dz-started")},addedfile:function(e){var n,i,r,o,a,s,l,u,c,d,p,h,f;if(this.element===this.previewsContainer&&this.element.classList.add("dz-started"),this.previewsContainer){for(e.previewElement=t.createElement(this.options.previewTemplate.trim()),e.previewTemplate=e.previewElement,this.previewsContainer.appendChild(e.previewElement),d=e.previewElement.querySelectorAll("[data-dz-name]"),o=0,l=d.length;l>o;o++)n=d[o],n.textContent=this._renameFilename(e.name);for(p=e.previewElement.querySelectorAll("[data-dz-size]"),a=0,u=p.length;u>a;a++)n=p[a],n.innerHTML=this.filesize(e.size);for(this.options.addRemoveLinks&&(e._removeLink=t.createElement('<a class="dz-remove" href="javascript:undefined;" data-dz-remove>'+this.options.dictRemoveFile+"</a>"),e.previewElement.appendChild(e._removeLink)),i=function(n){return function(i){return i.preventDefault(),i.stopPropagation(),e.status===t.UPLOADING?t.confirm(n.options.dictCancelUploadConfirmation,function(){return n.removeFile(e)}):n.options.dictRemoveFileConfirmation?t.confirm(n.options.dictRemoveFileConfirmation,function(){return n.removeFile(e)}):n.removeFile(e)}}(this),h=e.previewElement.querySelectorAll("[data-dz-remove]"),f=[],s=0,c=h.length;c>s;s++)r=h[s],f.push(r.addEventListener("click",i));return f}},removedfile:function(e){var t;return e.previewElement&&null!=(t=e.previewElement)&&t.parentNode.removeChild(e.previewElement),this._updateMaxFilesReachedClass()},thumbnail:function(e,t){var n,i,r,o;if(e.previewElement){for(e.previewElement.classList.remove("dz-file-preview"),o=e.previewElement.querySelectorAll("[data-dz-thumbnail]"),i=0,r=o.length;r>i;i++)n=o[i],n.alt=e.name,n.src=t;return setTimeout(function(t){return function(){return e.previewElement.classList.add("dz-image-preview")}}(this),1)}},error:function(e,t){var n,i,r,o,a;if(e.previewElement){for(e.previewElement.classList.add("dz-error"),"String"!=typeof t&&t.error&&(t=t.error),o=e.previewElement.querySelectorAll("[data-dz-errormessage]"),a=[],i=0,r=o.length;r>i;i++)n=o[i],a.push(n.textContent=t);return a}},errormultiple:l,processing:function(e){return e.previewElement&&(e.previewElement.classList.add("dz-processing"),e._removeLink)?e._removeLink.textContent=this.options.dictCancelUpload:void 0},processingmultiple:l,uploadprogress:function(e,t,n){var i,r,o,a,s;if(e.previewElement){for(a=e.previewElement.querySelectorAll("[data-dz-uploadprogress]"),s=[],r=0,o=a.length;o>r;r++)i=a[r],"PROGRESS"===i.nodeName?s.push(i.value=t):s.push(i.style.width=""+t+"%");return s}},totaluploadprogress:l,sending:l,sendingmultiple:l,success:function(e){return e.previewElement?e.previewElement.classList.add("dz-success"):void 0},successmultiple:l,canceled:function(e){return this.emit("error",e,"Upload canceled.")},canceledmultiple:l,complete:function(e){return e._removeLink&&(e._removeLink.textContent=this.options.dictRemoveFile),e.previewElement?e.previewElement.classList.add("dz-complete"):void 0},completemultiple:l,maxfilesexceeded:l,maxfilesreached:l,queuecomplete:l,addedfiles:l,previewTemplate:'<div class="dz-preview dz-file-preview">\n  <div class="dz-image"><img data-dz-thumbnail /></div>\n  <div class="dz-details">\n    <div class="dz-size"><span data-dz-size></span></div>\n    <div class="dz-filename"><span data-dz-name></span></div>\n  </div>\n  <div class="dz-progress"><span class="dz-upload" data-dz-uploadprogress></span></div>\n  <div class="dz-error-message"><span data-dz-errormessage></span></div>\n  <div class="dz-success-mark">\n    <svg width="54px" height="54px" viewBox="0 0 54 54" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" xmlns:sketch="http://www.bohemiancoding.com/sketch/ns">\n      <title>Check</title>\n      <defs></defs>\n      <g id="Page-1" stroke="none" stroke-width="1" fill="none" fill-rule="evenodd" sketch:type="MSPage">\n        <path d="M23.5,31.8431458 L17.5852419,25.9283877 C16.0248253,24.3679711 13.4910294,24.366835 11.9289322,25.9289322 C10.3700136,27.4878508 10.3665912,30.0234455 11.9283877,31.5852419 L20.4147581,40.0716123 C20.5133999,40.1702541 20.6159315,40.2626649 20.7218615,40.3488435 C22.2835669,41.8725651 24.794234,41.8626202 26.3461564,40.3106978 L43.3106978,23.3461564 C44.8771021,21.7797521 44.8758057,19.2483887 43.3137085,17.6862915 C41.7547899,16.1273729 39.2176035,16.1255422 37.6538436,17.6893022 L23.5,31.8431458 Z M27,53 C41.3594035,53 53,41.3594035 53,27 C53,12.6405965 41.3594035,1 27,1 C12.6405965,1 1,12.6405965 1,27 C1,41.3594035 12.6405965,53 27,53 Z" id="Oval-2" stroke-opacity="0.198794158" stroke="#747474" fill-opacity="0.816519475" fill="#FFFFFF" sketch:type="MSShapeGroup"></path>\n      </g>\n    </svg>\n  </div>\n  <div class="dz-error-mark">\n    <svg width="54px" height="54px" viewBox="0 0 54 54" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" xmlns:sketch="http://www.bohemiancoding.com/sketch/ns">\n      <title>Error</title>\n      <defs></defs>\n      <g id="Page-1" stroke="none" stroke-width="1" fill="none" fill-rule="evenodd" sketch:type="MSPage">\n        <g id="Check-+-Oval-2" sketch:type="MSLayerGroup" stroke="#747474" stroke-opacity="0.198794158" fill="#FFFFFF" fill-opacity="0.816519475">\n          <path d="M32.6568542,29 L38.3106978,23.3461564 C39.8771021,21.7797521 39.8758057,19.2483887 38.3137085,17.6862915 C36.7547899,16.1273729 34.2176035,16.1255422 32.6538436,17.6893022 L27,23.3431458 L21.3461564,17.6893022 C19.7823965,16.1255422 17.2452101,16.1273729 15.6862915,17.6862915 C14.1241943,19.2483887 14.1228979,21.7797521 15.6893022,23.3461564 L21.3431458,29 L15.6893022,34.6538436 C14.1228979,36.2202479 14.1241943,38.7516113 15.6862915,40.3137085 C17.2452101,41.8726271 19.7823965,41.8744578 21.3461564,40.3106978 L27,34.6568542 L32.6538436,40.3106978 C34.2176035,41.8744578 36.7547899,41.8726271 38.3137085,40.3137085 C39.8758057,38.7516113 39.8771021,36.2202479 38.3106978,34.6538436 L32.6568542,29 Z M27,53 C41.3594035,53 53,41.3594035 53,27 C53,12.6405965 41.3594035,1 27,1 C12.6405965,1 1,12.6405965 1,27 C1,41.3594035 12.6405965,53 27,53 Z" id="Oval-2" sketch:type="MSShapeGroup"></path>\n        </g>\n      </g>\n    </svg>\n  </div>\n</div>'},n=function(){var e,t,n,i,r,o,a;for(i=arguments[0],n=2<=arguments.length?c.call(arguments,1):[],o=0,a=n.length;a>o;o++){t=n[o];for(e in t)r=t[e],i[e]=r}return i},t.prototype.getAcceptedFiles=function(){var e,t,n,i,r;for(i=this.files,r=[],t=0,n=i.length;n>t;t++)e=i[t],e.accepted&&r.push(e);return r},t.prototype.getRejectedFiles=function(){var e,t,n,i,r;for(i=this.files,r=[],t=0,n=i.length;n>t;t++)e=i[t],e.accepted||r.push(e);return r},t.prototype.getFilesWithStatus=function(e){var t,n,i,r,o;for(r=this.files,o=[],n=0,i=r.length;i>n;n++)t=r[n],t.status===e&&o.push(t);return o},t.prototype.getQueuedFiles=function(){return this.getFilesWithStatus(t.QUEUED)},t.prototype.getUploadingFiles=function(){return this.getFilesWithStatus(t.UPLOADING)},t.prototype.getAddedFiles=function(){return this.getFilesWithStatus(t.ADDED)},t.prototype.getActiveFiles=function(){var e,n,i,r,o;for(r=this.files,o=[],n=0,i=r.length;i>n;n++)e=r[n],e.status!==t.UPLOADING&&e.status!==t.QUEUED||o.push(e);return o},t.prototype.init=function(){var e,n,i,r,o,a,s;for("form"===this.element.tagName&&this.element.setAttribute("enctype","multipart/form-data"),this.element.classList.contains("dropzone")&&!this.element.querySelector(".dz-message")&&this.element.appendChild(t.createElement('<div class="dz-default dz-message"><span>'+this.options.dictDefaultMessage+"</span></div>")),this.clickableElements.length&&(i=function(e){return function(){return e.hiddenFileInput&&e.hiddenFileInput.parentNode.removeChild(e.hiddenFileInput),e.hiddenFileInput=document.createElement("input"),e.hiddenFileInput.setAttribute("type","file"),(null==e.options.maxFiles||e.options.maxFiles>1)&&e.hiddenFileInput.setAttribute("multiple","multiple"),e.hiddenFileInput.className="dz-hidden-input",null!=e.options.acceptedFiles&&e.hiddenFileInput.setAttribute("accept",e.options.acceptedFiles),null!=e.options.capture&&e.hiddenFileInput.setAttribute("capture",e.options.capture),e.hiddenFileInput.style.visibility="hidden",e.hiddenFileInput.style.position="absolute",e.hiddenFileInput.style.top="0",e.hiddenFileInput.style.left="0",e.hiddenFileInput.style.height="0",e.hiddenFileInput.style.width="0",document.querySelector(e.options.hiddenInputContainer).appendChild(e.hiddenFileInput),e.hiddenFileInput.addEventListener("change",function(){var t,n,r,o;if(n=e.hiddenFileInput.files,n.length)for(r=0,o=n.length;o>r;r++)t=n[r],e.addFile(t);return e.emit("addedfiles",n),i()})}}(this))(),this.URL=null!=(a=window.URL)?a:window.webkitURL,s=this.events,r=0,o=s.length;o>r;r++)e=s[r],this.on(e,this.options[e]);return this.on("uploadprogress",function(e){return function(){return e.updateTotalUploadProgress()}}(this)),this.on("removedfile",function(e){return function(){return e.updateTotalUploadProgress()}}(this)),this.on("canceled",function(e){return function(t){return e.emit("complete",t)}}(this)),this.on("complete",function(e){return function(t){return 0===e.getAddedFiles().length&&0===e.getUploadingFiles().length&&0===e.getQueuedFiles().length?setTimeout(function(){return e.emit("queuecomplete")},0):void 0}}(this)),n=function(e){return e.stopPropagation(),e.preventDefault?e.preventDefault():e.returnValue=!1},this.listeners=[{element:this.element,events:{dragstart:function(e){return function(t){return e.emit("dragstart",t)}}(this),dragenter:function(e){return function(t){return n(t),e.emit("dragenter",t)}}(this),dragover:function(e){return function(t){var i;try{i=t.dataTransfer.effectAllowed}catch(r){}return t.dataTransfer.dropEffect="move"===i||"linkMove"===i?"move":"copy",n(t),e.emit("dragover",t)}}(this),dragleave:function(e){return function(t){return e.emit("dragleave",t)}}(this),drop:function(e){return function(t){return n(t),e.drop(t)}}(this),dragend:function(e){return function(t){return e.emit("dragend",t)}}(this)}}],this.clickableElements.forEach(function(e){return function(n){return e.listeners.push({element:n,events:{click:function(i){return(n!==e.element||i.target===e.element||t.elementInside(i.target,e.element.querySelector(".dz-message")))&&e.hiddenFileInput.click(),!0}}})}}(this)),this.enable(),this.options.init.call(this)},t.prototype.destroy=function(){var e;return this.disable(),this.removeAllFiles(!0),(null!=(e=this.hiddenFileInput)?e.parentNode:void 0)&&(this.hiddenFileInput.parentNode.removeChild(this.hiddenFileInput),this.hiddenFileInput=null),delete this.element.dropzone,t.instances.splice(t.instances.indexOf(this),1)},t.prototype.updateTotalUploadProgress=function(){var e,t,n,i,r,o,a,s;if(i=0,n=0,e=this.getActiveFiles(),e.length){for(s=this.getActiveFiles(),o=0,a=s.length;a>o;o++)t=s[o],i+=t.upload.bytesSent,n+=t.upload.total;r=100*i/n}else r=100;return this.emit("totaluploadprogress",r,n,i)},t.prototype._getParamName=function(e){return"function"==typeof this.options.paramName?this.options.paramName(e):""+this.options.paramName+(this.options.uploadMultiple?"["+e+"]":"")},t.prototype._renameFilename=function(e){return"function"!=typeof this.options.renameFilename?e:this.options.renameFilename(e)},t.prototype.getFallbackForm=function(){var e,n,i,r;return(e=this.getExistingFallback())?e:(i='<div class="dz-fallback">',this.options.dictFallbackText&&(i+="<p>"+this.options.dictFallbackText+"</p>"),i+='<input type="file" name="'+this._getParamName(0)+'" '+(this.options.uploadMultiple?'multiple="multiple"':void 0)+' /><input type="submit" value="Upload!"></div>',n=t.createElement(i),"FORM"!==this.element.tagName?(r=t.createElement('<form action="'+this.options.url+'" enctype="multipart/form-data" method="'+this.options.method+'"></form>'),r.appendChild(n)):(this.element.setAttribute("enctype","multipart/form-data"),this.element.setAttribute("method",this.options.method)),null!=r?r:n)},t.prototype.getExistingFallback=function(){var e,t,n,i,r,o;for(t=function(e){var t,n,i;for(n=0,i=e.length;i>n;n++)if(t=e[n],/(^| )fallback($| )/.test(t.className))return t},o=["div","form"],i=0,r=o.length;r>i;i++)if(n=o[i],e=t(this.element.getElementsByTagName(n)))return e},t.prototype.setupEventListeners=function(){var e,t,n,i,r,o,a;for(o=this.listeners,a=[],i=0,r=o.length;r>i;i++)e=o[i],a.push(function(){var i,r;i=e.events,r=[];for(t in i)n=i[t],r.push(e.element.addEventListener(t,n,!1));return r}());return a},t.prototype.removeEventListeners=function(){var e,t,n,i,r,o,a;for(o=this.listeners,a=[],i=0,r=o.length;r>i;i++)e=o[i],a.push(function(){var i,r;i=e.events,r=[];for(t in i)n=i[t],r.push(e.element.removeEventListener(t,n,!1));return r}());return a},t.prototype.disable=function(){var e,t,n,i,r;for(this.clickableElements.forEach(function(e){return e.classList.remove("dz-clickable")}),this.removeEventListeners(),i=this.files,r=[],t=0,n=i.length;n>t;t++)e=i[t],r.push(this.cancelUpload(e));return r},t.prototype.enable=function(){return this.clickableElements.forEach(function(e){return e.classList.add("dz-clickable")}),this.setupEventListeners()},t.prototype.filesize=function(e){var t,n,i,r,o,a,s,l;if(i=0,r="b",e>0){for(a=["TB","GB","MB","KB","b"],n=s=0,l=a.length;l>s;n=++s)if(o=a[n],t=Math.pow(this.options.filesizeBase,4-n)/10,e>=t){i=e/Math.pow(this.options.filesizeBase,4-n),r=o;break}i=Math.round(10*i)/10}return"<strong>"+i+"</strong> "+r},t.prototype._updateMaxFilesReachedClass=function(){return null!=this.options.maxFiles&&this.getAcceptedFiles().length>=this.options.maxFiles?(this.getAcceptedFiles().length===this.options.maxFiles&&this.emit("maxfilesreached",this.files),this.element.classList.add("dz-max-files-reached")):this.element.classList.remove("dz-max-files-reached")},t.prototype.drop=function(e){var t,n;e.dataTransfer&&(this.emit("drop",e),t=e.dataTransfer.files,this.emit("addedfiles",t),t.length&&(n=e.dataTransfer.items,n&&n.length&&null!=n[0].webkitGetAsEntry?this._addFilesFromItems(n):this.handleFiles(t)))},t.prototype.paste=function(e){var t,n;if(null!=(null!=e&&null!=(n=e.clipboardData)?n.items:void 0))return this.emit("paste",e),t=e.clipboardData.items,t.length?this._addFilesFromItems(t):void 0},t.prototype.handleFiles=function(e){var t,n,i,r;for(r=[],n=0,i=e.length;i>n;n++)t=e[n],r.push(this.addFile(t));return r},t.prototype._addFilesFromItems=function(e){var t,n,i,r,o;for(o=[],i=0,r=e.length;r>i;i++)n=e[i],null!=n.webkitGetAsEntry&&(t=n.webkitGetAsEntry())?t.isFile?o.push(this.addFile(n.getAsFile())):t.isDirectory?o.push(this._addFilesFromDirectory(t,t.name)):o.push(void 0):null!=n.getAsFile&&(null==n.kind||"file"===n.kind)?o.push(this.addFile(n.getAsFile())):o.push(void 0);return o},t.prototype._addFilesFromDirectory=function(e,t){var n,i,r;return n=e.createReader(),i=function(e){return"undefined"!=typeof console&&null!==console&&"function"==typeof console.log?console.log(e):void 0},(r=function(e){return function(){return n.readEntries(function(n){var i,o,a;if(n.length>0){for(o=0,a=n.length;a>o;o++)i=n[o],i.isFile?i.file(function(n){return e.options.ignoreHiddenFiles&&"."===n.name.substring(0,1)?void 0:(n.fullPath=""+t+"/"+n.name,e.addFile(n))}):i.isDirectory&&e._addFilesFromDirectory(i,""+t+"/"+i.name);r()}return null},i)}}(this))()},t.prototype.accept=function(e,n){return e.size>1024*this.options.maxFilesize*1024?n(this.options.dictFileTooBig.replace("{{filesize}}",Math.round(e.size/1024/10.24)/100).replace("{{maxFilesize}}",this.options.maxFilesize)):t.isValidFile(e,this.options.acceptedFiles)?null!=this.options.maxFiles&&this.getAcceptedFiles().length>=this.options.maxFiles?(n(this.options.dictMaxFilesExceeded.replace("{{maxFiles}}",this.options.maxFiles)),this.emit("maxfilesexceeded",e)):this.options.accept.call(this,e,n):n(this.options.dictInvalidFileType)},t.prototype.addFile=function(e){return e.upload={progress:0,total:e.size,bytesSent:0},this.files.push(e),e.status=t.ADDED,this.emit("addedfile",e),this._enqueueThumbnail(e),this.accept(e,function(t){return function(n){return n?(e.accepted=!1,t._errorProcessing([e],n)):(e.accepted=!0,t.options.autoQueue&&t.enqueueFile(e)),t._updateMaxFilesReachedClass()}}(this))},t.prototype.enqueueFiles=function(e){var t,n,i;for(n=0,i=e.length;i>n;n++)t=e[n],this.enqueueFile(t);return null},t.prototype.enqueueFile=function(e){if(e.status!==t.ADDED||e.accepted!==!0)throw new Error("This file can't be queued because it has already been processed or was rejected.");return e.status=t.QUEUED,this.options.autoProcessQueue?setTimeout(function(e){return function(){return e.processQueue()}}(this),0):void 0},t.prototype._thumbnailQueue=[],t.prototype._processingThumbnail=!1,t.prototype._enqueueThumbnail=function(e){return this.options.createImageThumbnails&&e.type.match(/image.*/)&&e.size<=1024*this.options.maxThumbnailFilesize*1024?(this._thumbnailQueue.push(e),setTimeout(function(e){return function(){return e._processThumbnailQueue()}}(this),0)):void 0},t.prototype._processThumbnailQueue=function(){return this._processingThumbnail||0===this._thumbnailQueue.length?void 0:(this._processingThumbnail=!0,this.createThumbnail(this._thumbnailQueue.shift(),function(e){return function(){return e._processingThumbnail=!1,e._processThumbnailQueue()}}(this)))},t.prototype.removeFile=function(e){return e.status===t.UPLOADING&&this.cancelUpload(e),this.files=u(this.files,e),this.emit("removedfile",e),0===this.files.length?this.emit("reset"):void 0},t.prototype.removeAllFiles=function(e){var n,i,r,o;for(null==e&&(e=!1),o=this.files.slice(),i=0,r=o.length;r>i;i++)n=o[i],(n.status!==t.UPLOADING||e)&&this.removeFile(n);return null},t.prototype.createThumbnail=function(e,t){var n;return n=new FileReader,n.onload=function(i){return function(){return"image/svg+xml"===e.type?(i.emit("thumbnail",e,n.result),void(null!=t&&t())):i.createThumbnailFromUrl(e,n.result,t)}}(this),n.readAsDataURL(e)},t.prototype.createThumbnailFromUrl=function(e,t,n,i){var r;return r=document.createElement("img"),i&&(r.crossOrigin=i),r.onload=function(t){return function(){var i,o,a,l,u,c,d,p;return e.width=r.width,e.height=r.height,a=t.options.resize.call(t,e),null==a.trgWidth&&(a.trgWidth=a.optWidth),null==a.trgHeight&&(a.trgHeight=a.optHeight),i=document.createElement("canvas"),o=i.getContext("2d"),i.width=a.trgWidth,i.height=a.trgHeight,s(o,r,null!=(u=a.srcX)?u:0,null!=(c=a.srcY)?c:0,a.srcWidth,a.srcHeight,null!=(d=a.trgX)?d:0,null!=(p=a.trgY)?p:0,a.trgWidth,a.trgHeight),l=i.toDataURL("image/png"),t.emit("thumbnail",e,l),null!=n?n():void 0}}(this),null!=n&&(r.onerror=n),r.src=t},t.prototype.processQueue=function(){var e,t,n,i;if(t=this.options.parallelUploads,n=this.getUploadingFiles().length,e=n,!(n>=t)&&(i=this.getQueuedFiles(),i.length>0)){if(this.options.uploadMultiple)return this.processFiles(i.slice(0,t-n));for(;t>e;){if(!i.length)return;this.processFile(i.shift()),e++}}},t.prototype.processFile=function(e){return this.processFiles([e])},t.prototype.processFiles=function(e){var n,i,r;for(i=0,r=e.length;r>i;i++)n=e[i],n.processing=!0,n.status=t.UPLOADING,this.emit("processing",n);return this.options.uploadMultiple&&this.emit("processingmultiple",e),this.uploadFiles(e)},t.prototype._getFilesWithXhr=function(e){var t,n;return n=function(){var n,i,r,o;for(r=this.files,o=[],n=0,i=r.length;i>n;n++)t=r[n],t.xhr===e&&o.push(t);return o}.call(this)},t.prototype.cancelUpload=function(e){var n,i,r,o,a,s,l;if(e.status===t.UPLOADING){for(i=this._getFilesWithXhr(e.xhr),r=0,a=i.length;a>r;r++)n=i[r],n.status=t.CANCELED;for(e.xhr.abort(),o=0,s=i.length;s>o;o++)n=i[o],this.emit("canceled",n);this.options.uploadMultiple&&this.emit("canceledmultiple",i)}else(l=e.status)!==t.ADDED&&l!==t.QUEUED||(e.status=t.CANCELED,this.emit("canceled",e),this.options.uploadMultiple&&this.emit("canceledmultiple",[e]));
return this.options.autoProcessQueue?this.processQueue():void 0},r=function(){var e,t;return t=arguments[0],e=2<=arguments.length?c.call(arguments,1):[],"function"==typeof t?t.apply(this,e):t},t.prototype.uploadFile=function(e){return this.uploadFiles([e])},t.prototype.uploadFiles=function(e){var i,o,a,s,l,u,c,d,p,h,f,g,v,m,y,b,w,x,_,k,C,T,D,S,E,A,M,O,I,N,F,P,$,L;for(_=new XMLHttpRequest,k=0,S=e.length;S>k;k++)i=e[k],i.xhr=_;g=r(this.options.method,e),w=r(this.options.url,e),_.open(g,w,!0),_.withCredentials=!!this.options.withCredentials,y=null,a=function(t){return function(){var n,r,o;for(o=[],n=0,r=e.length;r>n;n++)i=e[n],o.push(t._errorProcessing(e,y||t.options.dictResponseError.replace("{{statusCode}}",_.status),_));return o}}(this),b=function(t){return function(n){var r,o,a,s,l,u,c,d,p;if(null!=n)for(o=100*n.loaded/n.total,a=0,u=e.length;u>a;a++)i=e[a],i.upload={progress:o,total:n.total,bytesSent:n.loaded};else{for(r=!0,o=100,s=0,c=e.length;c>s;s++)i=e[s],100===i.upload.progress&&i.upload.bytesSent===i.upload.total||(r=!1),i.upload.progress=o,i.upload.bytesSent=i.upload.total;if(r)return}for(p=[],l=0,d=e.length;d>l;l++)i=e[l],p.push(t.emit("uploadprogress",i,o,i.upload.bytesSent));return p}}(this),_.onload=function(n){return function(i){var r;if(e[0].status!==t.CANCELED&&4===_.readyState){if(y=_.responseText,_.getResponseHeader("content-type")&&~_.getResponseHeader("content-type").indexOf("application/json"))try{y=JSON.parse(y)}catch(o){i=o,y="Invalid JSON response from server."}return b(),200<=(r=_.status)&&300>r?n._finished(e,y,i):a()}}}(this),_.onerror=function(n){return function(){return e[0].status!==t.CANCELED?a():void 0}}(this),m=null!=(I=_.upload)?I:_,m.onprogress=b,u={Accept:"application/json","Cache-Control":"no-cache","X-Requested-With":"XMLHttpRequest"},this.options.headers&&n(u,this.options.headers);for(s in u)l=u[s],l&&_.setRequestHeader(s,l);if(o=new FormData,this.options.params){N=this.options.params;for(f in N)x=N[f],o.append(f,x)}for(C=0,E=e.length;E>C;C++)i=e[C],this.emit("sending",i,_,o);if(this.options.uploadMultiple&&this.emit("sendingmultiple",e,_,o),"FORM"===this.element.tagName)for(F=this.element.querySelectorAll("input, textarea, select, button"),T=0,A=F.length;A>T;T++)if(d=F[T],p=d.getAttribute("name"),h=d.getAttribute("type"),"SELECT"===d.tagName&&d.hasAttribute("multiple"))for(P=d.options,D=0,M=P.length;M>D;D++)v=P[D],v.selected&&o.append(p,v.value);else(!h||"checkbox"!==($=h.toLowerCase())&&"radio"!==$||d.checked)&&o.append(p,d.value);for(c=O=0,L=e.length-1;L>=0?L>=O:O>=L;c=L>=0?++O:--O)o.append(this._getParamName(c),e[c],this._renameFilename(e[c].name));return this.submitRequest(_,o,e)},t.prototype.submitRequest=function(e,t,n){return e.send(t)},t.prototype._finished=function(e,n,i){var r,o,a;for(o=0,a=e.length;a>o;o++)r=e[o],r.status=t.SUCCESS,this.emit("success",r,n,i),this.emit("complete",r);return this.options.uploadMultiple&&(this.emit("successmultiple",e,n,i),this.emit("completemultiple",e)),this.options.autoProcessQueue?this.processQueue():void 0},t.prototype._errorProcessing=function(e,n,i){var r,o,a;for(o=0,a=e.length;a>o;o++)r=e[o],r.status=t.ERROR,this.emit("error",r,n,i),this.emit("complete",r);return this.options.uploadMultiple&&(this.emit("errormultiple",e,n,i),this.emit("completemultiple",e)),this.options.autoProcessQueue?this.processQueue():void 0},t}(i),n.version="4.3.0",n.options={},n.optionsForElement=function(e){return e.getAttribute("id")?n.options[r(e.getAttribute("id"))]:void 0},n.instances=[],n.forElement=function(e){if("string"==typeof e&&(e=document.querySelector(e)),null==(null!=e?e.dropzone:void 0))throw new Error("No Dropzone found for given element. This is probably because you're trying to access it before Dropzone had the time to initialize. Use the `init` option to setup any additional observers on your Dropzone.");return e.dropzone},n.autoDiscover=!0,n.discover=function(){var e,t,i,r,o,a;for(document.querySelectorAll?i=document.querySelectorAll(".dropzone"):(i=[],e=function(e){var t,n,r,o;for(o=[],n=0,r=e.length;r>n;n++)t=e[n],/(^| )dropzone($| )/.test(t.className)?o.push(i.push(t)):o.push(void 0);return o},e(document.getElementsByTagName("div")),e(document.getElementsByTagName("form"))),a=[],r=0,o=i.length;o>r;r++)t=i[r],n.optionsForElement(t)!==!1?a.push(new n(t)):a.push(void 0);return a},n.blacklistedBrowsers=[/opera.*Macintosh.*version\/12/i],n.isBrowserSupported=function(){var e,t,i,r,o;if(e=!0,window.File&&window.FileReader&&window.FileList&&window.Blob&&window.FormData&&document.querySelector)if("classList"in document.createElement("a"))for(o=n.blacklistedBrowsers,i=0,r=o.length;r>i;i++)t=o[i],t.test(navigator.userAgent)&&(e=!1);else e=!1;else e=!1;return e},u=function(e,t){var n,i,r,o;for(o=[],i=0,r=e.length;r>i;i++)n=e[i],n!==t&&o.push(n);return o},r=function(e){return e.replace(/[\-_](\w)/g,function(e){return e.charAt(1).toUpperCase()})},n.createElement=function(e){var t;return t=document.createElement("div"),t.innerHTML=e,t.childNodes[0]},n.elementInside=function(e,t){if(e===t)return!0;for(;e=e.parentNode;)if(e===t)return!0;return!1},n.getElement=function(e,t){var n;if("string"==typeof e?n=document.querySelector(e):null!=e.nodeType&&(n=e),null==n)throw new Error("Invalid `"+t+"` option provided. Please provide a CSS selector or a plain HTML element.");return n},n.getElements=function(e,t){var n,i,r,o,a,s,l,u;if(e instanceof Array){r=[];try{for(o=0,s=e.length;s>o;o++)i=e[o],r.push(this.getElement(i,t))}catch(c){n=c,r=null}}else if("string"==typeof e)for(r=[],u=document.querySelectorAll(e),a=0,l=u.length;l>a;a++)i=u[a],r.push(i);else null!=e.nodeType&&(r=[e]);if(null==r||!r.length)throw new Error("Invalid `"+t+"` option provided. Please provide a CSS selector, a plain HTML element or a list of those.");return r},n.confirm=function(e,t,n){return window.confirm(e)?t():null!=n?n():void 0},n.isValidFile=function(e,t){var n,i,r,o,a;if(!t)return!0;for(t=t.split(","),i=e.type,n=i.replace(/\/.*$/,""),o=0,a=t.length;a>o;o++)if(r=t[o],r=r.trim(),"."===r.charAt(0)){if(-1!==e.name.toLowerCase().indexOf(r.toLowerCase(),e.name.length-r.length))return!0}else if(/\/\*$/.test(r)){if(n===r.replace(/\/.*$/,""))return!0}else if(i===r)return!0;return!1},"undefined"!=typeof e&&null!==e&&(e.fn.dropzone=function(e){return this.each(function(){return new n(this,e)})}),"undefined"!=typeof t&&null!==t?t.exports=n:window.Dropzone=n,n.ADDED="added",n.QUEUED="queued",n.ACCEPTED=n.QUEUED,n.UPLOADING="uploading",n.PROCESSING=n.UPLOADING,n.CANCELED="canceled",n.ERROR="error",n.SUCCESS="success",a=function(e){var t,n,i,r,o,a,s,l,u,c;for(s=e.naturalWidth,a=e.naturalHeight,n=document.createElement("canvas"),n.width=1,n.height=a,i=n.getContext("2d"),i.drawImage(e,0,0),r=i.getImageData(0,0,1,a).data,c=0,o=a,l=a;l>c;)t=r[4*(l-1)+3],0===t?o=l:c=l,l=o+c>>1;return u=l/a,0===u?1:u},s=function(e,t,n,i,r,o,s,l,u,c){var d;return d=a(t),e.drawImage(t,n,i,r,o,s,l,u,c/d)},o=function(e,t){var n,i,r,o,a,s,l,u,c;if(r=!1,c=!0,i=e.document,u=i.documentElement,n=i.addEventListener?"addEventListener":"attachEvent",l=i.addEventListener?"removeEventListener":"detachEvent",s=i.addEventListener?"":"on",o=function(n){return"readystatechange"!==n.type||"complete"===i.readyState?(("load"===n.type?e:i)[l](s+n.type,o,!1),!r&&(r=!0)?t.call(e,n.type||n):void 0):void 0},a=function(){var e;try{u.doScroll("left")}catch(t){return e=t,void setTimeout(a,50)}return o("poll")},"complete"!==i.readyState){if(i.createEventObject&&u.doScroll){try{c=!e.frameElement}catch(d){}c&&a()}return i[n](s+"DOMContentLoaded",o,!1),i[n](s+"readystatechange",o,!1),e[n](s+"load",o,!1)}},n._autoDiscoverFunction=function(){return n.autoDiscover?n.discover():void 0},o(window,n._autoDiscoverFunction)}).call(this)}).call(t,n(1),n(3)(e))},function(e,t){e.exports=function(e){return e.webpackPolyfill||(e.deprecate=function(){},e.paths=[],e.children=[],e.webpackPolyfill=1),e}},function(e,t,n){var i,r;/**!
	 * Sortable
	 * @author	RubaXa   <trash@rubaxa.org>
	 * @license MIT
	 */
!function(o){"use strict";i=o,r="function"==typeof i?i.call(t,n,t,e):i,!(void 0!==r&&(e.exports=r))}(function(){"use strict";function e(e,t){if(!e||!e.nodeType||1!==e.nodeType)throw"Sortable: `el` must be HTMLElement, and not "+{}.toString.call(e);this.el=e,this.options=t=m({},t),e[L]=this;var n={group:Math.random(),sort:!0,disabled:!1,store:null,handle:null,scroll:!0,scrollSensitivity:30,scrollSpeed:10,draggable:/[uo]l/i.test(e.nodeName)?"li":">*",ghostClass:"sortable-ghost",chosenClass:"sortable-chosen",ignore:"a, img",filter:null,animation:0,setData:function(e,t){e.setData("Text",t.textContent)},dropBubble:!1,dragoverBubble:!1,dataIdAttr:"data-id",delay:0,forceFallback:!1,fallbackClass:"sortable-fallback",fallbackOnBody:!1};for(var i in n)!(i in t)&&(t[i]=n[i]);V(t);for(var o in this)"_"===o.charAt(0)&&(this[o]=this[o].bind(this));this.nativeDraggable=t.forceFallback?!1:z,r(e,"mousedown",this._onTapStart),r(e,"touchstart",this._onTapStart),this.nativeDraggable&&(r(e,"dragover",this),r(e,"dragenter",this)),B.push(this._onDragOver),t.store&&this.sort(t.store.get(this))}function t(e){x&&x.state!==e&&(s(x,"display",e?"none":""),!e&&x.state&&_.insertBefore(x,y),x.state=e)}function n(e,t,n){if(e){n=n||j,t=t.split(".");var i=t.shift().toUpperCase(),r=new RegExp("\\s("+t.join("|")+")(?=\\s)","g");do if(">*"===i&&e.parentNode===n||(""===i||e.nodeName.toUpperCase()==i)&&(!t.length||((" "+e.className+" ").match(r)||[]).length==t.length))return e;while(e!==n&&(e=e.parentNode))}return null}function i(e){e.dataTransfer&&(e.dataTransfer.dropEffect="move"),e.preventDefault()}function r(e,t,n){e.addEventListener(t,n,!1)}function o(e,t,n){e.removeEventListener(t,n,!1)}function a(e,t,n){if(e)if(e.classList)e.classList[n?"add":"remove"](t);else{var i=(" "+e.className+" ").replace($," ").replace(" "+t+" "," ");e.className=(i+(n?" "+t:"")).replace($," ")}}function s(e,t,n){var i=e&&e.style;if(i){if(void 0===n)return j.defaultView&&j.defaultView.getComputedStyle?n=j.defaultView.getComputedStyle(e,""):e.currentStyle&&(n=e.currentStyle),void 0===t?n:n[t];t in i||(t="-webkit-"+t),i[t]=n+("string"==typeof n?"":"px")}}function l(e,t,n){if(e){var i=e.getElementsByTagName(t),r=0,o=i.length;if(n)for(;o>r;r++)n(i[r],r);return i}return[]}function u(e,t,n,i,r,o,a){var s=j.createEvent("Event"),l=(e||t[L]).options,u="on"+n.charAt(0).toUpperCase()+n.substr(1);s.initEvent(n,!0,!0),s.to=t,s.from=r||t,s.item=i||t,s.clone=x,s.oldIndex=o,s.newIndex=a,t.dispatchEvent(s),l[u]&&l[u].call(e,s)}function c(e,t,n,i,r,o){var a,s,l=e[L],u=l.options.onMove;return a=j.createEvent("Event"),a.initEvent("move",!0,!0),a.to=t,a.from=e,a.dragged=n,a.draggedRect=i,a.related=r||t,a.relatedRect=o||t.getBoundingClientRect(),e.dispatchEvent(a),u&&(s=u.call(l,a)),s}function d(e){e.draggable=!1}function p(){W=!1}function h(e,t){var n=e.lastElementChild,i=n.getBoundingClientRect();return(t.clientY-(i.top+i.height)>5||t.clientX-(i.right+i.width)>5)&&n}function f(e){for(var t=e.tagName+e.className+e.src+e.href+e.textContent,n=t.length,i=0;n--;)i+=t.charCodeAt(n);return i.toString(36)}function g(e){var t=0;if(!e||!e.parentNode)return-1;for(;e&&(e=e.previousElementSibling);)"TEMPLATE"!==e.nodeName.toUpperCase()&&t++;return t}function v(e,t){var n,i;return function(){void 0===n&&(n=arguments,i=this,setTimeout(function(){1===n.length?e.call(i,n[0]):e.apply(i,n),n=void 0},t))}}function m(e,t){if(e&&t)for(var n in t)t.hasOwnProperty(n)&&(e[n]=t[n]);return e}var y,b,w,x,_,k,C,T,D,S,E,A,M,O,I,N,F,P={},$=/\s+/g,L="Sortable"+(new Date).getTime(),q=window,j=q.document,R=q.parseInt,z=!!("draggable"in j.createElement("div")),H=function(e){return e=j.createElement("x"),e.style.cssText="pointer-events:auto","auto"===e.style.pointerEvents}(),W=!1,Y=Math.abs,B=([].slice,[]),U=v(function(e,t,n){if(n&&t.scroll){var i,r,o,a,s=t.scrollSensitivity,l=t.scrollSpeed,u=e.clientX,c=e.clientY,d=window.innerWidth,p=window.innerHeight;if(T!==n&&(C=t.scroll,T=n,C===!0)){C=n;do if(C.offsetWidth<C.scrollWidth||C.offsetHeight<C.scrollHeight)break;while(C=C.parentNode)}C&&(i=C,r=C.getBoundingClientRect(),o=(Y(r.right-u)<=s)-(Y(r.left-u)<=s),a=(Y(r.bottom-c)<=s)-(Y(r.top-c)<=s)),o||a||(o=(s>=d-u)-(s>=u),a=(s>=p-c)-(s>=c),(o||a)&&(i=q)),P.vx===o&&P.vy===a&&P.el===i||(P.el=i,P.vx=o,P.vy=a,clearInterval(P.pid),i&&(P.pid=setInterval(function(){i===q?q.scrollTo(q.pageXOffset+o*l,q.pageYOffset+a*l):(a&&(i.scrollTop+=a*l),o&&(i.scrollLeft+=o*l))},24)))}},30),V=function(e){var t=e.group;t&&"object"==typeof t||(t=e.group={name:t}),["pull","put"].forEach(function(e){e in t||(t[e]=!0)}),e.groups=" "+t.name+(t.put.join?" "+t.put.join(" "):"")+" "};return e.prototype={constructor:e,_onTapStart:function(e){var t=this,i=this.el,r=this.options,o=e.type,a=e.touches&&e.touches[0],s=(a||e).target,l=s,c=r.filter;if(!("mousedown"===o&&0!==e.button||r.disabled)&&(s=n(s,r.draggable,i))){if(A=g(s),"function"==typeof c){if(c.call(this,e,s,this))return u(t,l,"filter",s,i,A),void e.preventDefault()}else if(c&&(c=c.split(",").some(function(e){return e=n(l,e.trim(),i),e?(u(t,e,"filter",s,i,A),!0):void 0})))return void e.preventDefault();r.handle&&!n(l,r.handle,i)||this._prepareDragStart(e,a,s)}},_prepareDragStart:function(e,t,n){var i,o=this,s=o.el,u=o.options,c=s.ownerDocument;n&&!y&&n.parentNode===s&&(I=e,_=s,y=n,b=y.parentNode,k=y.nextSibling,O=u.group,i=function(){o._disableDelayedDrag(),y.draggable=!0,a(y,o.options.chosenClass,!0),o._triggerDragStart(t)},u.ignore.split(",").forEach(function(e){l(y,e.trim(),d)}),r(c,"mouseup",o._onDrop),r(c,"touchend",o._onDrop),r(c,"touchcancel",o._onDrop),u.delay?(r(c,"mouseup",o._disableDelayedDrag),r(c,"touchend",o._disableDelayedDrag),r(c,"touchcancel",o._disableDelayedDrag),r(c,"mousemove",o._disableDelayedDrag),r(c,"touchmove",o._disableDelayedDrag),o._dragStartTimer=setTimeout(i,u.delay)):i())},_disableDelayedDrag:function(){var e=this.el.ownerDocument;clearTimeout(this._dragStartTimer),o(e,"mouseup",this._disableDelayedDrag),o(e,"touchend",this._disableDelayedDrag),o(e,"touchcancel",this._disableDelayedDrag),o(e,"mousemove",this._disableDelayedDrag),o(e,"touchmove",this._disableDelayedDrag)},_triggerDragStart:function(e){e?(I={target:y,clientX:e.clientX,clientY:e.clientY},this._onDragStart(I,"touch")):this.nativeDraggable?(r(y,"dragend",this),r(_,"dragstart",this._onDragStart)):this._onDragStart(I,!0);try{j.selection?j.selection.empty():window.getSelection().removeAllRanges()}catch(t){}},_dragStarted:function(){_&&y&&(a(y,this.options.ghostClass,!0),e.active=this,u(this,_,"start",y,_,A))},_emulateDragOver:function(){if(N){if(this._lastX===N.clientX&&this._lastY===N.clientY)return;this._lastX=N.clientX,this._lastY=N.clientY,H||s(w,"display","none");var e=j.elementFromPoint(N.clientX,N.clientY),t=e,n=" "+this.options.group.name,i=B.length;if(t)do{if(t[L]&&t[L].options.groups.indexOf(n)>-1){for(;i--;)B[i]({clientX:N.clientX,clientY:N.clientY,target:e,rootEl:t});break}e=t}while(t=t.parentNode);H||s(w,"display","")}},_onTouchMove:function(t){if(I){e.active||this._dragStarted(),this._appendGhost();var n=t.touches?t.touches[0]:t,i=n.clientX-I.clientX,r=n.clientY-I.clientY,o=t.touches?"translate3d("+i+"px,"+r+"px,0)":"translate("+i+"px,"+r+"px)";F=!0,N=n,s(w,"webkitTransform",o),s(w,"mozTransform",o),s(w,"msTransform",o),s(w,"transform",o),t.preventDefault()}},_appendGhost:function(){if(!w){var e,t=y.getBoundingClientRect(),n=s(y),i=this.options;w=y.cloneNode(!0),a(w,i.ghostClass,!1),a(w,i.fallbackClass,!0),s(w,"top",t.top-R(n.marginTop,10)),s(w,"left",t.left-R(n.marginLeft,10)),s(w,"width",t.width),s(w,"height",t.height),s(w,"opacity","0.8"),s(w,"position","fixed"),s(w,"zIndex","100000"),s(w,"pointerEvents","none"),i.fallbackOnBody&&j.body.appendChild(w)||_.appendChild(w),e=w.getBoundingClientRect(),s(w,"width",2*t.width-e.width),s(w,"height",2*t.height-e.height)}},_onDragStart:function(e,t){var n=e.dataTransfer,i=this.options;this._offUpEvents(),"clone"==O.pull&&(x=y.cloneNode(!0),s(x,"display","none"),_.insertBefore(x,y)),t?("touch"===t?(r(j,"touchmove",this._onTouchMove),r(j,"touchend",this._onDrop),r(j,"touchcancel",this._onDrop)):(r(j,"mousemove",this._onTouchMove),r(j,"mouseup",this._onDrop)),this._loopId=setInterval(this._emulateDragOver,50)):(n&&(n.effectAllowed="move",i.setData&&i.setData.call(this,n,y)),r(j,"drop",this),setTimeout(this._dragStarted,0))},_onDragOver:function(e){var i,r,o,a=this.el,l=this.options,u=l.group,d=u.put,f=O===u,g=l.sort;if(void 0!==e.preventDefault&&(e.preventDefault(),!l.dragoverBubble&&e.stopPropagation()),F=!0,O&&!l.disabled&&(f?g||(o=!_.contains(y)):O.pull&&d&&(O.name===u.name||d.indexOf&&~d.indexOf(O.name)))&&(void 0===e.rootEl||e.rootEl===this.el)){if(U(e,l,this.el),W)return;if(i=n(e.target,l.draggable,a),r=y.getBoundingClientRect(),o)return t(!0),void(x||k?_.insertBefore(y,x||k):g||_.appendChild(y));if(0===a.children.length||a.children[0]===w||a===e.target&&(i=h(a,e))){if(i){if(i.animated)return;m=i.getBoundingClientRect()}t(f),c(_,a,y,r,i,m)!==!1&&(y.contains(a)||(a.appendChild(y),b=a),this._animate(r,y),i&&this._animate(m,i))}else if(i&&!i.animated&&i!==y&&void 0!==i.parentNode[L]){D!==i&&(D=i,S=s(i),E=s(i.parentNode));var v,m=i.getBoundingClientRect(),C=m.right-m.left,T=m.bottom-m.top,A=/left|right|inline/.test(S.cssFloat+S.display)||"flex"==E.display&&0===E["flex-direction"].indexOf("row"),M=i.offsetWidth>y.offsetWidth,I=i.offsetHeight>y.offsetHeight,N=(A?(e.clientX-m.left)/C:(e.clientY-m.top)/T)>.5,P=i.nextElementSibling,$=c(_,a,y,r,i,m);if($!==!1){if(W=!0,setTimeout(p,30),t(f),1===$||-1===$)v=1===$;else if(A){var q=y.offsetTop,j=i.offsetTop;v=q===j?i.previousElementSibling===y&&!M||N&&M:j>q}else v=P!==y&&!I||N&&I;y.contains(a)||(v&&!P?a.appendChild(y):i.parentNode.insertBefore(y,v?P:i)),b=y.parentNode,this._animate(r,y),this._animate(m,i)}}}},_animate:function(e,t){var n=this.options.animation;if(n){var i=t.getBoundingClientRect();s(t,"transition","none"),s(t,"transform","translate3d("+(e.left-i.left)+"px,"+(e.top-i.top)+"px,0)"),t.offsetWidth,s(t,"transition","all "+n+"ms"),s(t,"transform","translate3d(0,0,0)"),clearTimeout(t.animated),t.animated=setTimeout(function(){s(t,"transition",""),s(t,"transform",""),t.animated=!1},n)}},_offUpEvents:function(){var e=this.el.ownerDocument;o(j,"touchmove",this._onTouchMove),o(e,"mouseup",this._onDrop),o(e,"touchend",this._onDrop),o(e,"touchcancel",this._onDrop)},_onDrop:function(t){var n=this.el,i=this.options;clearInterval(this._loopId),clearInterval(P.pid),clearTimeout(this._dragStartTimer),o(j,"mousemove",this._onTouchMove),this.nativeDraggable&&(o(j,"drop",this),o(n,"dragstart",this._onDragStart)),this._offUpEvents(),t&&(F&&(t.preventDefault(),!i.dropBubble&&t.stopPropagation()),w&&w.parentNode.removeChild(w),y&&(this.nativeDraggable&&o(y,"dragend",this),d(y),a(y,this.options.ghostClass,!1),a(y,this.options.chosenClass,!1),_!==b?(M=g(y),M>=0&&(u(null,b,"sort",y,_,A,M),u(this,_,"sort",y,_,A,M),u(null,b,"add",y,_,A,M),u(this,_,"remove",y,_,A,M))):(x&&x.parentNode.removeChild(x),y.nextSibling!==k&&(M=g(y),M>=0&&(u(this,_,"update",y,_,A,M),u(this,_,"sort",y,_,A,M)))),e.active&&(null!==M&&-1!==M||(M=A),u(this,_,"end",y,_,A,M),this.save())),_=y=b=w=k=x=C=T=I=N=F=M=D=S=O=e.active=null)},handleEvent:function(e){var t=e.type;"dragover"===t||"dragenter"===t?y&&(this._onDragOver(e),i(e)):"drop"!==t&&"dragend"!==t||this._onDrop(e)},toArray:function(){for(var e,t=[],i=this.el.children,r=0,o=i.length,a=this.options;o>r;r++)e=i[r],n(e,a.draggable,this.el)&&t.push(e.getAttribute(a.dataIdAttr)||f(e));return t},sort:function(e){var t={},i=this.el;this.toArray().forEach(function(e,r){var o=i.children[r];n(o,this.options.draggable,i)&&(t[e]=o)},this),e.forEach(function(e){t[e]&&(i.removeChild(t[e]),i.appendChild(t[e]))})},save:function(){var e=this.options.store;e&&e.set(this)},closest:function(e,t){return n(e,t||this.options.draggable,this.el)},option:function(e,t){var n=this.options;return void 0===t?n[e]:(n[e]=t,void("group"===e&&V(n)))},destroy:function(){var e=this.el;e[L]=null,o(e,"mousedown",this._onTapStart),o(e,"touchstart",this._onTapStart),this.nativeDraggable&&(o(e,"dragover",this),o(e,"dragenter",this)),Array.prototype.forEach.call(e.querySelectorAll("[draggable]"),function(e){e.removeAttribute("draggable")}),B.splice(B.indexOf(this._onDragOver),1),this._onDrop(),this.el=e=null}},e.utils={on:r,off:o,css:s,find:l,is:function(e,t){return!!n(e,t,e)},extend:m,throttle:v,closest:n,toggleClass:a,index:g},e.create=function(t,n){return new e(t,n)},e.version="1.4.2",e})},function(e,t,n){var i=n(1);n(6),/*!
	 * jQuery UI Datepicker 1.10.4
	 * http://jqueryui.com
	 *
	 * Copyright 2014 jQuery Foundation and other contributors
	 * Released under the MIT license.
	 * http://jquery.org/license
	 *
	 * http://api.jqueryui.com/datepicker/
	 *
	 * Depends:
	 *	jquery.ui.core.js
	 */
function(e,t){function n(){this._curInst=null,this._keyEvent=!1,this._disabledInputs=[],this._datepickerShowing=!1,this._inDialog=!1,this._mainDivId="ui-datepicker-div",this._inlineClass="ui-datepicker-inline",this._appendClass="ui-datepicker-append",this._triggerClass="ui-datepicker-trigger",this._dialogClass="ui-datepicker-dialog",this._disableClass="ui-datepicker-disabled",this._unselectableClass="ui-datepicker-unselectable",this._currentClass="ui-datepicker-current-day",this._dayOverClass="ui-datepicker-days-cell-over",this.regional=[],this.regional[""]={closeText:"Done",prevText:"Prev",nextText:"Next",currentText:"Today",monthNames:["January","February","March","April","May","June","July","August","September","October","November","December"],monthNamesShort:["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"],dayNames:["Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday"],dayNamesShort:["Sun","Mon","Tue","Wed","Thu","Fri","Sat"],dayNamesMin:["Su","Mo","Tu","We","Th","Fr","Sa"],weekHeader:"Wk",dateFormat:"mm/dd/yy",firstDay:0,isRTL:!1,showMonthAfterYear:!1,yearSuffix:""},this._defaults={showOn:"focus",showAnim:"fadeIn",showOptions:{},defaultDate:null,appendText:"",buttonText:"...",buttonImage:"",buttonImageOnly:!1,hideIfNoPrevNext:!1,navigationAsDateFormat:!1,gotoCurrent:!1,changeMonth:!1,changeYear:!1,yearRange:"c-10:c+10",showOtherMonths:!1,selectOtherMonths:!1,showWeek:!1,calculateWeek:this.iso8601Week,shortYearCutoff:"+10",minDate:null,maxDate:null,duration:"fast",beforeShowDay:null,beforeShow:null,onSelect:null,onChangeMonthYear:null,onClose:null,numberOfMonths:1,showCurrentAtPos:0,stepMonths:1,stepBigMonths:12,altField:"",altFormat:"",constrainInput:!0,showButtonPanel:!1,autoSize:!1,disabled:!1},e.extend(this._defaults,this.regional[""]),this.dpDiv=i(e("<div id='"+this._mainDivId+"' class='ui-datepicker ui-widget ui-widget-content ui-helper-clearfix ui-corner-all'></div>"))}function i(t){var n="button, .ui-datepicker-prev, .ui-datepicker-next, .ui-datepicker-calendar td a";return t.delegate(n,"mouseout",function(){e(this).removeClass("ui-state-hover"),-1!==this.className.indexOf("ui-datepicker-prev")&&e(this).removeClass("ui-datepicker-prev-hover"),-1!==this.className.indexOf("ui-datepicker-next")&&e(this).removeClass("ui-datepicker-next-hover")}).delegate(n,"mouseover",function(){e.datepicker._isDisabledDatepicker(o.inline?t.parent()[0]:o.input[0])||(e(this).parents(".ui-datepicker-calendar").find("a").removeClass("ui-state-hover"),e(this).addClass("ui-state-hover"),-1!==this.className.indexOf("ui-datepicker-prev")&&e(this).addClass("ui-datepicker-prev-hover"),-1!==this.className.indexOf("ui-datepicker-next")&&e(this).addClass("ui-datepicker-next-hover"))})}function r(t,n){e.extend(t,n);for(var i in n)null==n[i]&&(t[i]=n[i]);return t}e.extend(e.ui,{datepicker:{version:"1.10.4"}});var o,a="datepicker";e.extend(n.prototype,{markerClassName:"hasDatepicker",maxRows:4,_widgetDatepicker:function(){return this.dpDiv},setDefaults:function(e){return r(this._defaults,e||{}),this},_attachDatepicker:function(t,n){var i,r,o;i=t.nodeName.toLowerCase(),r="div"===i||"span"===i,t.id||(this.uuid+=1,t.id="dp"+this.uuid),o=this._newInst(e(t),r),o.settings=e.extend({},n||{}),"input"===i?this._connectDatepicker(t,o):r&&this._inlineDatepicker(t,o)},_newInst:function(t,n){var r=t[0].id.replace(/([^A-Za-z0-9_\-])/g,"\\\\$1");return{id:r,input:t,selectedDay:0,selectedMonth:0,selectedYear:0,drawMonth:0,drawYear:0,inline:n,dpDiv:n?i(e("<div class='"+this._inlineClass+" ui-datepicker ui-widget ui-widget-content ui-helper-clearfix ui-corner-all'></div>")):this.dpDiv}},_connectDatepicker:function(t,n){var i=e(t);n.append=e([]),n.trigger=e([]),i.hasClass(this.markerClassName)||(this._attachments(i,n),i.addClass(this.markerClassName).keydown(this._doKeyDown).keypress(this._doKeyPress).keyup(this._doKeyUp),this._autoSize(n),e.data(t,a,n),n.settings.disabled&&this._disableDatepicker(t))},_attachments:function(t,n){var i,r,o,a=this._get(n,"appendText"),s=this._get(n,"isRTL");n.append&&n.append.remove(),a&&(n.append=e("<span class='"+this._appendClass+"'>"+a+"</span>"),t[s?"before":"after"](n.append)),t.unbind("focus",this._showDatepicker),n.trigger&&n.trigger.remove(),i=this._get(n,"showOn"),"focus"!==i&&"both"!==i||t.focus(this._showDatepicker),"button"!==i&&"both"!==i||(r=this._get(n,"buttonText"),o=this._get(n,"buttonImage"),n.trigger=e(this._get(n,"buttonImageOnly")?e("<img/>").addClass(this._triggerClass).attr({src:o,alt:r,title:r}):e("<button type='button'></button>").addClass(this._triggerClass).html(o?e("<img/>").attr({src:o,alt:r,title:r}):r)),t[s?"before":"after"](n.trigger),n.trigger.click(function(){return e.datepicker._datepickerShowing&&e.datepicker._lastInput===t[0]?e.datepicker._hideDatepicker():e.datepicker._datepickerShowing&&e.datepicker._lastInput!==t[0]?(e.datepicker._hideDatepicker(),e.datepicker._showDatepicker(t[0])):e.datepicker._showDatepicker(t[0]),!1}))},_autoSize:function(e){if(this._get(e,"autoSize")&&!e.inline){var t,n,i,r,o=new Date(2009,11,20),a=this._get(e,"dateFormat");a.match(/[DM]/)&&(t=function(e){for(n=0,i=0,r=0;r<e.length;r++)e[r].length>n&&(n=e[r].length,i=r);return i},o.setMonth(t(this._get(e,a.match(/MM/)?"monthNames":"monthNamesShort"))),o.setDate(t(this._get(e,a.match(/DD/)?"dayNames":"dayNamesShort"))+20-o.getDay())),e.input.attr("size",this._formatDate(e,o).length)}},_inlineDatepicker:function(t,n){var i=e(t);i.hasClass(this.markerClassName)||(i.addClass(this.markerClassName).append(n.dpDiv),e.data(t,a,n),this._setDate(n,this._getDefaultDate(n),!0),this._updateDatepicker(n),this._updateAlternate(n),n.settings.disabled&&this._disableDatepicker(t),n.dpDiv.css("display","block"))},_dialogDatepicker:function(t,n,i,o,s){var l,u,c,d,p,h=this._dialogInst;return h||(this.uuid+=1,l="dp"+this.uuid,this._dialogInput=e("<input type='text' id='"+l+"' style='position: absolute; top: -100px; width: 0px;'/>"),this._dialogInput.keydown(this._doKeyDown),e("body").append(this._dialogInput),h=this._dialogInst=this._newInst(this._dialogInput,!1),h.settings={},e.data(this._dialogInput[0],a,h)),r(h.settings,o||{}),n=n&&n.constructor===Date?this._formatDate(h,n):n,this._dialogInput.val(n),this._pos=s?s.length?s:[s.pageX,s.pageY]:null,this._pos||(u=document.documentElement.clientWidth,c=document.documentElement.clientHeight,d=document.documentElement.scrollLeft||document.body.scrollLeft,p=document.documentElement.scrollTop||document.body.scrollTop,this._pos=[u/2-100+d,c/2-150+p]),this._dialogInput.css("left",this._pos[0]+20+"px").css("top",this._pos[1]+"px"),h.settings.onSelect=i,this._inDialog=!0,this.dpDiv.addClass(this._dialogClass),this._showDatepicker(this._dialogInput[0]),e.blockUI&&e.blockUI(this.dpDiv),e.data(this._dialogInput[0],a,h),this},_destroyDatepicker:function(t){var n,i=e(t),r=e.data(t,a);i.hasClass(this.markerClassName)&&(n=t.nodeName.toLowerCase(),e.removeData(t,a),"input"===n?(r.append.remove(),r.trigger.remove(),i.removeClass(this.markerClassName).unbind("focus",this._showDatepicker).unbind("keydown",this._doKeyDown).unbind("keypress",this._doKeyPress).unbind("keyup",this._doKeyUp)):"div"!==n&&"span"!==n||i.removeClass(this.markerClassName).empty())},_enableDatepicker:function(t){var n,i,r=e(t),o=e.data(t,a);r.hasClass(this.markerClassName)&&(n=t.nodeName.toLowerCase(),"input"===n?(t.disabled=!1,o.trigger.filter("button").each(function(){this.disabled=!1}).end().filter("img").css({opacity:"1.0",cursor:""})):"div"!==n&&"span"!==n||(i=r.children("."+this._inlineClass),i.children().removeClass("ui-state-disabled"),i.find("select.ui-datepicker-month, select.ui-datepicker-year").prop("disabled",!1)),this._disabledInputs=e.map(this._disabledInputs,function(e){return e===t?null:e}))},_disableDatepicker:function(t){var n,i,r=e(t),o=e.data(t,a);r.hasClass(this.markerClassName)&&(n=t.nodeName.toLowerCase(),"input"===n?(t.disabled=!0,o.trigger.filter("button").each(function(){this.disabled=!0}).end().filter("img").css({opacity:"0.5",cursor:"default"})):"div"!==n&&"span"!==n||(i=r.children("."+this._inlineClass),i.children().addClass("ui-state-disabled"),i.find("select.ui-datepicker-month, select.ui-datepicker-year").prop("disabled",!0)),this._disabledInputs=e.map(this._disabledInputs,function(e){return e===t?null:e}),this._disabledInputs[this._disabledInputs.length]=t)},_isDisabledDatepicker:function(e){if(!e)return!1;for(var t=0;t<this._disabledInputs.length;t++)if(this._disabledInputs[t]===e)return!0;return!1},_getInst:function(t){try{return e.data(t,a)}catch(n){throw"Missing instance data for this datepicker"}},_optionDatepicker:function(n,i,o){var a,s,l,u,c=this._getInst(n);return 2===arguments.length&&"string"==typeof i?"defaults"===i?e.extend({},e.datepicker._defaults):c?"all"===i?e.extend({},c.settings):this._get(c,i):null:(a=i||{},"string"==typeof i&&(a={},a[i]=o),void(c&&(this._curInst===c&&this._hideDatepicker(),s=this._getDateDatepicker(n,!0),l=this._getMinMaxDate(c,"min"),u=this._getMinMaxDate(c,"max"),r(c.settings,a),null!==l&&a.dateFormat!==t&&a.minDate===t&&(c.settings.minDate=this._formatDate(c,l)),null!==u&&a.dateFormat!==t&&a.maxDate===t&&(c.settings.maxDate=this._formatDate(c,u)),"disabled"in a&&(a.disabled?this._disableDatepicker(n):this._enableDatepicker(n)),this._attachments(e(n),c),this._autoSize(c),this._setDate(c,s),this._updateAlternate(c),this._updateDatepicker(c))))},_changeDatepicker:function(e,t,n){this._optionDatepicker(e,t,n)},_refreshDatepicker:function(e){var t=this._getInst(e);t&&this._updateDatepicker(t)},_setDateDatepicker:function(e,t){var n=this._getInst(e);n&&(this._setDate(n,t),this._updateDatepicker(n),this._updateAlternate(n))},_getDateDatepicker:function(e,t){var n=this._getInst(e);return n&&!n.inline&&this._setDateFromField(n,t),n?this._getDate(n):null},_doKeyDown:function(t){var n,i,r,o=e.datepicker._getInst(t.target),a=!0,s=o.dpDiv.is(".ui-datepicker-rtl");if(o._keyEvent=!0,e.datepicker._datepickerShowing)switch(t.keyCode){case 9:e.datepicker._hideDatepicker(),a=!1;break;case 13:return r=e("td."+e.datepicker._dayOverClass+":not(."+e.datepicker._currentClass+")",o.dpDiv),r[0]&&e.datepicker._selectDay(t.target,o.selectedMonth,o.selectedYear,r[0]),n=e.datepicker._get(o,"onSelect"),n?(i=e.datepicker._formatDate(o),n.apply(o.input?o.input[0]:null,[i,o])):e.datepicker._hideDatepicker(),!1;case 27:e.datepicker._hideDatepicker();break;case 33:e.datepicker._adjustDate(t.target,t.ctrlKey?-e.datepicker._get(o,"stepBigMonths"):-e.datepicker._get(o,"stepMonths"),"M");break;case 34:e.datepicker._adjustDate(t.target,t.ctrlKey?+e.datepicker._get(o,"stepBigMonths"):+e.datepicker._get(o,"stepMonths"),"M");break;case 35:(t.ctrlKey||t.metaKey)&&e.datepicker._clearDate(t.target),a=t.ctrlKey||t.metaKey;break;case 36:(t.ctrlKey||t.metaKey)&&e.datepicker._gotoToday(t.target),a=t.ctrlKey||t.metaKey;break;case 37:(t.ctrlKey||t.metaKey)&&e.datepicker._adjustDate(t.target,s?1:-1,"D"),a=t.ctrlKey||t.metaKey,t.originalEvent.altKey&&e.datepicker._adjustDate(t.target,t.ctrlKey?-e.datepicker._get(o,"stepBigMonths"):-e.datepicker._get(o,"stepMonths"),"M");break;case 38:(t.ctrlKey||t.metaKey)&&e.datepicker._adjustDate(t.target,-7,"D"),a=t.ctrlKey||t.metaKey;break;case 39:(t.ctrlKey||t.metaKey)&&e.datepicker._adjustDate(t.target,s?-1:1,"D"),a=t.ctrlKey||t.metaKey,t.originalEvent.altKey&&e.datepicker._adjustDate(t.target,t.ctrlKey?+e.datepicker._get(o,"stepBigMonths"):+e.datepicker._get(o,"stepMonths"),"M");break;case 40:(t.ctrlKey||t.metaKey)&&e.datepicker._adjustDate(t.target,7,"D"),a=t.ctrlKey||t.metaKey;break;default:a=!1}else 36===t.keyCode&&t.ctrlKey?e.datepicker._showDatepicker(this):a=!1;a&&(t.preventDefault(),t.stopPropagation())},_doKeyPress:function(t){var n,i,r=e.datepicker._getInst(t.target);return e.datepicker._get(r,"constrainInput")?(n=e.datepicker._possibleChars(e.datepicker._get(r,"dateFormat")),i=String.fromCharCode(null==t.charCode?t.keyCode:t.charCode),t.ctrlKey||t.metaKey||" ">i||!n||n.indexOf(i)>-1):void 0},_doKeyUp:function(t){var n,i=e.datepicker._getInst(t.target);if(i.input.val()!==i.lastVal)try{n=e.datepicker.parseDate(e.datepicker._get(i,"dateFormat"),i.input?i.input.val():null,e.datepicker._getFormatConfig(i)),n&&(e.datepicker._setDateFromField(i),e.datepicker._updateAlternate(i),e.datepicker._updateDatepicker(i))}catch(r){}return!0},_showDatepicker:function(t){if(t=t.target||t,"input"!==t.nodeName.toLowerCase()&&(t=e("input",t.parentNode)[0]),!e.datepicker._isDisabledDatepicker(t)&&e.datepicker._lastInput!==t){var n,i,o,a,s,l,u;n=e.datepicker._getInst(t),e.datepicker._curInst&&e.datepicker._curInst!==n&&(e.datepicker._curInst.dpDiv.stop(!0,!0),n&&e.datepicker._datepickerShowing&&e.datepicker._hideDatepicker(e.datepicker._curInst.input[0])),i=e.datepicker._get(n,"beforeShow"),o=i?i.apply(t,[t,n]):{},o!==!1&&(r(n.settings,o),n.lastVal=null,e.datepicker._lastInput=t,e.datepicker._setDateFromField(n),e.datepicker._inDialog&&(t.value=""),e.datepicker._pos||(e.datepicker._pos=e.datepicker._findPos(t),e.datepicker._pos[1]+=t.offsetHeight),a=!1,e(t).parents().each(function(){return a|="fixed"===e(this).css("position"),!a}),s={left:e.datepicker._pos[0],top:e.datepicker._pos[1]},e.datepicker._pos=null,n.dpDiv.empty(),n.dpDiv.css({position:"absolute",display:"block",top:"-1000px"}),e.datepicker._updateDatepicker(n),s=e.datepicker._checkOffset(n,s,a),n.dpDiv.css({position:e.datepicker._inDialog&&e.blockUI?"static":a?"fixed":"absolute",display:"none",left:s.left+"px",top:s.top+"px"}),n.inline||(l=e.datepicker._get(n,"showAnim"),u=e.datepicker._get(n,"duration"),n.dpDiv.zIndex(e(t).zIndex()+1),e.datepicker._datepickerShowing=!0,e.effects&&e.effects.effect[l]?n.dpDiv.show(l,e.datepicker._get(n,"showOptions"),u):n.dpDiv[l||"show"](l?u:null),e.datepicker._shouldFocusInput(n)&&n.input.focus(),e.datepicker._curInst=n))}},_updateDatepicker:function(t){this.maxRows=4,o=t,t.dpDiv.empty().append(this._generateHTML(t)),this._attachHandlers(t),t.dpDiv.find("."+this._dayOverClass+" a").mouseover();var n,i=this._getNumberOfMonths(t),r=i[1],a=17;t.dpDiv.removeClass("ui-datepicker-multi-2 ui-datepicker-multi-3 ui-datepicker-multi-4").width(""),r>1&&t.dpDiv.addClass("ui-datepicker-multi-"+r).css("width",a*r+"em"),t.dpDiv[(1!==i[0]||1!==i[1]?"add":"remove")+"Class"]("ui-datepicker-multi"),t.dpDiv[(this._get(t,"isRTL")?"add":"remove")+"Class"]("ui-datepicker-rtl"),t===e.datepicker._curInst&&e.datepicker._datepickerShowing&&e.datepicker._shouldFocusInput(t)&&t.input.focus(),t.yearshtml&&(n=t.yearshtml,setTimeout(function(){n===t.yearshtml&&t.yearshtml&&t.dpDiv.find("select.ui-datepicker-year:first").replaceWith(t.yearshtml),n=t.yearshtml=null},0))},_shouldFocusInput:function(e){return e.input&&e.input.is(":visible")&&!e.input.is(":disabled")&&!e.input.is(":focus")},_checkOffset:function(t,n,i){var r=t.dpDiv.outerWidth(),o=t.dpDiv.outerHeight(),a=t.input?t.input.outerWidth():0,s=t.input?t.input.outerHeight():0,l=document.documentElement.clientWidth+(i?0:e(document).scrollLeft()),u=document.documentElement.clientHeight+(i?0:e(document).scrollTop());return n.left-=this._get(t,"isRTL")?r-a:0,n.left-=i&&n.left===t.input.offset().left?e(document).scrollLeft():0,n.top-=i&&n.top===t.input.offset().top+s?e(document).scrollTop():0,n.left-=Math.min(n.left,n.left+r>l&&l>r?Math.abs(n.left+r-l):0),n.top-=Math.min(n.top,n.top+o>u&&u>o?Math.abs(o+s):0),n},_findPos:function(t){for(var n,i=this._getInst(t),r=this._get(i,"isRTL");t&&("hidden"===t.type||1!==t.nodeType||e.expr.filters.hidden(t));)t=t[r?"previousSibling":"nextSibling"];return n=e(t).offset(),[n.left,n.top]},_hideDatepicker:function(t){var n,i,r,o,s=this._curInst;!s||t&&s!==e.data(t,a)||this._datepickerShowing&&(n=this._get(s,"showAnim"),i=this._get(s,"duration"),r=function(){e.datepicker._tidyDialog(s)},e.effects&&(e.effects.effect[n]||e.effects[n])?s.dpDiv.hide(n,e.datepicker._get(s,"showOptions"),i,r):s.dpDiv["slideDown"===n?"slideUp":"fadeIn"===n?"fadeOut":"hide"](n?i:null,r),n||r(),this._datepickerShowing=!1,o=this._get(s,"onClose"),o&&o.apply(s.input?s.input[0]:null,[s.input?s.input.val():"",s]),this._lastInput=null,this._inDialog&&(this._dialogInput.css({position:"absolute",left:"0",top:"-100px"}),e.blockUI&&(e.unblockUI(),e("body").append(this.dpDiv))),this._inDialog=!1)},_tidyDialog:function(e){e.dpDiv.removeClass(this._dialogClass).unbind(".ui-datepicker-calendar")},_checkExternalClick:function(t){if(e.datepicker._curInst){var n=e(t.target),i=e.datepicker._getInst(n[0]);(n[0].id===e.datepicker._mainDivId||0!==n.parents("#"+e.datepicker._mainDivId).length||n.hasClass(e.datepicker.markerClassName)||n.closest("."+e.datepicker._triggerClass).length||!e.datepicker._datepickerShowing||e.datepicker._inDialog&&e.blockUI)&&(!n.hasClass(e.datepicker.markerClassName)||e.datepicker._curInst===i)||e.datepicker._hideDatepicker()}},_adjustDate:function(t,n,i){var r=e(t),o=this._getInst(r[0]);this._isDisabledDatepicker(r[0])||(this._adjustInstDate(o,n+("M"===i?this._get(o,"showCurrentAtPos"):0),i),this._updateDatepicker(o))},_gotoToday:function(t){var n,i=e(t),r=this._getInst(i[0]);this._get(r,"gotoCurrent")&&r.currentDay?(r.selectedDay=r.currentDay,r.drawMonth=r.selectedMonth=r.currentMonth,r.drawYear=r.selectedYear=r.currentYear):(n=new Date,r.selectedDay=n.getDate(),r.drawMonth=r.selectedMonth=n.getMonth(),r.drawYear=r.selectedYear=n.getFullYear()),this._notifyChange(r),this._adjustDate(i)},_selectMonthYear:function(t,n,i){var r=e(t),o=this._getInst(r[0]);o["selected"+("M"===i?"Month":"Year")]=o["draw"+("M"===i?"Month":"Year")]=parseInt(n.options[n.selectedIndex].value,10),this._notifyChange(o),this._adjustDate(r)},_selectDay:function(t,n,i,r){var o,a=e(t);e(r).hasClass(this._unselectableClass)||this._isDisabledDatepicker(a[0])||(o=this._getInst(a[0]),o.selectedDay=o.currentDay=e("a",r).html(),o.selectedMonth=o.currentMonth=n,o.selectedYear=o.currentYear=i,this._selectDate(t,this._formatDate(o,o.currentDay,o.currentMonth,o.currentYear)))},_clearDate:function(t){var n=e(t);this._selectDate(n,"")},_selectDate:function(t,n){var i,r=e(t),o=this._getInst(r[0]);n=null!=n?n:this._formatDate(o),o.input&&o.input.val(n),this._updateAlternate(o),i=this._get(o,"onSelect"),i?i.apply(o.input?o.input[0]:null,[n,o]):o.input&&o.input.trigger("change"),o.inline?this._updateDatepicker(o):(this._hideDatepicker(),this._lastInput=o.input[0],"object"!=typeof o.input[0]&&o.input.focus(),this._lastInput=null)},_updateAlternate:function(t){var n,i,r,o=this._get(t,"altField");o&&(n=this._get(t,"altFormat")||this._get(t,"dateFormat"),i=this._getDate(t),r=this.formatDate(n,i,this._getFormatConfig(t)),e(o).each(function(){e(this).val(r)}))},noWeekends:function(e){var t=e.getDay();return[t>0&&6>t,""]},iso8601Week:function(e){var t,n=new Date(e.getTime());return n.setDate(n.getDate()+4-(n.getDay()||7)),t=n.getTime(),n.setMonth(0),n.setDate(1),Math.floor(Math.round((t-n)/864e5)/7)+1},parseDate:function(t,n,i){if(null==t||null==n)throw"Invalid arguments";if(n="object"==typeof n?n.toString():n+"",""===n)return null;var r,o,a,s,l=0,u=(i?i.shortYearCutoff:null)||this._defaults.shortYearCutoff,c="string"!=typeof u?u:(new Date).getFullYear()%100+parseInt(u,10),d=(i?i.dayNamesShort:null)||this._defaults.dayNamesShort,p=(i?i.dayNames:null)||this._defaults.dayNames,h=(i?i.monthNamesShort:null)||this._defaults.monthNamesShort,f=(i?i.monthNames:null)||this._defaults.monthNames,g=-1,v=-1,m=-1,y=-1,b=!1,w=function(e){var n=r+1<t.length&&t.charAt(r+1)===e;return n&&r++,n},x=function(e){var t=w(e),i="@"===e?14:"!"===e?20:"y"===e&&t?4:"o"===e?3:2,r=new RegExp("^\\d{1,"+i+"}"),o=n.substring(l).match(r);if(!o)throw"Missing number at position "+l;return l+=o[0].length,parseInt(o[0],10)},_=function(t,i,r){var o=-1,a=e.map(w(t)?r:i,function(e,t){return[[t,e]]}).sort(function(e,t){return-(e[1].length-t[1].length)});if(e.each(a,function(e,t){var i=t[1];return n.substr(l,i.length).toLowerCase()===i.toLowerCase()?(o=t[0],l+=i.length,!1):void 0}),-1!==o)return o+1;throw"Unknown name at position "+l},k=function(){if(n.charAt(l)!==t.charAt(r))throw"Unexpected literal at position "+l;l++};for(r=0;r<t.length;r++)if(b)"'"!==t.charAt(r)||w("'")?k():b=!1;else switch(t.charAt(r)){case"d":m=x("d");break;case"D":_("D",d,p);break;case"o":y=x("o");break;case"m":v=x("m");break;case"M":v=_("M",h,f);break;case"y":g=x("y");break;case"@":s=new Date(x("@")),g=s.getFullYear(),v=s.getMonth()+1,m=s.getDate();break;case"!":s=new Date((x("!")-this._ticksTo1970)/1e4),g=s.getFullYear(),v=s.getMonth()+1,m=s.getDate();break;case"'":w("'")?k():b=!0;break;default:k()}if(l<n.length&&(a=n.substr(l),!/^\s+/.test(a)))throw"Extra/unparsed characters found in date: "+a;if(-1===g?g=(new Date).getFullYear():100>g&&(g+=(new Date).getFullYear()-(new Date).getFullYear()%100+(c>=g?0:-100)),y>-1)for(v=1,m=y;;){if(o=this._getDaysInMonth(g,v-1),o>=m)break;v++,m-=o}if(s=this._daylightSavingAdjust(new Date(g,v-1,m)),s.getFullYear()!==g||s.getMonth()+1!==v||s.getDate()!==m)throw"Invalid date";return s},ATOM:"yy-mm-dd",COOKIE:"D, dd M yy",ISO_8601:"yy-mm-dd",RFC_822:"D, d M y",RFC_850:"DD, dd-M-y",RFC_1036:"D, d M y",RFC_1123:"D, d M yy",RFC_2822:"D, d M yy",RSS:"D, d M y",TICKS:"!",TIMESTAMP:"@",W3C:"yy-mm-dd",_ticksTo1970:24*(718685+Math.floor(492.5)-Math.floor(19.7)+Math.floor(4.925))*60*60*1e7,formatDate:function(e,t,n){if(!t)return"";var i,r=(n?n.dayNamesShort:null)||this._defaults.dayNamesShort,o=(n?n.dayNames:null)||this._defaults.dayNames,a=(n?n.monthNamesShort:null)||this._defaults.monthNamesShort,s=(n?n.monthNames:null)||this._defaults.monthNames,l=function(t){var n=i+1<e.length&&e.charAt(i+1)===t;return n&&i++,n},u=function(e,t,n){var i=""+t;if(l(e))for(;i.length<n;)i="0"+i;return i},c=function(e,t,n,i){return l(e)?i[t]:n[t]},d="",p=!1;if(t)for(i=0;i<e.length;i++)if(p)"'"!==e.charAt(i)||l("'")?d+=e.charAt(i):p=!1;else switch(e.charAt(i)){case"d":d+=u("d",t.getDate(),2);break;case"D":d+=c("D",t.getDay(),r,o);break;case"o":d+=u("o",Math.round((new Date(t.getFullYear(),t.getMonth(),t.getDate()).getTime()-new Date(t.getFullYear(),0,0).getTime())/864e5),3);break;case"m":d+=u("m",t.getMonth()+1,2);break;case"M":d+=c("M",t.getMonth(),a,s);break;case"y":d+=l("y")?t.getFullYear():(t.getYear()%100<10?"0":"")+t.getYear()%100;break;case"@":d+=t.getTime();break;case"!":d+=1e4*t.getTime()+this._ticksTo1970;break;case"'":l("'")?d+="'":p=!0;break;default:d+=e.charAt(i)}return d},_possibleChars:function(e){var t,n="",i=!1,r=function(n){var i=t+1<e.length&&e.charAt(t+1)===n;return i&&t++,i};for(t=0;t<e.length;t++)if(i)"'"!==e.charAt(t)||r("'")?n+=e.charAt(t):i=!1;else switch(e.charAt(t)){case"d":case"m":case"y":case"@":n+="0123456789";break;case"D":case"M":return null;case"'":r("'")?n+="'":i=!0;break;default:n+=e.charAt(t)}return n},_get:function(e,n){return e.settings[n]!==t?e.settings[n]:this._defaults[n]},_setDateFromField:function(e,t){if(e.input.val()!==e.lastVal){var n=this._get(e,"dateFormat"),i=e.lastVal=e.input?e.input.val():null,r=this._getDefaultDate(e),o=r,a=this._getFormatConfig(e);try{o=this.parseDate(n,i,a)||r}catch(s){i=t?"":i}e.selectedDay=o.getDate(),e.drawMonth=e.selectedMonth=o.getMonth(),e.drawYear=e.selectedYear=o.getFullYear(),e.currentDay=i?o.getDate():0,e.currentMonth=i?o.getMonth():0,e.currentYear=i?o.getFullYear():0,this._adjustInstDate(e)}},_getDefaultDate:function(e){return this._restrictMinMax(e,this._determineDate(e,this._get(e,"defaultDate"),new Date))},_determineDate:function(t,n,i){var r=function(e){var t=new Date;return t.setDate(t.getDate()+e),t},o=function(n){try{return e.datepicker.parseDate(e.datepicker._get(t,"dateFormat"),n,e.datepicker._getFormatConfig(t))}catch(i){}for(var r=(n.toLowerCase().match(/^c/)?e.datepicker._getDate(t):null)||new Date,o=r.getFullYear(),a=r.getMonth(),s=r.getDate(),l=/([+\-]?[0-9]+)\s*(d|D|w|W|m|M|y|Y)?/g,u=l.exec(n);u;){switch(u[2]||"d"){case"d":case"D":s+=parseInt(u[1],10);break;case"w":case"W":s+=7*parseInt(u[1],10);break;case"m":case"M":a+=parseInt(u[1],10),s=Math.min(s,e.datepicker._getDaysInMonth(o,a));break;case"y":case"Y":o+=parseInt(u[1],10),s=Math.min(s,e.datepicker._getDaysInMonth(o,a))}u=l.exec(n)}return new Date(o,a,s)},a=null==n||""===n?i:"string"==typeof n?o(n):"number"==typeof n?isNaN(n)?i:r(n):new Date(n.getTime());return a=a&&"Invalid Date"===a.toString()?i:a,a&&(a.setHours(0),a.setMinutes(0),a.setSeconds(0),a.setMilliseconds(0)),this._daylightSavingAdjust(a)},_daylightSavingAdjust:function(e){return e?(e.setHours(e.getHours()>12?e.getHours()+2:0),e):null},_setDate:function(e,t,n){var i=!t,r=e.selectedMonth,o=e.selectedYear,a=this._restrictMinMax(e,this._determineDate(e,t,new Date));e.selectedDay=e.currentDay=a.getDate(),e.drawMonth=e.selectedMonth=e.currentMonth=a.getMonth(),e.drawYear=e.selectedYear=e.currentYear=a.getFullYear(),r===e.selectedMonth&&o===e.selectedYear||n||this._notifyChange(e),this._adjustInstDate(e),e.input&&e.input.val(i?"":this._formatDate(e))},_getDate:function(e){var t=!e.currentYear||e.input&&""===e.input.val()?null:this._daylightSavingAdjust(new Date(e.currentYear,e.currentMonth,e.currentDay));return t},_attachHandlers:function(t){var n=this._get(t,"stepMonths"),i="#"+t.id.replace(/\\\\/g,"\\");t.dpDiv.find("[data-handler]").map(function(){var t={prev:function(){e.datepicker._adjustDate(i,-n,"M")},next:function(){e.datepicker._adjustDate(i,+n,"M")},hide:function(){e.datepicker._hideDatepicker()},today:function(){e.datepicker._gotoToday(i)},selectDay:function(){return e.datepicker._selectDay(i,+this.getAttribute("data-month"),+this.getAttribute("data-year"),this),!1},selectMonth:function(){return e.datepicker._selectMonthYear(i,this,"M"),!1},selectYear:function(){return e.datepicker._selectMonthYear(i,this,"Y"),!1}};e(this).bind(this.getAttribute("data-event"),t[this.getAttribute("data-handler")])})},_generateHTML:function(e){var t,n,i,r,o,a,s,l,u,c,d,p,h,f,g,v,m,y,b,w,x,_,k,C,T,D,S,E,A,M,O,I,N,F,P,$,L,q,j,R=new Date,z=this._daylightSavingAdjust(new Date(R.getFullYear(),R.getMonth(),R.getDate())),H=this._get(e,"isRTL"),W=this._get(e,"showButtonPanel"),Y=this._get(e,"hideIfNoPrevNext"),B=this._get(e,"navigationAsDateFormat"),U=this._getNumberOfMonths(e),V=this._get(e,"showCurrentAtPos"),X=this._get(e,"stepMonths"),Q=1!==U[0]||1!==U[1],G=this._daylightSavingAdjust(e.currentDay?new Date(e.currentYear,e.currentMonth,e.currentDay):new Date(9999,9,9)),K=this._getMinMaxDate(e,"min"),Z=this._getMinMaxDate(e,"max"),J=e.drawMonth-V,ee=e.drawYear;if(0>J&&(J+=12,ee--),Z)for(t=this._daylightSavingAdjust(new Date(Z.getFullYear(),Z.getMonth()-U[0]*U[1]+1,Z.getDate())),t=K&&K>t?K:t;this._daylightSavingAdjust(new Date(ee,J,1))>t;)J--,0>J&&(J=11,ee--);for(e.drawMonth=J,e.drawYear=ee,n=this._get(e,"prevText"),n=B?this.formatDate(n,this._daylightSavingAdjust(new Date(ee,J-X,1)),this._getFormatConfig(e)):n,i=this._canAdjustMonth(e,-1,ee,J)?"<a class='ui-datepicker-prev ui-corner-all' data-handler='prev' data-event='click' title='"+n+"'><span class='ui-icon ui-icon-circle-triangle-"+(H?"e":"w")+"'>"+n+"</span></a>":Y?"":"<a class='ui-datepicker-prev ui-corner-all ui-state-disabled' title='"+n+"'><span class='ui-icon ui-icon-circle-triangle-"+(H?"e":"w")+"'>"+n+"</span></a>",r=this._get(e,"nextText"),r=B?this.formatDate(r,this._daylightSavingAdjust(new Date(ee,J+X,1)),this._getFormatConfig(e)):r,o=this._canAdjustMonth(e,1,ee,J)?"<a class='ui-datepicker-next ui-corner-all' data-handler='next' data-event='click' title='"+r+"'><span class='ui-icon ui-icon-circle-triangle-"+(H?"w":"e")+"'>"+r+"</span></a>":Y?"":"<a class='ui-datepicker-next ui-corner-all ui-state-disabled' title='"+r+"'><span class='ui-icon ui-icon-circle-triangle-"+(H?"w":"e")+"'>"+r+"</span></a>",a=this._get(e,"currentText"),s=this._get(e,"gotoCurrent")&&e.currentDay?G:z,a=B?this.formatDate(a,s,this._getFormatConfig(e)):a,l=e.inline?"":"<button type='button' class='ui-datepicker-close ui-state-default ui-priority-primary ui-corner-all' data-handler='hide' data-event='click'>"+this._get(e,"closeText")+"</button>",u=W?"<div class='ui-datepicker-buttonpane ui-widget-content'>"+(H?l:"")+(this._isInRange(e,s)?"<button type='button' class='ui-datepicker-current ui-state-default ui-priority-secondary ui-corner-all' data-handler='today' data-event='click'>"+a+"</button>":"")+(H?"":l)+"</div>":"",c=parseInt(this._get(e,"firstDay"),10),c=isNaN(c)?0:c,d=this._get(e,"showWeek"),p=this._get(e,"dayNames"),h=this._get(e,"dayNamesMin"),f=this._get(e,"monthNames"),g=this._get(e,"monthNamesShort"),v=this._get(e,"beforeShowDay"),m=this._get(e,"showOtherMonths"),y=this._get(e,"selectOtherMonths"),b=this._getDefaultDate(e),w="",_=0;_<U[0];_++){for(k="",this.maxRows=4,C=0;C<U[1];C++){if(T=this._daylightSavingAdjust(new Date(ee,J,e.selectedDay)),D=" ui-corner-all",S="",Q){if(S+="<div class='ui-datepicker-group",U[1]>1)switch(C){case 0:S+=" ui-datepicker-group-first",D=" ui-corner-"+(H?"right":"left");break;case U[1]-1:S+=" ui-datepicker-group-last",D=" ui-corner-"+(H?"left":"right");break;default:S+=" ui-datepicker-group-middle",D=""}S+="'>"}for(S+="<div class='ui-datepicker-header ui-widget-header ui-helper-clearfix"+D+"'>"+(/all|left/.test(D)&&0===_?H?o:i:"")+(/all|right/.test(D)&&0===_?H?i:o:"")+this._generateMonthYearHeader(e,J,ee,K,Z,_>0||C>0,f,g)+"</div><table class='ui-datepicker-calendar'><thead><tr>",E=d?"<th class='ui-datepicker-week-col'>"+this._get(e,"weekHeader")+"</th>":"",x=0;7>x;x++)A=(x+c)%7,E+="<th"+((x+c+6)%7>=5?" class='ui-datepicker-week-end'":"")+"><span title='"+p[A]+"'>"+h[A]+"</span></th>";for(S+=E+"</tr></thead><tbody>",M=this._getDaysInMonth(ee,J),ee===e.selectedYear&&J===e.selectedMonth&&(e.selectedDay=Math.min(e.selectedDay,M)),O=(this._getFirstDayOfMonth(ee,J)-c+7)%7,I=Math.ceil((O+M)/7),N=Q&&this.maxRows>I?this.maxRows:I,this.maxRows=N,F=this._daylightSavingAdjust(new Date(ee,J,1-O)),P=0;N>P;P++){for(S+="<tr>",$=d?"<td class='ui-datepicker-week-col'>"+this._get(e,"calculateWeek")(F)+"</td>":"",x=0;7>x;x++)L=v?v.apply(e.input?e.input[0]:null,[F]):[!0,""],q=F.getMonth()!==J,j=q&&!y||!L[0]||K&&K>F||Z&&F>Z,$+="<td class='"+((x+c+6)%7>=5?" ui-datepicker-week-end":"")+(q?" ui-datepicker-other-month":"")+(F.getTime()===T.getTime()&&J===e.selectedMonth&&e._keyEvent||b.getTime()===F.getTime()&&b.getTime()===T.getTime()?" "+this._dayOverClass:"")+(j?" "+this._unselectableClass+" ui-state-disabled":"")+(q&&!m?"":" "+L[1]+(F.getTime()===G.getTime()?" "+this._currentClass:"")+(F.getTime()===z.getTime()?" ui-datepicker-today":""))+"'"+(q&&!m||!L[2]?"":" title='"+L[2].replace(/'/g,"&#39;")+"'")+(j?"":" data-handler='selectDay' data-event='click' data-month='"+F.getMonth()+"' data-year='"+F.getFullYear()+"'")+">"+(q&&!m?"&#xa0;":j?"<span class='ui-state-default'>"+F.getDate()+"</span>":"<a class='ui-state-default"+(F.getTime()===z.getTime()?" ui-state-highlight":"")+(F.getTime()===G.getTime()?" ui-state-active":"")+(q?" ui-priority-secondary":"")+"' href='#'>"+F.getDate()+"</a>")+"</td>",F.setDate(F.getDate()+1),F=this._daylightSavingAdjust(F);S+=$+"</tr>"}J++,J>11&&(J=0,ee++),S+="</tbody></table>"+(Q?"</div>"+(U[0]>0&&C===U[1]-1?"<div class='ui-datepicker-row-break'></div>":""):""),k+=S}w+=k}return w+=u,e._keyEvent=!1,w},_generateMonthYearHeader:function(e,t,n,i,r,o,a,s){var l,u,c,d,p,h,f,g,v=this._get(e,"changeMonth"),m=this._get(e,"changeYear"),y=this._get(e,"showMonthAfterYear"),b="<div class='ui-datepicker-title'>",w="";if(o||!v)w+="<span class='ui-datepicker-month'>"+a[t]+"</span>";else{for(l=i&&i.getFullYear()===n,u=r&&r.getFullYear()===n,w+="<select class='ui-datepicker-month' data-handler='selectMonth' data-event='change'>",c=0;12>c;c++)(!l||c>=i.getMonth())&&(!u||c<=r.getMonth())&&(w+="<option value='"+c+"'"+(c===t?" selected='selected'":"")+">"+s[c]+"</option>");w+="</select>"}if(y||(b+=w+(!o&&v&&m?"":"&#xa0;")),!e.yearshtml)if(e.yearshtml="",o||!m)b+="<span class='ui-datepicker-year'>"+n+"</span>";else{for(d=this._get(e,"yearRange").split(":"),p=(new Date).getFullYear(),h=function(e){var t=e.match(/c[+\-].*/)?n+parseInt(e.substring(1),10):e.match(/[+\-].*/)?p+parseInt(e,10):parseInt(e,10);
return isNaN(t)?p:t},f=h(d[0]),g=Math.max(f,h(d[1]||"")),f=i?Math.max(f,i.getFullYear()):f,g=r?Math.min(g,r.getFullYear()):g,e.yearshtml+="<select class='ui-datepicker-year' data-handler='selectYear' data-event='change'>";g>=f;f++)e.yearshtml+="<option value='"+f+"'"+(f===n?" selected='selected'":"")+">"+f+"</option>";e.yearshtml+="</select>",b+=e.yearshtml,e.yearshtml=null}return b+=this._get(e,"yearSuffix"),y&&(b+=(!o&&v&&m?"":"&#xa0;")+w),b+="</div>"},_adjustInstDate:function(e,t,n){var i=e.drawYear+("Y"===n?t:0),r=e.drawMonth+("M"===n?t:0),o=Math.min(e.selectedDay,this._getDaysInMonth(i,r))+("D"===n?t:0),a=this._restrictMinMax(e,this._daylightSavingAdjust(new Date(i,r,o)));e.selectedDay=a.getDate(),e.drawMonth=e.selectedMonth=a.getMonth(),e.drawYear=e.selectedYear=a.getFullYear(),"M"!==n&&"Y"!==n||this._notifyChange(e)},_restrictMinMax:function(e,t){var n=this._getMinMaxDate(e,"min"),i=this._getMinMaxDate(e,"max"),r=n&&n>t?n:t;return i&&r>i?i:r},_notifyChange:function(e){var t=this._get(e,"onChangeMonthYear");t&&t.apply(e.input?e.input[0]:null,[e.selectedYear,e.selectedMonth+1,e])},_getNumberOfMonths:function(e){var t=this._get(e,"numberOfMonths");return null==t?[1,1]:"number"==typeof t?[1,t]:t},_getMinMaxDate:function(e,t){return this._determineDate(e,this._get(e,t+"Date"),null)},_getDaysInMonth:function(e,t){return 32-this._daylightSavingAdjust(new Date(e,t,32)).getDate()},_getFirstDayOfMonth:function(e,t){return new Date(e,t,1).getDay()},_canAdjustMonth:function(e,t,n,i){var r=this._getNumberOfMonths(e),o=this._daylightSavingAdjust(new Date(n,i+(0>t?t:r[0]*r[1]),1));return 0>t&&o.setDate(this._getDaysInMonth(o.getFullYear(),o.getMonth())),this._isInRange(e,o)},_isInRange:function(e,t){var n,i,r=this._getMinMaxDate(e,"min"),o=this._getMinMaxDate(e,"max"),a=null,s=null,l=this._get(e,"yearRange");return l&&(n=l.split(":"),i=(new Date).getFullYear(),a=parseInt(n[0],10),s=parseInt(n[1],10),n[0].match(/[+\-].*/)&&(a+=i),n[1].match(/[+\-].*/)&&(s+=i)),(!r||t.getTime()>=r.getTime())&&(!o||t.getTime()<=o.getTime())&&(!a||t.getFullYear()>=a)&&(!s||t.getFullYear()<=s)},_getFormatConfig:function(e){var t=this._get(e,"shortYearCutoff");return t="string"!=typeof t?t:(new Date).getFullYear()%100+parseInt(t,10),{shortYearCutoff:t,dayNamesShort:this._get(e,"dayNamesShort"),dayNames:this._get(e,"dayNames"),monthNamesShort:this._get(e,"monthNamesShort"),monthNames:this._get(e,"monthNames")}},_formatDate:function(e,t,n,i){t||(e.currentDay=e.selectedDay,e.currentMonth=e.selectedMonth,e.currentYear=e.selectedYear);var r=t?"object"==typeof t?t:this._daylightSavingAdjust(new Date(i,n,t)):this._daylightSavingAdjust(new Date(e.currentYear,e.currentMonth,e.currentDay));return this.formatDate(this._get(e,"dateFormat"),r,this._getFormatConfig(e))}}),e.fn.datepicker=function(t){if(!this.length)return this;e.datepicker.initialized||(e(document).mousedown(e.datepicker._checkExternalClick),e.datepicker.initialized=!0),0===e("#"+e.datepicker._mainDivId).length&&e("body").append(e.datepicker.dpDiv);var n=Array.prototype.slice.call(arguments,1);return"string"!=typeof t||"isDisabled"!==t&&"getDate"!==t&&"widget"!==t?"option"===t&&2===arguments.length&&"string"==typeof arguments[1]?e.datepicker["_"+t+"Datepicker"].apply(e.datepicker,[this[0]].concat(n)):this.each(function(){"string"==typeof t?e.datepicker["_"+t+"Datepicker"].apply(e.datepicker,[this].concat(n)):e.datepicker._attachDatepicker(this,t)}):e.datepicker["_"+t+"Datepicker"].apply(e.datepicker,[this[0]].concat(n))},e.datepicker=new n,e.datepicker.initialized=!1,e.datepicker.uuid=(new Date).getTime(),e.datepicker.version="1.10.4"}(i)},function(e,t,n){var i=n(1);/*!
	 * jQuery UI Core 1.10.4
	 * http://jqueryui.com
	 *
	 * Copyright 2014 jQuery Foundation and other contributors
	 * Released under the MIT license.
	 * http://jquery.org/license
	 *
	 * http://api.jqueryui.com/category/ui-core/
	 */
!function(e,t){function n(t,n){var r,o,a,s=t.nodeName.toLowerCase();return"area"===s?(r=t.parentNode,o=r.name,t.href&&o&&"map"===r.nodeName.toLowerCase()?(a=e("img[usemap=#"+o+"]")[0],!!a&&i(a)):!1):(/input|select|textarea|button|object/.test(s)?!t.disabled:"a"===s?t.href||n:n)&&i(t)}function i(t){return e.expr.filters.visible(t)&&!e(t).parents().addBack().filter(function(){return"hidden"===e.css(this,"visibility")}).length}var r=0,o=/^ui-id-\d+$/;e.ui=e.ui||{},e.extend(e.ui,{version:"1.10.4",keyCode:{BACKSPACE:8,COMMA:188,DELETE:46,DOWN:40,END:35,ENTER:13,ESCAPE:27,HOME:36,LEFT:37,NUMPAD_ADD:107,NUMPAD_DECIMAL:110,NUMPAD_DIVIDE:111,NUMPAD_ENTER:108,NUMPAD_MULTIPLY:106,NUMPAD_SUBTRACT:109,PAGE_DOWN:34,PAGE_UP:33,PERIOD:190,RIGHT:39,SPACE:32,TAB:9,UP:38}}),e.fn.extend({focus:function(t){return function(n,i){return"number"==typeof n?this.each(function(){var t=this;setTimeout(function(){e(t).focus(),i&&i.call(t)},n)}):t.apply(this,arguments)}}(e.fn.focus),scrollParent:function(){var t;return t=e.ui.ie&&/(static|relative)/.test(this.css("position"))||/absolute/.test(this.css("position"))?this.parents().filter(function(){return/(relative|absolute|fixed)/.test(e.css(this,"position"))&&/(auto|scroll)/.test(e.css(this,"overflow")+e.css(this,"overflow-y")+e.css(this,"overflow-x"))}).eq(0):this.parents().filter(function(){return/(auto|scroll)/.test(e.css(this,"overflow")+e.css(this,"overflow-y")+e.css(this,"overflow-x"))}).eq(0),/fixed/.test(this.css("position"))||!t.length?e(document):t},zIndex:function(n){if(n!==t)return this.css("zIndex",n);if(this.length)for(var i,r,o=e(this[0]);o.length&&o[0]!==document;){if(i=o.css("position"),("absolute"===i||"relative"===i||"fixed"===i)&&(r=parseInt(o.css("zIndex"),10),!isNaN(r)&&0!==r))return r;o=o.parent()}return 0},uniqueId:function(){return this.each(function(){this.id||(this.id="ui-id-"+ ++r)})},removeUniqueId:function(){return this.each(function(){o.test(this.id)&&e(this).removeAttr("id")})}}),e.extend(e.expr[":"],{data:e.expr.createPseudo?e.expr.createPseudo(function(t){return function(n){return!!e.data(n,t)}}):function(t,n,i){return!!e.data(t,i[3])},focusable:function(t){return n(t,!isNaN(e.attr(t,"tabindex")))},tabbable:function(t){var i=e.attr(t,"tabindex"),r=isNaN(i);return(r||i>=0)&&n(t,!r)}}),e("<a>").outerWidth(1).jquery||e.each(["Width","Height"],function(n,i){function r(t,n,i,r){return e.each(o,function(){n-=parseFloat(e.css(t,"padding"+this))||0,i&&(n-=parseFloat(e.css(t,"border"+this+"Width"))||0),r&&(n-=parseFloat(e.css(t,"margin"+this))||0)}),n}var o="Width"===i?["Left","Right"]:["Top","Bottom"],a=i.toLowerCase(),s={innerWidth:e.fn.innerWidth,innerHeight:e.fn.innerHeight,outerWidth:e.fn.outerWidth,outerHeight:e.fn.outerHeight};e.fn["inner"+i]=function(n){return n===t?s["inner"+i].call(this):this.each(function(){e(this).css(a,r(this,n)+"px")})},e.fn["outer"+i]=function(t,n){return"number"!=typeof t?s["outer"+i].call(this,t):this.each(function(){e(this).css(a,r(this,t,!0,n)+"px")})}}),e.fn.addBack||(e.fn.addBack=function(e){return this.add(null==e?this.prevObject:this.prevObject.filter(e))}),e("<a>").data("a-b","a").removeData("a-b").data("a-b")&&(e.fn.removeData=function(t){return function(n){return arguments.length?t.call(this,e.camelCase(n)):t.call(this)}}(e.fn.removeData)),e.ui.ie=!!/msie [\w.]+/.exec(navigator.userAgent.toLowerCase()),e.support.selectstart="onselectstart"in document.createElement("div"),e.fn.extend({disableSelection:function(){return this.bind((e.support.selectstart?"selectstart":"mousedown")+".ui-disableSelection",function(e){e.preventDefault()})},enableSelection:function(){return this.unbind(".ui-disableSelection")}}),e.extend(e.ui,{plugin:{add:function(t,n,i){var r,o=e.ui[t].prototype;for(r in i)o.plugins[r]=o.plugins[r]||[],o.plugins[r].push([n,i[r]])},call:function(e,t,n){var i,r=e.plugins[t];if(r&&e.element[0].parentNode&&11!==e.element[0].parentNode.nodeType)for(i=0;i<r.length;i++)e.options[r[i][0]]&&r[i][1].apply(e.element,n)}},hasScroll:function(t,n){if("hidden"===e(t).css("overflow"))return!1;var i=n&&"left"===n?"scrollLeft":"scrollTop",r=!1;return t[i]>0?!0:(t[i]=1,r=t[i]>0,t[i]=0,r)}})}(i)},function(e,t,n){(function(e){!function(e){var t=-1,n=-1,i=function(e){return parseFloat(e)||0},r=function(t){var n=1,r=e(t),o=null,a=[];return r.each(function(){var t=e(this),r=t.offset().top-i(t.css("margin-top")),s=a.length>0?a[a.length-1]:null;null===s?a.push(t):Math.floor(Math.abs(o-r))<=n?a[a.length-1]=s.add(t):a.push(t),o=r}),a},o=function(t){var n={byRow:!0,property:"height",target:null,remove:!1};return"object"==typeof t?e.extend(n,t):("boolean"==typeof t?n.byRow=t:"remove"===t&&(n.remove=!0),n)},a=e.fn.matchHeight=function(t){var n=o(t);if(n.remove){var i=this;return this.css(n.property,""),e.each(a._groups,function(e,t){t.elements=t.elements.not(i)}),this}return this.length<=1&&!n.target?this:(a._groups.push({elements:this,options:n}),a._apply(this,n),this)};a._groups=[],a._throttle=80,a._maintainScroll=!1,a._beforeUpdate=null,a._afterUpdate=null,a._apply=function(t,n){var s=o(n),l=e(t),u=[l],c=e(window).scrollTop(),d=e("html").outerHeight(!0),p=l.parents().filter(":hidden");return p.each(function(){var t=e(this);t.data("style-cache",t.attr("style"))}),p.css("display","block"),s.byRow&&!s.target&&(l.each(function(){var t=e(this),n=t.css("display");"inline-block"!==n&&"inline-flex"!==n&&(n="block"),t.data("style-cache",t.attr("style")),t.css({display:n,"padding-top":"0","padding-bottom":"0","margin-top":"0","margin-bottom":"0","border-top-width":"0","border-bottom-width":"0",height:"100px"})}),u=r(l),l.each(function(){var t=e(this);t.attr("style",t.data("style-cache")||"")})),e.each(u,function(t,n){var r=e(n),o=0;if(s.target)o=s.target.outerHeight(!1);else{if(s.byRow&&r.length<=1)return void r.css(s.property,"");r.each(function(){var t=e(this),n=t.css("display");"inline-block"!==n&&"inline-flex"!==n&&(n="block");var i={display:n};i[s.property]="",t.css(i),t.outerHeight(!1)>o&&(o=t.outerHeight(!1)),t.css("display","")})}r.each(function(){var t=e(this),n=0;s.target&&t.is(s.target)||("border-box"!==t.css("box-sizing")&&(n+=i(t.css("border-top-width"))+i(t.css("border-bottom-width")),n+=i(t.css("padding-top"))+i(t.css("padding-bottom"))),t.css(s.property,o-n+"px"))})}),p.each(function(){var t=e(this);t.attr("style",t.data("style-cache")||null)}),a._maintainScroll&&e(window).scrollTop(c/d*e("html").outerHeight(!0)),this},a._applyDataApi=function(){var t={};e("[data-match-height], [data-mh]").each(function(){var n=e(this),i=n.attr("data-mh")||n.attr("data-match-height");i in t?t[i]=t[i].add(n):t[i]=n}),e.each(t,function(){this.matchHeight(!0)})};var s=function(t){a._beforeUpdate&&a._beforeUpdate(t,a._groups),e.each(a._groups,function(){a._apply(this.elements,this.options)}),a._afterUpdate&&a._afterUpdate(t,a._groups)};a._update=function(i,r){if(r&&"resize"===r.type){var o=e(window).width();if(o===t)return;t=o}i?-1===n&&(n=setTimeout(function(){s(r),n=-1},a._throttle)):s(r)},e(a._applyDataApi),e(window).bind("load",function(e){a._update(!1,e)}),e(window).bind("resize orientationchange",function(e){a._update(!0,e)})}(e)}).call(t,n(1))},function(e,t,n){var i,r,r,i,o,r,o,i,a,i,o,r;(function(s,l,u,c,d){/*!
	 * Materialize v0.97.0 (http://materializecss.com)
	 * Copyright 2014-2015 Materialize
	 * MIT License (https://raw.githubusercontent.com/Dogfalo/materialize/master/LICENSE)
	 */
s.easing.jswing=s.easing.swing,s.extend(s.easing,{def:"easeOutQuad",swing:function(e,t,n,i,r){return s.easing[s.easing.def](e,t,n,i,r)},easeInQuad:function(e,t,n,i,r){return i*(t/=r)*t+n},easeOutQuad:function(e,t,n,i,r){return-i*(t/=r)*(t-2)+n},easeInOutQuad:function(e,t,n,i,r){return(t/=r/2)<1?i/2*t*t+n:-i/2*(--t*(t-2)-1)+n},easeInCubic:function(e,t,n,i,r){return i*(t/=r)*t*t+n},easeOutCubic:function(e,t,n,i,r){return i*((t=t/r-1)*t*t+1)+n},easeInOutCubic:function(e,t,n,i,r){return(t/=r/2)<1?i/2*t*t*t+n:i/2*((t-=2)*t*t+2)+n},easeInQuart:function(e,t,n,i,r){return i*(t/=r)*t*t*t+n},easeOutQuart:function(e,t,n,i,r){return-i*((t=t/r-1)*t*t*t-1)+n},easeInOutQuart:function(e,t,n,i,r){return(t/=r/2)<1?i/2*t*t*t*t+n:-i/2*((t-=2)*t*t*t-2)+n},easeInQuint:function(e,t,n,i,r){return i*(t/=r)*t*t*t*t+n},easeOutQuint:function(e,t,n,i,r){return i*((t=t/r-1)*t*t*t*t+1)+n},easeInOutQuint:function(e,t,n,i,r){return(t/=r/2)<1?i/2*t*t*t*t*t+n:i/2*((t-=2)*t*t*t*t+2)+n},easeInSine:function(e,t,n,i,r){return-i*Math.cos(t/r*(Math.PI/2))+i+n},easeOutSine:function(e,t,n,i,r){return i*Math.sin(t/r*(Math.PI/2))+n},easeInOutSine:function(e,t,n,i,r){return-i/2*(Math.cos(Math.PI*t/r)-1)+n},easeInExpo:function(e,t,n,i,r){return 0==t?n:i*Math.pow(2,10*(t/r-1))+n},easeOutExpo:function(e,t,n,i,r){return t==r?n+i:i*(-Math.pow(2,-10*t/r)+1)+n},easeInOutExpo:function(e,t,n,i,r){return 0==t?n:t==r?n+i:(t/=r/2)<1?i/2*Math.pow(2,10*(t-1))+n:i/2*(-Math.pow(2,-10*--t)+2)+n},easeInCirc:function(e,t,n,i,r){return-i*(Math.sqrt(1-(t/=r)*t)-1)+n},easeOutCirc:function(e,t,n,i,r){return i*Math.sqrt(1-(t=t/r-1)*t)+n},easeInOutCirc:function(e,t,n,i,r){return(t/=r/2)<1?-i/2*(Math.sqrt(1-t*t)-1)+n:i/2*(Math.sqrt(1-(t-=2)*t)+1)+n},easeInElastic:function(e,t,n,i,r){var o=1.70158,a=0,s=i;if(0==t)return n;if(1==(t/=r))return n+i;if(a||(a=.3*r),s<Math.abs(i)){s=i;var o=a/4}else var o=a/(2*Math.PI)*Math.asin(i/s);return-(s*Math.pow(2,10*(t-=1))*Math.sin((t*r-o)*(2*Math.PI)/a))+n},easeOutElastic:function(e,t,n,i,r){var o=1.70158,a=0,s=i;if(0==t)return n;if(1==(t/=r))return n+i;if(a||(a=.3*r),s<Math.abs(i)){s=i;var o=a/4}else var o=a/(2*Math.PI)*Math.asin(i/s);return s*Math.pow(2,-10*t)*Math.sin((t*r-o)*(2*Math.PI)/a)+i+n},easeInOutElastic:function(e,t,n,i,r){var o=1.70158,a=0,s=i;if(0==t)return n;if(2==(t/=r/2))return n+i;if(a||(a=r*(.3*1.5)),s<Math.abs(i)){s=i;var o=a/4}else var o=a/(2*Math.PI)*Math.asin(i/s);return 1>t?-.5*(s*Math.pow(2,10*(t-=1))*Math.sin((t*r-o)*(2*Math.PI)/a))+n:s*Math.pow(2,-10*(t-=1))*Math.sin((t*r-o)*(2*Math.PI)/a)*.5+i+n},easeInBack:function(e,t,n,i,r,o){return void 0==o&&(o=1.70158),i*(t/=r)*t*((o+1)*t-o)+n},easeOutBack:function(e,t,n,i,r,o){return void 0==o&&(o=1.70158),i*((t=t/r-1)*t*((o+1)*t+o)+1)+n},easeInOutBack:function(e,t,n,i,r,o){return void 0==o&&(o=1.70158),(t/=r/2)<1?i/2*(t*t*(((o*=1.525)+1)*t-o))+n:i/2*((t-=2)*t*(((o*=1.525)+1)*t+o)+2)+n},easeInBounce:function(e,t,n,i,r){return i-s.easing.easeOutBounce(e,r-t,0,i,r)+n},easeOutBounce:function(e,t,n,i,r){return(t/=r)<1/2.75?i*(7.5625*t*t)+n:2/2.75>t?i*(7.5625*(t-=1.5/2.75)*t+.75)+n:2.5/2.75>t?i*(7.5625*(t-=2.25/2.75)*t+.9375)+n:i*(7.5625*(t-=2.625/2.75)*t+.984375)+n},easeInOutBounce:function(e,t,n,i,r){return r/2>t?.5*s.easing.easeInBounce(e,2*t,0,i,r)+n:.5*s.easing.easeOutBounce(e,2*t-r,0,i,r)+.5*i+n}}),s.extend(s.easing,{easeInOutMaterial:function(e,t,n,i,r){return(t/=r/2)<1?i/2*t*t+n:i/4*((t-=2)*t*t+2)+n}}),/*! VelocityJS.org (1.2.2). (C) 2014 Julian Shapiro. MIT @license: en.wikipedia.org/wiki/MIT_License */
/*! VelocityJS.org jQuery Shim (1.0.1). (C) 2014 The jQuery Foundation. MIT @license: en.wikipedia.org/wiki/MIT_License. */
!function(e){function t(e){var t=e.length,i=n.type(e);return"function"===i||n.isWindow(e)?!1:1===e.nodeType&&t?!0:"array"===i||0===t||"number"==typeof t&&t>0&&t-1 in e}if(!u){var n=function(e,t){return new n.fn.init(e,t)};n.isWindow=function(e){return null!=e&&e==e.window},n.type=function(e){return null==e?e+"":"object"==typeof e||"function"==typeof e?r[a.call(e)]||"object":typeof e},n.isArray=Array.isArray||function(e){return"array"===n.type(e)},n.isPlainObject=function(e){var t;if(!e||"object"!==n.type(e)||e.nodeType||n.isWindow(e))return!1;try{if(e.constructor&&!o.call(e,"constructor")&&!o.call(e.constructor.prototype,"isPrototypeOf"))return!1}catch(i){return!1}for(t in e);return void 0===t||o.call(e,t)},n.each=function(e,n,i){var r,o=0,a=e.length,s=t(e);if(i){if(s)for(;a>o&&(r=n.apply(e[o],i),r!==!1);o++);else for(o in e)if(r=n.apply(e[o],i),r===!1)break}else if(s)for(;a>o&&(r=n.call(e[o],o,e[o]),r!==!1);o++);else for(o in e)if(r=n.call(e[o],o,e[o]),r===!1)break;return e},n.data=function(e,t,r){if(void 0===r){var o=e[n.expando],a=o&&i[o];if(void 0===t)return a;if(a&&t in a)return a[t]}else if(void 0!==t){var o=e[n.expando]||(e[n.expando]=++n.uuid);return i[o]=i[o]||{},i[o][t]=r,r}},n.removeData=function(e,t){var r=e[n.expando],o=r&&i[r];o&&n.each(t,function(e,t){delete o[t]})},n.extend=function(){var e,t,i,r,o,a,s=arguments[0]||{},l=1,u=arguments.length,c=!1;for("boolean"==typeof s&&(c=s,s=arguments[l]||{},l++),"object"!=typeof s&&"function"!==n.type(s)&&(s={}),l===u&&(s=this,l--);u>l;l++)if(null!=(o=arguments[l]))for(r in o)e=s[r],i=o[r],s!==i&&(c&&i&&(n.isPlainObject(i)||(t=n.isArray(i)))?(t?(t=!1,a=e&&n.isArray(e)?e:[]):a=e&&n.isPlainObject(e)?e:{},s[r]=n.extend(c,a,i)):void 0!==i&&(s[r]=i));return s},n.queue=function(e,i,r){function o(e,n){var i=n||[];return null!=e&&(t(Object(e))?!function(e,t){for(var n=+t.length,i=0,r=e.length;n>i;)e[r++]=t[i++];if(n!==n)for(;void 0!==t[i];)e[r++]=t[i++];return e.length=r,e}(i,"string"==typeof e?[e]:e):[].push.call(i,e)),i}if(e){i=(i||"fx")+"queue";var a=n.data(e,i);return r?(!a||n.isArray(r)?a=n.data(e,i,o(r)):a.push(r),a):a||[]}},n.dequeue=function(e,t){n.each(e.nodeType?[e]:e,function(e,i){t=t||"fx";var r=n.queue(i,t),o=r.shift();"inprogress"===o&&(o=r.shift()),o&&("fx"===t&&r.unshift("inprogress"),o.call(i,function(){n.dequeue(i,t)}))})},n.fn=n.prototype={init:function(e){if(e.nodeType)return this[0]=e,this;throw new Error("Not a DOM node.")},offset:function(){var t=this[0].getBoundingClientRect?this[0].getBoundingClientRect():{top:0,left:0};return{top:t.top+(e.pageYOffset||document.scrollTop||0)-(document.clientTop||0),left:t.left+(e.pageXOffset||document.scrollLeft||0)-(document.clientLeft||0)}},position:function(){function e(){for(var e=this.offsetParent||document;e&&"html"===!e.nodeType.toLowerCase&&"static"===e.style.position;)e=e.offsetParent;return e||document}var t=this[0],e=e.apply(t),i=this.offset(),r=/^(?:body|html)$/i.test(e.nodeName)?{top:0,left:0}:n(e).offset();return i.top-=parseFloat(t.style.marginTop)||0,i.left-=parseFloat(t.style.marginLeft)||0,e.style&&(r.top+=parseFloat(e.style.borderTopWidth)||0,r.left+=parseFloat(e.style.borderLeftWidth)||0),{top:i.top-r.top,left:i.left-r.left}}};var i={};n.expando="velocity"+(new Date).getTime(),n.uuid=0;for(var r={},o=r.hasOwnProperty,a=r.toString,s="Boolean Number String Function Array Date RegExp Object Error".split(" "),l=0;l<s.length;l++)r["[object "+s[l]+"]"]=s[l].toLowerCase();n.fn.init.prototype=n.fn,e.Velocity={Utilities:n}}}(window),function(o){"object"==typeof e&&"object"==typeof e.exports?e.exports=o():(i=o,r="function"==typeof i?i.call(t,n,t,e):i,!(void 0!==r&&(e.exports=r)))}(function(){return function(e,t,n,i){function r(e){for(var t=-1,n=e?e.length:0,i=[];++t<n;){var r=e[t];r&&i.push(r)}return i}function o(e){return v.isWrapped(e)?e=[].slice.call(e):v.isNode(e)&&(e=[e]),e}function a(e){var t=h.data(e,"velocity");return null===t?i:t}function l(e){return function(t){return Math.round(t*e)*(1/e)}}function u(e,n,i,r){function o(e,t){return 1-3*t+3*e}function a(e,t){return 3*t-6*e}function s(e){return 3*e}function l(e,t,n){return((o(t,n)*e+a(t,n))*e+s(t))*e}function u(e,t,n){return 3*o(t,n)*e*e+2*a(t,n)*e+s(t)}function c(t,n){for(var r=0;g>r;++r){var o=u(n,e,i);if(0===o)return n;var a=l(n,e,i)-t;n-=a/o}return n}function d(){for(var t=0;b>t;++t)k[t]=l(t*w,e,i)}function p(t,n,r){var o,a,s=0;do a=n+(r-n)/2,o=l(a,e,i)-t,o>0?r=a:n=a;while(Math.abs(o)>m&&++s<y);return a}function h(t){for(var n=0,r=1,o=b-1;r!=o&&k[r]<=t;++r)n+=w;--r;var a=(t-k[r])/(k[r+1]-k[r]),s=n+a*w,l=u(s,e,i);return l>=v?c(t,s):0==l?s:p(t,n,n+w)}function f(){C=!0,(e!=n||i!=r)&&d()}var g=4,v=.001,m=1e-7,y=10,b=11,w=1/(b-1),x="Float32Array"in t;if(4!==arguments.length)return!1;for(var _=0;4>_;++_)if("number"!=typeof arguments[_]||isNaN(arguments[_])||!isFinite(arguments[_]))return!1;e=Math.min(e,1),i=Math.min(i,1),e=Math.max(e,0),i=Math.max(i,0);var k=x?new Float32Array(b):new Array(b),C=!1,T=function(t){return C||f(),e===n&&i===r?t:0===t?0:1===t?1:l(h(t),n,r)};T.getControlPoints=function(){return[{x:e,y:n},{x:i,y:r}]};var D="generateBezier("+[e,n,i,r]+")";return T.toString=function(){return D},T}function c(e,t){var n=e;return v.isString(e)?w.Easings[e]||(n=!1):n=v.isArray(e)&&1===e.length?l.apply(null,e):v.isArray(e)&&2===e.length?x.apply(null,e.concat([t])):v.isArray(e)&&4===e.length?u.apply(null,e):!1,n===!1&&(n=w.Easings[w.defaults.easing]?w.defaults.easing:b),n}function d(e){if(e){var t=(new Date).getTime(),n=w.State.calls.length;n>1e4&&(w.State.calls=r(w.State.calls));for(var o=0;n>o;o++)if(w.State.calls[o]){var s=w.State.calls[o],l=s[0],u=s[2],c=s[3],f=!!c,g=null;c||(c=w.State.calls[o][3]=t-16);for(var m=Math.min((t-c)/u.duration,1),y=0,b=l.length;b>y;y++){var x=l[y],k=x.element;if(a(k)){var T=!1;if(u.display!==i&&null!==u.display&&"none"!==u.display){if("flex"===u.display){var D=["-webkit-box","-moz-box","-ms-flexbox","-webkit-flex"];h.each(D,function(e,t){_.setPropertyValue(k,"display",t)})}_.setPropertyValue(k,"display",u.display)}u.visibility!==i&&"hidden"!==u.visibility&&_.setPropertyValue(k,"visibility",u.visibility);for(var S in x)if("element"!==S){var E,A=x[S],M=v.isString(A.easing)?w.Easings[A.easing]:A.easing;if(1===m)E=A.endValue;else{var O=A.endValue-A.startValue;if(E=A.startValue+O*M(m,u,O),!f&&E===A.currentValue)continue}if(A.currentValue=E,"tween"===S)g=E;else{if(_.Hooks.registered[S]){var I=_.Hooks.getRoot(S),N=a(k).rootPropertyValueCache[I];N&&(A.rootPropertyValue=N)}var F=_.setPropertyValue(k,S,A.currentValue+(0===parseFloat(E)?"":A.unitType),A.rootPropertyValue,A.scrollData);_.Hooks.registered[S]&&(a(k).rootPropertyValueCache[I]=_.Normalizations.registered[I]?_.Normalizations.registered[I]("extract",null,F[1]):F[1]),"transform"===F[0]&&(T=!0)}}u.mobileHA&&a(k).transformCache.translate3d===i&&(a(k).transformCache.translate3d="(0px, 0px, 0px)",T=!0),T&&_.flushTransformCache(k)}}u.display!==i&&"none"!==u.display&&(w.State.calls[o][2].display=!1),u.visibility!==i&&"hidden"!==u.visibility&&(w.State.calls[o][2].visibility=!1),u.progress&&u.progress.call(s[1],s[1],m,Math.max(0,c+u.duration-t),c,g),1===m&&p(o)}}w.State.isTicking&&C(d)}function p(e,t){if(!w.State.calls[e])return!1;for(var n=w.State.calls[e][0],r=w.State.calls[e][1],o=w.State.calls[e][2],s=w.State.calls[e][4],l=!1,u=0,c=n.length;c>u;u++){var d=n[u].element;if(t||o.loop||("none"===o.display&&_.setPropertyValue(d,"display",o.display),"hidden"===o.visibility&&_.setPropertyValue(d,"visibility",o.visibility)),o.loop!==!0&&(h.queue(d)[1]===i||!/\.velocityQueueEntryFlag/i.test(h.queue(d)[1]))&&a(d)){a(d).isAnimating=!1,a(d).rootPropertyValueCache={};var p=!1;h.each(_.Lists.transforms3D,function(e,t){var n=/^scale/.test(t)?1:0,r=a(d).transformCache[t];a(d).transformCache[t]!==i&&new RegExp("^\\("+n+"[^.]").test(r)&&(p=!0,delete a(d).transformCache[t])}),o.mobileHA&&(p=!0,delete a(d).transformCache.translate3d),p&&_.flushTransformCache(d),_.Values.removeClass(d,"velocity-animating")}if(!t&&o.complete&&!o.loop&&u===c-1)try{o.complete.call(r,r)}catch(f){setTimeout(function(){throw f},1)}s&&o.loop!==!0&&s(r),a(d)&&o.loop===!0&&!t&&(h.each(a(d).tweensContainer,function(e,t){/^rotate/.test(e)&&360===parseFloat(t.endValue)&&(t.endValue=0,t.startValue=360),/^backgroundPosition/.test(e)&&100===parseFloat(t.endValue)&&"%"===t.unitType&&(t.endValue=0,t.startValue=100)}),w(d,"reverse",{loop:!0,delay:o.delay})),o.queue!==!1&&h.dequeue(d,o.queue)}w.State.calls[e]=!1;for(var g=0,v=w.State.calls.length;v>g;g++)if(w.State.calls[g]!==!1){l=!0;break}l===!1&&(w.State.isTicking=!1,delete w.State.calls,w.State.calls=[])}var h,f=function(){if(n.documentMode)return n.documentMode;for(var e=7;e>4;e--){var t=n.createElement("div");if(t.innerHTML="<!--[if IE "+e+"]><span></span><![endif]-->",t.getElementsByTagName("span").length)return t=null,e}return i}(),g=function(){var e=0;return t.webkitRequestAnimationFrame||t.mozRequestAnimationFrame||function(t){var n,i=(new Date).getTime();return n=Math.max(0,16-(i-e)),e=i+n,setTimeout(function(){t(i+n)},n)}}(),v={isString:function(e){return"string"==typeof e},isArray:Array.isArray||function(e){return"[object Array]"===Object.prototype.toString.call(e)},isFunction:function(e){return"[object Function]"===Object.prototype.toString.call(e)},isNode:function(e){return e&&e.nodeType},isNodeList:function(e){return"object"==typeof e&&/^\[object (HTMLCollection|NodeList|Object)\]$/.test(Object.prototype.toString.call(e))&&e.length!==i&&(0===e.length||"object"==typeof e[0]&&e[0].nodeType>0)},isWrapped:function(e){return e&&(e.jquery||t.Zepto&&t.Zepto.zepto.isZ(e))},isSVG:function(e){return t.SVGElement&&e instanceof t.SVGElement},isEmptyObject:function(e){for(var t in e)return!1;return!0}},m=!1;if(e.fn&&e.fn.jquery?(h=e,m=!0):h=t.Velocity.Utilities,8>=f&&!m)throw new Error("Velocity: IE8 and below require jQuery to be loaded before Velocity.");if(7>=f)return void(s.fn.velocity=s.fn.animate);var y=400,b="swing",w={State:{isMobile:/Android|webOS|iPhone|iPad|iPod|BlackBerry|IEMobile|Opera Mini/i.test(navigator.userAgent),isAndroid:/Android/i.test(navigator.userAgent),isGingerbread:/Android 2\.3\.[3-7]/i.test(navigator.userAgent),isChrome:t.chrome,isFirefox:/Firefox/i.test(navigator.userAgent),prefixElement:n.createElement("div"),prefixMatches:{},scrollAnchor:null,scrollPropertyLeft:null,scrollPropertyTop:null,isTicking:!1,calls:[]},CSS:{},Utilities:h,Redirects:{},Easings:{},Promise:t.Promise,defaults:{queue:"",duration:y,easing:b,begin:i,complete:i,progress:i,display:i,visibility:i,loop:!1,delay:!1,mobileHA:!0,_cacheValues:!0},init:function(e){h.data(e,"velocity",{isSVG:v.isSVG(e),isAnimating:!1,computedStyle:null,tweensContainer:null,rootPropertyValueCache:{},transformCache:{}})},hook:null,mock:!1,version:{major:1,minor:2,patch:2},debug:!1};t.pageYOffset!==i?(w.State.scrollAnchor=t,w.State.scrollPropertyLeft="pageXOffset",w.State.scrollPropertyTop="pageYOffset"):(w.State.scrollAnchor=n.documentElement||n.body.parentNode||n.body,w.State.scrollPropertyLeft="scrollLeft",w.State.scrollPropertyTop="scrollTop");var x=function(){function e(e){return-e.tension*e.x-e.friction*e.v}function t(t,n,i){var r={x:t.x+i.dx*n,v:t.v+i.dv*n,tension:t.tension,friction:t.friction};return{dx:r.v,dv:e(r)}}function n(n,i){var r={dx:n.v,dv:e(n)},o=t(n,.5*i,r),a=t(n,.5*i,o),s=t(n,i,a),l=1/6*(r.dx+2*(o.dx+a.dx)+s.dx),u=1/6*(r.dv+2*(o.dv+a.dv)+s.dv);return n.x=n.x+l*i,n.v=n.v+u*i,n}return function i(e,t,r){var o,a,s,l={x:-1,v:0,tension:null,friction:null},u=[0],c=0,d=1e-4,p=.016;for(e=parseFloat(e)||500,t=parseFloat(t)||20,r=r||null,l.tension=e,l.friction=t,o=null!==r,o?(c=i(e,t),a=c/r*p):a=p;s=n(s||l,a),u.push(1+s.x),c+=16,Math.abs(s.x)>d&&Math.abs(s.v)>d;);return o?function(e){return u[e*(u.length-1)|0]}:c}}();w.Easings={linear:function(e){return e},swing:function(e){return.5-Math.cos(e*Math.PI)/2},spring:function(e){return 1-Math.cos(4.5*e*Math.PI)*Math.exp(6*-e)}},h.each([["ease",[.25,.1,.25,1]],["ease-in",[.42,0,1,1]],["ease-out",[0,0,.58,1]],["ease-in-out",[.42,0,.58,1]],["easeInSine",[.47,0,.745,.715]],["easeOutSine",[.39,.575,.565,1]],["easeInOutSine",[.445,.05,.55,.95]],["easeInQuad",[.55,.085,.68,.53]],["easeOutQuad",[.25,.46,.45,.94]],["easeInOutQuad",[.455,.03,.515,.955]],["easeInCubic",[.55,.055,.675,.19]],["easeOutCubic",[.215,.61,.355,1]],["easeInOutCubic",[.645,.045,.355,1]],["easeInQuart",[.895,.03,.685,.22]],["easeOutQuart",[.165,.84,.44,1]],["easeInOutQuart",[.77,0,.175,1]],["easeInQuint",[.755,.05,.855,.06]],["easeOutQuint",[.23,1,.32,1]],["easeInOutQuint",[.86,0,.07,1]],["easeInExpo",[.95,.05,.795,.035]],["easeOutExpo",[.19,1,.22,1]],["easeInOutExpo",[1,0,0,1]],["easeInCirc",[.6,.04,.98,.335]],["easeOutCirc",[.075,.82,.165,1]],["easeInOutCirc",[.785,.135,.15,.86]]],function(e,t){w.Easings[t[0]]=u.apply(null,t[1])});var _=w.CSS={RegEx:{isHex:/^#([A-f\d]{3}){1,2}$/i,valueUnwrap:/^[A-z]+\((.*)\)$/i,wrappedValueAlreadyExtracted:/[0-9.]+ [0-9.]+ [0-9.]+( [0-9.]+)?/,valueSplit:/([A-z]+\(.+\))|(([A-z0-9#-.]+?)(?=\s|$))/gi},Lists:{colors:["fill","stroke","stopColor","color","backgroundColor","borderColor","borderTopColor","borderRightColor","borderBottomColor","borderLeftColor","outlineColor"],transformsBase:["translateX","translateY","scale","scaleX","scaleY","skewX","skewY","rotateZ"],transforms3D:["transformPerspective","translateZ","scaleZ","rotateX","rotateY"]},Hooks:{templates:{textShadow:["Color X Y Blur","black 0px 0px 0px"],boxShadow:["Color X Y Blur Spread","black 0px 0px 0px 0px"],clip:["Top Right Bottom Left","0px 0px 0px 0px"],backgroundPosition:["X Y","0% 0%"],transformOrigin:["X Y Z","50% 50% 0px"],perspectiveOrigin:["X Y","50% 50%"]},registered:{},register:function(){for(var e=0;e<_.Lists.colors.length;e++){var t="color"===_.Lists.colors[e]?"0 0 0 1":"255 255 255 1";_.Hooks.templates[_.Lists.colors[e]]=["Red Green Blue Alpha",t]}var n,i,r;if(f)for(n in _.Hooks.templates){i=_.Hooks.templates[n],r=i[0].split(" ");var o=i[1].match(_.RegEx.valueSplit);"Color"===r[0]&&(r.push(r.shift()),o.push(o.shift()),_.Hooks.templates[n]=[r.join(" "),o.join(" ")])}for(n in _.Hooks.templates){i=_.Hooks.templates[n],r=i[0].split(" ");for(var e in r){var a=n+r[e],s=e;_.Hooks.registered[a]=[n,s]}}},getRoot:function(e){var t=_.Hooks.registered[e];return t?t[0]:e},cleanRootPropertyValue:function(e,t){return _.RegEx.valueUnwrap.test(t)&&(t=t.match(_.RegEx.valueUnwrap)[1]),_.Values.isCSSNullValue(t)&&(t=_.Hooks.templates[e][1]),t},extractValue:function(e,t){var n=_.Hooks.registered[e];if(n){var i=n[0],r=n[1];return t=_.Hooks.cleanRootPropertyValue(i,t),t.toString().match(_.RegEx.valueSplit)[r]}return t},injectValue:function(e,t,n){var i=_.Hooks.registered[e];if(i){var r,o,a=i[0],s=i[1];return n=_.Hooks.cleanRootPropertyValue(a,n),r=n.toString().match(_.RegEx.valueSplit),r[s]=t,o=r.join(" ")}return n}},Normalizations:{registered:{clip:function(e,t,n){switch(e){case"name":return"clip";case"extract":var i;return _.RegEx.wrappedValueAlreadyExtracted.test(n)?i=n:(i=n.toString().match(_.RegEx.valueUnwrap),i=i?i[1].replace(/,(\s+)?/g," "):n),i;case"inject":return"rect("+n+")"}},blur:function(e,t,n){switch(e){case"name":return w.State.isFirefox?"filter":"-webkit-filter";case"extract":var i=parseFloat(n);if(!i&&0!==i){var r=n.toString().match(/blur\(([0-9]+[A-z]+)\)/i);i=r?r[1]:0}return i;case"inject":return parseFloat(n)?"blur("+n+")":"none"}},opacity:function(e,t,n){if(8>=f)switch(e){case"name":return"filter";case"extract":var i=n.toString().match(/alpha\(opacity=(.*)\)/i);return n=i?i[1]/100:1;case"inject":return t.style.zoom=1,parseFloat(n)>=1?"":"alpha(opacity="+parseInt(100*parseFloat(n),10)+")"}else switch(e){case"name":return"opacity";case"extract":return n;case"inject":return n}}},register:function(){9>=f||w.State.isGingerbread||(_.Lists.transformsBase=_.Lists.transformsBase.concat(_.Lists.transforms3D));for(var e=0;e<_.Lists.transformsBase.length;e++)!function(){var t=_.Lists.transformsBase[e];_.Normalizations.registered[t]=function(e,n,r){switch(e){case"name":return"transform";case"extract":return a(n)===i||a(n).transformCache[t]===i?/^scale/i.test(t)?1:0:a(n).transformCache[t].replace(/[()]/g,"");case"inject":var o=!1;switch(t.substr(0,t.length-1)){case"translate":o=!/(%|px|em|rem|vw|vh|\d)$/i.test(r);break;case"scal":case"scale":w.State.isAndroid&&a(n).transformCache[t]===i&&1>r&&(r=1),o=!/(\d)$/i.test(r);break;case"skew":o=!/(deg|\d)$/i.test(r);break;case"rotate":o=!/(deg|\d)$/i.test(r)}return o||(a(n).transformCache[t]="("+r+")"),a(n).transformCache[t]}}}();for(var e=0;e<_.Lists.colors.length;e++)!function(){var t=_.Lists.colors[e];_.Normalizations.registered[t]=function(e,n,r){switch(e){case"name":return t;case"extract":var o;if(_.RegEx.wrappedValueAlreadyExtracted.test(r))o=r;else{var a,s={black:"rgb(0, 0, 0)",blue:"rgb(0, 0, 255)",gray:"rgb(128, 128, 128)",green:"rgb(0, 128, 0)",red:"rgb(255, 0, 0)",white:"rgb(255, 255, 255)"};/^[A-z]+$/i.test(r)?a=s[r]!==i?s[r]:s.black:_.RegEx.isHex.test(r)?a="rgb("+_.Values.hexToRgb(r).join(" ")+")":/^rgba?\(/i.test(r)||(a=s.black),o=(a||r).toString().match(_.RegEx.valueUnwrap)[1].replace(/,(\s+)?/g," ")}return 8>=f||3!==o.split(" ").length||(o+=" 1"),o;case"inject":return 8>=f?4===r.split(" ").length&&(r=r.split(/\s+/).slice(0,3).join(" ")):3===r.split(" ").length&&(r+=" 1"),(8>=f?"rgb":"rgba")+"("+r.replace(/\s+/g,",").replace(/\.(\d)+(?=,)/g,"")+")"}}}()}},Names:{camelCase:function(e){return e.replace(/-(\w)/g,function(e,t){return t.toUpperCase()})},SVGAttribute:function(e){var t="width|height|x|y|cx|cy|r|rx|ry|x1|x2|y1|y2";return(f||w.State.isAndroid&&!w.State.isChrome)&&(t+="|transform"),new RegExp("^("+t+")$","i").test(e)},prefixCheck:function(e){if(w.State.prefixMatches[e])return[w.State.prefixMatches[e],!0];for(var t=["","Webkit","Moz","ms","O"],n=0,i=t.length;i>n;n++){var r;if(r=0===n?e:t[n]+e.replace(/^\w/,function(e){return e.toUpperCase()}),v.isString(w.State.prefixElement.style[r]))return w.State.prefixMatches[e]=r,[r,!0]}return[e,!1]}},Values:{hexToRgb:function(e){var t,n=/^#?([a-f\d])([a-f\d])([a-f\d])$/i,i=/^#?([a-f\d]{2})([a-f\d]{2})([a-f\d]{2})$/i;return e=e.replace(n,function(e,t,n,i){return t+t+n+n+i+i}),t=i.exec(e),t?[parseInt(t[1],16),parseInt(t[2],16),parseInt(t[3],16)]:[0,0,0]},isCSSNullValue:function(e){return 0==e||/^(none|auto|transparent|(rgba\(0, ?0, ?0, ?0\)))$/i.test(e)},getUnitType:function(e){return/^(rotate|skew)/i.test(e)?"deg":/(^(scale|scaleX|scaleY|scaleZ|alpha|flexGrow|flexHeight|zIndex|fontWeight)$)|((opacity|red|green|blue|alpha)$)/i.test(e)?"":"px"},getDisplayType:function(e){var t=e&&e.tagName.toString().toLowerCase();return/^(b|big|i|small|tt|abbr|acronym|cite|code|dfn|em|kbd|strong|samp|var|a|bdo|br|img|map|object|q|script|span|sub|sup|button|input|label|select|textarea)$/i.test(t)?"inline":/^(li)$/i.test(t)?"list-item":/^(tr)$/i.test(t)?"table-row":/^(table)$/i.test(t)?"table":/^(tbody)$/i.test(t)?"table-row-group":"block"},addClass:function(e,t){e.classList?e.classList.add(t):e.className+=(e.className.length?" ":"")+t},removeClass:function(e,t){e.classList?e.classList.remove(t):e.className=e.className.toString().replace(new RegExp("(^|\\s)"+t.split(" ").join("|")+"(\\s|$)","gi")," ")}},getPropertyValue:function(e,n,r,o){function s(e,n){function r(){u&&_.setPropertyValue(e,"display","none")}var l=0;if(8>=f)l=h.css(e,n);else{var u=!1;if(/^(width|height)$/.test(n)&&0===_.getPropertyValue(e,"display")&&(u=!0,_.setPropertyValue(e,"display",_.Values.getDisplayType(e))),!o){if("height"===n&&"border-box"!==_.getPropertyValue(e,"boxSizing").toString().toLowerCase()){var c=e.offsetHeight-(parseFloat(_.getPropertyValue(e,"borderTopWidth"))||0)-(parseFloat(_.getPropertyValue(e,"borderBottomWidth"))||0)-(parseFloat(_.getPropertyValue(e,"paddingTop"))||0)-(parseFloat(_.getPropertyValue(e,"paddingBottom"))||0);return r(),c}if("width"===n&&"border-box"!==_.getPropertyValue(e,"boxSizing").toString().toLowerCase()){var d=e.offsetWidth-(parseFloat(_.getPropertyValue(e,"borderLeftWidth"))||0)-(parseFloat(_.getPropertyValue(e,"borderRightWidth"))||0)-(parseFloat(_.getPropertyValue(e,"paddingLeft"))||0)-(parseFloat(_.getPropertyValue(e,"paddingRight"))||0);return r(),d}}var p;p=a(e)===i?t.getComputedStyle(e,null):a(e).computedStyle?a(e).computedStyle:a(e).computedStyle=t.getComputedStyle(e,null),"borderColor"===n&&(n="borderTopColor"),l=9===f&&"filter"===n?p.getPropertyValue(n):p[n],(""===l||null===l)&&(l=e.style[n]),r()}if("auto"===l&&/^(top|right|bottom|left)$/i.test(n)){var g=s(e,"position");("fixed"===g||"absolute"===g&&/top|left/i.test(n))&&(l=h(e).position()[n]+"px")}return l}var l;if(_.Hooks.registered[n]){var u=n,c=_.Hooks.getRoot(u);r===i&&(r=_.getPropertyValue(e,_.Names.prefixCheck(c)[0])),_.Normalizations.registered[c]&&(r=_.Normalizations.registered[c]("extract",e,r)),l=_.Hooks.extractValue(u,r)}else if(_.Normalizations.registered[n]){var d,p;d=_.Normalizations.registered[n]("name",e),"transform"!==d&&(p=s(e,_.Names.prefixCheck(d)[0]),_.Values.isCSSNullValue(p)&&_.Hooks.templates[n]&&(p=_.Hooks.templates[n][1])),l=_.Normalizations.registered[n]("extract",e,p)}if(!/^[\d-]/.test(l))if(a(e)&&a(e).isSVG&&_.Names.SVGAttribute(n))if(/^(height|width)$/i.test(n))try{l=e.getBBox()[n]}catch(g){l=0}else l=e.getAttribute(n);else l=s(e,_.Names.prefixCheck(n)[0]);return _.Values.isCSSNullValue(l)&&(l=0),w.debug>=2&&console.log("Get "+n+": "+l),l},setPropertyValue:function(e,n,i,r,o){var s=n;if("scroll"===n)o.container?o.container["scroll"+o.direction]=i:"Left"===o.direction?t.scrollTo(i,o.alternateValue):t.scrollTo(o.alternateValue,i);else if(_.Normalizations.registered[n]&&"transform"===_.Normalizations.registered[n]("name",e))_.Normalizations.registered[n]("inject",e,i),s="transform",i=a(e).transformCache[n];else{if(_.Hooks.registered[n]){var l=n,u=_.Hooks.getRoot(n);r=r||_.getPropertyValue(e,u),i=_.Hooks.injectValue(l,i,r),n=u}if(_.Normalizations.registered[n]&&(i=_.Normalizations.registered[n]("inject",e,i),n=_.Normalizations.registered[n]("name",e)),s=_.Names.prefixCheck(n)[0],8>=f)try{e.style[s]=i}catch(c){w.debug&&console.log("Browser does not support ["+i+"] for ["+s+"]")}else a(e)&&a(e).isSVG&&_.Names.SVGAttribute(n)?e.setAttribute(n,i):e.style[s]=i;w.debug>=2&&console.log("Set "+n+" ("+s+"): "+i)}return[s,i]},flushTransformCache:function(e){function t(t){return parseFloat(_.getPropertyValue(e,t))}var n="";if((f||w.State.isAndroid&&!w.State.isChrome)&&a(e).isSVG){var i={translate:[t("translateX"),t("translateY")],skewX:[t("skewX")],skewY:[t("skewY")],scale:1!==t("scale")?[t("scale"),t("scale")]:[t("scaleX"),t("scaleY")],rotate:[t("rotateZ"),0,0]};h.each(a(e).transformCache,function(e){/^translate/i.test(e)?e="translate":/^scale/i.test(e)?e="scale":/^rotate/i.test(e)&&(e="rotate"),i[e]&&(n+=e+"("+i[e].join(" ")+") ",delete i[e])})}else{var r,o;h.each(a(e).transformCache,function(t){return r=a(e).transformCache[t],"transformPerspective"===t?(o=r,!0):(9===f&&"rotateZ"===t&&(t="rotate"),void(n+=t+r+" "))}),o&&(n="perspective"+o+" "+n)}_.setPropertyValue(e,"transform",n)}};_.Hooks.register(),_.Normalizations.register(),w.hook=function(e,t,n){var r=i;return e=o(e),h.each(e,function(e,o){if(a(o)===i&&w.init(o),n===i)r===i&&(r=w.CSS.getPropertyValue(o,t));else{var s=w.CSS.setPropertyValue(o,t,n);"transform"===s[0]&&w.CSS.flushTransformCache(o),r=s}}),r};var k=function(){function e(){return s?S.promise||null:l}function r(){function e(e){function u(e,t){var n=i,r=i,a=i;return v.isArray(e)?(n=e[0],!v.isArray(e[1])&&/^[\d-]/.test(e[1])||v.isFunction(e[1])||_.RegEx.isHex.test(e[1])?a=e[1]:(v.isString(e[1])&&!_.RegEx.isHex.test(e[1])||v.isArray(e[1]))&&(r=t?e[1]:c(e[1],s.duration),e[2]!==i&&(a=e[2]))):n=e,t||(r=r||s.easing),v.isFunction(n)&&(n=n.call(o,C,x)),v.isFunction(a)&&(a=a.call(o,C,x)),[n||0,r,a]}function p(e,t){var n,i;return i=(t||"0").toString().toLowerCase().replace(/[%A-z]+$/,function(e){return n=e,""}),n||(n=_.Values.getUnitType(e)),[i,n]}function y(){var e={myParent:o.parentNode||n.body,position:_.getPropertyValue(o,"position"),fontSize:_.getPropertyValue(o,"fontSize")},i=e.position===F.lastPosition&&e.myParent===F.lastParent,r=e.fontSize===F.lastFontSize;F.lastParent=e.myParent,F.lastPosition=e.position,F.lastFontSize=e.fontSize;var s=100,l={};if(r&&i)l.emToPx=F.lastEmToPx,l.percentToPxWidth=F.lastPercentToPxWidth,l.percentToPxHeight=F.lastPercentToPxHeight;else{var u=a(o).isSVG?n.createElementNS("http://www.w3.org/2000/svg","rect"):n.createElement("div");w.init(u),e.myParent.appendChild(u),h.each(["overflow","overflowX","overflowY"],function(e,t){w.CSS.setPropertyValue(u,t,"hidden")}),w.CSS.setPropertyValue(u,"position",e.position),w.CSS.setPropertyValue(u,"fontSize",e.fontSize),w.CSS.setPropertyValue(u,"boxSizing","content-box"),h.each(["minWidth","maxWidth","width","minHeight","maxHeight","height"],function(e,t){w.CSS.setPropertyValue(u,t,s+"%")}),w.CSS.setPropertyValue(u,"paddingLeft",s+"em"),l.percentToPxWidth=F.lastPercentToPxWidth=(parseFloat(_.getPropertyValue(u,"width",null,!0))||1)/s,l.percentToPxHeight=F.lastPercentToPxHeight=(parseFloat(_.getPropertyValue(u,"height",null,!0))||1)/s,l.emToPx=F.lastEmToPx=(parseFloat(_.getPropertyValue(u,"paddingLeft"))||1)/s,e.myParent.removeChild(u)}return null===F.remToPx&&(F.remToPx=parseFloat(_.getPropertyValue(n.body,"fontSize"))||16),null===F.vwToPx&&(F.vwToPx=parseFloat(t.innerWidth)/100,F.vhToPx=parseFloat(t.innerHeight)/100),l.remToPx=F.remToPx,l.vwToPx=F.vwToPx,l.vhToPx=F.vhToPx,w.debug>=1&&console.log("Unit ratios: "+JSON.stringify(l),o),l}if(s.begin&&0===C)try{s.begin.call(f,f)}catch(b){setTimeout(function(){throw b},1)}if("scroll"===E){var k,T,D,A=/^x$/i.test(s.axis)?"Left":"Top",M=parseFloat(s.offset)||0;s.container?v.isWrapped(s.container)||v.isNode(s.container)?(s.container=s.container[0]||s.container,k=s.container["scroll"+A],D=k+h(o).position()[A.toLowerCase()]+M):s.container=null:(k=w.State.scrollAnchor[w.State["scrollProperty"+A]],T=w.State.scrollAnchor[w.State["scrollProperty"+("Left"===A?"Top":"Left")]],D=h(o).offset()[A.toLowerCase()]+M),l={scroll:{rootPropertyValue:!1,startValue:k,currentValue:k,endValue:D,unitType:"",easing:s.easing,scrollData:{container:s.container,direction:A,alternateValue:T}},element:o},w.debug&&console.log("tweensContainer (scroll): ",l.scroll,o)}else if("reverse"===E){if(!a(o).tweensContainer)return void h.dequeue(o,s.queue);"none"===a(o).opts.display&&(a(o).opts.display="auto"),"hidden"===a(o).opts.visibility&&(a(o).opts.visibility="visible"),a(o).opts.loop=!1,a(o).opts.begin=null,a(o).opts.complete=null,m.easing||delete s.easing,m.duration||delete s.duration,s=h.extend({},a(o).opts,s);var O=h.extend(!0,{},a(o).tweensContainer);for(var I in O)if("element"!==I){var N=O[I].startValue;O[I].startValue=O[I].currentValue=O[I].endValue,O[I].endValue=N,v.isEmptyObject(m)||(O[I].easing=s.easing),w.debug&&console.log("reverse tweensContainer ("+I+"): "+JSON.stringify(O[I]),o)}l=O}else if("start"===E){var O;a(o).tweensContainer&&a(o).isAnimating===!0&&(O=a(o).tweensContainer),h.each(g,function(e,t){if(RegExp("^"+_.Lists.colors.join("$|^")+"$").test(e)){var n=u(t,!0),r=n[0],o=n[1],a=n[2];if(_.RegEx.isHex.test(r)){for(var s=["Red","Green","Blue"],l=_.Values.hexToRgb(r),c=a?_.Values.hexToRgb(a):i,d=0;d<s.length;d++){var p=[l[d]];o&&p.push(o),c!==i&&p.push(c[d]),g[e+s[d]]=p}delete g[e]}}});for(var $ in g){var L=u(g[$]),q=L[0],j=L[1],R=L[2];$=_.Names.camelCase($);var z=_.Hooks.getRoot($),H=!1;if(a(o).isSVG||"tween"===z||_.Names.prefixCheck(z)[1]!==!1||_.Normalizations.registered[z]!==i){(s.display!==i&&null!==s.display&&"none"!==s.display||s.visibility!==i&&"hidden"!==s.visibility)&&/opacity|filter/.test($)&&!R&&0!==q&&(R=0),s._cacheValues&&O&&O[$]?(R===i&&(R=O[$].endValue+O[$].unitType),H=a(o).rootPropertyValueCache[z]):_.Hooks.registered[$]?R===i?(H=_.getPropertyValue(o,z),R=_.getPropertyValue(o,$,H)):H=_.Hooks.templates[z][1]:R===i&&(R=_.getPropertyValue(o,$));var W,Y,B,U=!1;if(W=p($,R),R=W[0],B=W[1],W=p($,q),q=W[0].replace(/^([+-\/*])=/,function(e,t){return U=t,""}),Y=W[1],R=parseFloat(R)||0,q=parseFloat(q)||0,"%"===Y&&(/^(fontSize|lineHeight)$/.test($)?(q/=100,Y="em"):/^scale/.test($)?(q/=100,Y=""):/(Red|Green|Blue)$/i.test($)&&(q=q/100*255,Y="")),/[\/*]/.test(U))Y=B;else if(B!==Y&&0!==R)if(0===q)Y=B;else{r=r||y();var V=/margin|padding|left|right|width|text|word|letter/i.test($)||/X$/.test($)||"x"===$?"x":"y";switch(B){case"%":R*="x"===V?r.percentToPxWidth:r.percentToPxHeight;break;case"px":break;default:R*=r[B+"ToPx"]}switch(Y){case"%":R*=1/("x"===V?r.percentToPxWidth:r.percentToPxHeight);break;case"px":break;default:R*=1/r[Y+"ToPx"]}}switch(U){case"+":q=R+q;break;case"-":q=R-q;break;case"*":q=R*q;break;case"/":q=R/q}l[$]={rootPropertyValue:H,startValue:R,currentValue:R,endValue:q,unitType:Y,easing:j},w.debug&&console.log("tweensContainer ("+$+"): "+JSON.stringify(l[$]),o)}else w.debug&&console.log("Skipping ["+z+"] due to a lack of browser support.")}l.element=o}l.element&&(_.Values.addClass(o,"velocity-animating"),P.push(l),""===s.queue&&(a(o).tweensContainer=l,a(o).opts=s),a(o).isAnimating=!0,C===x-1?(w.State.calls.push([P,f,s,null,S.resolver]),w.State.isTicking===!1&&(w.State.isTicking=!0,d())):C++)}var r,o=this,s=h.extend({},w.defaults,m),l={};switch(a(o)===i&&w.init(o),parseFloat(s.delay)&&s.queue!==!1&&h.queue(o,s.queue,function(e){w.velocityQueueEntryFlag=!0,a(o).delayTimer={setTimeout:setTimeout(e,parseFloat(s.delay)),next:e}}),s.duration.toString().toLowerCase()){case"fast":s.duration=200;break;case"normal":s.duration=y;break;case"slow":s.duration=600;break;default:s.duration=parseFloat(s.duration)||1}w.mock!==!1&&(w.mock===!0?s.duration=s.delay=1:(s.duration*=parseFloat(w.mock)||1,s.delay*=parseFloat(w.mock)||1)),s.easing=c(s.easing,s.duration),s.begin&&!v.isFunction(s.begin)&&(s.begin=null),s.progress&&!v.isFunction(s.progress)&&(s.progress=null),s.complete&&!v.isFunction(s.complete)&&(s.complete=null),s.display!==i&&null!==s.display&&(s.display=s.display.toString().toLowerCase(),"auto"===s.display&&(s.display=w.CSS.Values.getDisplayType(o))),s.visibility!==i&&null!==s.visibility&&(s.visibility=s.visibility.toString().toLowerCase()),s.mobileHA=s.mobileHA&&w.State.isMobile&&!w.State.isGingerbread,s.queue===!1?s.delay?setTimeout(e,s.delay):e():h.queue(o,s.queue,function(t,n){return n===!0?(S.promise&&S.resolver(f),!0):(w.velocityQueueEntryFlag=!0,void e(t))}),""!==s.queue&&"fx"!==s.queue||"inprogress"===h.queue(o)[0]||h.dequeue(o)}var s,l,u,f,g,m,b=arguments[0]&&(arguments[0].p||h.isPlainObject(arguments[0].properties)&&!arguments[0].properties.names||v.isString(arguments[0].properties));if(v.isWrapped(this)?(s=!1,u=0,f=this,l=this):(s=!0,u=1,f=b?arguments[0].elements||arguments[0].e:arguments[0]),f=o(f)){b?(g=arguments[0].properties||arguments[0].p,m=arguments[0].options||arguments[0].o):(g=arguments[u],m=arguments[u+1]);var x=f.length,C=0;if(!/^(stop|finish)$/i.test(g)&&!h.isPlainObject(m)){var T=u+1;m={};for(var D=T;D<arguments.length;D++)v.isArray(arguments[D])||!/^(fast|normal|slow)$/i.test(arguments[D])&&!/^\d/.test(arguments[D])?v.isString(arguments[D])||v.isArray(arguments[D])?m.easing=arguments[D]:v.isFunction(arguments[D])&&(m.complete=arguments[D]):m.duration=arguments[D]}var S={promise:null,resolver:null,rejecter:null};s&&w.Promise&&(S.promise=new w.Promise(function(e,t){S.resolver=e,S.rejecter=t}));var E;switch(g){case"scroll":E="scroll";break;case"reverse":E="reverse";break;case"finish":case"stop":h.each(f,function(e,t){a(t)&&a(t).delayTimer&&(clearTimeout(a(t).delayTimer.setTimeout),a(t).delayTimer.next&&a(t).delayTimer.next(),delete a(t).delayTimer)});var A=[];return h.each(w.State.calls,function(e,t){t&&h.each(t[1],function(n,r){var o=m===i?"":m;return o===!0||t[2].queue===o||m===i&&t[2].queue===!1?void h.each(f,function(n,i){i===r&&((m===!0||v.isString(m))&&(h.each(h.queue(i,v.isString(m)?m:""),function(e,t){v.isFunction(t)&&t(null,!0)}),h.queue(i,v.isString(m)?m:"",[])),"stop"===g?(a(i)&&a(i).tweensContainer&&o!==!1&&h.each(a(i).tweensContainer,function(e,t){t.endValue=t.currentValue;
}),A.push(e)):"finish"===g&&(t[2].duration=1))}):!0})}),"stop"===g&&(h.each(A,function(e,t){p(t,!0)}),S.promise&&S.resolver(f)),e();default:if(!h.isPlainObject(g)||v.isEmptyObject(g)){if(v.isString(g)&&w.Redirects[g]){var M=h.extend({},m),O=M.duration,I=M.delay||0;return M.backwards===!0&&(f=h.extend(!0,[],f).reverse()),h.each(f,function(e,t){parseFloat(M.stagger)?M.delay=I+parseFloat(M.stagger)*e:v.isFunction(M.stagger)&&(M.delay=I+M.stagger.call(t,e,x)),M.drag&&(M.duration=parseFloat(O)||(/^(callout|transition)/.test(g)?1e3:y),M.duration=Math.max(M.duration*(M.backwards?1-e/x:(e+1)/x),.75*M.duration,200)),w.Redirects[g].call(t,t,M||{},e,x,f,S.promise?S:i)}),e()}var N="Velocity: First argument ("+g+") was not a property map, a known action, or a registered redirect. Aborting.";return S.promise?S.rejecter(new Error(N)):console.log(N),e()}E="start"}var F={lastParent:null,lastPosition:null,lastFontSize:null,lastPercentToPxWidth:null,lastPercentToPxHeight:null,lastEmToPx:null,remToPx:null,vwToPx:null,vhToPx:null},P=[];h.each(f,function(e,t){v.isNode(t)&&r.call(t)});var $,M=h.extend({},w.defaults,m);if(M.loop=parseInt(M.loop),$=2*M.loop-1,M.loop)for(var L=0;$>L;L++){var q={delay:M.delay,progress:M.progress};L===$-1&&(q.display=M.display,q.visibility=M.visibility,q.complete=M.complete),k(f,"reverse",q)}return e()}};w=h.extend(k,w),w.animate=k;var C=t.requestAnimationFrame||g;return w.State.isMobile||n.hidden===i||n.addEventListener("visibilitychange",function(){n.hidden?(C=function(e){return setTimeout(function(){e(!0)},16)},d()):C=t.requestAnimationFrame||g}),e.Velocity=w,e!==t&&(e.fn.velocity=k,e.fn.velocity.defaults=w.defaults),h.each(["Down","Up"],function(e,t){w.Redirects["slide"+t]=function(e,n,r,o,a,s){var l=h.extend({},n),u=l.begin,c=l.complete,d={height:"",marginTop:"",marginBottom:"",paddingTop:"",paddingBottom:""},p={};l.display===i&&(l.display="Down"===t?"inline"===w.CSS.Values.getDisplayType(e)?"inline-block":"block":"none"),l.begin=function(){u&&u.call(a,a);for(var n in d){p[n]=e.style[n];var i=w.CSS.getPropertyValue(e,n);d[n]="Down"===t?[i,0]:[0,i]}p.overflow=e.style.overflow,e.style.overflow="hidden"},l.complete=function(){for(var t in p)e.style[t]=p[t];c&&c.call(a,a),s&&s.resolver(a)},w(e,d,l)}}),h.each(["In","Out"],function(e,t){w.Redirects["fade"+t]=function(e,n,r,o,a,s){var l=h.extend({},n),u={opacity:"In"===t?1:0},c=l.complete;l.complete=r!==o-1?l.begin=null:function(){c&&c.call(a,a),s&&s.resolver(a)},l.display===i&&(l.display="In"===t?"auto":"none"),w(this,u,l)}}),w}(u||window.Zepto||window,window,document)}),!function(i,o,a,s){"use strict";function l(e,t,n){return setTimeout(f(e,n),t)}function u(e,t,n){return Array.isArray(e)?(c(e,n[t],n),!0):!1}function c(e,t,n){var i;if(e)if(e.forEach)e.forEach(t,n);else if(e.length!==s)for(i=0;i<e.length;)t.call(n,e[i],i,e),i++;else for(i in e)e.hasOwnProperty(i)&&t.call(n,e[i],i,e)}function d(e,t,n){for(var i=Object.keys(t),r=0;r<i.length;)(!n||n&&e[i[r]]===s)&&(e[i[r]]=t[i[r]]),r++;return e}function p(e,t){return d(e,t,!0)}function h(e,t,n){var i,r=t.prototype;i=e.prototype=Object.create(r),i.constructor=e,i._super=r,n&&d(i,n)}function f(e,t){return function(){return e.apply(t,arguments)}}function g(e,t){return typeof e==fe?e.apply(t?t[0]||s:s,t):e}function v(e,t){return e===s?t:e}function m(e,t,n){c(x(t),function(t){e.addEventListener(t,n,!1)})}function y(e,t,n){c(x(t),function(t){e.removeEventListener(t,n,!1)})}function b(e,t){for(;e;){if(e==t)return!0;e=e.parentNode}return!1}function w(e,t){return e.indexOf(t)>-1}function x(e){return e.trim().split(/\s+/g)}function _(e,t,n){if(e.indexOf&&!n)return e.indexOf(t);for(var i=0;i<e.length;){if(n&&e[i][n]==t||!n&&e[i]===t)return i;i++}return-1}function k(e){return Array.prototype.slice.call(e,0)}function C(e,t,n){for(var i=[],r=[],o=0;o<e.length;){var a=t?e[o][t]:e[o];_(r,a)<0&&i.push(e[o]),r[o]=a,o++}return n&&(i=t?i.sort(function(e,n){return e[t]>n[t]}):i.sort()),i}function T(e,t){for(var n,i,r=t[0].toUpperCase()+t.slice(1),o=0;o<pe.length;){if(n=pe[o],i=n?n+r:t,i in e)return i;o++}return s}function D(){return ye++}function S(e){var t=e.ownerDocument;return t.defaultView||t.parentWindow}function E(e,t){var n=this;this.manager=e,this.callback=t,this.element=e.element,this.target=e.options.inputTarget,this.domHandler=function(t){g(e.options.enable,[e])&&n.handler(t)},this.init()}function A(e){var t,n=e.options.inputClass;return new(t=n?n:xe?W:_e?U:we?X:H)(e,M)}function M(e,t,n){var i=n.pointers.length,r=n.changedPointers.length,o=t&Ee&&0===i-r,a=t&(Me|Oe)&&0===i-r;n.isFirst=!!o,n.isFinal=!!a,o&&(e.session={}),n.eventType=t,O(e,n),e.emit("hammer.input",n),e.recognize(n),e.session.prevInput=n}function O(e,t){var n=e.session,i=t.pointers,r=i.length;n.firstInput||(n.firstInput=F(t)),r>1&&!n.firstMultiple?n.firstMultiple=F(t):1===r&&(n.firstMultiple=!1);var o=n.firstInput,a=n.firstMultiple,s=a?a.center:o.center,l=t.center=P(i);t.timeStamp=me(),t.deltaTime=t.timeStamp-o.timeStamp,t.angle=j(s,l),t.distance=q(s,l),I(n,t),t.offsetDirection=L(t.deltaX,t.deltaY),t.scale=a?z(a.pointers,i):1,t.rotation=a?R(a.pointers,i):0,N(n,t);var u=e.element;b(t.srcEvent.target,u)&&(u=t.srcEvent.target),t.target=u}function I(e,t){var n=t.center,i=e.offsetDelta||{},r=e.prevDelta||{},o=e.prevInput||{};(t.eventType===Ee||o.eventType===Me)&&(r=e.prevDelta={x:o.deltaX||0,y:o.deltaY||0},i=e.offsetDelta={x:n.x,y:n.y}),t.deltaX=r.x+(n.x-i.x),t.deltaY=r.y+(n.y-i.y)}function N(e,t){var n,i,r,o,a=e.lastInterval||t,l=t.timeStamp-a.timeStamp;if(t.eventType!=Oe&&(l>Se||a.velocity===s)){var u=a.deltaX-t.deltaX,c=a.deltaY-t.deltaY,d=$(l,u,c);i=d.x,r=d.y,n=ve(d.x)>ve(d.y)?d.x:d.y,o=L(u,c),e.lastInterval=t}else n=a.velocity,i=a.velocityX,r=a.velocityY,o=a.direction;t.velocity=n,t.velocityX=i,t.velocityY=r,t.direction=o}function F(e){for(var t=[],n=0;n<e.pointers.length;)t[n]={clientX:ge(e.pointers[n].clientX),clientY:ge(e.pointers[n].clientY)},n++;return{timeStamp:me(),pointers:t,center:P(t),deltaX:e.deltaX,deltaY:e.deltaY}}function P(e){var t=e.length;if(1===t)return{x:ge(e[0].clientX),y:ge(e[0].clientY)};for(var n=0,i=0,r=0;t>r;)n+=e[r].clientX,i+=e[r].clientY,r++;return{x:ge(n/t),y:ge(i/t)}}function $(e,t,n){return{x:t/e||0,y:n/e||0}}function L(e,t){return e===t?Ie:ve(e)>=ve(t)?e>0?Ne:Fe:t>0?Pe:$e}function q(e,t,n){n||(n=Re);var i=t[n[0]]-e[n[0]],r=t[n[1]]-e[n[1]];return Math.sqrt(i*i+r*r)}function j(e,t,n){n||(n=Re);var i=t[n[0]]-e[n[0]],r=t[n[1]]-e[n[1]];return 180*Math.atan2(r,i)/Math.PI}function R(e,t){return j(t[1],t[0],ze)-j(e[1],e[0],ze)}function z(e,t){return q(t[0],t[1],ze)/q(e[0],e[1],ze)}function H(){this.evEl=We,this.evWin=Ye,this.allow=!0,this.pressed=!1,E.apply(this,arguments)}function W(){this.evEl=Ve,this.evWin=Xe,E.apply(this,arguments),this.store=this.manager.session.pointerEvents=[]}function Y(){this.evTarget=Ge,this.evWin=Ke,this.started=!1,E.apply(this,arguments)}function B(e,t){var n=k(e.touches),i=k(e.changedTouches);return t&(Me|Oe)&&(n=C(n.concat(i),"identifier",!0)),[n,i]}function U(){this.evTarget=Je,this.targetIds={},E.apply(this,arguments)}function V(e,t){var n=k(e.touches),i=this.targetIds;if(t&(Ee|Ae)&&1===n.length)return i[n[0].identifier]=!0,[n,n];var r,o,a=k(e.changedTouches),s=[],l=this.target;if(o=n.filter(function(e){return b(e.target,l)}),t===Ee)for(r=0;r<o.length;)i[o[r].identifier]=!0,r++;for(r=0;r<a.length;)i[a[r].identifier]&&s.push(a[r]),t&(Me|Oe)&&delete i[a[r].identifier],r++;return s.length?[C(o.concat(s),"identifier",!0),s]:void 0}function X(){E.apply(this,arguments);var e=f(this.handler,this);this.touch=new U(this.manager,e),this.mouse=new H(this.manager,e)}function Q(e,t){this.manager=e,this.set(t)}function G(e){if(w(e,ot))return ot;var t=w(e,at),n=w(e,st);return t&&n?at+" "+st:t||n?t?at:st:w(e,rt)?rt:it}function K(e){this.id=D(),this.manager=null,this.options=p(e||{},this.defaults),this.options.enable=v(this.options.enable,!0),this.state=lt,this.simultaneous={},this.requireFail=[]}function Z(e){return e&ht?"cancel":e&dt?"end":e&ct?"move":e&ut?"start":""}function J(e){return e==$e?"down":e==Pe?"up":e==Ne?"left":e==Fe?"right":""}function ee(e,t){var n=t.manager;return n?n.get(e):e}function te(){K.apply(this,arguments)}function ne(){te.apply(this,arguments),this.pX=null,this.pY=null}function ie(){te.apply(this,arguments)}function re(){K.apply(this,arguments),this._timer=null,this._input=null}function oe(){te.apply(this,arguments)}function ae(){te.apply(this,arguments)}function se(){K.apply(this,arguments),this.pTime=!1,this.pCenter=!1,this._timer=null,this._input=null,this.count=0}function le(e,t){return t=t||{},t.recognizers=v(t.recognizers,le.defaults.preset),new ue(e,t)}function ue(e,t){t=t||{},this.options=p(t,le.defaults),this.options.inputTarget=this.options.inputTarget||e,this.handlers={},this.session={},this.recognizers=[],this.element=e,this.input=A(this),this.touchAction=new Q(this,this.options.touchAction),ce(this,!0),c(t.recognizers,function(e){var t=this.add(new e[0](e[1]));e[2]&&t.recognizeWith(e[2]),e[3]&&t.requireFailure(e[3])},this)}function ce(e,t){var n=e.element;c(e.options.cssProps,function(e,i){n.style[T(n.style,i)]=t?e:""})}function de(e,t){var n=o.createEvent("Event");n.initEvent(e,!0,!0),n.gesture=t,t.target.dispatchEvent(n)}var pe=["","webkit","moz","MS","ms","o"],he=o.createElement("div"),fe="function",ge=Math.round,ve=Math.abs,me=Date.now,ye=1,be=/mobile|tablet|ip(ad|hone|od)|android/i,we="ontouchstart"in i,xe=T(i,"PointerEvent")!==s,_e=we&&be.test(navigator.userAgent),ke="touch",Ce="pen",Te="mouse",De="kinect",Se=25,Ee=1,Ae=2,Me=4,Oe=8,Ie=1,Ne=2,Fe=4,Pe=8,$e=16,Le=Ne|Fe,qe=Pe|$e,je=Le|qe,Re=["x","y"],ze=["clientX","clientY"];E.prototype={handler:function(){},init:function(){this.evEl&&m(this.element,this.evEl,this.domHandler),this.evTarget&&m(this.target,this.evTarget,this.domHandler),this.evWin&&m(S(this.element),this.evWin,this.domHandler)},destroy:function(){this.evEl&&y(this.element,this.evEl,this.domHandler),this.evTarget&&y(this.target,this.evTarget,this.domHandler),this.evWin&&y(S(this.element),this.evWin,this.domHandler)}};var He={mousedown:Ee,mousemove:Ae,mouseup:Me},We="mousedown",Ye="mousemove mouseup";h(H,E,{handler:function(e){var t=He[e.type];t&Ee&&0===e.button&&(this.pressed=!0),t&Ae&&1!==e.which&&(t=Me),this.pressed&&this.allow&&(t&Me&&(this.pressed=!1),this.callback(this.manager,t,{pointers:[e],changedPointers:[e],pointerType:Te,srcEvent:e}))}});var Be={pointerdown:Ee,pointermove:Ae,pointerup:Me,pointercancel:Oe,pointerout:Oe},Ue={2:ke,3:Ce,4:Te,5:De},Ve="pointerdown",Xe="pointermove pointerup pointercancel";i.MSPointerEvent&&(Ve="MSPointerDown",Xe="MSPointerMove MSPointerUp MSPointerCancel"),h(W,E,{handler:function(e){var t=this.store,n=!1,i=e.type.toLowerCase().replace("ms",""),r=Be[i],o=Ue[e.pointerType]||e.pointerType,a=o==ke,s=_(t,e.pointerId,"pointerId");r&Ee&&(0===e.button||a)?0>s&&(t.push(e),s=t.length-1):r&(Me|Oe)&&(n=!0),0>s||(t[s]=e,this.callback(this.manager,r,{pointers:t,changedPointers:[e],pointerType:o,srcEvent:e}),n&&t.splice(s,1))}});var Qe={touchstart:Ee,touchmove:Ae,touchend:Me,touchcancel:Oe},Ge="touchstart",Ke="touchstart touchmove touchend touchcancel";h(Y,E,{handler:function(e){var t=Qe[e.type];if(t===Ee&&(this.started=!0),this.started){var n=B.call(this,e,t);t&(Me|Oe)&&0===n[0].length-n[1].length&&(this.started=!1),this.callback(this.manager,t,{pointers:n[0],changedPointers:n[1],pointerType:ke,srcEvent:e})}}});var Ze={touchstart:Ee,touchmove:Ae,touchend:Me,touchcancel:Oe},Je="touchstart touchmove touchend touchcancel";h(U,E,{handler:function(e){var t=Ze[e.type],n=V.call(this,e,t);n&&this.callback(this.manager,t,{pointers:n[0],changedPointers:n[1],pointerType:ke,srcEvent:e})}}),h(X,E,{handler:function(e,t,n){var i=n.pointerType==ke,r=n.pointerType==Te;if(i)this.mouse.allow=!1;else if(r&&!this.mouse.allow)return;t&(Me|Oe)&&(this.mouse.allow=!0),this.callback(e,t,n)},destroy:function(){this.touch.destroy(),this.mouse.destroy()}});var et=T(he.style,"touchAction"),tt=et!==s,nt="compute",it="auto",rt="manipulation",ot="none",at="pan-x",st="pan-y";Q.prototype={set:function(e){e==nt&&(e=this.compute()),tt&&(this.manager.element.style[et]=e),this.actions=e.toLowerCase().trim()},update:function(){this.set(this.manager.options.touchAction)},compute:function(){var e=[];return c(this.manager.recognizers,function(t){g(t.options.enable,[t])&&(e=e.concat(t.getTouchAction()))}),G(e.join(" "))},preventDefaults:function(e){if(!tt){var t=e.srcEvent,n=e.offsetDirection;if(this.manager.session.prevented)return void t.preventDefault();var i=this.actions,r=w(i,ot),o=w(i,st),a=w(i,at);return r||o&&n&Le||a&&n&qe?this.preventSrc(t):void 0}},preventSrc:function(e){this.manager.session.prevented=!0,e.preventDefault()}};var lt=1,ut=2,ct=4,dt=8,pt=dt,ht=16,ft=32;K.prototype={defaults:{},set:function(e){return d(this.options,e),this.manager&&this.manager.touchAction.update(),this},recognizeWith:function(e){if(u(e,"recognizeWith",this))return this;var t=this.simultaneous;return e=ee(e,this),t[e.id]||(t[e.id]=e,e.recognizeWith(this)),this},dropRecognizeWith:function(e){return u(e,"dropRecognizeWith",this)?this:(e=ee(e,this),delete this.simultaneous[e.id],this)},requireFailure:function(e){if(u(e,"requireFailure",this))return this;var t=this.requireFail;return e=ee(e,this),-1===_(t,e)&&(t.push(e),e.requireFailure(this)),this},dropRequireFailure:function(e){if(u(e,"dropRequireFailure",this))return this;e=ee(e,this);var t=_(this.requireFail,e);return t>-1&&this.requireFail.splice(t,1),this},hasRequireFailures:function(){return this.requireFail.length>0},canRecognizeWith:function(e){return!!this.simultaneous[e.id]},emit:function(e){function t(t){n.manager.emit(n.options.event+(t?Z(i):""),e)}var n=this,i=this.state;dt>i&&t(!0),t(),i>=dt&&t(!0)},tryEmit:function(e){return this.canEmit()?this.emit(e):void(this.state=ft)},canEmit:function(){for(var e=0;e<this.requireFail.length;){if(!(this.requireFail[e].state&(ft|lt)))return!1;e++}return!0},recognize:function(e){var t=d({},e);return g(this.options.enable,[this,t])?(this.state&(pt|ht|ft)&&(this.state=lt),this.state=this.process(t),void(this.state&(ut|ct|dt|ht)&&this.tryEmit(t))):(this.reset(),void(this.state=ft))},process:function(){},getTouchAction:function(){},reset:function(){}},h(te,K,{defaults:{pointers:1},attrTest:function(e){var t=this.options.pointers;return 0===t||e.pointers.length===t},process:function(e){var t=this.state,n=e.eventType,i=t&(ut|ct),r=this.attrTest(e);return i&&(n&Oe||!r)?t|ht:i||r?n&Me?t|dt:t&ut?t|ct:ut:ft}}),h(ne,te,{defaults:{event:"pan",threshold:10,pointers:1,direction:je},getTouchAction:function(){var e=this.options.direction,t=[];return e&Le&&t.push(st),e&qe&&t.push(at),t},directionTest:function(e){var t=this.options,n=!0,i=e.distance,r=e.direction,o=e.deltaX,a=e.deltaY;return r&t.direction||(t.direction&Le?(r=0===o?Ie:0>o?Ne:Fe,n=o!=this.pX,i=Math.abs(e.deltaX)):(r=0===a?Ie:0>a?Pe:$e,n=a!=this.pY,i=Math.abs(e.deltaY))),e.direction=r,n&&i>t.threshold&&r&t.direction},attrTest:function(e){return te.prototype.attrTest.call(this,e)&&(this.state&ut||!(this.state&ut)&&this.directionTest(e))},emit:function(e){this.pX=e.deltaX,this.pY=e.deltaY;var t=J(e.direction);t&&this.manager.emit(this.options.event+t,e),this._super.emit.call(this,e)}}),h(ie,te,{defaults:{event:"pinch",threshold:0,pointers:2},getTouchAction:function(){return[ot]},attrTest:function(e){return this._super.attrTest.call(this,e)&&(Math.abs(e.scale-1)>this.options.threshold||this.state&ut)},emit:function(e){if(this._super.emit.call(this,e),1!==e.scale){var t=e.scale<1?"in":"out";this.manager.emit(this.options.event+t,e)}}}),h(re,K,{defaults:{event:"press",pointers:1,time:500,threshold:5},getTouchAction:function(){return[it]},process:function(e){var t=this.options,n=e.pointers.length===t.pointers,i=e.distance<t.threshold,r=e.deltaTime>t.time;if(this._input=e,!i||!n||e.eventType&(Me|Oe)&&!r)this.reset();else if(e.eventType&Ee)this.reset(),this._timer=l(function(){this.state=pt,this.tryEmit()},t.time,this);else if(e.eventType&Me)return pt;return ft},reset:function(){clearTimeout(this._timer)},emit:function(e){this.state===pt&&(e&&e.eventType&Me?this.manager.emit(this.options.event+"up",e):(this._input.timeStamp=me(),this.manager.emit(this.options.event,this._input)))}}),h(oe,te,{defaults:{event:"rotate",threshold:0,pointers:2},getTouchAction:function(){return[ot]},attrTest:function(e){return this._super.attrTest.call(this,e)&&(Math.abs(e.rotation)>this.options.threshold||this.state&ut)}}),h(ae,te,{defaults:{event:"swipe",threshold:10,velocity:.65,direction:Le|qe,pointers:1},getTouchAction:function(){return ne.prototype.getTouchAction.call(this)},attrTest:function(e){var t,n=this.options.direction;return n&(Le|qe)?t=e.velocity:n&Le?t=e.velocityX:n&qe&&(t=e.velocityY),this._super.attrTest.call(this,e)&&n&e.direction&&e.distance>this.options.threshold&&ve(t)>this.options.velocity&&e.eventType&Me},emit:function(e){var t=J(e.direction);t&&this.manager.emit(this.options.event+t,e),this.manager.emit(this.options.event,e)}}),h(se,K,{defaults:{event:"tap",pointers:1,taps:1,interval:300,time:250,threshold:2,posThreshold:10},getTouchAction:function(){return[rt]},process:function(e){var t=this.options,n=e.pointers.length===t.pointers,i=e.distance<t.threshold,r=e.deltaTime<t.time;if(this.reset(),e.eventType&Ee&&0===this.count)return this.failTimeout();if(i&&r&&n){if(e.eventType!=Me)return this.failTimeout();var o=this.pTime?e.timeStamp-this.pTime<t.interval:!0,a=!this.pCenter||q(this.pCenter,e.center)<t.posThreshold;this.pTime=e.timeStamp,this.pCenter=e.center,a&&o?this.count+=1:this.count=1,this._input=e;var s=this.count%t.taps;if(0===s)return this.hasRequireFailures()?(this._timer=l(function(){this.state=pt,this.tryEmit()},t.interval,this),ut):pt}return ft},failTimeout:function(){return this._timer=l(function(){this.state=ft},this.options.interval,this),ft},reset:function(){clearTimeout(this._timer)},emit:function(){this.state==pt&&(this._input.tapCount=this.count,this.manager.emit(this.options.event,this._input))}}),le.VERSION="2.0.4",le.defaults={domEvents:!1,touchAction:nt,enable:!0,inputTarget:null,inputClass:null,preset:[[oe,{enable:!1}],[ie,{enable:!1},["rotate"]],[ae,{direction:Le}],[ne,{direction:Le},["swipe"]],[se],[se,{event:"doubletap",taps:2},["tap"]],[re]],cssProps:{userSelect:"default",touchSelect:"none",touchCallout:"none",contentZooming:"none",userDrag:"none",tapHighlightColor:"rgba(0,0,0,0)"}};var gt=1,vt=2;ue.prototype={set:function(e){return d(this.options,e),e.touchAction&&this.touchAction.update(),e.inputTarget&&(this.input.destroy(),this.input.target=e.inputTarget,this.input.init()),this},stop:function(e){this.session.stopped=e?vt:gt},recognize:function(e){var t=this.session;if(!t.stopped){this.touchAction.preventDefaults(e);var n,i=this.recognizers,r=t.curRecognizer;(!r||r&&r.state&pt)&&(r=t.curRecognizer=null);for(var o=0;o<i.length;)n=i[o],t.stopped===vt||r&&n!=r&&!n.canRecognizeWith(r)?n.reset():n.recognize(e),!r&&n.state&(ut|ct|dt)&&(r=t.curRecognizer=n),o++}},get:function(e){if(e instanceof K)return e;for(var t=this.recognizers,n=0;n<t.length;n++)if(t[n].options.event==e)return t[n];return null},add:function(e){if(u(e,"add",this))return this;var t=this.get(e.options.event);return t&&this.remove(t),this.recognizers.push(e),e.manager=this,this.touchAction.update(),e},remove:function(e){if(u(e,"remove",this))return this;var t=this.recognizers;return e=this.get(e),t.splice(_(t,e),1),this.touchAction.update(),this},on:function(e,t){var n=this.handlers;return c(x(e),function(e){n[e]=n[e]||[],n[e].push(t)}),this},off:function(e,t){var n=this.handlers;return c(x(e),function(e){t?n[e].splice(_(n[e],t),1):delete n[e]}),this},emit:function(e,t){this.options.domEvents&&de(e,t);var n=this.handlers[e]&&this.handlers[e].slice();if(n&&n.length){t.type=e,t.preventDefault=function(){t.srcEvent.preventDefault()};for(var i=0;i<n.length;)n[i](t),i++}},destroy:function(){this.element&&ce(this,!1),this.handlers={},this.session={},this.input.destroy(),this.element=null}},d(le,{INPUT_START:Ee,INPUT_MOVE:Ae,INPUT_END:Me,INPUT_CANCEL:Oe,STATE_POSSIBLE:lt,STATE_BEGAN:ut,STATE_CHANGED:ct,STATE_ENDED:dt,STATE_RECOGNIZED:pt,STATE_CANCELLED:ht,STATE_FAILED:ft,DIRECTION_NONE:Ie,DIRECTION_LEFT:Ne,DIRECTION_RIGHT:Fe,DIRECTION_UP:Pe,DIRECTION_DOWN:$e,DIRECTION_HORIZONTAL:Le,DIRECTION_VERTICAL:qe,DIRECTION_ALL:je,Manager:ue,Input:E,TouchAction:Q,TouchInput:U,MouseInput:H,PointerEventInput:W,TouchMouseInput:X,SingleTouchInput:Y,Recognizer:K,AttrRecognizer:te,Tap:se,Pan:ne,Swipe:ae,Pinch:ie,Rotate:oe,Press:re,on:m,off:y,each:c,merge:p,extend:d,inherit:h,bindFn:f,prefixed:T}),"function"==fe&&n(11)?(r=function(){return le}.call(t,n,t,e),!(void 0!==r&&(e.exports=r))):"undefined"!=typeof e&&e.exports?e.exports=le:i[a]=le}(window,document,"Hammer"),function(a){o=[n(1),n(10)],i=a,r="function"==typeof i?i.apply(t,o):i,!(void 0!==r&&(e.exports=r))}(function(e,t){function n(n,i){var r=e(n);r.data("hammer")||r.data("hammer",new t(r[0],i))}e.fn.hammer=function(e){return this.each(function(){n(this,e)})},t.Manager.prototype.emit=function(t){return function(n,i){t.call(this,n,i),e(this.element).trigger({type:n,gesture:i})}}(t.Manager.prototype.emit)}),Materialize={},Materialize.guid=function(){function e(){return Math.floor(65536*(1+Math.random())).toString(16).substring(1)}return function(){return e()+e()+"-"+e()+"-"+e()+"-"+e()+"-"+e()+e()+e()}}(),Materialize.elementOrParentIsFixed=function(e){var t=l(e),n=t.add(t.parents()),i=!1;return n.each(function(){return"fixed"===l(this).css("position")?(i=!0,!1):void 0}),i};var p;p=l?l.Velocity:Velocity,function(e){e.fn.collapsible=function(t){var n={accordion:void 0};return t=e.extend(n,t),this.each(function(){function n(t){s=a.find("> li > .collapsible-header"),t.hasClass("active")?t.parent().addClass("active"):t.parent().removeClass("active"),t.parent().hasClass("active")?t.siblings(".collapsible-body").stop(!0,!1).slideDown({duration:350,easing:"easeOutQuart",queue:!1,complete:function(){e(this).css("height","")}}):t.siblings(".collapsible-body").stop(!0,!1).slideUp({duration:350,easing:"easeOutQuart",queue:!1,complete:function(){e(this).css("height","")}}),s.not(t).removeClass("active").parent().removeClass("active"),s.not(t).parent().children(".collapsible-body").stop(!0,!1).slideUp({duration:350,easing:"easeOutQuart",queue:!1,complete:function(){e(this).css("height","")}})}function i(t){t.hasClass("active")?t.parent().addClass("active"):t.parent().removeClass("active"),t.parent().hasClass("active")?t.siblings(".collapsible-body").stop(!0,!1).slideDown({duration:350,easing:"easeOutQuart",queue:!1,complete:function(){e(this).css("height","")}}):t.siblings(".collapsible-body").stop(!0,!1).slideUp({duration:350,easing:"easeOutQuart",queue:!1,complete:function(){e(this).css("height","")}})}function r(e){var t=o(e);return t.length>0}function o(e){return e.closest("li > .collapsible-header")}var a=e(this),s=e(this).find("> li > .collapsible-header"),l=a.data("collapsible");a.off("click.collapse",".collapsible-header"),s.off("click.collapse"),t.accordion||"accordion"===l||void 0===l?(s=a.find("> li > .collapsible-header"),s.on("click.collapse",function(t){var i=e(t.target);r(i)&&(i=o(i)),i.toggleClass("active"),n(i)}),n(s.filter(".active").first())):s.each(function(){e(this).on("click.collapse",function(t){var n=e(t.target);r(n)&&(n=o(n)),n.toggleClass("active"),i(n)}),e(this).hasClass("active")&&i(e(this))})})},e(document).ready(function(){e(".collapsible").collapsible()})}(s),function(e){e.fn.scrollTo=function(t){return e(this).scrollTop(e(this).scrollTop()-e(this).offset().top+e(t).offset().top),this},e.fn.dropdown=function(t){var n={inDuration:300,outDuration:225,constrain_width:!0,hover:!1,gutter:0,belowOrigin:!1};this.each(function(){function i(){void 0!==a.data("induration")&&(s.inDuration=a.data("inDuration")),void 0!==a.data("outduration")&&(s.outDuration=a.data("outDuration")),void 0!==a.data("constrainwidth")&&(s.constrain_width=a.data("constrainwidth")),void 0!==a.data("hover")&&(s.hover=a.data("hover")),void 0!==a.data("gutter")&&(s.gutter=a.data("gutter")),void 0!==a.data("beloworigin")&&(s.belowOrigin=a.data("beloworigin"))}function r(){i(),l.addClass("active"),s.constrain_width===!0&&l.css("width",a.outerWidth());var t=0;s.belowOrigin===!0&&(t=a.height());var n=a.offset().left,r=0,o=s.gutter;n+l.innerWidth()>e(window).width()&&(r=a.innerWidth()-l.innerWidth(),o=-1*o),l.css({position:"absolute",top:a.position().top+t,left:a.position().left+r+o}),l.stop(!0,!0).css("opacity",0).slideDown({queue:!1,duration:s.inDuration,easing:"easeOutCubic",complete:function(){e(this).css("height","")}}).animate({opacity:1},{queue:!1,duration:s.inDuration,easing:"easeOutSine"})}function o(){l.fadeOut(s.outDuration),l.removeClass("active")}var a=e(this),s=e.extend({},n,t),l=e("#"+a.attr("data-activates"));if(i(),a.after(l),s.hover){var u=!1;a.unbind("click."+a.attr("id")),a.on("mouseenter",function(e){u===!1&&(r(),u=!0)}),a.on("mouseleave",function(t){var n=t.toElement||t.relatedTarget;e(n).closest(".dropdown-content").is(l)||(l.stop(!0,!0),o(),u=!1)}),l.on("mouseleave",function(t){var n=t.toElement||t.relatedTarget;e(n).closest(".dropdown-button").is(a)||(l.stop(!0,!0),o(),u=!1)})}else a.unbind("click."+a.attr("id")),a.bind("click."+a.attr("id"),function(t){a[0]==t.currentTarget&&0===e(t.target).closest(".dropdown-content").length?(t.preventDefault(),r()):a.hasClass("active")&&(o(),e(document).unbind("click."+l.attr("id"))),l.hasClass("active")&&e(document).bind("click."+l.attr("id"),function(t){!l.is(t.target)&&!a.is(t.target)&&!a.find(t.target).length>0&&(o(),e(document).unbind("click."+l.attr("id")))})});a.on("open",r),a.on("close",o)})},e(document).ready(function(){e(".dropdown-button").dropdown()})}(s),function(e){var t=0,n=0,i=function(){return n++,"materialize-lean-overlay-"+n};e.fn.extend({openModal:function(n){e("body").css("overflow","hidden");var r={opacity:.5,in_duration:350,out_duration:250,ready:void 0,complete:void 0,dismissible:!0,starting_top:"4%"},o=i(),a=e(this),s=e('<div class="lean-overlay"></div>'),l=++t;s.attr("id",o).css("z-index",1e3+2*l),a.data("overlay-id",o).css("z-index",1e3+2*l+1),e("body").append(s),n=e.extend(r,n),n.dismissible&&(s.click(function(){a.closeModal(n)}),e(document).on("keyup.leanModal"+o,function(e){27===e.keyCode&&a.closeModal(n)})),a.find(".modal-close").on("click.close",function(e){a.closeModal(n)}),s.css({display:"block",opacity:0}),a.css({display:"block",opacity:0}),s.velocity({opacity:n.opacity},{duration:n.in_duration,queue:!1,ease:"easeOutCubic"}),a.data("associated-overlay",s[0]),a.hasClass("bottom-sheet")?a.velocity({bottom:"0",opacity:1},{duration:n.in_duration,queue:!1,ease:"easeOutCubic",complete:function(){"function"==typeof n.ready&&n.ready()}}):(e.Velocity.hook(a,"scaleX",.7),a.css({top:n.starting_top}),a.velocity({top:"10%",opacity:1,scaleX:"1"},{duration:n.in_duration,queue:!1,ease:"easeOutCubic",complete:function(){"function"==typeof n.ready&&n.ready()}}))}}),e.fn.extend({closeModal:function(n){var i={out_duration:250,complete:void 0},r=e(this),o=r.data("overlay-id"),a=e("#"+o);n=e.extend(i,n),e("body").css("overflow",""),r.find(".modal-close").off("click.close"),e(document).off("keyup.leanModal"+o),a.velocity({opacity:0},{duration:n.out_duration,queue:!1,ease:"easeOutQuart"}),r.hasClass("bottom-sheet")?r.velocity({bottom:"-100%",opacity:0},{duration:n.out_duration,queue:!1,ease:"easeOutCubic",complete:function(){a.css({display:"none"}),"function"==typeof n.complete&&n.complete(),a.remove(),t--}}):r.velocity({top:n.starting_top,opacity:0,scaleX:.7},{duration:n.out_duration,complete:function(){e(this).css("display","none"),"function"==typeof n.complete&&n.complete(),a.remove(),t--}})}}),e.fn.extend({leanModal:function(t){return this.each(function(){var n={starting_top:"4%"},i=e.extend(n,t);e(this).click(function(t){i.starting_top=(e(this).offset().top-e(window).scrollTop())/1.15;var n=e(this).attr("href")||"#"+e(this).data("target");e(n).openModal(i),t.preventDefault()})})}})}(s),function(e){e.fn.materialbox=function(){return this.each(function(){function t(){i=!1;var t=a.parent(".material-placeholder"),r=(window.innerWidth,window.innerHeight,a.data("width")),s=a.data("height");a.velocity("stop",!0),e("#materialbox-overlay").velocity("stop",!0),e(".materialbox-caption").velocity("stop",!0),e("#materialbox-overlay").velocity({opacity:0},{duration:o,queue:!1,easing:"easeOutQuad",complete:function(){n=!1,e(this).remove()}}),a.velocity({width:r,height:s,left:0,top:0},{duration:o,queue:!1,easing:"easeOutQuad"}),e(".materialbox-caption").velocity({opacity:0},{duration:o,queue:!1,easing:"easeOutQuad",complete:function(){t.css({height:"",width:"",position:"",top:"",left:""}),a.css({height:"",top:"",left:"",width:"","max-width":"",position:"","z-index":""}),a.removeClass("active"),i=!0,e(this).remove()}})}if(!e(this).hasClass("initialized")){e(this).addClass("initialized");var n=!1,i=!0,r=275,o=200,a=e(this),s=e("<div></div>").addClass("material-placeholder");a.wrap(s),a.on("click",function(){var o=a.parent(".material-placeholder"),s=window.innerWidth,l=window.innerHeight,u=a.width(),c=a.height();if(i===!1)return t(),!1;if(n&&i===!0)return t(),!1;i=!1,a.addClass("active"),n=!0,o.css({width:o[0].getBoundingClientRect().width,height:o[0].getBoundingClientRect().height,position:"relative",top:0,left:0}),a.css({position:"absolute","z-index":1e3}).data("width",u).data("height",c);var d=e('<div id="materialbox-overlay"></div>').css({opacity:0}).click(function(){i===!0&&t()});if(e("body").append(d),d.velocity({opacity:1},{duration:r,queue:!1,easing:"easeOutQuad"}),""!==a.data("caption")){var p=e('<div class="materialbox-caption"></div>');p.text(a.data("caption")),e("body").append(p),p.css({display:"inline"}),p.velocity({opacity:1},{duration:r,queue:!1,easing:"easeOutQuad"})}var h=0,f=u/s,g=c/l,v=0,m=0;f>g?(h=c/u,v=.9*s,m=.9*s*h):(h=u/c,v=.9*l*h,m=.9*l),a.hasClass("responsive-img")?a.velocity({"max-width":v,width:u},{duration:0,queue:!1,complete:function(){a.css({left:0,top:0}).velocity({height:m,width:v,left:e(document).scrollLeft()+s/2-a.parent(".material-placeholder").offset().left-v/2,top:e(document).scrollTop()+l/2-a.parent(".material-placeholder").offset().top-m/2},{duration:r,queue:!1,easing:"easeOutQuad",complete:function(){i=!0}})}}):a.css("left",0).css("top",0).velocity({height:m,width:v,left:e(document).scrollLeft()+s/2-a.parent(".material-placeholder").offset().left-v/2,top:e(document).scrollTop()+l/2-a.parent(".material-placeholder").offset().top-m/2},{duration:r,queue:!1,easing:"easeOutQuad",complete:function(){i=!0}})}),e(window).scroll(function(){n&&t()}),e(document).keyup(function(e){27===e.keyCode&&i===!0&&n&&t()})}})},e(document).ready(function(){e(".materialboxed").materialbox()})}(s),function(e){e.fn.parallax=function(){var t=e(window).width();return this.each(function(n){function i(n){var i;i=601>t?r.height()>0?r.height():r.children("img").height():r.height()>0?r.height():500;var o=r.children("img").first(),a=o.height(),s=a-i,l=r.offset().top+i,u=r.offset().top,c=e(window).scrollTop(),d=window.innerHeight,p=c+d,h=(p-u)/(i+d),f=Math.round(s*h);n&&o.css("display","block"),l>c&&c+d>u&&o.css("transform","translate3D(-50%,"+f+"px, 0)")}var r=e(this);r.addClass("parallax"),r.children("img").one("load",function(){i(!0)}).each(function(){this.complete&&e(this).load()}),e(window).scroll(function(){t=e(window).width(),i(!1)}),e(window).resize(function(){t=e(window).width(),i(!1)})})}}(s),function(e){var t={init:function(){return this.each(function(){var t=e(this);e(window).width();t.width("100%");var n=e(this).children("li").length;t.children("li").each(function(){e(this).width(100/n+"%")});var i,r,o=t.find("li.tab a"),a=t.width(),s=t.find("li").first().outerWidth(),l=0;i=e(o.filter('[href="'+location.hash+'"]')),0===i.length&&(i=e(this).find("li.tab a.active").first()),0===i.length&&(i=e(this).find("li.tab a").first()),i.addClass("active"),l=o.index(i),
0>l&&(l=0),r=e(i[0].hash),t.append('<div class="indicator"></div>');var u=t.find(".indicator");t.is(":visible")&&(u.css({right:a-(l+1)*s}),u.css({left:l*s})),e(window).resize(function(){a=t.width(),s=t.find("li").first().outerWidth(),0>l&&(l=0),0!==s&&0!==a&&(u.css({right:a-(l+1)*s}),u.css({left:l*s}))}),o.not(i).each(function(){e(this.hash).hide()}),t.on("click","a",function(n){if(e(this).parent().hasClass("disabled"))return void n.preventDefault();a=t.width(),s=t.find("li").first().outerWidth(),i.removeClass("active"),r.hide(),i=e(this),r=e(this.hash),o=t.find("li.tab a"),i.addClass("active");var c=l;l=o.index(e(this)),0>l&&(l=0),r.show(),l-c>=0?(u.velocity({right:a-(l+1)*s},{duration:300,queue:!1,easing:"easeOutQuad"}),u.velocity({left:l*s},{duration:300,queue:!1,easing:"easeOutQuad",delay:90})):(u.velocity({left:l*s},{duration:300,queue:!1,easing:"easeOutQuad"}),u.velocity({right:a-(l+1)*s},{duration:300,queue:!1,easing:"easeOutQuad",delay:90})),n.preventDefault()})})},select_tab:function(e){this.find('a[href="#'+e+'"]').trigger("click")}};e.fn.tabs=function(n){return t[n]?t[n].apply(this,Array.prototype.slice.call(arguments,1)):"object"!=typeof n&&n?void e.error("Method "+n+" does not exist on jQuery.tooltip"):t.init.apply(this,arguments)},e(document).ready(function(){e("ul.tabs").tabs()})}(s),function(e){e.fn.tooltip=function(t){var n=null,i=!1,r=null,o=5,a={delay:350};return t=e.extend(a,t),e(".material-tooltip").remove(),this.each(function(){var a=e(this),s=e("<span></span>").text(a.attr("data-tooltip")),l=e("<div></div>");l.addClass("material-tooltip").append(s),l.appendTo(e("body"));var u=e("<div></div>").addClass("backdrop");u.appendTo(l),u.css({top:0,left:0}),e(this).off("mouseenter mouseleave"),e(this).on({mouseenter:function(e){var s=a.data("delay");s=void 0===s||""===s?t.delay:s,n=0,r=setInterval(function(){if(n+=10,n>=s&&i===!1){i=!0,l.css({display:"block",left:"0px",top:"0px"}),l.children("span").text(a.attr("data-tooltip"));var e=a.outerWidth(),t=a.outerHeight(),r=a.attr("data-position"),c=l.outerHeight(),d=l.outerWidth(),p="0px",h="0px",f=8;"top"===r?(l.css({top:a.offset().top-c-o,left:a.offset().left+e/2-d/2}),p="-10px",u.css({borderRadius:"14px 14px 0 0",transformOrigin:"50% 90%",marginTop:c,marginLeft:d/2-u.width()/2})):"left"===r?(l.css({top:a.offset().top+t/2-c/2,left:a.offset().left-d-o}),h="-10px",u.css({width:"14px",height:"14px",borderRadius:"14px 0 0 14px",transformOrigin:"95% 50%",marginTop:c/2,marginLeft:d})):"right"===r?(l.css({top:a.offset().top+t/2-c/2,left:a.offset().left+e+o}),h="+10px",u.css({width:"14px",height:"14px",borderRadius:"0 14px 14px 0",transformOrigin:"5% 50%",marginTop:c/2,marginLeft:"0px"})):(l.css({top:a.offset().top+a.outerHeight()+o,left:a.offset().left+e/2-d/2}),p="+10px",u.css({marginLeft:d/2-u.width()/2})),f=d/8,8>f&&(f=8),"right"!==r&&"left"!==r||(f=d/10,6>f&&(f=6)),l.velocity({opacity:1,marginTop:p,marginLeft:h},{duration:350,queue:!1}),u.css({display:"block"}).velocity({opacity:1},{duration:55,delay:0,queue:!1}).velocity({scale:f},{duration:300,delay:0,queue:!1,easing:"easeInOutQuad"})}},10)},mouseleave:function(){clearInterval(r),n=0,l.velocity({opacity:0,marginTop:0,marginLeft:0},{duration:225,queue:!1,delay:275}),u.velocity({opacity:0,scale:1},{duration:225,delay:275,queue:!1,complete:function(){u.css("display","none"),l.css("display","none"),i=!1}})}})})},e(document).ready(function(){e(".tooltipped").tooltip()})}(s),function(e){"use strict";function t(e){return null!==e&&e===e.window}function n(e){return t(e)?e:9===e.nodeType&&e.defaultView}function i(e){var t,i,r={top:0,left:0},o=e&&e.ownerDocument;return t=o.documentElement,"undefined"!=typeof e.getBoundingClientRect&&(r=e.getBoundingClientRect()),i=n(o),{top:r.top+i.pageYOffset-t.clientTop,left:r.left+i.pageXOffset-t.clientLeft}}function r(e){var t="";for(var n in e)e.hasOwnProperty(n)&&(t+=n+":"+e[n]+";");return t}function o(e){if(c.allowEvent(e)===!1)return null;for(var t=null,n=e.target||e.srcElement;null!==n.parentElement;){if(!(n instanceof SVGElement||-1===n.className.indexOf("waves-effect"))){t=n;break}if(n.classList.contains("waves-effect")){t=n;break}n=n.parentElement}return t}function a(t){var n=o(t);null!==n&&(u.show(t,n),"ontouchstart"in e&&(n.addEventListener("touchend",u.hide,!1),n.addEventListener("touchcancel",u.hide,!1)),n.addEventListener("mouseup",u.hide,!1),n.addEventListener("mouseleave",u.hide,!1))}var s=s||{},l=document.querySelectorAll.bind(document),u={duration:750,show:function(e,t){if(2===e.button)return!1;var n=t||this,o=document.createElement("div");o.className="waves-ripple",n.appendChild(o);var a=i(n),s=e.pageY-a.top,l=e.pageX-a.left,c="scale("+n.clientWidth/100*10+")";"touches"in e&&(s=e.touches[0].pageY-a.top,l=e.touches[0].pageX-a.left),o.setAttribute("data-hold",Date.now()),o.setAttribute("data-scale",c),o.setAttribute("data-x",l),o.setAttribute("data-y",s);var d={top:s+"px",left:l+"px"};o.className=o.className+" waves-notransition",o.setAttribute("style",r(d)),o.className=o.className.replace("waves-notransition",""),d["-webkit-transform"]=c,d["-moz-transform"]=c,d["-ms-transform"]=c,d["-o-transform"]=c,d.transform=c,d.opacity="1",d["-webkit-transition-duration"]=u.duration+"ms",d["-moz-transition-duration"]=u.duration+"ms",d["-o-transition-duration"]=u.duration+"ms",d["transition-duration"]=u.duration+"ms",d["-webkit-transition-timing-function"]="cubic-bezier(0.250, 0.460, 0.450, 0.940)",d["-moz-transition-timing-function"]="cubic-bezier(0.250, 0.460, 0.450, 0.940)",d["-o-transition-timing-function"]="cubic-bezier(0.250, 0.460, 0.450, 0.940)",d["transition-timing-function"]="cubic-bezier(0.250, 0.460, 0.450, 0.940)",o.setAttribute("style",r(d))},hide:function(e){c.touchup(e);var t=this,n=(1.4*t.clientWidth,null),i=t.getElementsByClassName("waves-ripple");if(!(i.length>0))return!1;n=i[i.length-1];var o=n.getAttribute("data-x"),a=n.getAttribute("data-y"),s=n.getAttribute("data-scale"),l=Date.now()-Number(n.getAttribute("data-hold")),d=350-l;0>d&&(d=0),setTimeout(function(){var e={top:a+"px",left:o+"px",opacity:"0","-webkit-transition-duration":u.duration+"ms","-moz-transition-duration":u.duration+"ms","-o-transition-duration":u.duration+"ms","transition-duration":u.duration+"ms","-webkit-transform":s,"-moz-transform":s,"-ms-transform":s,"-o-transform":s,transform:s};n.setAttribute("style",r(e)),setTimeout(function(){try{t.removeChild(n)}catch(e){return!1}},u.duration)},d)},wrapInput:function(e){for(var t=0;t<e.length;t++){var n=e[t];if("input"===n.tagName.toLowerCase()){var i=n.parentNode;if("i"===i.tagName.toLowerCase()&&-1!==i.className.indexOf("waves-effect"))continue;var r=document.createElement("i");r.className=n.className+" waves-input-wrapper";var o=n.getAttribute("style");o||(o=""),r.setAttribute("style",o),n.className="waves-button-input",n.removeAttribute("style"),i.replaceChild(r,n),r.appendChild(n)}}}},c={touches:0,allowEvent:function(e){var t=!0;return"touchstart"===e.type?c.touches+=1:"touchend"===e.type||"touchcancel"===e.type?setTimeout(function(){c.touches>0&&(c.touches-=1)},500):"mousedown"===e.type&&c.touches>0&&(t=!1),t},touchup:function(e){c.allowEvent(e)}};s.displayEffect=function(t){t=t||{},"duration"in t&&(u.duration=t.duration),u.wrapInput(l(".waves-effect")),"ontouchstart"in e&&document.body.addEventListener("touchstart",a,!1),document.body.addEventListener("mousedown",a,!1)},s.attach=function(t){"input"===t.tagName.toLowerCase()&&(u.wrapInput([t]),t=t.parentElement),"ontouchstart"in e&&t.addEventListener("touchstart",a,!1),t.addEventListener("mousedown",a,!1)},e.Waves=s,document.addEventListener("DOMContentLoaded",function(){s.displayEffect()},!1)}(window),Materialize.toast=function(e,t,n,i){function r(e){var t=document.createElement("div");if(t.classList.add("toast"),n)for(var r=n.split(" "),o=0,a=r.length;a>o;o++)t.classList.add(r[o]);t.innerHTML=e;var s=new d(t,{prevent_default:!1});return s.on("pan",function(e){var n=e.deltaX,i=80;t.classList.contains("panning")||t.classList.add("panning");var r=1-Math.abs(n/i);0>r&&(r=0),p(t,{left:n,opacity:r},{duration:50,queue:!1,easing:"easeOutQuad"})}),s.on("panend",function(e){var n=e.deltaX,r=80;Math.abs(n)>r?p(t,{marginTop:"-40px"},{duration:375,easing:"easeOutExpo",queue:!1,complete:function(){"function"==typeof i&&i(),t.parentNode.removeChild(t)}}):(t.classList.remove("panning"),p(t,{left:0,opacity:1},{duration:300,easing:"easeOutExpo",queue:!1}))}),t}n=n||"";var o=document.getElementById("toast-container");null===o&&(o=document.createElement("div"),o.id="toast-container",document.body.appendChild(o));var a=r(e);e&&o.appendChild(a),a.style.top="35px",a.style.opacity=0,p(a,{top:"0px",opacity:1},{duration:300,easing:"easeOutCubic",queue:!1});var s=t,l=setInterval(function(){null===a.parentNode&&window.clearInterval(l),a.classList.contains("panning")||(s-=20),0>=s&&(p(a,{opacity:0,marginTop:"-40px"},{duration:375,easing:"easeOutExpo",queue:!1,complete:function(){"function"==typeof i&&i(),this[0].parentNode.removeChild(this[0])}}),window.clearInterval(l))},20)},function(e){var t={init:function(t){var n={menuWidth:240,edge:"left",closeOnClick:!1};t=e.extend(n,t),e(this).each(function(){function n(n){o=!1,a=!1,e("body").css("overflow",""),e("#sidenav-overlay").velocity({opacity:0},{duration:200,queue:!1,easing:"easeOutQuad",complete:function(){e(this).remove()}}),"left"===t.edge?(e(".drag-target").css({width:"",right:"",left:"0"}),r.velocity({left:-1*(t.menuWidth+10)},{duration:200,queue:!1,easing:"easeOutCubic",complete:function(){n===!0&&(r.removeAttr("style"),r.css("width",t.menuWidth))}})):(e(".drag-target").css({width:"",right:"0",left:""}),r.velocity({right:-1*(t.menuWidth+10)},{duration:200,queue:!1,easing:"easeOutCubic",complete:function(){n===!0&&(r.removeAttr("style"),r.css("width",t.menuWidth))}}))}var i=e(this),r=e("#"+i.attr("data-activates"));240!=t.menuWidth&&r.css("width",t.menuWidth),e("body").append(e('<div class="drag-target"></div>')),"left"==t.edge?(r.css("left",-1*(t.menuWidth+10)),e(".drag-target").css({left:0})):(r.addClass("right-aligned").css("right",-1*(t.menuWidth+10)).css("left",""),e(".drag-target").css({right:0})),r.hasClass("fixed")&&window.innerWidth>992&&r.css("left",0),r.hasClass("fixed")&&e(window).resize(function(){window.innerWidth>992?0!==e("#sidenav-overlay").css("opacity")&&a?n(!0):(r.removeAttr("style"),r.css("width",t.menuWidth)):a===!1&&("left"===t.edge?r.css("left",-1*(t.menuWidth+10)):r.css("right",-1*(t.menuWidth+10)))}),t.closeOnClick===!0&&r.on("click.itemclick","a:not(.collapsible-header)",function(){n()});var o=!1,a=!1;e(".drag-target").on("click",function(){n()}),e(".drag-target").hammer({prevent_default:!1}).bind("pan",function(i){if("touch"==i.gesture.pointerType){var o=(i.gesture.direction,i.gesture.center.x);i.gesture.center.y,i.gesture.velocityX;if(e("body").css("overflow","hidden"),0===e("#sidenav-overlay").length){var s=e('<div id="sidenav-overlay"></div>');s.css("opacity",0).click(function(){n()}),e("body").append(s)}if("left"===t.edge&&(o>t.menuWidth?o=t.menuWidth:0>o&&(o=0)),"left"===t.edge)o<t.menuWidth/2?a=!1:o>=t.menuWidth/2&&(a=!0),r.css("left",o-t.menuWidth);else{o<window.innerWidth-t.menuWidth/2?a=!0:o>=window.innerWidth-t.menuWidth/2&&(a=!1);var l=-1*(o-t.menuWidth/2);l>0&&(l=0),r.css("right",l)}var u;"left"===t.edge?(u=o/t.menuWidth,e("#sidenav-overlay").velocity({opacity:u},{duration:50,queue:!1,easing:"easeOutQuad"})):(u=Math.abs((o-window.innerWidth)/t.menuWidth),e("#sidenav-overlay").velocity({opacity:u},{duration:50,queue:!1,easing:"easeOutQuad"}))}}).bind("panend",function(n){if("touch"==n.gesture.pointerType){var i=n.gesture.velocityX;o=!1,"left"===t.edge?a&&.3>=i||-.5>i?(r.velocity({left:0},{duration:300,queue:!1,easing:"easeOutQuad"}),e("#sidenav-overlay").velocity({opacity:1},{duration:50,queue:!1,easing:"easeOutQuad"}),e(".drag-target").css({width:"50%",right:0,left:""})):(!a||i>.3)&&(e("body").css("overflow",""),r.velocity({left:-1*(t.menuWidth+10)},{duration:200,queue:!1,easing:"easeOutQuad"}),e("#sidenav-overlay").velocity({opacity:0},{duration:200,queue:!1,easing:"easeOutQuad",complete:function(){e(this).remove()}}),e(".drag-target").css({width:"10px",right:"",left:0})):a&&i>=-.3||i>.5?(r.velocity({right:0},{duration:300,queue:!1,easing:"easeOutQuad"}),e("#sidenav-overlay").velocity({opacity:1},{duration:50,queue:!1,easing:"easeOutQuad"}),e(".drag-target").css({width:"50%",right:"",left:0})):(!a||-.3>i)&&(e("body").css("overflow",""),r.velocity({right:-1*(t.menuWidth+10)},{duration:200,queue:!1,easing:"easeOutQuad"}),e("#sidenav-overlay").velocity({opacity:0},{duration:200,queue:!1,easing:"easeOutQuad",complete:function(){e(this).remove()}}),e(".drag-target").css({width:"10px",right:0,left:""}))}}),i.click(function(){if(a===!0)a=!1,o=!1,n();else{e("body").css("overflow","hidden"),"left"===t.edge?(e(".drag-target").css({width:"50%",right:0,left:""}),r.velocity({left:0},{duration:300,queue:!1,easing:"easeOutQuad"})):(e(".drag-target").css({width:"50%",right:"",left:0}),r.velocity({right:0},{duration:300,queue:!1,easing:"easeOutQuad"}),r.css("left",""));var i=e('<div id="sidenav-overlay"></div>');i.css("opacity",0).click(function(){a=!1,o=!1,n(),i.velocity({opacity:0},{duration:300,queue:!1,easing:"easeOutQuad",complete:function(){e(this).remove()}})}),e("body").append(i),i.velocity({opacity:1},{duration:300,queue:!1,easing:"easeOutQuad",complete:function(){a=!0,o=!1}})}return!1})})},show:function(){this.trigger("click")},hide:function(){e("#sidenav-overlay").trigger("click")}};e.fn.sideNav=function(n){return t[n]?t[n].apply(this,Array.prototype.slice.call(arguments,1)):"object"!=typeof n&&n?void e.error("Method "+n+" does not exist on jQuery.sideNav"):t.init.apply(this,arguments)}}(s),function(e){function t(t,n,i,r){var o=e();return e.each(a,function(e,a){if(a.height()>0){var s=a.offset().top,l=a.offset().left,u=l+a.width(),c=s+a.height(),d=!(l>n||r>u||s>i||t>c);d&&o.push(a)}}),o}function n(){++u;var n=o.scrollTop(),i=o.scrollLeft(),r=i+o.width(),a=n+o.height(),l=t(n+c.top+200,r+c.right,a+c.bottom,i+c.left);e.each(l,function(e,t){var n=t.data("scrollSpy:ticks");"number"!=typeof n&&t.triggerHandler("scrollSpy:enter"),t.data("scrollSpy:ticks",u)}),e.each(s,function(e,t){var n=t.data("scrollSpy:ticks");"number"==typeof n&&n!==u&&(t.triggerHandler("scrollSpy:exit"),t.data("scrollSpy:ticks",null))}),s=l}function i(){o.trigger("scrollSpy:winSize")}function r(e,t,n){var i,r,o,a=null,s=0;n||(n={});var l=function(){s=n.leading===!1?0:d(),a=null,o=e.apply(i,r),i=r=null};return function(){var u=d();s||n.leading!==!1||(s=u);var c=t-(u-s);return i=this,r=arguments,0>=c?(clearTimeout(a),a=null,s=u,o=e.apply(i,r),i=r=null):a||n.trailing===!1||(a=setTimeout(l,c)),o}}var o=e(window),a=[],s=[],l=!1,u=0,c={top:0,right:0,bottom:0,left:0},d=Date.now||function(){return(new Date).getTime()};e.scrollSpy=function(t,i){var s=[];t=e(t),t.each(function(t,n){a.push(e(n)),e(n).data("scrollSpy:id",t),e("a[href=#"+e(n).attr("id")+"]").click(function(t){t.preventDefault();var n=e(this.hash).offset().top+1;e("html, body").animate({scrollTop:n-200},{duration:400,queue:!1,easing:"easeOutCubic"})})}),i=i||{throttle:100},c.top=i.offsetTop||0,c.right=i.offsetRight||0,c.bottom=i.offsetBottom||0,c.left=i.offsetLeft||0;var u=r(n,i.throttle||100),d=function(){e(document).ready(u)};return l||(o.on("scroll",d),o.on("resize",d),l=!0),setTimeout(d,0),t.on("scrollSpy:enter",function(){s=e.grep(s,function(e){return 0!=e.height()});var t=e(this);s[0]?(e("a[href=#"+s[0].attr("id")+"]").removeClass("active"),t.data("scrollSpy:id")<s[0].data("scrollSpy:id")?s.unshift(e(this)):s.push(e(this))):s.push(e(this)),e("a[href=#"+s[0].attr("id")+"]").addClass("active")}),t.on("scrollSpy:exit",function(){if(s=e.grep(s,function(e){return 0!=e.height()}),s[0]){e("a[href=#"+s[0].attr("id")+"]").removeClass("active");var t=e(this);s=e.grep(s,function(e){return e.attr("id")!=t.attr("id")}),s[0]&&e("a[href=#"+s[0].attr("id")+"]").addClass("active")}}),t},e.winSizeSpy=function(t){return e.winSizeSpy=function(){return o},t=t||{throttle:100},o.on("resize",r(i,t.throttle||100))},e.fn.scrollSpy=function(t){return e.scrollSpy(e(this),t)}}(s),function(e){e(document).ready(function(){function t(t){var n=t.css("font-family"),r=t.css("font-size");r&&i.css("font-size",r),n&&i.css("font-family",n),"off"===t.attr("wrap")&&i.css("overflow-wrap","normal").css("white-space","pre"),i.text(t.val()+"\n");var o=i.html().replace(/\n/g,"<br>");i.html(o),t.is(":visible")?i.css("width",t.width()):i.css("width",e(window).width()/2),t.css("height",i.height())}Materialize.updateTextFields=function(){var t="input[type=text], input[type=password], input[type=email], input[type=url], input[type=tel], input[type=number], input[type=search], textarea";e(t).each(function(t,n){e(n).val().length>0||void 0!==e(this).attr("placeholder")||e(n)[0].validity.badInput===!0?e(this).siblings("label, i").addClass("active"):e(this).siblings("label, i").removeClass("active")})};var n="input[type=text], input[type=password], input[type=email], input[type=url], input[type=tel], input[type=number], input[type=search], textarea";e("input[autofocus]").siblings("label, i").addClass("active"),e(document).on("change",n,function(){0===e(this).val().length&&void 0===e(this).attr("placeholder")||e(this).siblings("label, i").addClass("active"),validate_field(e(this))}),e(document).ready(function(){Materialize.updateTextFields()}),e(document).on("reset",function(t){var i=e(t.target);i.is("form")&&(i.find(n).removeClass("valid").removeClass("invalid"),i.find(n).each(function(){""===e(this).attr("value")&&e(this).siblings("label, i").removeClass("active")}),i.find("select.initialized").each(function(){var e=i.find("option[selected]").text();i.siblings("input.select-dropdown").val(e)}))}),e(document).on("focus",n,function(){e(this).siblings("label, i").addClass("active")}),e(document).on("blur",n,function(){var t=e(this);0===t.val().length&&t[0].validity.badInput!==!0&&void 0===t.attr("placeholder")&&t.siblings("label, i").removeClass("active"),validate_field(t)}),validate_field=function(e){var t=void 0!==e.attr("length"),n=parseInt(e.attr("length")),i=e.val().length;0===e.val().length&&e[0].validity.badInput===!1?e.hasClass("validate")&&(e.removeClass("valid"),e.removeClass("invalid")):e.hasClass("validate")&&(e.is(":valid")&&t&&n>i||e.is(":valid")&&!t?(e.removeClass("invalid"),e.addClass("valid")):(e.removeClass("valid"),e.addClass("invalid")))};var i=e(".hiddendiv").first();i.length||(i=e('<div class="hiddendiv common"></div>'),e("body").append(i));var r=".materialize-textarea";e(r).each(function(){var n=e(this);n.val().length&&t(n)}),e("body").on("keyup keydown",r,function(){t(e(this))}),e(".file-field").each(function(){var t=e(this).find("input.file-path");e(this).find('input[type="file"]').change(function(){t.val(e(this)[0].files[0].name),t.trigger("change")})});var o,a="input[type=range]",s=!1;e(a).each(function(){var t=e('<span class="thumb"><span class="value"></span></span>');e(this).after(t)});var l=".range-field";e(document).on("change",a,function(t){var n=e(this).siblings(".thumb");n.find(".value").html(e(this).val())}),e(document).on("mousedown touchstart",a,function(t){var n=e(this).siblings(".thumb");n.length<=0&&(n=e('<span class="thumb"><span class="value"></span></span>'),e(this).append(n)),n.find(".value").html(e(this).val()),s=!0,e(this).addClass("active"),n.hasClass("active")||n.velocity({height:"30px",width:"30px",top:"-20px",marginLeft:"-15px"},{duration:300,easing:"easeOutExpo"}),o=void 0===t.pageX||null===t.pageX?t.originalEvent.touches[0].pageX-e(this).offset().left:t.pageX-e(this).offset().left;var i=e(this).outerWidth();0>o?o=0:o>i&&(o=i),n.addClass("active").css("left",o),n.find(".value").html(e(this).val())}),e(document).on("mouseup touchend",l,function(){s=!1,e(this).removeClass("active")}),e(document).on("mousemove touchmove",l,function(t){var n,i=e(this).children(".thumb");if(s){i.hasClass("active")||i.velocity({height:"30px",width:"30px",top:"-20px",marginLeft:"-15px"},{duration:300,easing:"easeOutExpo"}),n=void 0===t.pageX||null===t.pageX?t.originalEvent.touches[0].pageX-e(this).offset().left:t.pageX-e(this).offset().left;var r=e(this).outerWidth();0>n?n=0:n>r&&(n=r),i.addClass("active").css("left",n)}}),e(document).on("mouseout touchleave",l,function(){if(!s){var t=e(this).children(".thumb");t.hasClass("active")&&t.velocity({height:"0",width:"0",top:"10px",marginLeft:"-6px"},{duration:100}),t.removeClass("active")}})}),e.fn.material_select=function(t){e(this).each(function(){if($select=e(this),!$select.hasClass("browser-default")){var n=$select.data("select-id");if(n&&($select.parent().find("i").remove(),$select.parent().find("input").remove(),$select.unwrap(),e("ul#select-options-"+n).remove()),"destroy"===t)return void $select.data("select-id",null).removeClass("initialized");var i=Materialize.guid();$select.data("select-id",i);var r=e('<div class="select-wrapper"></div>');r.addClass($select.attr("class"));var o,a=e('<ul id="select-options-'+i+'" class="dropdown-content select-dropdown"></ul>'),s=$select.children("option");o=void 0!==$select.find("option:selected")?$select.find("option:selected"):a.first(),s.each(function(){a.append(e('<li class="'+(e(this).is(":disabled")?"disabled":"")+'"><span>'+e(this).html()+"</span></li>"))}),a.find("li").each(function(n){var i=$select;e(this).click(function(){e(this).hasClass("disabled")||(i.find("option").eq(n).prop("selected",!0),i.trigger("change"),i.siblings("input.select-dropdown").val(e(this).text()),"undefined"!=typeof t&&t())})}),$select.wrap(r);var l=e('<span class="caret">&#9660;</span>');$select.is(":disabled")&&l.addClass("disabled");var u=e('<input type="text" class="select-dropdown" readonly="true" '+($select.is(":disabled")?"disabled":"")+' data-activates="select-options-'+i+'" value="'+o.html()+'"/>');$select.before(u),u.before(l),e("body").append(a),$select.is(":disabled")||u.dropdown({hover:!1}),$select.attr("tabindex")&&e(u[0]).attr("tabindex",$select.attr("tabindex")),$select.addClass("initialized"),u.on("focus",function(){e(this).trigger("open"),o=e(this).val(),selectedOption=a.find("li").filter(function(){return e(this).text().toLowerCase()===o.toLowerCase()})[0],activateOption(a,selectedOption)}),u.on("blur",function(){e(this).trigger("close")}),activateOption=function(t,n){t.find("li.active").removeClass("active"),e(n).addClass("active"),t.scrollTo(n)},filterQuery=[],onKeyDown=function(t){if(9==t.which)return void u.trigger("close");if(40==t.which&&!a.is(":visible"))return void u.trigger("open");if(13!=t.which||a.is(":visible")){t.preventDefault(),letter=String.fromCharCode(t.which).toLowerCase();var n=[9,13,27,38,40];letter&&-1===n.indexOf(t.which)&&(filterQuery.push(letter),string=filterQuery.join(""),newOption=a.find("li").filter(function(){return 0===e(this).text().toLowerCase().indexOf(string)})[0],newOption&&activateOption(a,newOption)),13==t.which&&(activeOption=a.find("li.active:not(.disabled)")[0],activeOption&&(e(activeOption).trigger("click"),u.trigger("close"))),40==t.which&&(newOption=a.find("li.active").next("li:not(.disabled)")[0],newOption&&activateOption(a,newOption)),27==t.which&&u.trigger("close"),38==t.which&&(newOption=a.find("li.active").prev("li:not(.disabled)")[0],newOption&&activateOption(a,newOption)),setTimeout(function(){filterQuery=[]},1e3)}},u.on("keydown",onKeyDown)}})}}(s),function(e){var t={init:function(t){var n={indicators:!0,height:400,transition:500,interval:6e3};return t=e.extend(n,t),this.each(function(){function n(e,t){e.hasClass("center-align")?e.velocity({opacity:0,translateY:-100},{duration:t,queue:!1}):e.hasClass("right-align")?e.velocity({opacity:0,translateX:100},{duration:t,queue:!1}):e.hasClass("left-align")&&e.velocity({opacity:0,translateX:-100},{duration:t,queue:!1})}function i(e){e>=s.length?e=0:0>e&&(e=s.length-1),l=a.find(".active").index(),l!=e&&(r=s.eq(l),$caption=r.find(".caption"),r.removeClass("active"),r.velocity({opacity:0},{duration:t.transition,queue:!1,easing:"easeOutQuad",complete:function(){s.not(".active").velocity({opacity:0,translateX:0,translateY:0},{duration:0,queue:!1})}}),n($caption,t.transition),t.indicators&&u.eq(l).removeClass("active"),s.eq(e).velocity({opacity:1},{duration:t.transition,queue:!1,easing:"easeOutQuad"}),s.eq(e).find(".caption").velocity({opacity:1,translateX:0,translateY:0},{duration:t.transition,delay:t.transition,queue:!1,easing:"easeOutQuad"}),s.eq(e).addClass("active"),t.indicators&&u.eq(e).addClass("active"))}var r,o=e(this),a=o.find("ul.slides").first(),s=a.find("li"),l=a.find(".active").index();if(-1!=l&&(r=s.eq(l)),o.hasClass("fullscreen")||(t.indicators?o.height(t.height+40):o.height(t.height),a.height(t.height)),s.find(".caption").each(function(){n(e(this),0)}),s.find("img").each(function(){e(this).css("background-image","url("+e(this).attr("src")+")"),e(this).attr("src","data:image/gif;base64,R0lGODlhAQABAIABAP///wAAACH5BAEKAAEALAAAAAABAAEAAAICTAEAOw==")}),t.indicators){var u=e('<ul class="indicators"></ul>');s.each(function(n){var r=e('<li class="indicator-item"></li>');r.click(function(){var n=a.parent(),r=n.find(e(this)).index();i(r),clearInterval($interval),$interval=setInterval(function(){l=a.find(".active").index(),s.length==l+1?l=0:l+=1,i(l)},t.transition+t.interval)}),u.append(r)}),o.append(u),u=o.find("ul.indicators").find("li.indicator-item")}r?r.show():(s.first().addClass("active").velocity({opacity:1},{duration:t.transition,queue:!1,easing:"easeOutQuad"}),l=0,r=s.eq(l),t.indicators&&u.eq(l).addClass("active")),r.find("img").each(function(){r.find(".caption").velocity({opacity:1,translateX:0,translateY:0},{duration:t.transition,queue:!1,easing:"easeOutQuad"})}),$interval=setInterval(function(){l=a.find(".active").index(),i(l+1)},t.transition+t.interval);var c=!1,d=!1,p=!1;o.hammer({prevent_default:!1}).bind("pan",function(e){if("touch"===e.gesture.pointerType){clearInterval($interval);var t=e.gesture.direction,n=e.gesture.deltaX,i=e.gesture.velocityX;$curr_slide=a.find(".active"),$curr_slide.velocity({translateX:n},{duration:50,queue:!1,easing:"easeOutQuad"}),4===t&&(n>o.innerWidth()/2||-.65>i)?p=!0:2===t&&(n<-1*o.innerWidth()/2||i>.65)&&(d=!0);var r;d&&(r=$curr_slide.next(),0===r.length&&(r=s.first()),r.velocity({opacity:1},{duration:300,queue:!1,easing:"easeOutQuad"})),p&&(r=$curr_slide.prev(),0===r.length&&(r=s.last()),r.velocity({opacity:1},{duration:300,queue:!1,easing:"easeOutQuad"}))}}).bind("panend",function(e){"touch"===e.gesture.pointerType&&($curr_slide=a.find(".active"),c=!1,curr_index=a.find(".active").index(),p||d?d?(i(curr_index+1),$curr_slide.velocity({translateX:-1*o.innerWidth()},{duration:300,queue:!1,easing:"easeOutQuad",complete:function(){$curr_slide.velocity({opacity:0,translateX:0},{duration:0,queue:!1})}})):p&&(i(curr_index-1),$curr_slide.velocity({translateX:o.innerWidth()},{duration:300,queue:!1,easing:"easeOutQuad",complete:function(){$curr_slide.velocity({opacity:0,translateX:0},{duration:0,queue:!1})}})):$curr_slide.velocity({translateX:0},{duration:300,queue:!1,easing:"easeOutQuad"}),d=!1,p=!1,clearInterval($interval),$interval=setInterval(function(){l=a.find(".active").index(),s.length==l+1?l=0:l+=1,i(l)},t.transition+t.interval))}),o.on("sliderPause",function(){clearInterval($interval)}),o.on("sliderStart",function(){clearInterval($interval),$interval=setInterval(function(){l=a.find(".active").index(),s.length==l+1?l=0:l+=1,i(l)},t.transition+t.interval)})})},pause:function(){e(this).trigger("sliderPause")},start:function(){e(this).trigger("sliderStart")}};e.fn.slider=function(n){return t[n]?t[n].apply(this,Array.prototype.slice.call(arguments,1)):"object"!=typeof n&&n?void e.error("Method "+n+" does not exist on jQuery.tooltip"):t.init.apply(this,arguments)}}(s),function(e){e(document).ready(function(){e(document).on("click.card",".card",function(t){e(this).find(".card-reveal").length&&(e(t.target).is(e(".card-reveal .card-title"))||e(t.target).is(e(".card-reveal .card-title i"))?e(this).find(".card-reveal").velocity({translateY:0},{duration:225,queue:!1,easing:"easeInOutQuad",complete:function(){e(this).css({display:"none"})}}):(e(t.target).is(e(".card .activator"))||e(t.target).is(e(".card .activator i")))&&e(this).find(".card-reveal").css({display:"block"}).velocity("stop",!1).velocity({translateY:"-100%"},{duration:300,queue:!1,easing:"easeInOutQuad"}))})})}(s),function(e){e(document).ready(function(){e.fn.pushpin=function(t){var n={top:0,bottom:1/0,offset:0};return t=e.extend(n,t),$index=0,this.each(function(){function n(e){e.removeClass("pin-top"),e.removeClass("pinned"),e.removeClass("pin-bottom")}function i(i,r){i.each(function(){t.top<=r&&t.bottom>=r&&!e(this).hasClass("pinned")&&(n(e(this)),e(this).css("top",t.offset),e(this).addClass("pinned")),r<t.top&&!e(this).hasClass("pin-top")&&(n(e(this)),e(this).css("top",0),e(this).addClass("pin-top")),r>t.bottom&&!e(this).hasClass("pin-bottom")&&(n(e(this)),e(this).addClass("pin-bottom"),e(this).css("top",t.bottom-a))})}var r=Materialize.guid(),o=e(this),a=e(this).offset().top;i(o,e(window).scrollTop()),e(window).on("scroll."+r,function(){var n=e(window).scrollTop()+t.offset;i(o,n)})})}})}(s),function(e){e(document).ready(function(){e.fn.reverse=[].reverse,e(document).on("mouseenter.fixedActionBtn",".fixed-action-btn",function(n){var i=e(this);t(i)}),e(document).on("mouseleave.fixedActionBtn",".fixed-action-btn",function(t){var i=e(this);n(i)})}),e.fn.extend({openFAB:function(){var n=e(this);t(n)},closeFAB:function(){n($this)}});var t=function(t){if($this=t,$this.hasClass("active")===!1){$this.addClass("active"),$this.find("ul .btn-floating").velocity({scaleY:".4",scaleX:".4",translateY:"40px"},{duration:0});var n=0;$this.find("ul .btn-floating").reverse().each(function(){e(this).velocity({opacity:"1",scaleX:"1",scaleY:"1",translateY:"0"},{duration:80,delay:n}),n+=40})}},n=function(e){$this=e,$this.removeClass("active");$this.find("ul .btn-floating").velocity("stop",!0),$this.find("ul .btn-floating").velocity({opacity:"0",scaleX:".4",scaleY:".4",translateY:"40px"},{duration:80})}}(s),function(e){Materialize.fadeInImage=function(t){var n=e(t);n.css({opacity:0}),e(n).velocity({opacity:1},{duration:650,queue:!1,easing:"easeOutSine"}),e(n).velocity({opacity:1},{duration:1300,queue:!1,easing:"swing",step:function(t,n){n.start=100;var i=t/100,r=150-(100-t)/1.75;100>r&&(r=100),t>=0&&e(this).css({"-webkit-filter":"grayscale("+i+")brightness("+r+"%)",filter:"grayscale("+i+")brightness("+r+"%)"})}})},Materialize.showStaggeredList=function(t){var n=0;e(t).find("li").velocity({translateX:"-100px"},{duration:0}),e(t).find("li").each(function(){e(this).velocity({opacity:"1",translateX:"0"},{duration:800,delay:n,easing:[60,10]}),n+=120})},e(document).ready(function(){var t=!1,n=!1;e(".dismissable").each(function(){e(this).hammer({prevent_default:!1}).bind("pan",function(i){if("touch"===i.gesture.pointerType){var r=e(this),o=i.gesture.direction,a=i.gesture.deltaX,s=i.gesture.velocityX;r.velocity({translateX:a},{duration:50,queue:!1,easing:"easeOutQuad"}),4===o&&(a>r.innerWidth()/2||-.75>s)&&(t=!0),2===o&&(a<-1*r.innerWidth()/2||s>.75)&&(n=!0)}}).bind("panend",function(i){if(Math.abs(i.gesture.deltaX)<e(this).innerWidth()/2&&(n=!1,t=!1),"touch"===i.gesture.pointerType){var r=e(this);if(t||n){var o;o=t?r.innerWidth():-1*r.innerWidth(),r.velocity({translateX:o},{duration:100,queue:!1,easing:"easeOutQuad",complete:function(){r.css("border","none"),r.velocity({height:0,padding:0},{duration:200,queue:!1,easing:"easeOutQuad",complete:function(){r.remove()}})}})}else r.velocity({translateX:0},{duration:100,queue:!1,easing:"easeOutQuad"});t=!1,n=!1}})})})}(s),function(e){Materialize.scrollFire=function(e){var t=!1;window.addEventListener("scroll",function(){t=!0}),setInterval(function(){if(t){t=!1;for(var n=window.pageYOffset+window.innerHeight,i=0;i<e.length;i++){var r=e[i],o=r.selector,a=r.offset,s=r.callback,l=document.querySelector(o);
if(null!==l){var u=l.getBoundingClientRect().top+document.body.scrollTop;if(n>u+a&&r.done!==!0){var c=new Function(s);c(),r.done=!0}}}}},100)}}(s),function(e){o=[n(1)],i=e,!(a="function"==typeof i?i.apply(t,o):i)}(function(e){function t(o,a,l,d){function p(){return t._.node("div",t._.node("div",t._.node("div",t._.node("div",C.component.nodes(b.open),x.box),x.wrap),x.frame),x.holder)}function h(){_.data(a,C).addClass(x.input).attr("tabindex",-1).val(_.data("value")?C.get("select",w.format):o.value),w.editable||_.on("focus."+b.id+" click."+b.id,function(e){e.preventDefault(),C.$root[0].focus()}).on("keydown."+b.id,v),r(o,{haspopup:!0,expanded:!1,readonly:!1,owns:o.id+"_root"})}function f(){C.$root.on({keydown:v,focusin:function(e){C.$root.removeClass(x.focused),e.stopPropagation()},"mousedown click":function(t){var n=t.target;n!=C.$root.children()[0]&&(t.stopPropagation(),"mousedown"!=t.type||e(n).is("input, select, textarea, button, option")||(t.preventDefault(),C.$root[0].focus()))}}).on({focus:function(){_.addClass(x.target)},blur:function(){_.removeClass(x.target)}}).on("focus.toOpen",m).on("click","[data-pick], [data-nav], [data-clear], [data-close]",function(){var t=e(this),n=t.data(),i=t.hasClass(x.navDisabled)||t.hasClass(x.disabled),r=s();r=r&&(r.type||r.href),(i||r&&!e.contains(C.$root[0],r))&&C.$root[0].focus(),!i&&n.nav?C.set("highlight",C.component.item.highlight,{nav:n.nav}):!i&&"pick"in n?C.set("select",n.pick):n.clear?C.clear().close(!0):n.close&&C.close(!0)}),r(C.$root[0],"hidden",!0)}function g(){var t;w.hiddenName===!0?(t=o.name,o.name=""):(t=["string"==typeof w.hiddenPrefix?w.hiddenPrefix:"","string"==typeof w.hiddenSuffix?w.hiddenSuffix:"_submit"],t=t[0]+o.name+t[1]),C._hidden=e('<input type=hidden name="'+t+'"'+(_.data("value")||o.value?' value="'+C.get("select",w.formatSubmit)+'"':"")+">")[0],_.on("change."+b.id,function(){C._hidden.value=o.value?C.get("select",w.formatSubmit):""}),w.container?e(w.container).append(C._hidden):_.after(C._hidden)}function v(e){var t=e.keyCode,n=/^(8|46)$/.test(t);return 27==t?(C.close(),!1):void((32==t||n||!b.open&&C.component.key[t])&&(e.preventDefault(),e.stopPropagation(),n?C.clear().close():C.open()))}function m(e){e.stopPropagation(),"focus"==e.type&&C.$root.addClass(x.focused),C.open()}if(!o)return t;var y=!1,b={id:o.id||"P"+Math.abs(~~(Math.random()*new Date))},w=l?e.extend(!0,{},l.defaults,d):d||{},x=e.extend({},t.klasses(),w.klass),_=e(o),k=function(){return this.start()},C=k.prototype={constructor:k,$node:_,start:function(){return b&&b.start?C:(b.methods={},b.start=!0,b.open=!1,b.type=o.type,o.autofocus=o==s(),o.readOnly=!w.editable,o.id=o.id||b.id,"text"!=o.type&&(o.type="text"),C.component=new l(C,w),C.$root=e(t._.node("div",p(),x.picker,'id="'+o.id+'_root" tabindex="0"')),f(),w.formatSubmit&&g(),h(),w.container?e(w.container).append(C.$root):_.after(C.$root),C.on({start:C.component.onStart,render:C.component.onRender,stop:C.component.onStop,open:C.component.onOpen,close:C.component.onClose,set:C.component.onSet}).on({start:w.onStart,render:w.onRender,stop:w.onStop,open:w.onOpen,close:w.onClose,set:w.onSet}),y=n(C.$root.children()[0]),o.autofocus&&C.open(),C.trigger("start").trigger("render"))},render:function(e){return e?C.$root.html(p()):C.$root.find("."+x.box).html(C.component.nodes(b.open)),C.trigger("render")},stop:function(){return b.start?(C.close(),C._hidden&&C._hidden.parentNode.removeChild(C._hidden),C.$root.remove(),_.removeClass(x.input).removeData(a),setTimeout(function(){_.off("."+b.id)},0),o.type=b.type,o.readOnly=!1,C.trigger("stop"),b.methods={},b.start=!1,C):C},open:function(n){return b.open?C:(_.addClass(x.active),r(o,"expanded",!0),setTimeout(function(){C.$root.addClass(x.opened),r(C.$root[0],"hidden",!1)},0),n!==!1&&(b.open=!0,y&&c.css("overflow","hidden").css("padding-right","+="+i()),C.$root[0].focus(),u.on("click."+b.id+" focusin."+b.id,function(e){var t=e.target;t!=o&&t!=document&&3!=e.which&&C.close(t===C.$root.children()[0])}).on("keydown."+b.id,function(n){var i=n.keyCode,r=C.component.key[i],o=n.target;27==i?C.close(!0):o!=C.$root[0]||!r&&13!=i?e.contains(C.$root[0],o)&&13==i&&(n.preventDefault(),o.click()):(n.preventDefault(),r?t._.trigger(C.component.key.go,C,[t._.trigger(r)]):C.$root.find("."+x.highlighted).hasClass(x.disabled)||C.set("select",C.component.item.highlight).close())})),C.trigger("open"))},close:function(e){return e&&(C.$root.off("focus.toOpen")[0].focus(),setTimeout(function(){C.$root.on("focus.toOpen",m)},0)),_.removeClass(x.active),r(o,"expanded",!1),setTimeout(function(){C.$root.removeClass(x.opened+" "+x.focused),r(C.$root[0],"hidden",!0)},0),b.open?(b.open=!1,y&&c.css("overflow","").css("padding-right","-="+i()),u.off("."+b.id),C.trigger("close")):C},clear:function(e){return C.set("clear",null,e)},set:function(t,n,i){var r,o,a=e.isPlainObject(t),s=a?t:{};if(i=a&&e.isPlainObject(n)?n:i||{},t){a||(s[t]=n);for(r in s)o=s[r],r in C.component.item&&(void 0===o&&(o=null),C.component.set(r,o,i)),"select"!=r&&"clear"!=r||_.val("clear"==r?"":C.get(r,w.format)).trigger("change");C.render()}return i.muted?C:C.trigger("set",s)},get:function(e,n){if(e=e||"value",null!=b[e])return b[e];if("valueSubmit"==e){if(C._hidden)return C._hidden.value;e="value"}if("value"==e)return o.value;if(e in C.component.item){if("string"==typeof n){var i=C.component.get(e);return i?t._.trigger(C.component.formats.toString,C.component,[n,i]):""}return C.component.get(e)}},on:function(t,n,i){var r,o,a=e.isPlainObject(t),s=a?t:{};if(t){a||(s[t]=n);for(r in s)o=s[r],i&&(r="_"+r),b.methods[r]=b.methods[r]||[],b.methods[r].push(o)}return C},off:function(){var e,t,n=arguments;for(e=0,namesCount=n.length;e<namesCount;e+=1)t=n[e],t in b.methods&&delete b.methods[t];return C},trigger:function(e,n){var i=function(e){var i=b.methods[e];i&&i.map(function(e){t._.trigger(e,C,[n])})};return i("_"+e),i(e),C}};return new k}function n(e){var t,n="position";return e.currentStyle?t=e.currentStyle[n]:window.getComputedStyle&&(t=getComputedStyle(e)[n]),"fixed"==t}function i(){if(c.height()<=l.height())return 0;var t=e('<div style="visibility:hidden;width:100px" />').appendTo("body"),n=t[0].offsetWidth;t.css("overflow","scroll");var i=e('<div style="width:100%" />').appendTo(t),r=i[0].offsetWidth;return t.remove(),n-r}function r(t,n,i){if(e.isPlainObject(n))for(var r in n)o(t,r,n[r]);else o(t,n,i)}function o(e,t,n){e.setAttribute(("role"==t?"":"aria-")+t,n)}function a(t,n){e.isPlainObject(t)||(t={attribute:n}),n="";for(var i in t){var r=("role"==i?"":"aria-")+i,o=t[i];n+=null==o?"":r+'="'+t[i]+'"'}return n}function s(){try{return document.activeElement}catch(e){}}var l=e(window),u=e(document),c=e(document.documentElement);return t.klasses=function(e){return e=e||"picker",{picker:e,opened:e+"--opened",focused:e+"--focused",input:e+"__input",active:e+"__input--active",target:e+"__input--target",holder:e+"__holder",frame:e+"__frame",wrap:e+"__wrap",box:e+"__box"}},t._={group:function(e){for(var n,i="",r=t._.trigger(e.min,e);r<=t._.trigger(e.max,e,[r]);r+=e.i)n=t._.trigger(e.item,e,[r]),i+=t._.node(e.node,n[0],n[1],n[2]);return i},node:function(t,n,i,r){return n?(n=e.isArray(n)?n.join(""):n,i=i?' class="'+i+'"':"",r=r?" "+r:"","<"+t+i+r+">"+n+"</"+t+">"):""},lead:function(e){return(10>e?"0":"")+e},trigger:function(e,t,n){return"function"==typeof e?e.apply(t,n||[]):e},digits:function(e){return/\d/.test(e[1])?2:1},isDate:function(e){return{}.toString.call(e).indexOf("Date")>-1&&this.isInteger(e.getDate())},isInteger:function(e){return{}.toString.call(e).indexOf("Number")>-1&&e%1===0},ariaAttr:a},t.extend=function(n,i){e.fn[n]=function(r,o){var a=this.data(n);return"picker"==r?a:a&&"string"==typeof r?t._.trigger(a[r],a,[o]):this.each(function(){var o=e(this);o.data(n)||new t(this,n,i,r)})},e.fn[n].defaults=i.defaults},t}),function(s){o=[a,n(1)],i=s,r="function"==typeof i?i.apply(t,o):i,!(void 0!==r&&(e.exports=r))}(function(e,t){function n(e,t){var n=this,i=e.$node[0],r=i.value,o=e.$node.data("value"),a=o||r,s=o?t.formatSubmit:t.format,l=function(){return i.currentStyle?"rtl"==i.currentStyle.direction:"rtl"==getComputedStyle(e.$root[0]).direction};n.settings=t,n.$node=e.$node,n.queue={min:"measure create",max:"measure create",now:"now create",select:"parse create validate",highlight:"parse navigate create validate",view:"parse create validate viewset",disable:"deactivate",enable:"activate"},n.item={},n.item.clear=null,n.item.disable=(t.disable||[]).slice(0),n.item.enable=-function(e){return e[0]===!0?e.shift():-1}(n.item.disable),n.set("min",t.min).set("max",t.max).set("now"),a?n.set("select",a,{format:s}):n.set("select",null).set("highlight",n.item.now),n.key={40:7,38:-7,39:function(){return l()?-1:1},37:function(){return l()?1:-1},go:function(e){var t=n.item.highlight,i=new Date(t.year,t.month,t.date+e);n.set("highlight",i,{interval:e}),this.render()}},e.on("render",function(){e.$root.find("."+t.klass.selectMonth).on("change",function(){var n=this.value;n&&(e.set("highlight",[e.get("view").year,n,e.get("highlight").date]),e.$root.find("."+t.klass.selectMonth).trigger("focus"))}),e.$root.find("."+t.klass.selectYear).on("change",function(){var n=this.value;n&&(e.set("highlight",[n,e.get("view").month,e.get("highlight").date]),e.$root.find("."+t.klass.selectYear).trigger("focus"))})},1).on("open",function(){var i="";n.disabled(n.get("now"))&&(i=":not(."+t.klass.buttonToday+")"),e.$root.find("button"+i+", select").attr("disabled",!1)},1).on("close",function(){e.$root.find("button, select").attr("disabled",!0)},1)}var i=7,r=6,o=e._;n.prototype.set=function(e,t,n){var i=this,r=i.item;return null===t?("clear"==e&&(e="select"),r[e]=t,i):(r["enable"==e?"disable":"flip"==e?"enable":e]=i.queue[e].split(" ").map(function(r){return t=i[r](e,t,n)}).pop(),"select"==e?i.set("highlight",r.select,n):"highlight"==e?i.set("view",r.highlight,n):e.match(/^(flip|min|max|disable|enable)$/)&&(r.select&&i.disabled(r.select)&&i.set("select",r.select,n),r.highlight&&i.disabled(r.highlight)&&i.set("highlight",r.highlight,n)),i)},n.prototype.get=function(e){return this.item[e]},n.prototype.create=function(e,n,i){var r,a=this;return n=void 0===n?e:n,n==-(1/0)||n==1/0?r=n:t.isPlainObject(n)&&o.isInteger(n.pick)?n=n.obj:t.isArray(n)?(n=new Date(n[0],n[1],n[2]),n=o.isDate(n)?n:a.create().obj):n=o.isInteger(n)||o.isDate(n)?a.normalize(new Date(n),i):a.now(e,n,i),{year:r||n.getFullYear(),month:r||n.getMonth(),date:r||n.getDate(),day:r||n.getDay(),obj:r||n,pick:r||n.getTime()}},n.prototype.createRange=function(e,n){var i=this,r=function(e){return e===!0||t.isArray(e)||o.isDate(e)?i.create(e):e};return o.isInteger(e)||(e=r(e)),o.isInteger(n)||(n=r(n)),o.isInteger(e)&&t.isPlainObject(n)?e=[n.year,n.month,n.date+e]:o.isInteger(n)&&t.isPlainObject(e)&&(n=[e.year,e.month,e.date+n]),{from:r(e),to:r(n)}},n.prototype.withinRange=function(e,t){return e=this.createRange(e.from,e.to),t.pick>=e.from.pick&&t.pick<=e.to.pick},n.prototype.overlapRanges=function(e,t){var n=this;return e=n.createRange(e.from,e.to),t=n.createRange(t.from,t.to),n.withinRange(e,t.from)||n.withinRange(e,t.to)||n.withinRange(t,e.from)||n.withinRange(t,e.to)},n.prototype.now=function(e,t,n){return t=new Date,n&&n.rel&&t.setDate(t.getDate()+n.rel),this.normalize(t,n)},n.prototype.navigate=function(e,n,i){var r,o,a,s,l=t.isArray(n),u=t.isPlainObject(n),c=this.item.view;if(l||u){for(u?(o=n.year,a=n.month,s=n.date):(o=+n[0],a=+n[1],s=+n[2]),i&&i.nav&&c&&c.month!==a&&(o=c.year,a=c.month),r=new Date(o,a+(i&&i.nav?i.nav:0),1),o=r.getFullYear(),a=r.getMonth();new Date(o,a,s).getMonth()!==a;)s-=1;n=[o,a,s]}return n},n.prototype.normalize=function(e){return e.setHours(0,0,0,0),e},n.prototype.measure=function(e,t){var n=this;return t?"string"==typeof t?t=n.parse(e,t):o.isInteger(t)&&(t=n.now(e,t,{rel:t})):t="min"==e?-(1/0):1/0,t},n.prototype.viewset=function(e,t){return this.create([t.year,t.month,1])},n.prototype.validate=function(e,n,i){var r,a,s,l,u=this,c=n,d=i&&i.interval?i.interval:1,p=-1===u.item.enable,h=u.item.min,f=u.item.max,g=p&&u.item.disable.filter(function(e){if(t.isArray(e)){var i=u.create(e).pick;i<n.pick?r=!0:i>n.pick&&(a=!0)}return o.isInteger(e)}).length;if((!i||!i.nav)&&(!p&&u.disabled(n)||p&&u.disabled(n)&&(g||r||a)||!p&&(n.pick<=h.pick||n.pick>=f.pick)))for(p&&!g&&(!a&&d>0||!r&&0>d)&&(d*=-1);u.disabled(n)&&(Math.abs(d)>1&&(n.month<c.month||n.month>c.month)&&(n=c,d=d>0?1:-1),n.pick<=h.pick?(s=!0,d=1,n=u.create([h.year,h.month,h.date+(n.pick===h.pick?0:-1)])):n.pick>=f.pick&&(l=!0,d=-1,n=u.create([f.year,f.month,f.date+(n.pick===f.pick?0:1)])),!s||!l);)n=u.create([n.year,n.month,n.date+d]);return n},n.prototype.disabled=function(e){var n=this,i=n.item.disable.filter(function(i){return o.isInteger(i)?e.day===(n.settings.firstDay?i:i-1)%7:t.isArray(i)||o.isDate(i)?e.pick===n.create(i).pick:t.isPlainObject(i)?n.withinRange(i,e):void 0});return i=i.length&&!i.filter(function(e){return t.isArray(e)&&"inverted"==e[3]||t.isPlainObject(e)&&e.inverted}).length,-1===n.item.enable?!i:i||e.pick<n.item.min.pick||e.pick>n.item.max.pick},n.prototype.parse=function(e,t,n){var i=this,r={};return t&&"string"==typeof t?(n&&n.format||(n=n||{},n.format=i.settings.format),i.formats.toArray(n.format).map(function(e){var n=i.formats[e],a=n?o.trigger(n,i,[t,r]):e.replace(/^!/,"").length;n&&(r[e]=t.substr(0,a)),t=t.substr(a)}),[r.yyyy||r.yy,+(r.mm||r.m)-1,r.dd||r.d]):t},n.prototype.formats=function(){function e(e,t,n){var i=e.match(/\w+/)[0];return n.mm||n.m||(n.m=t.indexOf(i)+1),i.length}function t(e){return e.match(/\w+/)[0].length}return{d:function(e,t){return e?o.digits(e):t.date},dd:function(e,t){return e?2:o.lead(t.date)},ddd:function(e,n){return e?t(e):this.settings.weekdaysShort[n.day]},dddd:function(e,n){return e?t(e):this.settings.weekdaysFull[n.day]},m:function(e,t){return e?o.digits(e):t.month+1},mm:function(e,t){return e?2:o.lead(t.month+1)},mmm:function(t,n){var i=this.settings.monthsShort;return t?e(t,i,n):i[n.month]},mmmm:function(t,n){var i=this.settings.monthsFull;return t?e(t,i,n):i[n.month]},yy:function(e,t){return e?2:(""+t.year).slice(2)},yyyy:function(e,t){return e?4:t.year},toArray:function(e){return e.split(/(d{1,4}|m{1,4}|y{4}|yy|!.)/g)},toString:function(e,t){var n=this;return n.formats.toArray(e).map(function(e){return o.trigger(n.formats[e],n,[0,t])||e.replace(/^!/,"")}).join("")}}}(),n.prototype.isDateExact=function(e,n){var i=this;return o.isInteger(e)&&o.isInteger(n)||"boolean"==typeof e&&"boolean"==typeof n?e===n:(o.isDate(e)||t.isArray(e))&&(o.isDate(n)||t.isArray(n))?i.create(e).pick===i.create(n).pick:t.isPlainObject(e)&&t.isPlainObject(n)?i.isDateExact(e.from,n.from)&&i.isDateExact(e.to,n.to):!1},n.prototype.isDateOverlap=function(e,n){var i=this,r=i.settings.firstDay?1:0;return o.isInteger(e)&&(o.isDate(n)||t.isArray(n))?(e=e%7+r,e===i.create(n).day+1):o.isInteger(n)&&(o.isDate(e)||t.isArray(e))?(n=n%7+r,n===i.create(e).day+1):t.isPlainObject(e)&&t.isPlainObject(n)?i.overlapRanges(e,n):!1},n.prototype.flipEnable=function(e){var t=this.item;t.enable=e||(-1==t.enable?1:-1)},n.prototype.deactivate=function(e,n){var i=this,r=i.item.disable.slice(0);return"flip"==n?i.flipEnable():n===!1?(i.flipEnable(1),r=[]):n===!0?(i.flipEnable(-1),r=[]):n.map(function(e){for(var n,a=0;a<r.length;a+=1)if(i.isDateExact(e,r[a])){n=!0;break}n||(o.isInteger(e)||o.isDate(e)||t.isArray(e)||t.isPlainObject(e)&&e.from&&e.to)&&r.push(e)}),r},n.prototype.activate=function(e,n){var i=this,r=i.item.disable,a=r.length;return"flip"==n?i.flipEnable():n===!0?(i.flipEnable(1),r=[]):n===!1?(i.flipEnable(-1),r=[]):n.map(function(e){var n,s,l,u;for(l=0;a>l;l+=1){if(s=r[l],i.isDateExact(s,e)){n=r[l]=null,u=!0;break}if(i.isDateOverlap(s,e)){t.isPlainObject(e)?(e.inverted=!0,n=e):t.isArray(e)?(n=e,n[3]||n.push("inverted")):o.isDate(e)&&(n=[e.getFullYear(),e.getMonth(),e.getDate(),"inverted"]);break}}if(n)for(l=0;a>l;l+=1)if(i.isDateExact(r[l],e)){r[l]=null;break}if(u)for(l=0;a>l;l+=1)if(i.isDateOverlap(r[l],e)){r[l]=null;break}n&&r.push(n)}),r.filter(function(e){return null!=e})},n.prototype.nodes=function(e){var t=this,n=t.settings,a=t.item,s=a.now,l=a.select,u=a.highlight,c=a.view,d=a.disable,p=a.min,h=a.max,f=function(e,t){return n.firstDay&&(e.push(e.shift()),t.push(t.shift())),o.node("thead",o.node("tr",o.group({min:0,max:i-1,i:1,node:"th",item:function(i){return[e[i],n.klass.weekdays,'scope=col title="'+t[i]+'"']}})))}((n.showWeekdaysFull?n.weekdaysFull:n.weekdaysLetter).slice(0),n.weekdaysFull.slice(0)),g=function(e){return o.node("div"," ",n.klass["nav"+(e?"Next":"Prev")]+(e&&c.year>=h.year&&c.month>=h.month||!e&&c.year<=p.year&&c.month<=p.month?" "+n.klass.navDisabled:""),"data-nav="+(e||-1)+" "+o.ariaAttr({role:"button",controls:t.$node[0].id+"_table"})+' title="'+(e?n.labelMonthNext:n.labelMonthPrev)+'"')},v=function(i){var r=n.showMonthsShort?n.monthsShort:n.monthsFull;return"short_months"==i&&(r=n.monthsShort),n.selectMonths&&void 0==i?o.node("select",o.group({min:0,max:11,i:1,node:"option",item:function(e){return[r[e],0,"value="+e+(c.month==e?" selected":"")+(c.year==p.year&&e<p.month||c.year==h.year&&e>h.month?" disabled":"")]}}),n.klass.selectMonth+" browser-default",(e?"":"disabled")+" "+o.ariaAttr({controls:t.$node[0].id+"_table"})+' title="'+n.labelMonthSelect+'"'):"short_months"==i?null!=l?o.node("div",r[l.month]):o.node("div",r[c.month]):o.node("div",r[c.month],n.klass.month)},m=function(i){var r=c.year,a=n.selectYears===!0?5:~~(n.selectYears/2);if(a){var s=p.year,l=h.year,u=r-a,d=r+a;if(s>u&&(d+=s-u,u=s),d>l){var f=u-s,g=d-l;u-=f>g?g:f,d=l}if(n.selectYears&&void 0==i)return o.node("select",o.group({min:u,max:d,i:1,node:"option",item:function(e){return[e,0,"value="+e+(r==e?" selected":"")]}}),n.klass.selectYear+" browser-default",(e?"":"disabled")+" "+o.ariaAttr({controls:t.$node[0].id+"_table"})+' title="'+n.labelYearSelect+'"')}return"raw"==i?o.node("div",r):o.node("div",r,n.klass.year)};return createDayLabel=function(){return null!=l?o.node("div",l.date):o.node("div",s.date)},createWeekdayLabel=function(){var e;e=null!=l?l.day:s.day;var t=n.weekdaysFull[e];return t},o.node("div",o.node("div",createWeekdayLabel(),"picker__weekday-display")+o.node("div",v("short_months"),n.klass.month_display)+o.node("div",createDayLabel(),n.klass.day_display)+o.node("div",m("raw"),n.klass.year_display),n.klass.date_display)+o.node("div",o.node("div",(n.selectYears?v()+m():v()+m())+g()+g(1),n.klass.header)+o.node("table",f+o.node("tbody",o.group({min:0,max:r-1,i:1,node:"tr",item:function(e){var r=n.firstDay&&0===t.create([c.year,c.month,1]).day?-7:0;return[o.group({min:i*e-c.day+r+1,max:function(){return this.min+i-1},i:1,node:"td",item:function(e){e=t.create([c.year,c.month,e+(n.firstDay?1:0)]);var i=l&&l.pick==e.pick,r=u&&u.pick==e.pick,a=d&&t.disabled(e)||e.pick<p.pick||e.pick>h.pick,f=o.trigger(t.formats.toString,t,[n.format,e]);return[o.node("div",e.date,function(t){return t.push(c.month==e.month?n.klass.infocus:n.klass.outfocus),s.pick==e.pick&&t.push(n.klass.now),i&&t.push(n.klass.selected),r&&t.push(n.klass.highlighted),a&&t.push(n.klass.disabled),t.join(" ")}([n.klass.day]),"data-pick="+e.pick+" "+o.ariaAttr({role:"gridcell",label:f,selected:i&&t.$node.val()===f?!0:null,activedescendant:r?!0:null,disabled:a?!0:null})),"",o.ariaAttr({role:"presentation"})]}})]}})),n.klass.table,'id="'+t.$node[0].id+'_table" '+o.ariaAttr({role:"grid",controls:t.$node[0].id,readonly:!0})),n.klass.calendar_container)+o.node("div",o.node("button",n.today,"btn-flat picker__today","type=button data-pick="+s.pick+(e&&!t.disabled(s)?"":" disabled")+" "+o.ariaAttr({controls:t.$node[0].id}))+o.node("button",n.clear,"btn-flat picker__clear","type=button data-clear=1"+(e?"":" disabled")+" "+o.ariaAttr({controls:t.$node[0].id}))+o.node("button",n.close,"btn-flat picker__close","type=button data-close=true "+(e?"":" disabled")+" "+o.ariaAttr({controls:t.$node[0].id})),n.klass.footer)},n.defaults=function(e){return{labelMonthNext:"Next month",labelMonthPrev:"Previous month",labelMonthSelect:"Select a month",labelYearSelect:"Select a year",monthsFull:["January","February","March","April","May","June","July","August","September","October","November","December"],monthsShort:["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"],weekdaysFull:["Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday"],weekdaysShort:["Sun","Mon","Tue","Wed","Thu","Fri","Sat"],weekdaysLetter:["S","M","T","W","T","F","S"],today:"Today",clear:"Clear",close:"Close",format:"d mmmm, yyyy",klass:{table:e+"table",header:e+"header",date_display:e+"date-display",day_display:e+"day-display",month_display:e+"month-display",year_display:e+"year-display",calendar_container:e+"calendar-container",navPrev:e+"nav--prev",navNext:e+"nav--next",navDisabled:e+"nav--disabled",month:e+"month",year:e+"year",selectMonth:e+"select--month",selectYear:e+"select--year",weekdays:e+"weekday",day:e+"day",disabled:e+"day--disabled",selected:e+"day--selected",highlighted:e+"day--highlighted",now:e+"day--today",infocus:e+"day--infocus",outfocus:e+"day--outfocus",footer:e+"footer",buttonClear:e+"button--clear",buttonToday:e+"button--today",buttonClose:e+"button--close"}}}(e.klasses().picker+"__"),e.extend("pickadate",n)}),function(e){function t(){var t=+e(this).attr("length"),n=+e(this).val().length,i=t>=n;e(this).parent().find('span[class="character-counter"]').html(n+"/"+t),r(i,e(this))}function n(t){var n=e("<span/>").addClass("character-counter").css("float","right").css("font-size","12px").css("height",1);t.parent().append(n)}function i(){e(this).parent().find('span[class="character-counter"]').html("")}function r(e,t){var n=t.hasClass("invalid");e&&n?t.removeClass("invalid"):e||n||(t.removeClass("valid"),t.addClass("invalid"))}e.fn.characterCounter=function(){return this.each(function(){var r=void 0!==e(this).attr("length");r&&(e(this).on("input",t),e(this).on("focus",t),e(this).on("blur",i),n(e(this)))})},e(document).ready(function(){e("input, textarea").characterCounter()})}(s)}).call(t,n(1),n(1),n(1),n(9),n(10))},function(e,t,n){var i,r;(function(){function n(e){function t(t,n,i,r,o,a){for(;o>=0&&a>o;o+=e){var s=r?r[o]:o;i=n(i,t[s],s,t)}return i}return function(n,i,r,o){i=k(i,o,4);var a=!M(n)&&_.keys(n),s=(a||n).length,l=e>0?0:s-1;return arguments.length<3&&(r=n[a?a[l]:l],l+=e),t(n,i,r,a,l,s)}}function o(e){return function(t,n,i){n=C(n,i);for(var r=A(t),o=e>0?0:r-1;o>=0&&r>o;o+=e)if(n(t[o],o,t))return o;return-1}}function a(e,t,n){return function(i,r,o){var a=0,s=A(i);if("number"==typeof o)e>0?a=o>=0?o:Math.max(o+s,a):s=o>=0?Math.min(o+1,s):o+s+1;else if(n&&o&&s)return o=n(i,r),i[o]===r?o:-1;if(r!==r)return o=t(f.call(i,a,s),_.isNaN),o>=0?o+a:-1;for(o=e>0?a:s-1;o>=0&&s>o;o+=e)if(i[o]===r)return o;return-1}}function s(e,t){var n=P.length,i=e.constructor,r=_.isFunction(i)&&i.prototype||d,o="constructor";for(_.has(e,o)&&!_.contains(t,o)&&t.push(o);n--;)o=P[n],o in e&&e[o]!==r[o]&&!_.contains(t,o)&&t.push(o)}var l=this,u=l._,c=Array.prototype,d=Object.prototype,p=Function.prototype,h=c.push,f=c.slice,g=d.toString,v=d.hasOwnProperty,m=Array.isArray,y=Object.keys,b=p.bind,w=Object.create,x=function(){},_=function(e){return e instanceof _?e:this instanceof _?void(this._wrapped=e):new _(e)};"undefined"!=typeof e&&e.exports&&(t=e.exports=_),t._=_,_.VERSION="1.8.3";var k=function(e,t,n){if(void 0===t)return e;switch(null==n?3:n){case 1:return function(n){return e.call(t,n)};case 2:return function(n,i){return e.call(t,n,i)};case 3:return function(n,i,r){return e.call(t,n,i,r)};case 4:return function(n,i,r,o){return e.call(t,n,i,r,o)}}return function(){return e.apply(t,arguments)}},C=function(e,t,n){return null==e?_.identity:_.isFunction(e)?k(e,t,n):_.isObject(e)?_.matcher(e):_.property(e)};_.iteratee=function(e,t){return C(e,t,1/0)};var T=function(e,t){return function(n){var i=arguments.length;if(2>i||null==n)return n;for(var r=1;i>r;r++)for(var o=arguments[r],a=e(o),s=a.length,l=0;s>l;l++){var u=a[l];t&&void 0!==n[u]||(n[u]=o[u])}return n}},D=function(e){if(!_.isObject(e))return{};if(w)return w(e);x.prototype=e;var t=new x;return x.prototype=null,t},S=function(e){return function(t){return null==t?void 0:t[e]}},E=Math.pow(2,53)-1,A=S("length"),M=function(e){var t=A(e);return"number"==typeof t&&t>=0&&E>=t};_.each=_.forEach=function(e,t,n){t=k(t,n);var i,r;if(M(e))for(i=0,r=e.length;r>i;i++)t(e[i],i,e);else{var o=_.keys(e);for(i=0,r=o.length;r>i;i++)t(e[o[i]],o[i],e)}return e},_.map=_.collect=function(e,t,n){t=C(t,n);for(var i=!M(e)&&_.keys(e),r=(i||e).length,o=Array(r),a=0;r>a;a++){var s=i?i[a]:a;o[a]=t(e[s],s,e)}return o},_.reduce=_.foldl=_.inject=n(1),_.reduceRight=_.foldr=n(-1),_.find=_.detect=function(e,t,n){var i;return i=M(e)?_.findIndex(e,t,n):_.findKey(e,t,n),void 0!==i&&-1!==i?e[i]:void 0},_.filter=_.select=function(e,t,n){var i=[];return t=C(t,n),_.each(e,function(e,n,r){t(e,n,r)&&i.push(e)}),i},_.reject=function(e,t,n){return _.filter(e,_.negate(C(t)),n)},_.every=_.all=function(e,t,n){t=C(t,n);for(var i=!M(e)&&_.keys(e),r=(i||e).length,o=0;r>o;o++){var a=i?i[o]:o;if(!t(e[a],a,e))return!1}return!0},_.some=_.any=function(e,t,n){t=C(t,n);for(var i=!M(e)&&_.keys(e),r=(i||e).length,o=0;r>o;o++){var a=i?i[o]:o;if(t(e[a],a,e))return!0}return!1},_.contains=_.includes=_.include=function(e,t,n,i){return M(e)||(e=_.values(e)),("number"!=typeof n||i)&&(n=0),_.indexOf(e,t,n)>=0},_.invoke=function(e,t){var n=f.call(arguments,2),i=_.isFunction(t);return _.map(e,function(e){var r=i?t:e[t];return null==r?r:r.apply(e,n)})},_.pluck=function(e,t){return _.map(e,_.property(t))},_.where=function(e,t){return _.filter(e,_.matcher(t))},_.findWhere=function(e,t){return _.find(e,_.matcher(t))},_.max=function(e,t,n){var i,r,o=-(1/0),a=-(1/0);if(null==t&&null!=e){e=M(e)?e:_.values(e);for(var s=0,l=e.length;l>s;s++)i=e[s],i>o&&(o=i)}else t=C(t,n),_.each(e,function(e,n,i){r=t(e,n,i),(r>a||r===-(1/0)&&o===-(1/0))&&(o=e,a=r)});return o},_.min=function(e,t,n){var i,r,o=1/0,a=1/0;if(null==t&&null!=e){e=M(e)?e:_.values(e);for(var s=0,l=e.length;l>s;s++)i=e[s],o>i&&(o=i)}else t=C(t,n),_.each(e,function(e,n,i){r=t(e,n,i),(a>r||r===1/0&&o===1/0)&&(o=e,a=r)});return o},_.shuffle=function(e){for(var t,n=M(e)?e:_.values(e),i=n.length,r=Array(i),o=0;i>o;o++)t=_.random(0,o),t!==o&&(r[o]=r[t]),r[t]=n[o];return r},_.sample=function(e,t,n){return null==t||n?(M(e)||(e=_.values(e)),e[_.random(e.length-1)]):_.shuffle(e).slice(0,Math.max(0,t))},_.sortBy=function(e,t,n){return t=C(t,n),_.pluck(_.map(e,function(e,n,i){return{value:e,index:n,criteria:t(e,n,i)}}).sort(function(e,t){var n=e.criteria,i=t.criteria;if(n!==i){if(n>i||void 0===n)return 1;if(i>n||void 0===i)return-1}return e.index-t.index}),"value")};var O=function(e){return function(t,n,i){var r={};return n=C(n,i),_.each(t,function(i,o){var a=n(i,o,t);e(r,i,a)}),r}};_.groupBy=O(function(e,t,n){_.has(e,n)?e[n].push(t):e[n]=[t]}),_.indexBy=O(function(e,t,n){e[n]=t}),_.countBy=O(function(e,t,n){_.has(e,n)?e[n]++:e[n]=1}),_.toArray=function(e){return e?_.isArray(e)?f.call(e):M(e)?_.map(e,_.identity):_.values(e):[]},_.size=function(e){return null==e?0:M(e)?e.length:_.keys(e).length},_.partition=function(e,t,n){t=C(t,n);var i=[],r=[];return _.each(e,function(e,n,o){(t(e,n,o)?i:r).push(e)}),[i,r]},_.first=_.head=_.take=function(e,t,n){return null!=e?null==t||n?e[0]:_.initial(e,e.length-t):void 0},_.initial=function(e,t,n){return f.call(e,0,Math.max(0,e.length-(null==t||n?1:t)))},_.last=function(e,t,n){return null!=e?null==t||n?e[e.length-1]:_.rest(e,Math.max(0,e.length-t)):void 0},_.rest=_.tail=_.drop=function(e,t,n){return f.call(e,null==t||n?1:t)},_.compact=function(e){return _.filter(e,_.identity)};var I=function(e,t,n,i){for(var r=[],o=0,a=i||0,s=A(e);s>a;a++){var l=e[a];if(M(l)&&(_.isArray(l)||_.isArguments(l))){t||(l=I(l,t,n));var u=0,c=l.length;for(r.length+=c;c>u;)r[o++]=l[u++]}else n||(r[o++]=l)}return r};_.flatten=function(e,t){return I(e,t,!1)},_.without=function(e){return _.difference(e,f.call(arguments,1))},_.uniq=_.unique=function(e,t,n,i){_.isBoolean(t)||(i=n,n=t,t=!1),null!=n&&(n=C(n,i));for(var r=[],o=[],a=0,s=A(e);s>a;a++){var l=e[a],u=n?n(l,a,e):l;t?(a&&o===u||r.push(l),o=u):n?_.contains(o,u)||(o.push(u),r.push(l)):_.contains(r,l)||r.push(l)}return r},_.union=function(){return _.uniq(I(arguments,!0,!0))},_.intersection=function(e){for(var t=[],n=arguments.length,i=0,r=A(e);r>i;i++){var o=e[i];if(!_.contains(t,o)){for(var a=1;n>a&&_.contains(arguments[a],o);a++);a===n&&t.push(o)}}return t},_.difference=function(e){var t=I(arguments,!0,!0,1);return _.filter(e,function(e){return!_.contains(t,e)})},_.zip=function(){return _.unzip(arguments)},_.unzip=function(e){for(var t=e&&_.max(e,A).length||0,n=Array(t),i=0;t>i;i++)n[i]=_.pluck(e,i);return n},_.object=function(e,t){for(var n={},i=0,r=A(e);r>i;i++)t?n[e[i]]=t[i]:n[e[i][0]]=e[i][1];return n},_.findIndex=o(1),_.findLastIndex=o(-1),_.sortedIndex=function(e,t,n,i){n=C(n,i,1);for(var r=n(t),o=0,a=A(e);a>o;){var s=Math.floor((o+a)/2);n(e[s])<r?o=s+1:a=s}return o},_.indexOf=a(1,_.findIndex,_.sortedIndex),_.lastIndexOf=a(-1,_.findLastIndex),_.range=function(e,t,n){null==t&&(t=e||0,e=0),n=n||1;for(var i=Math.max(Math.ceil((t-e)/n),0),r=Array(i),o=0;i>o;o++,e+=n)r[o]=e;return r};var N=function(e,t,n,i,r){if(!(i instanceof t))return e.apply(n,r);var o=D(e.prototype),a=e.apply(o,r);return _.isObject(a)?a:o};_.bind=function(e,t){if(b&&e.bind===b)return b.apply(e,f.call(arguments,1));if(!_.isFunction(e))throw new TypeError("Bind must be called on a function");var n=f.call(arguments,2),i=function(){return N(e,i,t,this,n.concat(f.call(arguments)))};return i},_.partial=function(e){var t=f.call(arguments,1),n=function(){for(var i=0,r=t.length,o=Array(r),a=0;r>a;a++)o[a]=t[a]===_?arguments[i++]:t[a];for(;i<arguments.length;)o.push(arguments[i++]);return N(e,n,this,this,o)};return n},_.bindAll=function(e){var t,n,i=arguments.length;if(1>=i)throw new Error("bindAll must be passed function names");for(t=1;i>t;t++)n=arguments[t],e[n]=_.bind(e[n],e);return e},_.memoize=function(e,t){var n=function(i){var r=n.cache,o=""+(t?t.apply(this,arguments):i);return _.has(r,o)||(r[o]=e.apply(this,arguments)),r[o]};return n.cache={},n},_.delay=function(e,t){var n=f.call(arguments,2);return setTimeout(function(){return e.apply(null,n)},t)},_.defer=_.partial(_.delay,_,1),_.throttle=function(e,t,n){var i,r,o,a=null,s=0;n||(n={});var l=function(){s=n.leading===!1?0:_.now(),a=null,o=e.apply(i,r),a||(i=r=null)};return function(){var u=_.now();s||n.leading!==!1||(s=u);var c=t-(u-s);return i=this,r=arguments,0>=c||c>t?(a&&(clearTimeout(a),a=null),s=u,o=e.apply(i,r),a||(i=r=null)):a||n.trailing===!1||(a=setTimeout(l,c)),o}},_.debounce=function(e,t,n){var i,r,o,a,s,l=function(){var u=_.now()-a;t>u&&u>=0?i=setTimeout(l,t-u):(i=null,n||(s=e.apply(o,r),i||(o=r=null)))};return function(){o=this,r=arguments,a=_.now();var u=n&&!i;return i||(i=setTimeout(l,t)),u&&(s=e.apply(o,r),o=r=null),s}},_.wrap=function(e,t){return _.partial(t,e)},_.negate=function(e){return function(){return!e.apply(this,arguments)}},_.compose=function(){var e=arguments,t=e.length-1;return function(){for(var n=t,i=e[t].apply(this,arguments);n--;)i=e[n].call(this,i);return i}},_.after=function(e,t){return function(){return--e<1?t.apply(this,arguments):void 0}},_.before=function(e,t){var n;return function(){return--e>0&&(n=t.apply(this,arguments)),1>=e&&(t=null),n}},_.once=_.partial(_.before,2);var F=!{toString:null}.propertyIsEnumerable("toString"),P=["valueOf","isPrototypeOf","toString","propertyIsEnumerable","hasOwnProperty","toLocaleString"];_.keys=function(e){if(!_.isObject(e))return[];if(y)return y(e);var t=[];for(var n in e)_.has(e,n)&&t.push(n);return F&&s(e,t),t},_.allKeys=function(e){if(!_.isObject(e))return[];var t=[];for(var n in e)t.push(n);return F&&s(e,t),t},_.values=function(e){for(var t=_.keys(e),n=t.length,i=Array(n),r=0;n>r;r++)i[r]=e[t[r]];return i},_.mapObject=function(e,t,n){t=C(t,n);for(var i,r=_.keys(e),o=r.length,a={},s=0;o>s;s++)i=r[s],a[i]=t(e[i],i,e);
return a},_.pairs=function(e){for(var t=_.keys(e),n=t.length,i=Array(n),r=0;n>r;r++)i[r]=[t[r],e[t[r]]];return i},_.invert=function(e){for(var t={},n=_.keys(e),i=0,r=n.length;r>i;i++)t[e[n[i]]]=n[i];return t},_.functions=_.methods=function(e){var t=[];for(var n in e)_.isFunction(e[n])&&t.push(n);return t.sort()},_.extend=T(_.allKeys),_.extendOwn=_.assign=T(_.keys),_.findKey=function(e,t,n){t=C(t,n);for(var i,r=_.keys(e),o=0,a=r.length;a>o;o++)if(i=r[o],t(e[i],i,e))return i},_.pick=function(e,t,n){var i,r,o={},a=e;if(null==a)return o;_.isFunction(t)?(r=_.allKeys(a),i=k(t,n)):(r=I(arguments,!1,!1,1),i=function(e,t,n){return t in n},a=Object(a));for(var s=0,l=r.length;l>s;s++){var u=r[s],c=a[u];i(c,u,a)&&(o[u]=c)}return o},_.omit=function(e,t,n){if(_.isFunction(t))t=_.negate(t);else{var i=_.map(I(arguments,!1,!1,1),String);t=function(e,t){return!_.contains(i,t)}}return _.pick(e,t,n)},_.defaults=T(_.allKeys,!0),_.create=function(e,t){var n=D(e);return t&&_.extendOwn(n,t),n},_.clone=function(e){return _.isObject(e)?_.isArray(e)?e.slice():_.extend({},e):e},_.tap=function(e,t){return t(e),e},_.isMatch=function(e,t){var n=_.keys(t),i=n.length;if(null==e)return!i;for(var r=Object(e),o=0;i>o;o++){var a=n[o];if(t[a]!==r[a]||!(a in r))return!1}return!0};var $=function(e,t,n,i){if(e===t)return 0!==e||1/e===1/t;if(null==e||null==t)return e===t;e instanceof _&&(e=e._wrapped),t instanceof _&&(t=t._wrapped);var r=g.call(e);if(r!==g.call(t))return!1;switch(r){case"[object RegExp]":case"[object String]":return""+e==""+t;case"[object Number]":return+e!==+e?+t!==+t:0===+e?1/+e===1/t:+e===+t;case"[object Date]":case"[object Boolean]":return+e===+t}var o="[object Array]"===r;if(!o){if("object"!=typeof e||"object"!=typeof t)return!1;var a=e.constructor,s=t.constructor;if(a!==s&&!(_.isFunction(a)&&a instanceof a&&_.isFunction(s)&&s instanceof s)&&"constructor"in e&&"constructor"in t)return!1}n=n||[],i=i||[];for(var l=n.length;l--;)if(n[l]===e)return i[l]===t;if(n.push(e),i.push(t),o){if(l=e.length,l!==t.length)return!1;for(;l--;)if(!$(e[l],t[l],n,i))return!1}else{var u,c=_.keys(e);if(l=c.length,_.keys(t).length!==l)return!1;for(;l--;)if(u=c[l],!_.has(t,u)||!$(e[u],t[u],n,i))return!1}return n.pop(),i.pop(),!0};_.isEqual=function(e,t){return $(e,t)},_.isEmpty=function(e){return null==e?!0:M(e)&&(_.isArray(e)||_.isString(e)||_.isArguments(e))?0===e.length:0===_.keys(e).length},_.isElement=function(e){return!(!e||1!==e.nodeType)},_.isArray=m||function(e){return"[object Array]"===g.call(e)},_.isObject=function(e){var t=typeof e;return"function"===t||"object"===t&&!!e},_.each(["Arguments","Function","String","Number","Date","RegExp","Error"],function(e){_["is"+e]=function(t){return g.call(t)==="[object "+e+"]"}}),_.isArguments(arguments)||(_.isArguments=function(e){return _.has(e,"callee")}),"function"!=typeof/./&&"object"!=typeof Int8Array&&(_.isFunction=function(e){return"function"==typeof e||!1}),_.isFinite=function(e){return isFinite(e)&&!isNaN(parseFloat(e))},_.isNaN=function(e){return _.isNumber(e)&&e!==+e},_.isBoolean=function(e){return e===!0||e===!1||"[object Boolean]"===g.call(e)},_.isNull=function(e){return null===e},_.isUndefined=function(e){return void 0===e},_.has=function(e,t){return null!=e&&v.call(e,t)},_.noConflict=function(){return l._=u,this},_.identity=function(e){return e},_.constant=function(e){return function(){return e}},_.noop=function(){},_.property=S,_.propertyOf=function(e){return null==e?function(){}:function(t){return e[t]}},_.matcher=_.matches=function(e){return e=_.extendOwn({},e),function(t){return _.isMatch(t,e)}},_.times=function(e,t,n){var i=Array(Math.max(0,e));t=k(t,n,1);for(var r=0;e>r;r++)i[r]=t(r);return i},_.random=function(e,t){return null==t&&(t=e,e=0),e+Math.floor(Math.random()*(t-e+1))},_.now=Date.now||function(){return(new Date).getTime()};var L={"&":"&amp;","<":"&lt;",">":"&gt;",'"':"&quot;","'":"&#x27;","`":"&#x60;"},q=_.invert(L),j=function(e){var t=function(t){return e[t]},n="(?:"+_.keys(e).join("|")+")",i=RegExp(n),r=RegExp(n,"g");return function(e){return e=null==e?"":""+e,i.test(e)?e.replace(r,t):e}};_.escape=j(L),_.unescape=j(q),_.result=function(e,t,n){var i=null==e?void 0:e[t];return void 0===i&&(i=n),_.isFunction(i)?i.call(e):i};var R=0;_.uniqueId=function(e){var t=++R+"";return e?e+t:t},_.templateSettings={evaluate:/<%([\s\S]+?)%>/g,interpolate:/<%=([\s\S]+?)%>/g,escape:/<%-([\s\S]+?)%>/g};var z=/(.)^/,H={"'":"'","\\":"\\","\r":"r","\n":"n","\u2028":"u2028","\u2029":"u2029"},W=/\\|'|\r|\n|\u2028|\u2029/g,Y=function(e){return"\\"+H[e]};_.template=function(e,t,n){!t&&n&&(t=n),t=_.defaults({},t,_.templateSettings);var i=RegExp([(t.escape||z).source,(t.interpolate||z).source,(t.evaluate||z).source].join("|")+"|$","g"),r=0,o="__p+='";e.replace(i,function(t,n,i,a,s){return o+=e.slice(r,s).replace(W,Y),r=s+t.length,n?o+="'+\n((__t=("+n+"))==null?'':_.escape(__t))+\n'":i?o+="'+\n((__t=("+i+"))==null?'':__t)+\n'":a&&(o+="';\n"+a+"\n__p+='"),t}),o+="';\n",t.variable||(o="with(obj||{}){\n"+o+"}\n"),o="var __t,__p='',__j=Array.prototype.join,print=function(){__p+=__j.call(arguments,'');};\n"+o+"return __p;\n";try{var a=new Function(t.variable||"obj","_",o)}catch(s){throw s.source=o,s}var l=function(e){return a.call(this,e,_)},u=t.variable||"obj";return l.source="function("+u+"){\n"+o+"}",l},_.chain=function(e){var t=_(e);return t._chain=!0,t};var B=function(e,t){return e._chain?_(t).chain():t};_.mixin=function(e){_.each(_.functions(e),function(t){var n=_[t]=e[t];_.prototype[t]=function(){var e=[this._wrapped];return h.apply(e,arguments),B(this,n.apply(_,e))}})},_.mixin(_),_.each(["pop","push","reverse","shift","sort","splice","unshift"],function(e){var t=c[e];_.prototype[e]=function(){var n=this._wrapped;return t.apply(n,arguments),"shift"!==e&&"splice"!==e||0!==n.length||delete n[0],B(this,n)}}),_.each(["concat","join","slice"],function(e){var t=c[e];_.prototype[e]=function(){return B(this,t.apply(this._wrapped,arguments))}}),_.prototype.value=function(){return this._wrapped},_.prototype.valueOf=_.prototype.toJSON=_.prototype.value,_.prototype.toString=function(){return""+this._wrapped},i=[],r=function(){return _}.apply(t,i),!(void 0!==r&&(e.exports=r))}).call(this)},function(e,t,n){var i;/*! Hammer.JS - v2.0.7 - 2016-04-22
	 * http://hammerjs.github.io/
	 *
	 * Copyright (c) 2016 Jorik Tangelder;
	 * Licensed under the MIT license */
!function(r,o,a,s){"use strict";function l(e,t,n){return setTimeout(h(e,n),t)}function u(e,t,n){return Array.isArray(e)?(c(e,n[t],n),!0):!1}function c(e,t,n){var i;if(e)if(e.forEach)e.forEach(t,n);else if(e.length!==s)for(i=0;i<e.length;)t.call(n,e[i],i,e),i++;else for(i in e)e.hasOwnProperty(i)&&t.call(n,e[i],i,e)}function d(e,t,n){var i="DEPRECATED METHOD: "+t+"\n"+n+" AT \n";return function(){var t=new Error("get-stack-trace"),n=t&&t.stack?t.stack.replace(/^[^\(]+?[\n$]/gm,"").replace(/^\s+at\s+/gm,"").replace(/^Object.<anonymous>\s*\(/gm,"{anonymous}()@"):"Unknown Stack Trace",o=r.console&&(r.console.warn||r.console.log);return o&&o.call(r.console,i,n),e.apply(this,arguments)}}function p(e,t,n){var i,r=t.prototype;i=e.prototype=Object.create(r),i.constructor=e,i._super=r,n&&ge(i,n)}function h(e,t){return function(){return e.apply(t,arguments)}}function f(e,t){return typeof e==ye?e.apply(t?t[0]||s:s,t):e}function g(e,t){return e===s?t:e}function v(e,t,n){c(w(t),function(t){e.addEventListener(t,n,!1)})}function m(e,t,n){c(w(t),function(t){e.removeEventListener(t,n,!1)})}function y(e,t){for(;e;){if(e==t)return!0;e=e.parentNode}return!1}function b(e,t){return e.indexOf(t)>-1}function w(e){return e.trim().split(/\s+/g)}function x(e,t,n){if(e.indexOf&&!n)return e.indexOf(t);for(var i=0;i<e.length;){if(n&&e[i][n]==t||!n&&e[i]===t)return i;i++}return-1}function _(e){return Array.prototype.slice.call(e,0)}function k(e,t,n){for(var i=[],r=[],o=0;o<e.length;){var a=t?e[o][t]:e[o];x(r,a)<0&&i.push(e[o]),r[o]=a,o++}return n&&(i=t?i.sort(function(e,n){return e[t]>n[t]}):i.sort()),i}function C(e,t){for(var n,i,r=t[0].toUpperCase()+t.slice(1),o=0;o<ve.length;){if(n=ve[o],i=n?n+r:t,i in e)return i;o++}return s}function T(){return Ce++}function D(e){var t=e.ownerDocument||e;return t.defaultView||t.parentWindow||r}function S(e,t){var n=this;this.manager=e,this.callback=t,this.element=e.element,this.target=e.options.inputTarget,this.domHandler=function(t){f(e.options.enable,[e])&&n.handler(t)},this.init()}function E(e){var t,n=e.options.inputClass;return new(t=n?n:Se?H:Ee?B:De?V:z)(e,A)}function A(e,t,n){var i=n.pointers.length,r=n.changedPointers.length,o=t&Fe&&i-r===0,a=t&($e|Le)&&i-r===0;n.isFirst=!!o,n.isFinal=!!a,o&&(e.session={}),n.eventType=t,M(e,n),e.emit("hammer.input",n),e.recognize(n),e.session.prevInput=n}function M(e,t){var n=e.session,i=t.pointers,r=i.length;n.firstInput||(n.firstInput=N(t)),r>1&&!n.firstMultiple?n.firstMultiple=N(t):1===r&&(n.firstMultiple=!1);var o=n.firstInput,a=n.firstMultiple,s=a?a.center:o.center,l=t.center=F(i);t.timeStamp=xe(),t.deltaTime=t.timeStamp-o.timeStamp,t.angle=q(s,l),t.distance=L(s,l),O(n,t),t.offsetDirection=$(t.deltaX,t.deltaY);var u=P(t.deltaTime,t.deltaX,t.deltaY);t.overallVelocityX=u.x,t.overallVelocityY=u.y,t.overallVelocity=we(u.x)>we(u.y)?u.x:u.y,t.scale=a?R(a.pointers,i):1,t.rotation=a?j(a.pointers,i):0,t.maxPointers=n.prevInput?t.pointers.length>n.prevInput.maxPointers?t.pointers.length:n.prevInput.maxPointers:t.pointers.length,I(n,t);var c=e.element;y(t.srcEvent.target,c)&&(c=t.srcEvent.target),t.target=c}function O(e,t){var n=t.center,i=e.offsetDelta||{},r=e.prevDelta||{},o=e.prevInput||{};t.eventType!==Fe&&o.eventType!==$e||(r=e.prevDelta={x:o.deltaX||0,y:o.deltaY||0},i=e.offsetDelta={x:n.x,y:n.y}),t.deltaX=r.x+(n.x-i.x),t.deltaY=r.y+(n.y-i.y)}function I(e,t){var n,i,r,o,a=e.lastInterval||t,l=t.timeStamp-a.timeStamp;if(t.eventType!=Le&&(l>Ne||a.velocity===s)){var u=t.deltaX-a.deltaX,c=t.deltaY-a.deltaY,d=P(l,u,c);i=d.x,r=d.y,n=we(d.x)>we(d.y)?d.x:d.y,o=$(u,c),e.lastInterval=t}else n=a.velocity,i=a.velocityX,r=a.velocityY,o=a.direction;t.velocity=n,t.velocityX=i,t.velocityY=r,t.direction=o}function N(e){for(var t=[],n=0;n<e.pointers.length;)t[n]={clientX:be(e.pointers[n].clientX),clientY:be(e.pointers[n].clientY)},n++;return{timeStamp:xe(),pointers:t,center:F(t),deltaX:e.deltaX,deltaY:e.deltaY}}function F(e){var t=e.length;if(1===t)return{x:be(e[0].clientX),y:be(e[0].clientY)};for(var n=0,i=0,r=0;t>r;)n+=e[r].clientX,i+=e[r].clientY,r++;return{x:be(n/t),y:be(i/t)}}function P(e,t,n){return{x:t/e||0,y:n/e||0}}function $(e,t){return e===t?qe:we(e)>=we(t)?0>e?je:Re:0>t?ze:He}function L(e,t,n){n||(n=Ue);var i=t[n[0]]-e[n[0]],r=t[n[1]]-e[n[1]];return Math.sqrt(i*i+r*r)}function q(e,t,n){n||(n=Ue);var i=t[n[0]]-e[n[0]],r=t[n[1]]-e[n[1]];return 180*Math.atan2(r,i)/Math.PI}function j(e,t){return q(t[1],t[0],Ve)+q(e[1],e[0],Ve)}function R(e,t){return L(t[0],t[1],Ve)/L(e[0],e[1],Ve)}function z(){this.evEl=Qe,this.evWin=Ge,this.pressed=!1,S.apply(this,arguments)}function H(){this.evEl=Je,this.evWin=et,S.apply(this,arguments),this.store=this.manager.session.pointerEvents=[]}function W(){this.evTarget=nt,this.evWin=it,this.started=!1,S.apply(this,arguments)}function Y(e,t){var n=_(e.touches),i=_(e.changedTouches);return t&($e|Le)&&(n=k(n.concat(i),"identifier",!0)),[n,i]}function B(){this.evTarget=ot,this.targetIds={},S.apply(this,arguments)}function U(e,t){var n=_(e.touches),i=this.targetIds;if(t&(Fe|Pe)&&1===n.length)return i[n[0].identifier]=!0,[n,n];var r,o,a=_(e.changedTouches),s=[],l=this.target;if(o=n.filter(function(e){return y(e.target,l)}),t===Fe)for(r=0;r<o.length;)i[o[r].identifier]=!0,r++;for(r=0;r<a.length;)i[a[r].identifier]&&s.push(a[r]),t&($e|Le)&&delete i[a[r].identifier],r++;return s.length?[k(o.concat(s),"identifier",!0),s]:void 0}function V(){S.apply(this,arguments);var e=h(this.handler,this);this.touch=new B(this.manager,e),this.mouse=new z(this.manager,e),this.primaryTouch=null,this.lastTouches=[]}function X(e,t){e&Fe?(this.primaryTouch=t.changedPointers[0].identifier,Q.call(this,t)):e&($e|Le)&&Q.call(this,t)}function Q(e){var t=e.changedPointers[0];if(t.identifier===this.primaryTouch){var n={x:t.clientX,y:t.clientY};this.lastTouches.push(n);var i=this.lastTouches,r=function(){var e=i.indexOf(n);e>-1&&i.splice(e,1)};setTimeout(r,at)}}function G(e){for(var t=e.srcEvent.clientX,n=e.srcEvent.clientY,i=0;i<this.lastTouches.length;i++){var r=this.lastTouches[i],o=Math.abs(t-r.x),a=Math.abs(n-r.y);if(st>=o&&st>=a)return!0}return!1}function K(e,t){this.manager=e,this.set(t)}function Z(e){if(b(e,ht))return ht;var t=b(e,ft),n=b(e,gt);return t&&n?ht:t||n?t?ft:gt:b(e,pt)?pt:dt}function J(){if(!ut)return!1;var e={},t=r.CSS&&r.CSS.supports;return["auto","manipulation","pan-y","pan-x","pan-x pan-y","none"].forEach(function(n){e[n]=t?r.CSS.supports("touch-action",n):!0}),e}function ee(e){this.options=ge({},this.defaults,e||{}),this.id=T(),this.manager=null,this.options.enable=g(this.options.enable,!0),this.state=mt,this.simultaneous={},this.requireFail=[]}function te(e){return e&_t?"cancel":e&wt?"end":e&bt?"move":e&yt?"start":""}function ne(e){return e==He?"down":e==ze?"up":e==je?"left":e==Re?"right":""}function ie(e,t){var n=t.manager;return n?n.get(e):e}function re(){ee.apply(this,arguments)}function oe(){re.apply(this,arguments),this.pX=null,this.pY=null}function ae(){re.apply(this,arguments)}function se(){ee.apply(this,arguments),this._timer=null,this._input=null}function le(){re.apply(this,arguments)}function ue(){re.apply(this,arguments)}function ce(){ee.apply(this,arguments),this.pTime=!1,this.pCenter=!1,this._timer=null,this._input=null,this.count=0}function de(e,t){return t=t||{},t.recognizers=g(t.recognizers,de.defaults.preset),new pe(e,t)}function pe(e,t){this.options=ge({},de.defaults,t||{}),this.options.inputTarget=this.options.inputTarget||e,this.handlers={},this.session={},this.recognizers=[],this.oldCssProps={},this.element=e,this.input=E(this),this.touchAction=new K(this,this.options.touchAction),he(this,!0),c(this.options.recognizers,function(e){var t=this.add(new e[0](e[1]));e[2]&&t.recognizeWith(e[2]),e[3]&&t.requireFailure(e[3])},this)}function he(e,t){var n=e.element;if(n.style){var i;c(e.options.cssProps,function(r,o){i=C(n.style,o),t?(e.oldCssProps[i]=n.style[i],n.style[i]=r):n.style[i]=e.oldCssProps[i]||""}),t||(e.oldCssProps={})}}function fe(e,t){var n=o.createEvent("Event");n.initEvent(e,!0,!0),n.gesture=t,t.target.dispatchEvent(n)}var ge,ve=["","webkit","Moz","MS","ms","o"],me=o.createElement("div"),ye="function",be=Math.round,we=Math.abs,xe=Date.now;ge="function"!=typeof Object.assign?function(e){if(e===s||null===e)throw new TypeError("Cannot convert undefined or null to object");for(var t=Object(e),n=1;n<arguments.length;n++){var i=arguments[n];if(i!==s&&null!==i)for(var r in i)i.hasOwnProperty(r)&&(t[r]=i[r])}return t}:Object.assign;var _e=d(function(e,t,n){for(var i=Object.keys(t),r=0;r<i.length;)(!n||n&&e[i[r]]===s)&&(e[i[r]]=t[i[r]]),r++;return e},"extend","Use `assign`."),ke=d(function(e,t){return _e(e,t,!0)},"merge","Use `assign`."),Ce=1,Te=/mobile|tablet|ip(ad|hone|od)|android/i,De="ontouchstart"in r,Se=C(r,"PointerEvent")!==s,Ee=De&&Te.test(navigator.userAgent),Ae="touch",Me="pen",Oe="mouse",Ie="kinect",Ne=25,Fe=1,Pe=2,$e=4,Le=8,qe=1,je=2,Re=4,ze=8,He=16,We=je|Re,Ye=ze|He,Be=We|Ye,Ue=["x","y"],Ve=["clientX","clientY"];S.prototype={handler:function(){},init:function(){this.evEl&&v(this.element,this.evEl,this.domHandler),this.evTarget&&v(this.target,this.evTarget,this.domHandler),this.evWin&&v(D(this.element),this.evWin,this.domHandler)},destroy:function(){this.evEl&&m(this.element,this.evEl,this.domHandler),this.evTarget&&m(this.target,this.evTarget,this.domHandler),this.evWin&&m(D(this.element),this.evWin,this.domHandler)}};var Xe={mousedown:Fe,mousemove:Pe,mouseup:$e},Qe="mousedown",Ge="mousemove mouseup";p(z,S,{handler:function(e){var t=Xe[e.type];t&Fe&&0===e.button&&(this.pressed=!0),t&Pe&&1!==e.which&&(t=$e),this.pressed&&(t&$e&&(this.pressed=!1),this.callback(this.manager,t,{pointers:[e],changedPointers:[e],pointerType:Oe,srcEvent:e}))}});var Ke={pointerdown:Fe,pointermove:Pe,pointerup:$e,pointercancel:Le,pointerout:Le},Ze={2:Ae,3:Me,4:Oe,5:Ie},Je="pointerdown",et="pointermove pointerup pointercancel";r.MSPointerEvent&&!r.PointerEvent&&(Je="MSPointerDown",et="MSPointerMove MSPointerUp MSPointerCancel"),p(H,S,{handler:function(e){var t=this.store,n=!1,i=e.type.toLowerCase().replace("ms",""),r=Ke[i],o=Ze[e.pointerType]||e.pointerType,a=o==Ae,s=x(t,e.pointerId,"pointerId");r&Fe&&(0===e.button||a)?0>s&&(t.push(e),s=t.length-1):r&($e|Le)&&(n=!0),0>s||(t[s]=e,this.callback(this.manager,r,{pointers:t,changedPointers:[e],pointerType:o,srcEvent:e}),n&&t.splice(s,1))}});var tt={touchstart:Fe,touchmove:Pe,touchend:$e,touchcancel:Le},nt="touchstart",it="touchstart touchmove touchend touchcancel";p(W,S,{handler:function(e){var t=tt[e.type];if(t===Fe&&(this.started=!0),this.started){var n=Y.call(this,e,t);t&($e|Le)&&n[0].length-n[1].length===0&&(this.started=!1),this.callback(this.manager,t,{pointers:n[0],changedPointers:n[1],pointerType:Ae,srcEvent:e})}}});var rt={touchstart:Fe,touchmove:Pe,touchend:$e,touchcancel:Le},ot="touchstart touchmove touchend touchcancel";p(B,S,{handler:function(e){var t=rt[e.type],n=U.call(this,e,t);n&&this.callback(this.manager,t,{pointers:n[0],changedPointers:n[1],pointerType:Ae,srcEvent:e})}});var at=2500,st=25;p(V,S,{handler:function(e,t,n){var i=n.pointerType==Ae,r=n.pointerType==Oe;if(!(r&&n.sourceCapabilities&&n.sourceCapabilities.firesTouchEvents)){if(i)X.call(this,t,n);else if(r&&G.call(this,n))return;this.callback(e,t,n)}},destroy:function(){this.touch.destroy(),this.mouse.destroy()}});var lt=C(me.style,"touchAction"),ut=lt!==s,ct="compute",dt="auto",pt="manipulation",ht="none",ft="pan-x",gt="pan-y",vt=J();K.prototype={set:function(e){e==ct&&(e=this.compute()),ut&&this.manager.element.style&&vt[e]&&(this.manager.element.style[lt]=e),this.actions=e.toLowerCase().trim()},update:function(){this.set(this.manager.options.touchAction)},compute:function(){var e=[];return c(this.manager.recognizers,function(t){f(t.options.enable,[t])&&(e=e.concat(t.getTouchAction()))}),Z(e.join(" "))},preventDefaults:function(e){var t=e.srcEvent,n=e.offsetDirection;if(this.manager.session.prevented)return void t.preventDefault();var i=this.actions,r=b(i,ht)&&!vt[ht],o=b(i,gt)&&!vt[gt],a=b(i,ft)&&!vt[ft];if(r){var s=1===e.pointers.length,l=e.distance<2,u=e.deltaTime<250;if(s&&l&&u)return}return a&&o?void 0:r||o&&n&We||a&&n&Ye?this.preventSrc(t):void 0},preventSrc:function(e){this.manager.session.prevented=!0,e.preventDefault()}};var mt=1,yt=2,bt=4,wt=8,xt=wt,_t=16,kt=32;ee.prototype={defaults:{},set:function(e){return ge(this.options,e),this.manager&&this.manager.touchAction.update(),this},recognizeWith:function(e){if(u(e,"recognizeWith",this))return this;var t=this.simultaneous;return e=ie(e,this),t[e.id]||(t[e.id]=e,e.recognizeWith(this)),this},dropRecognizeWith:function(e){return u(e,"dropRecognizeWith",this)?this:(e=ie(e,this),delete this.simultaneous[e.id],this)},requireFailure:function(e){if(u(e,"requireFailure",this))return this;var t=this.requireFail;return e=ie(e,this),-1===x(t,e)&&(t.push(e),e.requireFailure(this)),this},dropRequireFailure:function(e){if(u(e,"dropRequireFailure",this))return this;e=ie(e,this);var t=x(this.requireFail,e);return t>-1&&this.requireFail.splice(t,1),this},hasRequireFailures:function(){return this.requireFail.length>0},canRecognizeWith:function(e){return!!this.simultaneous[e.id]},emit:function(e){function t(t){n.manager.emit(t,e)}var n=this,i=this.state;wt>i&&t(n.options.event+te(i)),t(n.options.event),e.additionalEvent&&t(e.additionalEvent),i>=wt&&t(n.options.event+te(i))},tryEmit:function(e){return this.canEmit()?this.emit(e):void(this.state=kt)},canEmit:function(){for(var e=0;e<this.requireFail.length;){if(!(this.requireFail[e].state&(kt|mt)))return!1;e++}return!0},recognize:function(e){var t=ge({},e);return f(this.options.enable,[this,t])?(this.state&(xt|_t|kt)&&(this.state=mt),this.state=this.process(t),void(this.state&(yt|bt|wt|_t)&&this.tryEmit(t))):(this.reset(),void(this.state=kt))},process:function(e){},getTouchAction:function(){},reset:function(){}},p(re,ee,{defaults:{pointers:1},attrTest:function(e){var t=this.options.pointers;return 0===t||e.pointers.length===t},process:function(e){var t=this.state,n=e.eventType,i=t&(yt|bt),r=this.attrTest(e);return i&&(n&Le||!r)?t|_t:i||r?n&$e?t|wt:t&yt?t|bt:yt:kt}}),p(oe,re,{defaults:{event:"pan",threshold:10,pointers:1,direction:Be},getTouchAction:function(){var e=this.options.direction,t=[];return e&We&&t.push(gt),e&Ye&&t.push(ft),t},directionTest:function(e){var t=this.options,n=!0,i=e.distance,r=e.direction,o=e.deltaX,a=e.deltaY;return r&t.direction||(t.direction&We?(r=0===o?qe:0>o?je:Re,n=o!=this.pX,i=Math.abs(e.deltaX)):(r=0===a?qe:0>a?ze:He,n=a!=this.pY,i=Math.abs(e.deltaY))),e.direction=r,n&&i>t.threshold&&r&t.direction},attrTest:function(e){return re.prototype.attrTest.call(this,e)&&(this.state&yt||!(this.state&yt)&&this.directionTest(e))},emit:function(e){this.pX=e.deltaX,this.pY=e.deltaY;var t=ne(e.direction);t&&(e.additionalEvent=this.options.event+t),this._super.emit.call(this,e)}}),p(ae,re,{defaults:{event:"pinch",threshold:0,pointers:2},getTouchAction:function(){return[ht]},attrTest:function(e){return this._super.attrTest.call(this,e)&&(Math.abs(e.scale-1)>this.options.threshold||this.state&yt)},emit:function(e){if(1!==e.scale){var t=e.scale<1?"in":"out";e.additionalEvent=this.options.event+t}this._super.emit.call(this,e)}}),p(se,ee,{defaults:{event:"press",pointers:1,time:251,threshold:9},getTouchAction:function(){return[dt]},process:function(e){var t=this.options,n=e.pointers.length===t.pointers,i=e.distance<t.threshold,r=e.deltaTime>t.time;if(this._input=e,!i||!n||e.eventType&($e|Le)&&!r)this.reset();else if(e.eventType&Fe)this.reset(),this._timer=l(function(){this.state=xt,this.tryEmit()},t.time,this);else if(e.eventType&$e)return xt;return kt},reset:function(){clearTimeout(this._timer)},emit:function(e){this.state===xt&&(e&&e.eventType&$e?this.manager.emit(this.options.event+"up",e):(this._input.timeStamp=xe(),this.manager.emit(this.options.event,this._input)))}}),p(le,re,{defaults:{event:"rotate",threshold:0,pointers:2},getTouchAction:function(){return[ht]},attrTest:function(e){return this._super.attrTest.call(this,e)&&(Math.abs(e.rotation)>this.options.threshold||this.state&yt)}}),p(ue,re,{defaults:{event:"swipe",threshold:10,velocity:.3,direction:We|Ye,pointers:1},getTouchAction:function(){return oe.prototype.getTouchAction.call(this)},attrTest:function(e){var t,n=this.options.direction;return n&(We|Ye)?t=e.overallVelocity:n&We?t=e.overallVelocityX:n&Ye&&(t=e.overallVelocityY),this._super.attrTest.call(this,e)&&n&e.offsetDirection&&e.distance>this.options.threshold&&e.maxPointers==this.options.pointers&&we(t)>this.options.velocity&&e.eventType&$e},emit:function(e){var t=ne(e.offsetDirection);t&&this.manager.emit(this.options.event+t,e),this.manager.emit(this.options.event,e)}}),p(ce,ee,{defaults:{event:"tap",pointers:1,taps:1,interval:300,time:250,threshold:9,posThreshold:10},getTouchAction:function(){return[pt]},process:function(e){var t=this.options,n=e.pointers.length===t.pointers,i=e.distance<t.threshold,r=e.deltaTime<t.time;if(this.reset(),e.eventType&Fe&&0===this.count)return this.failTimeout();if(i&&r&&n){if(e.eventType!=$e)return this.failTimeout();var o=this.pTime?e.timeStamp-this.pTime<t.interval:!0,a=!this.pCenter||L(this.pCenter,e.center)<t.posThreshold;this.pTime=e.timeStamp,this.pCenter=e.center,a&&o?this.count+=1:this.count=1,this._input=e;var s=this.count%t.taps;if(0===s)return this.hasRequireFailures()?(this._timer=l(function(){this.state=xt,this.tryEmit()},t.interval,this),yt):xt}return kt},failTimeout:function(){return this._timer=l(function(){this.state=kt},this.options.interval,this),kt},reset:function(){clearTimeout(this._timer)},emit:function(){this.state==xt&&(this._input.tapCount=this.count,this.manager.emit(this.options.event,this._input))}}),de.VERSION="2.0.7",de.defaults={domEvents:!1,touchAction:ct,enable:!0,inputTarget:null,inputClass:null,preset:[[le,{enable:!1}],[ae,{enable:!1},["rotate"]],[ue,{direction:We}],[oe,{direction:We},["swipe"]],[ce],[ce,{event:"doubletap",taps:2},["tap"]],[se]],cssProps:{userSelect:"none",touchSelect:"none",touchCallout:"none",contentZooming:"none",userDrag:"none",tapHighlightColor:"rgba(0,0,0,0)"}};var Ct=1,Tt=2;pe.prototype={set:function(e){return ge(this.options,e),e.touchAction&&this.touchAction.update(),e.inputTarget&&(this.input.destroy(),this.input.target=e.inputTarget,this.input.init()),this},stop:function(e){this.session.stopped=e?Tt:Ct},recognize:function(e){var t=this.session;if(!t.stopped){this.touchAction.preventDefaults(e);var n,i=this.recognizers,r=t.curRecognizer;(!r||r&&r.state&xt)&&(r=t.curRecognizer=null);for(var o=0;o<i.length;)n=i[o],t.stopped===Tt||r&&n!=r&&!n.canRecognizeWith(r)?n.reset():n.recognize(e),!r&&n.state&(yt|bt|wt)&&(r=t.curRecognizer=n),o++}},get:function(e){if(e instanceof ee)return e;for(var t=this.recognizers,n=0;n<t.length;n++)if(t[n].options.event==e)return t[n];return null},add:function(e){if(u(e,"add",this))return this;var t=this.get(e.options.event);return t&&this.remove(t),this.recognizers.push(e),e.manager=this,this.touchAction.update(),e},remove:function(e){if(u(e,"remove",this))return this;if(e=this.get(e)){var t=this.recognizers,n=x(t,e);-1!==n&&(t.splice(n,1),this.touchAction.update())}return this},on:function(e,t){if(e!==s&&t!==s){var n=this.handlers;return c(w(e),function(e){n[e]=n[e]||[],n[e].push(t)}),this}},off:function(e,t){if(e!==s){var n=this.handlers;return c(w(e),function(e){t?n[e]&&n[e].splice(x(n[e],t),1):delete n[e]}),this}},emit:function(e,t){this.options.domEvents&&fe(e,t);var n=this.handlers[e]&&this.handlers[e].slice();if(n&&n.length){t.type=e,t.preventDefault=function(){t.srcEvent.preventDefault()};for(var i=0;i<n.length;)n[i](t),i++}},destroy:function(){this.element&&he(this,!1),this.handlers={},this.session={},this.input.destroy(),this.element=null}},ge(de,{INPUT_START:Fe,INPUT_MOVE:Pe,INPUT_END:$e,INPUT_CANCEL:Le,STATE_POSSIBLE:mt,STATE_BEGAN:yt,STATE_CHANGED:bt,STATE_ENDED:wt,STATE_RECOGNIZED:xt,STATE_CANCELLED:_t,STATE_FAILED:kt,DIRECTION_NONE:qe,DIRECTION_LEFT:je,DIRECTION_RIGHT:Re,DIRECTION_UP:ze,DIRECTION_DOWN:He,DIRECTION_HORIZONTAL:We,DIRECTION_VERTICAL:Ye,DIRECTION_ALL:Be,Manager:pe,Input:S,TouchAction:K,TouchInput:B,MouseInput:z,PointerEventInput:H,TouchMouseInput:V,SingleTouchInput:W,Recognizer:ee,AttrRecognizer:re,Tap:ce,Pan:oe,Swipe:ue,Pinch:ae,Rotate:le,Press:se,on:v,off:m,each:c,merge:ke,extend:_e,assign:ge,inherit:p,bindFn:h,prefixed:C});var Dt="undefined"!=typeof r?r:"undefined"!=typeof self?self:{};Dt.Hammer=de,i=function(){return de}.call(t,n,t,e),!(i!==s&&(e.exports=i))}(window,document,"Hammer")},function(e,t){(function(t){e.exports=t}).call(t,{})},function(e,t,n){var i,r,o;(function(a){/*!
	 * Select2 4.0.3
	 * https://select2.github.io
	 *
	 * Released under the MIT license
	 * https://github.com/select2/select2/blob/master/LICENSE.md
	 */
!function(a){r=[n(1)],i=a,o="function"==typeof i?i.apply(t,r):i,!(void 0!==o&&(e.exports=o))}(function(e){var t=function(){if(e&&e.fn&&e.fn.select2&&e.fn.select2.amd)var t=e.fn.select2.amd;var t;return function(){if(!t||!t.requirejs){t?n=t:t={};/**
	 * @license almond 0.3.1 Copyright (c) 2011-2014, The Dojo Foundation All Rights Reserved.
	 * Available via the MIT or new BSD license.
	 * see: http://github.com/jrburke/almond for details
	 */
var e,n,i;!function(t){function r(e,t){return w.call(e,t)}function o(e,t){var n,i,r,o,a,s,l,u,c,d,p,h=t&&t.split("/"),f=y.map,g=f&&f["*"]||{};if(e&&"."===e.charAt(0))if(t){for(e=e.split("/"),a=e.length-1,y.nodeIdCompat&&_.test(e[a])&&(e[a]=e[a].replace(_,"")),e=h.slice(0,h.length-1).concat(e),c=0;c<e.length;c+=1)if(p=e[c],"."===p)e.splice(c,1),c-=1;else if(".."===p){if(1===c&&(".."===e[2]||".."===e[0]))break;c>0&&(e.splice(c-1,2),c-=2)}e=e.join("/")}else 0===e.indexOf("./")&&(e=e.substring(2));if((h||g)&&f){for(n=e.split("/"),c=n.length;c>0;c-=1){if(i=n.slice(0,c).join("/"),h)for(d=h.length;d>0;d-=1)if(r=f[h.slice(0,d).join("/")],r&&(r=r[i])){o=r,s=c;break}if(o)break;!l&&g&&g[i]&&(l=g[i],u=c)}!o&&l&&(o=l,s=u),o&&(n.splice(0,s,o),e=n.join("/"))}return e}function a(e,n){return function(){var i=x.call(arguments,0);return"string"!=typeof i[0]&&1===i.length&&i.push(null),h.apply(t,i.concat([e,n]))}}function s(e){return function(t){return o(t,e)}}function l(e){return function(t){v[e]=t}}function u(e){if(r(m,e)){var n=m[e];delete m[e],b[e]=!0,p.apply(t,n)}if(!r(v,e)&&!r(b,e))throw new Error("No "+e);return v[e]}function c(e){var t,n=e?e.indexOf("!"):-1;return n>-1&&(t=e.substring(0,n),e=e.substring(n+1,e.length)),[t,e]}function d(e){return function(){return y&&y.config&&y.config[e]||{}}}var p,h,f,g,v={},m={},y={},b={},w=Object.prototype.hasOwnProperty,x=[].slice,_=/\.js$/;f=function(e,t){var n,i=c(e),r=i[0];return e=i[1],r&&(r=o(r,t),n=u(r)),r?e=n&&n.normalize?n.normalize(e,s(t)):o(e,t):(e=o(e,t),i=c(e),r=i[0],e=i[1],r&&(n=u(r))),{f:r?r+"!"+e:e,n:e,pr:r,p:n}},g={require:function(e){return a(e)},exports:function(e){var t=v[e];return"undefined"!=typeof t?t:v[e]={}},module:function(e){return{id:e,uri:"",exports:v[e],config:d(e)}}},p=function(e,n,i,o){var s,c,d,p,h,y,w=[],x=typeof i;if(o=o||e,"undefined"===x||"function"===x){for(n=!n.length&&i.length?["require","exports","module"]:n,h=0;h<n.length;h+=1)if(p=f(n[h],o),c=p.f,"require"===c)w[h]=g.require(e);else if("exports"===c)w[h]=g.exports(e),y=!0;else if("module"===c)s=w[h]=g.module(e);else if(r(v,c)||r(m,c)||r(b,c))w[h]=u(c);else{if(!p.p)throw new Error(e+" missing "+c);p.p.load(p.n,a(o,!0),l(c),{}),w[h]=v[c]}d=i?i.apply(v[e],w):void 0,e&&(s&&s.exports!==t&&s.exports!==v[e]?v[e]=s.exports:d===t&&y||(v[e]=d))}else e&&(v[e]=i)},e=n=h=function(e,n,i,r,o){if("string"==typeof e)return g[e]?g[e](n):u(f(e,n).f);if(!e.splice){if(y=e,y.deps&&h(y.deps,y.callback),!n)return;n.splice?(e=n,n=i,i=null):e=t}return n=n||function(){},"function"==typeof i&&(i=r,r=o),r?p(t,e,n,i):setTimeout(function(){p(t,e,n,i)},4),h},h.config=function(e){return h(e)},e._defined=v,i=function(e,t,n){if("string"!=typeof e)throw new Error("See almond README: incorrect module build, no module name");t.splice||(n=t,t=[]),r(v,e)||r(m,e)||(m[e]=[e,t,n])},i.amd={jQuery:!0}}(),t.requirejs=e,t.require=n,t.define=i}}(),t.define("almond",function(){}),t.define("jquery",[],function(){var t=e||a;return null==t&&console&&console.error&&console.error("Select2: An instance of jQuery or a jQuery-compatible library was not found. Make sure that you are including jQuery before Select2 on your web page."),t}),t.define("select2/utils",["jquery"],function(e){function t(e){var t=e.prototype,n=[];for(var i in t){var r=t[i];"function"==typeof r&&"constructor"!==i&&n.push(i)}return n}var n={};n.Extend=function(e,t){function n(){this.constructor=e}var i={}.hasOwnProperty;for(var r in t)i.call(t,r)&&(e[r]=t[r]);return n.prototype=t.prototype,e.prototype=new n,e.__super__=t.prototype,e},n.Decorate=function(e,n){function i(){var t=Array.prototype.unshift,i=n.prototype.constructor.length,r=e.prototype.constructor;i>0&&(t.call(arguments,e.prototype.constructor),r=n.prototype.constructor),r.apply(this,arguments)}function r(){this.constructor=i}var o=t(n),a=t(e);n.displayName=e.displayName,i.prototype=new r;for(var s=0;s<a.length;s++){var l=a[s];i.prototype[l]=e.prototype[l]}for(var u=(function(e){var t=function(){};e in i.prototype&&(t=i.prototype[e]);var r=n.prototype[e];return function(){var e=Array.prototype.unshift;return e.call(arguments,t),r.apply(this,arguments)}}),c=0;c<o.length;c++){var d=o[c];i.prototype[d]=u(d)}return i};var i=function(){this.listeners={}};return i.prototype.on=function(e,t){this.listeners=this.listeners||{},e in this.listeners?this.listeners[e].push(t):this.listeners[e]=[t]},i.prototype.trigger=function(e){var t=Array.prototype.slice,n=t.call(arguments,1);this.listeners=this.listeners||{},null==n&&(n=[]),0===n.length&&n.push({}),n[0]._type=e,e in this.listeners&&this.invoke(this.listeners[e],t.call(arguments,1)),"*"in this.listeners&&this.invoke(this.listeners["*"],arguments)},i.prototype.invoke=function(e,t){for(var n=0,i=e.length;i>n;n++)e[n].apply(this,t)},n.Observable=i,n.generateChars=function(e){for(var t="",n=0;e>n;n++){var i=Math.floor(36*Math.random());t+=i.toString(36)}return t},n.bind=function(e,t){return function(){e.apply(t,arguments)}},n._convertData=function(e){for(var t in e){var n=t.split("-"),i=e;if(1!==n.length){for(var r=0;r<n.length;r++){var o=n[r];o=o.substring(0,1).toLowerCase()+o.substring(1),o in i||(i[o]={}),r==n.length-1&&(i[o]=e[t]),i=i[o]}delete e[t]}}return e},n.hasScroll=function(t,n){var i=e(n),r=n.style.overflowX,o=n.style.overflowY;return r!==o||"hidden"!==o&&"visible"!==o?"scroll"===r||"scroll"===o?!0:i.innerHeight()<n.scrollHeight||i.innerWidth()<n.scrollWidth:!1},n.escapeMarkup=function(e){var t={"\\":"&#92;","&":"&amp;","<":"&lt;",">":"&gt;",'"':"&quot;","'":"&#39;","/":"&#47;"};return"string"!=typeof e?e:String(e).replace(/[&<>"'\/\\]/g,function(e){return t[e]})},n.appendMany=function(t,n){if("1.7"===e.fn.jquery.substr(0,3)){var i=e();e.map(n,function(e){i=i.add(e)}),n=i}t.append(n)},n}),t.define("select2/results",["jquery","./utils"],function(e,t){function n(e,t,i){this.$element=e,this.data=i,this.options=t,n.__super__.constructor.call(this)}return t.Extend(n,t.Observable),n.prototype.render=function(){var t=e('<ul class="select2-results__options" role="tree"></ul>');return this.options.get("multiple")&&t.attr("aria-multiselectable","true"),this.$results=t,t},n.prototype.clear=function(){this.$results.empty()},n.prototype.displayMessage=function(t){var n=this.options.get("escapeMarkup");this.clear(),this.hideLoading();var i=e('<li role="treeitem" aria-live="assertive" class="select2-results__option"></li>'),r=this.options.get("translations").get(t.message);i.append(n(r(t.args))),i[0].className+=" select2-results__message",this.$results.append(i)},n.prototype.hideMessages=function(){this.$results.find(".select2-results__message").remove()},n.prototype.append=function(e){this.hideLoading();var t=[];if(null==e.results||0===e.results.length)return void(0===this.$results.children().length&&this.trigger("results:message",{message:"noResults"}));e.results=this.sort(e.results);for(var n=0;n<e.results.length;n++){var i=e.results[n],r=this.option(i);t.push(r)}this.$results.append(t)},n.prototype.position=function(e,t){var n=t.find(".select2-results");n.append(e)},n.prototype.sort=function(e){var t=this.options.get("sorter");return t(e)},n.prototype.highlightFirstItem=function(){var e=this.$results.find(".select2-results__option[aria-selected]"),t=e.filter("[aria-selected=true]");t.length>0?t.first().trigger("mouseenter"):e.first().trigger("mouseenter"),this.ensureHighlightVisible()},n.prototype.setClasses=function(){var t=this;this.data.current(function(n){var i=e.map(n,function(e){return e.id.toString()}),r=t.$results.find(".select2-results__option[aria-selected]");r.each(function(){var t=e(this),n=e.data(this,"data"),r=""+n.id;null!=n.element&&n.element.selected||null==n.element&&e.inArray(r,i)>-1?t.attr("aria-selected","true"):t.attr("aria-selected","false")})})},n.prototype.showLoading=function(e){this.hideLoading();var t=this.options.get("translations").get("searching"),n={disabled:!0,loading:!0,text:t(e)},i=this.option(n);i.className+=" loading-results",this.$results.prepend(i)},n.prototype.hideLoading=function(){this.$results.find(".loading-results").remove()},n.prototype.option=function(t){var n=document.createElement("li");n.className="select2-results__option";var i={role:"treeitem","aria-selected":"false"};t.disabled&&(delete i["aria-selected"],i["aria-disabled"]="true"),null==t.id&&delete i["aria-selected"],null!=t._resultId&&(n.id=t._resultId),t.title&&(n.title=t.title),t.children&&(i.role="group",i["aria-label"]=t.text,delete i["aria-selected"]);for(var r in i){var o=i[r];n.setAttribute(r,o)}if(t.children){var a=e(n),s=document.createElement("strong");s.className="select2-results__group";e(s);this.template(t,s);for(var l=[],u=0;u<t.children.length;u++){var c=t.children[u],d=this.option(c);l.push(d)}var p=e("<ul></ul>",{"class":"select2-results__options select2-results__options--nested"});p.append(l),a.append(s),a.append(p)}else this.template(t,n);return e.data(n,"data",t),n},n.prototype.bind=function(t,n){var i=this,r=t.id+"-results";this.$results.attr("id",r),t.on("results:all",function(e){i.clear(),i.append(e.data),t.isOpen()&&(i.setClasses(),i.highlightFirstItem())}),t.on("results:append",function(e){i.append(e.data),t.isOpen()&&i.setClasses()}),t.on("query",function(e){i.hideMessages(),i.showLoading(e)}),t.on("select",function(){t.isOpen()&&(i.setClasses(),i.highlightFirstItem())}),t.on("unselect",function(){t.isOpen()&&(i.setClasses(),i.highlightFirstItem())}),t.on("open",function(){i.$results.attr("aria-expanded","true"),i.$results.attr("aria-hidden","false"),i.setClasses(),i.ensureHighlightVisible()}),t.on("close",function(){i.$results.attr("aria-expanded","false"),i.$results.attr("aria-hidden","true"),i.$results.removeAttr("aria-activedescendant")}),t.on("results:toggle",function(){var e=i.getHighlightedResults();0!==e.length&&e.trigger("mouseup")}),t.on("results:select",function(){var e=i.getHighlightedResults();if(0!==e.length){var t=e.data("data");"true"==e.attr("aria-selected")?i.trigger("close",{}):i.trigger("select",{data:t})}}),t.on("results:previous",function(){var e=i.getHighlightedResults(),t=i.$results.find("[aria-selected]"),n=t.index(e);if(0!==n){var r=n-1;0===e.length&&(r=0);var o=t.eq(r);o.trigger("mouseenter");var a=i.$results.offset().top,s=o.offset().top,l=i.$results.scrollTop()+(s-a);0===r?i.$results.scrollTop(0):0>s-a&&i.$results.scrollTop(l)}}),t.on("results:next",function(){var e=i.getHighlightedResults(),t=i.$results.find("[aria-selected]"),n=t.index(e),r=n+1;if(!(r>=t.length)){var o=t.eq(r);o.trigger("mouseenter");var a=i.$results.offset().top+i.$results.outerHeight(!1),s=o.offset().top+o.outerHeight(!1),l=i.$results.scrollTop()+s-a;0===r?i.$results.scrollTop(0):s>a&&i.$results.scrollTop(l)}}),t.on("results:focus",function(e){e.element.addClass("select2-results__option--highlighted")}),t.on("results:message",function(e){i.displayMessage(e)}),e.fn.mousewheel&&this.$results.on("mousewheel",function(e){var t=i.$results.scrollTop(),n=i.$results.get(0).scrollHeight-t+e.deltaY,r=e.deltaY>0&&t-e.deltaY<=0,o=e.deltaY<0&&n<=i.$results.height();r?(i.$results.scrollTop(0),e.preventDefault(),e.stopPropagation()):o&&(i.$results.scrollTop(i.$results.get(0).scrollHeight-i.$results.height()),e.preventDefault(),e.stopPropagation())}),this.$results.on("mouseup",".select2-results__option[aria-selected]",function(t){var n=e(this),r=n.data("data");return"true"===n.attr("aria-selected")?void(i.options.get("multiple")?i.trigger("unselect",{originalEvent:t,data:r}):i.trigger("close",{})):void i.trigger("select",{originalEvent:t,data:r})}),this.$results.on("mouseenter",".select2-results__option[aria-selected]",function(t){var n=e(this).data("data");i.getHighlightedResults().removeClass("select2-results__option--highlighted"),i.trigger("results:focus",{data:n,element:e(this)})})},n.prototype.getHighlightedResults=function(){var e=this.$results.find(".select2-results__option--highlighted");return e},n.prototype.destroy=function(){this.$results.remove()},n.prototype.ensureHighlightVisible=function(){var e=this.getHighlightedResults();if(0!==e.length){var t=this.$results.find("[aria-selected]"),n=t.index(e),i=this.$results.offset().top,r=e.offset().top,o=this.$results.scrollTop()+(r-i),a=r-i;o-=2*e.outerHeight(!1),2>=n?this.$results.scrollTop(0):(a>this.$results.outerHeight()||0>a)&&this.$results.scrollTop(o)}},n.prototype.template=function(t,n){var i=this.options.get("templateResult"),r=this.options.get("escapeMarkup"),o=i(t,n);null==o?n.style.display="none":"string"==typeof o?n.innerHTML=r(o):e(n).append(o)},n}),t.define("select2/keys",[],function(){var e={BACKSPACE:8,TAB:9,ENTER:13,SHIFT:16,CTRL:17,ALT:18,ESC:27,SPACE:32,PAGE_UP:33,PAGE_DOWN:34,END:35,HOME:36,LEFT:37,UP:38,RIGHT:39,DOWN:40,DELETE:46};return e}),t.define("select2/selection/base",["jquery","../utils","../keys"],function(e,t,n){function i(e,t){this.$element=e,this.options=t,i.__super__.constructor.call(this)}return t.Extend(i,t.Observable),i.prototype.render=function(){var t=e('<span class="select2-selection" role="combobox"  aria-haspopup="true" aria-expanded="false"></span>');return this._tabindex=0,null!=this.$element.data("old-tabindex")?this._tabindex=this.$element.data("old-tabindex"):null!=this.$element.attr("tabindex")&&(this._tabindex=this.$element.attr("tabindex")),t.attr("title",this.$element.attr("title")),t.attr("tabindex",this._tabindex),this.$selection=t,t},i.prototype.bind=function(e,t){var i=this,r=(e.id+"-container",e.id+"-results");this.container=e,this.$selection.on("focus",function(e){i.trigger("focus",e)}),this.$selection.on("blur",function(e){i._handleBlur(e)}),this.$selection.on("keydown",function(e){i.trigger("keypress",e),e.which===n.SPACE&&e.preventDefault()}),e.on("results:focus",function(e){i.$selection.attr("aria-activedescendant",e.data._resultId)}),e.on("selection:update",function(e){i.update(e.data)}),e.on("open",function(){i.$selection.attr("aria-expanded","true"),i.$selection.attr("aria-owns",r),i._attachCloseHandler(e)}),e.on("close",function(){i.$selection.attr("aria-expanded","false"),i.$selection.removeAttr("aria-activedescendant"),i.$selection.removeAttr("aria-owns"),i.$selection.focus(),i._detachCloseHandler(e)}),e.on("enable",function(){i.$selection.attr("tabindex",i._tabindex)}),e.on("disable",function(){i.$selection.attr("tabindex","-1")})},i.prototype._handleBlur=function(t){var n=this;window.setTimeout(function(){document.activeElement==n.$selection[0]||e.contains(n.$selection[0],document.activeElement)||n.trigger("blur",t)},1)},i.prototype._attachCloseHandler=function(t){e(document.body).on("mousedown.select2."+t.id,function(t){var n=e(t.target),i=n.closest(".select2"),r=e(".select2.select2-container--open");r.each(function(){var t=e(this);if(this!=i[0]){var n=t.data("element");n.select2("close")}})})},i.prototype._detachCloseHandler=function(t){e(document.body).off("mousedown.select2."+t.id)},i.prototype.position=function(e,t){var n=t.find(".selection");n.append(e)},i.prototype.destroy=function(){this._detachCloseHandler(this.container)},i.prototype.update=function(e){throw new Error("The `update` method must be defined in child classes.")},i}),t.define("select2/selection/single",["jquery","./base","../utils","../keys"],function(e,t,n,i){function r(){r.__super__.constructor.apply(this,arguments)}return n.Extend(r,t),r.prototype.render=function(){var e=r.__super__.render.call(this);return e.addClass("select2-selection--single"),e.html('<span class="select2-selection__rendered"></span><span class="select2-selection__arrow" role="presentation"><b role="presentation"></b></span>'),e},r.prototype.bind=function(e,t){var n=this;r.__super__.bind.apply(this,arguments);var i=e.id+"-container";this.$selection.find(".select2-selection__rendered").attr("id",i),this.$selection.attr("aria-labelledby",i),this.$selection.on("mousedown",function(e){1===e.which&&n.trigger("toggle",{originalEvent:e})}),this.$selection.on("focus",function(e){}),this.$selection.on("blur",function(e){}),e.on("focus",function(t){e.isOpen()||n.$selection.focus()}),e.on("selection:update",function(e){n.update(e.data)})},r.prototype.clear=function(){this.$selection.find(".select2-selection__rendered").empty()},r.prototype.display=function(e,t){var n=this.options.get("templateSelection"),i=this.options.get("escapeMarkup");return i(n(e,t))},r.prototype.selectionContainer=function(){return e("<span></span>")},r.prototype.update=function(e){if(0===e.length)return void this.clear();var t=e[0],n=this.$selection.find(".select2-selection__rendered"),i=this.display(t,n);n.empty().append(i),n.prop("title",t.title||t.text)},r}),t.define("select2/selection/multiple",["jquery","./base","../utils"],function(e,t,n){function i(e,t){i.__super__.constructor.apply(this,arguments)}return n.Extend(i,t),i.prototype.render=function(){var e=i.__super__.render.call(this);return e.addClass("select2-selection--multiple"),e.html('<ul class="select2-selection__rendered"></ul>'),e},i.prototype.bind=function(t,n){var r=this;i.__super__.bind.apply(this,arguments),this.$selection.on("click",function(e){r.trigger("toggle",{originalEvent:e})}),this.$selection.on("click",".select2-selection__choice__remove",function(t){if(!r.options.get("disabled")){var n=e(this),i=n.parent(),o=i.data("data");r.trigger("unselect",{originalEvent:t,data:o})}})},i.prototype.clear=function(){this.$selection.find(".select2-selection__rendered").empty()},i.prototype.display=function(e,t){var n=this.options.get("templateSelection"),i=this.options.get("escapeMarkup");return i(n(e,t))},i.prototype.selectionContainer=function(){var t=e('<li class="select2-selection__choice"><span class="select2-selection__choice__remove" role="presentation">&times;</span></li>');return t},i.prototype.update=function(e){if(this.clear(),0!==e.length){for(var t=[],i=0;i<e.length;i++){var r=e[i],o=this.selectionContainer(),a=this.display(r,o);o.append(a),o.prop("title",r.title||r.text),o.data("data",r),t.push(o)}var s=this.$selection.find(".select2-selection__rendered");n.appendMany(s,t)}},i}),t.define("select2/selection/placeholder",["../utils"],function(e){function t(e,t,n){this.placeholder=this.normalizePlaceholder(n.get("placeholder")),e.call(this,t,n)}return t.prototype.normalizePlaceholder=function(e,t){return"string"==typeof t&&(t={id:"",text:t}),t},t.prototype.createPlaceholder=function(e,t){var n=this.selectionContainer();return n.html(this.display(t)),n.addClass("select2-selection__placeholder").removeClass("select2-selection__choice"),n},t.prototype.update=function(e,t){var n=1==t.length&&t[0].id!=this.placeholder.id,i=t.length>1;if(i||n)return e.call(this,t);this.clear();var r=this.createPlaceholder(this.placeholder);this.$selection.find(".select2-selection__rendered").append(r)},t}),t.define("select2/selection/allowClear",["jquery","../keys"],function(e,t){function n(){}return n.prototype.bind=function(e,t,n){var i=this;e.call(this,t,n),null==this.placeholder&&this.options.get("debug")&&window.console&&console.error&&console.error("Select2: The `allowClear` option should be used in combination with the `placeholder` option."),this.$selection.on("mousedown",".select2-selection__clear",function(e){i._handleClear(e)}),t.on("keypress",function(e){i._handleKeyboardClear(e,t)})},n.prototype._handleClear=function(e,t){if(!this.options.get("disabled")){var n=this.$selection.find(".select2-selection__clear");if(0!==n.length){t.stopPropagation();for(var i=n.data("data"),r=0;r<i.length;r++){var o={data:i[r]};if(this.trigger("unselect",o),o.prevented)return}this.$element.val(this.placeholder.id).trigger("change"),this.trigger("toggle",{})}}},n.prototype._handleKeyboardClear=function(e,n,i){i.isOpen()||n.which!=t.DELETE&&n.which!=t.BACKSPACE||this._handleClear(n)},n.prototype.update=function(t,n){if(t.call(this,n),!(this.$selection.find(".select2-selection__placeholder").length>0||0===n.length)){var i=e('<span class="select2-selection__clear">&times;</span>');i.data("data",n),this.$selection.find(".select2-selection__rendered").prepend(i)}},n}),t.define("select2/selection/search",["jquery","../utils","../keys"],function(e,t,n){function i(e,t,n){e.call(this,t,n)}return i.prototype.render=function(t){var n=e('<li class="select2-search select2-search--inline"><input class="select2-search__field" type="search" tabindex="-1" autocomplete="off" autocorrect="off" autocapitalize="off" spellcheck="false" role="textbox" aria-autocomplete="list" /></li>');this.$searchContainer=n,this.$search=n.find("input");var i=t.call(this);return this._transferTabIndex(),i},i.prototype.bind=function(e,t,i){var r=this;e.call(this,t,i),t.on("open",function(){r.$search.trigger("focus")}),t.on("close",function(){r.$search.val(""),r.$search.removeAttr("aria-activedescendant"),r.$search.trigger("focus")}),t.on("enable",function(){r.$search.prop("disabled",!1),r._transferTabIndex()}),t.on("disable",function(){r.$search.prop("disabled",!0)}),t.on("focus",function(e){r.$search.trigger("focus")}),t.on("results:focus",function(e){r.$search.attr("aria-activedescendant",e.id)}),this.$selection.on("focusin",".select2-search--inline",function(e){r.trigger("focus",e)}),this.$selection.on("focusout",".select2-search--inline",function(e){r._handleBlur(e)}),this.$selection.on("keydown",".select2-search--inline",function(e){e.stopPropagation(),r.trigger("keypress",e),r._keyUpPrevented=e.isDefaultPrevented();var t=e.which;if(t===n.BACKSPACE&&""===r.$search.val()){var i=r.$searchContainer.prev(".select2-selection__choice");if(i.length>0){var o=i.data("data");r.searchRemoveChoice(o),e.preventDefault()}}});var o=document.documentMode,a=o&&11>=o;this.$selection.on("input.searchcheck",".select2-search--inline",function(e){return a?void r.$selection.off("input.search input.searchcheck"):void r.$selection.off("keyup.search")}),this.$selection.on("keyup.search input.search",".select2-search--inline",function(e){if(a&&"input"===e.type)return void r.$selection.off("input.search input.searchcheck");var t=e.which;t!=n.SHIFT&&t!=n.CTRL&&t!=n.ALT&&t!=n.TAB&&r.handleSearch(e)})},i.prototype._transferTabIndex=function(e){this.$search.attr("tabindex",this.$selection.attr("tabindex")),this.$selection.attr("tabindex","-1")},i.prototype.createPlaceholder=function(e,t){this.$search.attr("placeholder",t.text)},i.prototype.update=function(e,t){var n=this.$search[0]==document.activeElement;this.$search.attr("placeholder",""),e.call(this,t),this.$selection.find(".select2-selection__rendered").append(this.$searchContainer),this.resizeSearch(),n&&this.$search.focus()},i.prototype.handleSearch=function(){if(this.resizeSearch(),!this._keyUpPrevented){var e=this.$search.val();this.trigger("query",{term:e})}this._keyUpPrevented=!1},i.prototype.searchRemoveChoice=function(e,t){this.trigger("unselect",{data:t}),this.$search.val(t.text),this.handleSearch()},i.prototype.resizeSearch=function(){this.$search.css("width","25px");var e="";if(""!==this.$search.attr("placeholder"))e=this.$selection.find(".select2-selection__rendered").innerWidth();else{var t=this.$search.val().length+1;e=.75*t+"em"}this.$search.css("width",e)},i}),t.define("select2/selection/eventRelay",["jquery"],function(e){function t(){}return t.prototype.bind=function(t,n,i){var r=this,o=["open","opening","close","closing","select","selecting","unselect","unselecting"],a=["opening","closing","selecting","unselecting"];t.call(this,n,i),n.on("*",function(t,n){if(-1!==e.inArray(t,o)){n=n||{};var i=e.Event("select2:"+t,{params:n});r.$element.trigger(i),-1!==e.inArray(t,a)&&(n.prevented=i.isDefaultPrevented())}})},t}),t.define("select2/translation",["jquery","require"],function(e,t){function n(e){this.dict=e||{}}return n.prototype.all=function(){return this.dict},n.prototype.get=function(e){return this.dict[e]},n.prototype.extend=function(t){this.dict=e.extend({},t.all(),this.dict)},n._cache={},n.loadPath=function(e){if(!(e in n._cache)){var i=t(e);n._cache[e]=i}return new n(n._cache[e])},n}),t.define("select2/diacritics",[],function(){var e={"Ⓐ":"A","Ａ":"A","À":"A","Á":"A","Â":"A","Ầ":"A","Ấ":"A","Ẫ":"A","Ẩ":"A","Ã":"A","Ā":"A","Ă":"A","Ằ":"A","Ắ":"A","Ẵ":"A","Ẳ":"A","Ȧ":"A","Ǡ":"A","Ä":"A","Ǟ":"A","Ả":"A","Å":"A","Ǻ":"A","Ǎ":"A","Ȁ":"A","Ȃ":"A","Ạ":"A","Ậ":"A","Ặ":"A","Ḁ":"A","Ą":"A","Ⱥ":"A","Ɐ":"A","Ꜳ":"AA","Æ":"AE","Ǽ":"AE","Ǣ":"AE","Ꜵ":"AO","Ꜷ":"AU","Ꜹ":"AV","Ꜻ":"AV","Ꜽ":"AY","Ⓑ":"B","Ｂ":"B","Ḃ":"B","Ḅ":"B","Ḇ":"B","Ƀ":"B","Ƃ":"B","Ɓ":"B","Ⓒ":"C","Ｃ":"C","Ć":"C","Ĉ":"C","Ċ":"C","Č":"C","Ç":"C","Ḉ":"C","Ƈ":"C","Ȼ":"C","Ꜿ":"C","Ⓓ":"D","Ｄ":"D","Ḋ":"D","Ď":"D","Ḍ":"D","Ḑ":"D","Ḓ":"D","Ḏ":"D","Đ":"D","Ƌ":"D","Ɗ":"D","Ɖ":"D","Ꝺ":"D","Ǳ":"DZ","Ǆ":"DZ","ǲ":"Dz","ǅ":"Dz","Ⓔ":"E","Ｅ":"E","È":"E","É":"E","Ê":"E","Ề":"E","Ế":"E","Ễ":"E","Ể":"E","Ẽ":"E","Ē":"E","Ḕ":"E","Ḗ":"E","Ĕ":"E","Ė":"E","Ë":"E","Ẻ":"E","Ě":"E","Ȅ":"E","Ȇ":"E","Ẹ":"E","Ệ":"E","Ȩ":"E","Ḝ":"E","Ę":"E","Ḙ":"E","Ḛ":"E","Ɛ":"E","Ǝ":"E","Ⓕ":"F","Ｆ":"F","Ḟ":"F","Ƒ":"F","Ꝼ":"F","Ⓖ":"G","Ｇ":"G","Ǵ":"G","Ĝ":"G","Ḡ":"G","Ğ":"G","Ġ":"G","Ǧ":"G","Ģ":"G","Ǥ":"G","Ɠ":"G","Ꞡ":"G","Ᵹ":"G","Ꝿ":"G","Ⓗ":"H","Ｈ":"H","Ĥ":"H","Ḣ":"H","Ḧ":"H","Ȟ":"H","Ḥ":"H","Ḩ":"H","Ḫ":"H","Ħ":"H","Ⱨ":"H","Ⱶ":"H","Ɥ":"H","Ⓘ":"I","Ｉ":"I","Ì":"I","Í":"I","Î":"I","Ĩ":"I","Ī":"I","Ĭ":"I","İ":"I","Ï":"I","Ḯ":"I","Ỉ":"I","Ǐ":"I","Ȉ":"I","Ȋ":"I","Ị":"I","Į":"I","Ḭ":"I","Ɨ":"I","Ⓙ":"J","Ｊ":"J","Ĵ":"J","Ɉ":"J","Ⓚ":"K","Ｋ":"K","Ḱ":"K","Ǩ":"K","Ḳ":"K","Ķ":"K","Ḵ":"K","Ƙ":"K","Ⱪ":"K","Ꝁ":"K","Ꝃ":"K","Ꝅ":"K","Ꞣ":"K","Ⓛ":"L","Ｌ":"L","Ŀ":"L","Ĺ":"L","Ľ":"L","Ḷ":"L","Ḹ":"L","Ļ":"L","Ḽ":"L","Ḻ":"L","Ł":"L","Ƚ":"L","Ɫ":"L","Ⱡ":"L","Ꝉ":"L","Ꝇ":"L","Ꞁ":"L","Ǉ":"LJ","ǈ":"Lj","Ⓜ":"M","Ｍ":"M","Ḿ":"M","Ṁ":"M","Ṃ":"M","Ɱ":"M","Ɯ":"M","Ⓝ":"N","Ｎ":"N","Ǹ":"N","Ń":"N","Ñ":"N","Ṅ":"N","Ň":"N","Ṇ":"N","Ņ":"N","Ṋ":"N","Ṉ":"N","Ƞ":"N","Ɲ":"N","Ꞑ":"N","Ꞥ":"N","Ǌ":"NJ","ǋ":"Nj","Ⓞ":"O","Ｏ":"O","Ò":"O","Ó":"O","Ô":"O","Ồ":"O","Ố":"O","Ỗ":"O","Ổ":"O","Õ":"O","Ṍ":"O","Ȭ":"O","Ṏ":"O","Ō":"O","Ṑ":"O","Ṓ":"O","Ŏ":"O","Ȯ":"O","Ȱ":"O","Ö":"O","Ȫ":"O","Ỏ":"O","Ő":"O","Ǒ":"O","Ȍ":"O","Ȏ":"O","Ơ":"O","Ờ":"O","Ớ":"O","Ỡ":"O","Ở":"O","Ợ":"O","Ọ":"O","Ộ":"O","Ǫ":"O","Ǭ":"O","Ø":"O","Ǿ":"O","Ɔ":"O","Ɵ":"O","Ꝋ":"O","Ꝍ":"O","Ƣ":"OI","Ꝏ":"OO","Ȣ":"OU","Ⓟ":"P","Ｐ":"P","Ṕ":"P","Ṗ":"P","Ƥ":"P","Ᵽ":"P","Ꝑ":"P","Ꝓ":"P","Ꝕ":"P","Ⓠ":"Q","Ｑ":"Q","Ꝗ":"Q","Ꝙ":"Q","Ɋ":"Q","Ⓡ":"R","Ｒ":"R","Ŕ":"R","Ṙ":"R","Ř":"R","Ȑ":"R","Ȓ":"R","Ṛ":"R","Ṝ":"R","Ŗ":"R","Ṟ":"R","Ɍ":"R","Ɽ":"R","Ꝛ":"R","Ꞧ":"R","Ꞃ":"R","Ⓢ":"S","Ｓ":"S","ẞ":"S","Ś":"S","Ṥ":"S","Ŝ":"S","Ṡ":"S","Š":"S","Ṧ":"S","Ṣ":"S","Ṩ":"S","Ș":"S","Ş":"S","Ȿ":"S","Ꞩ":"S","Ꞅ":"S","Ⓣ":"T","Ｔ":"T","Ṫ":"T","Ť":"T","Ṭ":"T","Ț":"T","Ţ":"T","Ṱ":"T","Ṯ":"T","Ŧ":"T","Ƭ":"T","Ʈ":"T","Ⱦ":"T","Ꞇ":"T","Ꜩ":"TZ","Ⓤ":"U","Ｕ":"U","Ù":"U","Ú":"U","Û":"U","Ũ":"U","Ṹ":"U","Ū":"U","Ṻ":"U","Ŭ":"U","Ü":"U","Ǜ":"U","Ǘ":"U","Ǖ":"U","Ǚ":"U","Ủ":"U","Ů":"U","Ű":"U","Ǔ":"U","Ȕ":"U","Ȗ":"U","Ư":"U","Ừ":"U","Ứ":"U","Ữ":"U","Ử":"U","Ự":"U","Ụ":"U","Ṳ":"U","Ų":"U","Ṷ":"U","Ṵ":"U","Ʉ":"U","Ⓥ":"V","Ｖ":"V","Ṽ":"V","Ṿ":"V","Ʋ":"V","Ꝟ":"V","Ʌ":"V","Ꝡ":"VY","Ⓦ":"W","Ｗ":"W","Ẁ":"W","Ẃ":"W","Ŵ":"W","Ẇ":"W","Ẅ":"W","Ẉ":"W","Ⱳ":"W","Ⓧ":"X","Ｘ":"X","Ẋ":"X","Ẍ":"X","Ⓨ":"Y","Ｙ":"Y","Ỳ":"Y","Ý":"Y","Ŷ":"Y","Ỹ":"Y","Ȳ":"Y","Ẏ":"Y","Ÿ":"Y","Ỷ":"Y","Ỵ":"Y","Ƴ":"Y","Ɏ":"Y","Ỿ":"Y","Ⓩ":"Z","Ｚ":"Z","Ź":"Z","Ẑ":"Z","Ż":"Z","Ž":"Z","Ẓ":"Z","Ẕ":"Z","Ƶ":"Z","Ȥ":"Z","Ɀ":"Z","Ⱬ":"Z","Ꝣ":"Z","ⓐ":"a","ａ":"a","ẚ":"a","à":"a","á":"a","â":"a","ầ":"a","ấ":"a","ẫ":"a","ẩ":"a","ã":"a","ā":"a","ă":"a","ằ":"a","ắ":"a","ẵ":"a","ẳ":"a","ȧ":"a","ǡ":"a","ä":"a","ǟ":"a","ả":"a","å":"a","ǻ":"a","ǎ":"a","ȁ":"a","ȃ":"a","ạ":"a","ậ":"a","ặ":"a","ḁ":"a","ą":"a","ⱥ":"a","ɐ":"a","ꜳ":"aa","æ":"ae","ǽ":"ae","ǣ":"ae","ꜵ":"ao","ꜷ":"au","ꜹ":"av","ꜻ":"av","ꜽ":"ay","ⓑ":"b","ｂ":"b","ḃ":"b","ḅ":"b","ḇ":"b","ƀ":"b","ƃ":"b","ɓ":"b","ⓒ":"c","ｃ":"c","ć":"c","ĉ":"c","ċ":"c","č":"c","ç":"c","ḉ":"c","ƈ":"c","ȼ":"c","ꜿ":"c","ↄ":"c","ⓓ":"d","ｄ":"d","ḋ":"d","ď":"d","ḍ":"d","ḑ":"d","ḓ":"d","ḏ":"d","đ":"d","ƌ":"d","ɖ":"d","ɗ":"d","ꝺ":"d","ǳ":"dz","ǆ":"dz","ⓔ":"e","ｅ":"e","è":"e","é":"e","ê":"e","ề":"e","ế":"e","ễ":"e","ể":"e","ẽ":"e","ē":"e","ḕ":"e","ḗ":"e","ĕ":"e","ė":"e","ë":"e","ẻ":"e","ě":"e","ȅ":"e","ȇ":"e","ẹ":"e","ệ":"e","ȩ":"e","ḝ":"e","ę":"e","ḙ":"e","ḛ":"e","ɇ":"e","ɛ":"e","ǝ":"e","ⓕ":"f","ｆ":"f","ḟ":"f","ƒ":"f","ꝼ":"f","ⓖ":"g","ｇ":"g","ǵ":"g","ĝ":"g","ḡ":"g","ğ":"g","ġ":"g","ǧ":"g","ģ":"g","ǥ":"g","ɠ":"g","ꞡ":"g","ᵹ":"g","ꝿ":"g","ⓗ":"h","ｈ":"h","ĥ":"h","ḣ":"h","ḧ":"h","ȟ":"h","ḥ":"h","ḩ":"h","ḫ":"h","ẖ":"h","ħ":"h","ⱨ":"h","ⱶ":"h","ɥ":"h","ƕ":"hv","ⓘ":"i","ｉ":"i","ì":"i","í":"i","î":"i","ĩ":"i","ī":"i","ĭ":"i","ï":"i","ḯ":"i","ỉ":"i","ǐ":"i","ȉ":"i","ȋ":"i","ị":"i","į":"i","ḭ":"i","ɨ":"i","ı":"i","ⓙ":"j","ｊ":"j","ĵ":"j","ǰ":"j","ɉ":"j","ⓚ":"k","ｋ":"k","ḱ":"k","ǩ":"k","ḳ":"k","ķ":"k","ḵ":"k","ƙ":"k","ⱪ":"k","ꝁ":"k","ꝃ":"k","ꝅ":"k","ꞣ":"k","ⓛ":"l","ｌ":"l","ŀ":"l","ĺ":"l","ľ":"l","ḷ":"l","ḹ":"l","ļ":"l","ḽ":"l","ḻ":"l","ſ":"l","ł":"l","ƚ":"l","ɫ":"l","ⱡ":"l","ꝉ":"l","ꞁ":"l","ꝇ":"l","ǉ":"lj","ⓜ":"m","ｍ":"m","ḿ":"m","ṁ":"m","ṃ":"m","ɱ":"m","ɯ":"m","ⓝ":"n","ｎ":"n","ǹ":"n","ń":"n","ñ":"n","ṅ":"n","ň":"n","ṇ":"n","ņ":"n","ṋ":"n","ṉ":"n","ƞ":"n","ɲ":"n","ŉ":"n","ꞑ":"n","ꞥ":"n","ǌ":"nj","ⓞ":"o","ｏ":"o","ò":"o","ó":"o","ô":"o","ồ":"o","ố":"o","ỗ":"o","ổ":"o","õ":"o","ṍ":"o","ȭ":"o","ṏ":"o","ō":"o","ṑ":"o","ṓ":"o","ŏ":"o","ȯ":"o","ȱ":"o","ö":"o","ȫ":"o","ỏ":"o","ő":"o","ǒ":"o","ȍ":"o","ȏ":"o","ơ":"o","ờ":"o","ớ":"o","ỡ":"o","ở":"o","ợ":"o","ọ":"o","ộ":"o","ǫ":"o","ǭ":"o","ø":"o","ǿ":"o","ɔ":"o","ꝋ":"o","ꝍ":"o","ɵ":"o","ƣ":"oi","ȣ":"ou","ꝏ":"oo","ⓟ":"p","ｐ":"p","ṕ":"p","ṗ":"p","ƥ":"p","ᵽ":"p","ꝑ":"p","ꝓ":"p","ꝕ":"p","ⓠ":"q","ｑ":"q","ɋ":"q","ꝗ":"q","ꝙ":"q","ⓡ":"r","ｒ":"r","ŕ":"r","ṙ":"r","ř":"r","ȑ":"r","ȓ":"r","ṛ":"r","ṝ":"r","ŗ":"r","ṟ":"r","ɍ":"r","ɽ":"r","ꝛ":"r","ꞧ":"r","ꞃ":"r","ⓢ":"s","ｓ":"s","ß":"s","ś":"s","ṥ":"s","ŝ":"s","ṡ":"s","š":"s","ṧ":"s","ṣ":"s","ṩ":"s","ș":"s","ş":"s","ȿ":"s","ꞩ":"s","ꞅ":"s","ẛ":"s","ⓣ":"t","ｔ":"t","ṫ":"t","ẗ":"t","ť":"t","ṭ":"t","ț":"t","ţ":"t","ṱ":"t","ṯ":"t","ŧ":"t","ƭ":"t","ʈ":"t","ⱦ":"t","ꞇ":"t","ꜩ":"tz","ⓤ":"u","ｕ":"u","ù":"u","ú":"u","û":"u","ũ":"u","ṹ":"u","ū":"u","ṻ":"u","ŭ":"u","ü":"u","ǜ":"u","ǘ":"u","ǖ":"u","ǚ":"u","ủ":"u","ů":"u","ű":"u","ǔ":"u","ȕ":"u","ȗ":"u","ư":"u","ừ":"u","ứ":"u","ữ":"u","ử":"u","ự":"u","ụ":"u","ṳ":"u","ų":"u","ṷ":"u","ṵ":"u","ʉ":"u","ⓥ":"v","ｖ":"v","ṽ":"v","ṿ":"v","ʋ":"v","ꝟ":"v","ʌ":"v","ꝡ":"vy","ⓦ":"w","ｗ":"w","ẁ":"w","ẃ":"w","ŵ":"w","ẇ":"w","ẅ":"w","ẘ":"w","ẉ":"w","ⱳ":"w","ⓧ":"x","ｘ":"x","ẋ":"x","ẍ":"x","ⓨ":"y","ｙ":"y","ỳ":"y","ý":"y","ŷ":"y","ỹ":"y","ȳ":"y","ẏ":"y","ÿ":"y","ỷ":"y","ẙ":"y","ỵ":"y","ƴ":"y","ɏ":"y","ỿ":"y","ⓩ":"z","ｚ":"z","ź":"z","ẑ":"z","ż":"z","ž":"z","ẓ":"z","ẕ":"z","ƶ":"z","ȥ":"z","ɀ":"z","ⱬ":"z","ꝣ":"z","Ά":"Α","Έ":"Ε","Ή":"Η","Ί":"Ι","Ϊ":"Ι","Ό":"Ο","Ύ":"Υ","Ϋ":"Υ","Ώ":"Ω","ά":"α","έ":"ε","ή":"η","ί":"ι","ϊ":"ι","ΐ":"ι","ό":"ο","ύ":"υ","ϋ":"υ","ΰ":"υ","ω":"ω","ς":"σ"};return e}),t.define("select2/data/base",["../utils"],function(e){function t(e,n){t.__super__.constructor.call(this)}return e.Extend(t,e.Observable),t.prototype.current=function(e){throw new Error("The `current` method must be defined in child classes.")},t.prototype.query=function(e,t){throw new Error("The `query` method must be defined in child classes.")},t.prototype.bind=function(e,t){},t.prototype.destroy=function(){},t.prototype.generateResultId=function(t,n){var i=t.id+"-result-";return i+=e.generateChars(4),i+=null!=n.id?"-"+n.id.toString():"-"+e.generateChars(4)},t}),t.define("select2/data/select",["./base","../utils","jquery"],function(e,t,n){function i(e,t){this.$element=e,this.options=t,i.__super__.constructor.call(this)}return t.Extend(i,e),i.prototype.current=function(e){var t=[],i=this;this.$element.find(":selected").each(function(){var e=n(this),r=i.item(e);t.push(r)}),e(t)},i.prototype.select=function(e){var t=this;if(e.selected=!0,n(e.element).is("option"))return e.element.selected=!0,void this.$element.trigger("change");if(this.$element.prop("multiple"))this.current(function(i){var r=[];e=[e],e.push.apply(e,i);for(var o=0;o<e.length;o++){var a=e[o].id;-1===n.inArray(a,r)&&r.push(a)}t.$element.val(r),t.$element.trigger("change")});else{var i=e.id;this.$element.val(i),this.$element.trigger("change");
}},i.prototype.unselect=function(e){var t=this;if(this.$element.prop("multiple"))return e.selected=!1,n(e.element).is("option")?(e.element.selected=!1,void this.$element.trigger("change")):void this.current(function(i){for(var r=[],o=0;o<i.length;o++){var a=i[o].id;a!==e.id&&-1===n.inArray(a,r)&&r.push(a)}t.$element.val(r),t.$element.trigger("change")})},i.prototype.bind=function(e,t){var n=this;this.container=e,e.on("select",function(e){n.select(e.data)}),e.on("unselect",function(e){n.unselect(e.data)})},i.prototype.destroy=function(){this.$element.find("*").each(function(){n.removeData(this,"data")})},i.prototype.query=function(e,t){var i=[],r=this,o=this.$element.children();o.each(function(){var t=n(this);if(t.is("option")||t.is("optgroup")){var o=r.item(t),a=r.matches(e,o);null!==a&&i.push(a)}}),t({results:i})},i.prototype.addOptions=function(e){t.appendMany(this.$element,e)},i.prototype.option=function(e){var t;e.children?(t=document.createElement("optgroup"),t.label=e.text):(t=document.createElement("option"),void 0!==t.textContent?t.textContent=e.text:t.innerText=e.text),e.id&&(t.value=e.id),e.disabled&&(t.disabled=!0),e.selected&&(t.selected=!0),e.title&&(t.title=e.title);var i=n(t),r=this._normalizeItem(e);return r.element=t,n.data(t,"data",r),i},i.prototype.item=function(e){var t={};if(t=n.data(e[0],"data"),null!=t)return t;if(e.is("option"))t={id:e.val(),text:e.text(),disabled:e.prop("disabled"),selected:e.prop("selected"),title:e.prop("title")};else if(e.is("optgroup")){t={text:e.prop("label"),children:[],title:e.prop("title")};for(var i=e.children("option"),r=[],o=0;o<i.length;o++){var a=n(i[o]),s=this.item(a);r.push(s)}t.children=r}return t=this._normalizeItem(t),t.element=e[0],n.data(e[0],"data",t),t},i.prototype._normalizeItem=function(e){n.isPlainObject(e)||(e={id:e,text:e}),e=n.extend({},{text:""},e);var t={selected:!1,disabled:!1};return null!=e.id&&(e.id=e.id.toString()),null!=e.text&&(e.text=e.text.toString()),null==e._resultId&&e.id&&null!=this.container&&(e._resultId=this.generateResultId(this.container,e)),n.extend({},t,e)},i.prototype.matches=function(e,t){var n=this.options.get("matcher");return n(e,t)},i}),t.define("select2/data/array",["./select","../utils","jquery"],function(e,t,n){function i(e,t){var n=t.get("data")||[];i.__super__.constructor.call(this,e,t),this.addOptions(this.convertToOptions(n))}return t.Extend(i,e),i.prototype.select=function(e){var t=this.$element.find("option").filter(function(t,n){return n.value==e.id.toString()});0===t.length&&(t=this.option(e),this.addOptions(t)),i.__super__.select.call(this,e)},i.prototype.convertToOptions=function(e){function i(e){return function(){return n(this).val()==e.id}}for(var r=this,o=this.$element.find("option"),a=o.map(function(){return r.item(n(this)).id}).get(),s=[],l=0;l<e.length;l++){var u=this._normalizeItem(e[l]);if(n.inArray(u.id,a)>=0){var c=o.filter(i(u)),d=this.item(c),p=n.extend(!0,{},u,d),h=this.option(p);c.replaceWith(h)}else{var f=this.option(u);if(u.children){var g=this.convertToOptions(u.children);t.appendMany(f,g)}s.push(f)}}return s},i}),t.define("select2/data/ajax",["./array","../utils","jquery"],function(e,t,n){function i(e,t){this.ajaxOptions=this._applyDefaults(t.get("ajax")),null!=this.ajaxOptions.processResults&&(this.processResults=this.ajaxOptions.processResults),i.__super__.constructor.call(this,e,t)}return t.Extend(i,e),i.prototype._applyDefaults=function(e){var t={data:function(e){return n.extend({},e,{q:e.term})},transport:function(e,t,i){var r=n.ajax(e);return r.then(t),r.fail(i),r}};return n.extend({},t,e,!0)},i.prototype.processResults=function(e){return e},i.prototype.query=function(e,t){function i(){var i=o.transport(o,function(i){var o=r.processResults(i,e);r.options.get("debug")&&window.console&&console.error&&(o&&o.results&&n.isArray(o.results)||console.error("Select2: The AJAX results did not return an array in the `results` key of the response.")),t(o)},function(){i.status&&"0"===i.status||r.trigger("results:message",{message:"errorLoading"})});r._request=i}var r=this;null!=this._request&&(n.isFunction(this._request.abort)&&this._request.abort(),this._request=null);var o=n.extend({type:"GET"},this.ajaxOptions);"function"==typeof o.url&&(o.url=o.url.call(this.$element,e)),"function"==typeof o.data&&(o.data=o.data.call(this.$element,e)),this.ajaxOptions.delay&&null!=e.term?(this._queryTimeout&&window.clearTimeout(this._queryTimeout),this._queryTimeout=window.setTimeout(i,this.ajaxOptions.delay)):i()},i}),t.define("select2/data/tags",["jquery"],function(e){function t(t,n,i){var r=i.get("tags"),o=i.get("createTag");void 0!==o&&(this.createTag=o);var a=i.get("insertTag");if(void 0!==a&&(this.insertTag=a),t.call(this,n,i),e.isArray(r))for(var s=0;s<r.length;s++){var l=r[s],u=this._normalizeItem(l),c=this.option(u);this.$element.append(c)}}return t.prototype.query=function(e,t,n){function i(e,o){for(var a=e.results,s=0;s<a.length;s++){var l=a[s],u=null!=l.children&&!i({results:l.children},!0),c=l.text===t.term;if(c||u)return o?!1:(e.data=a,void n(e))}if(o)return!0;var d=r.createTag(t);if(null!=d){var p=r.option(d);p.attr("data-select2-tag",!0),r.addOptions([p]),r.insertTag(a,d)}e.results=a,n(e)}var r=this;return this._removeOldTags(),null==t.term||null!=t.page?void e.call(this,t,n):void e.call(this,t,i)},t.prototype.createTag=function(t,n){var i=e.trim(n.term);return""===i?null:{id:i,text:i}},t.prototype.insertTag=function(e,t,n){t.unshift(n)},t.prototype._removeOldTags=function(t){var n=(this._lastTag,this.$element.find("option[data-select2-tag]"));n.each(function(){this.selected||e(this).remove()})},t}),t.define("select2/data/tokenizer",["jquery"],function(e){function t(e,t,n){var i=n.get("tokenizer");void 0!==i&&(this.tokenizer=i),e.call(this,t,n)}return t.prototype.bind=function(e,t,n){e.call(this,t,n),this.$search=t.dropdown.$search||t.selection.$search||n.find(".select2-search__field")},t.prototype.query=function(t,n,i){function r(t){var n=a._normalizeItem(t),i=a.$element.find("option").filter(function(){return e(this).val()===n.id});if(!i.length){var r=a.option(n);r.attr("data-select2-tag",!0),a._removeOldTags(),a.addOptions([r])}o(n)}function o(e){a.trigger("select",{data:e})}var a=this;n.term=n.term||"";var s=this.tokenizer(n,this.options,r);s.term!==n.term&&(this.$search.length&&(this.$search.val(s.term),this.$search.focus()),n.term=s.term),t.call(this,n,i)},t.prototype.tokenizer=function(t,n,i,r){for(var o=i.get("tokenSeparators")||[],a=n.term,s=0,l=this.createTag||function(e){return{id:e.term,text:e.term}};s<a.length;){var u=a[s];if(-1!==e.inArray(u,o)){var c=a.substr(0,s),d=e.extend({},n,{term:c}),p=l(d);null!=p?(r(p),a=a.substr(s+1)||"",s=0):s++}else s++}return{term:a}},t}),t.define("select2/data/minimumInputLength",[],function(){function e(e,t,n){this.minimumInputLength=n.get("minimumInputLength"),e.call(this,t,n)}return e.prototype.query=function(e,t,n){return t.term=t.term||"",t.term.length<this.minimumInputLength?void this.trigger("results:message",{message:"inputTooShort",args:{minimum:this.minimumInputLength,input:t.term,params:t}}):void e.call(this,t,n)},e}),t.define("select2/data/maximumInputLength",[],function(){function e(e,t,n){this.maximumInputLength=n.get("maximumInputLength"),e.call(this,t,n)}return e.prototype.query=function(e,t,n){return t.term=t.term||"",this.maximumInputLength>0&&t.term.length>this.maximumInputLength?void this.trigger("results:message",{message:"inputTooLong",args:{maximum:this.maximumInputLength,input:t.term,params:t}}):void e.call(this,t,n)},e}),t.define("select2/data/maximumSelectionLength",[],function(){function e(e,t,n){this.maximumSelectionLength=n.get("maximumSelectionLength"),e.call(this,t,n)}return e.prototype.query=function(e,t,n){var i=this;this.current(function(r){var o=null!=r?r.length:0;return i.maximumSelectionLength>0&&o>=i.maximumSelectionLength?void i.trigger("results:message",{message:"maximumSelected",args:{maximum:i.maximumSelectionLength}}):void e.call(i,t,n)})},e}),t.define("select2/dropdown",["jquery","./utils"],function(e,t){function n(e,t){this.$element=e,this.options=t,n.__super__.constructor.call(this)}return t.Extend(n,t.Observable),n.prototype.render=function(){var t=e('<span class="select2-dropdown"><span class="select2-results"></span></span>');return t.attr("dir",this.options.get("dir")),this.$dropdown=t,t},n.prototype.bind=function(){},n.prototype.position=function(e,t){},n.prototype.destroy=function(){this.$dropdown.remove()},n}),t.define("select2/dropdown/search",["jquery","../utils"],function(e,t){function n(){}return n.prototype.render=function(t){var n=t.call(this),i=e('<span class="select2-search select2-search--dropdown"><input class="select2-search__field" type="search" tabindex="-1" autocomplete="off" autocorrect="off" autocapitalize="off" spellcheck="false" role="textbox" /></span>');return this.$searchContainer=i,this.$search=i.find("input"),n.prepend(i),n},n.prototype.bind=function(t,n,i){var r=this;t.call(this,n,i),this.$search.on("keydown",function(e){r.trigger("keypress",e),r._keyUpPrevented=e.isDefaultPrevented()}),this.$search.on("input",function(t){e(this).off("keyup")}),this.$search.on("keyup input",function(e){r.handleSearch(e)}),n.on("open",function(){r.$search.attr("tabindex",0),r.$search.focus(),window.setTimeout(function(){r.$search.focus()},0)}),n.on("close",function(){r.$search.attr("tabindex",-1),r.$search.val("")}),n.on("focus",function(){n.isOpen()&&r.$search.focus()}),n.on("results:all",function(e){if(null==e.query.term||""===e.query.term){var t=r.showSearch(e);t?r.$searchContainer.removeClass("select2-search--hide"):r.$searchContainer.addClass("select2-search--hide")}})},n.prototype.handleSearch=function(e){if(!this._keyUpPrevented){var t=this.$search.val();this.trigger("query",{term:t})}this._keyUpPrevented=!1},n.prototype.showSearch=function(e,t){return!0},n}),t.define("select2/dropdown/hidePlaceholder",[],function(){function e(e,t,n,i){this.placeholder=this.normalizePlaceholder(n.get("placeholder")),e.call(this,t,n,i)}return e.prototype.append=function(e,t){t.results=this.removePlaceholder(t.results),e.call(this,t)},e.prototype.normalizePlaceholder=function(e,t){return"string"==typeof t&&(t={id:"",text:t}),t},e.prototype.removePlaceholder=function(e,t){for(var n=t.slice(0),i=t.length-1;i>=0;i--){var r=t[i];this.placeholder.id===r.id&&n.splice(i,1)}return n},e}),t.define("select2/dropdown/infiniteScroll",["jquery"],function(e){function t(e,t,n,i){this.lastParams={},e.call(this,t,n,i),this.$loadingMore=this.createLoadingMore(),this.loading=!1}return t.prototype.append=function(e,t){this.$loadingMore.remove(),this.loading=!1,e.call(this,t),this.showLoadingMore(t)&&this.$results.append(this.$loadingMore)},t.prototype.bind=function(t,n,i){var r=this;t.call(this,n,i),n.on("query",function(e){r.lastParams=e,r.loading=!0}),n.on("query:append",function(e){r.lastParams=e,r.loading=!0}),this.$results.on("scroll",function(){var t=e.contains(document.documentElement,r.$loadingMore[0]);if(!r.loading&&t){var n=r.$results.offset().top+r.$results.outerHeight(!1),i=r.$loadingMore.offset().top+r.$loadingMore.outerHeight(!1);n+50>=i&&r.loadMore()}})},t.prototype.loadMore=function(){this.loading=!0;var t=e.extend({},{page:1},this.lastParams);t.page++,this.trigger("query:append",t)},t.prototype.showLoadingMore=function(e,t){return t.pagination&&t.pagination.more},t.prototype.createLoadingMore=function(){var t=e('<li class="select2-results__option select2-results__option--load-more"role="treeitem" aria-disabled="true"></li>'),n=this.options.get("translations").get("loadingMore");return t.html(n(this.lastParams)),t},t}),t.define("select2/dropdown/attachBody",["jquery","../utils"],function(e,t){function n(t,n,i){this.$dropdownParent=i.get("dropdownParent")||e(document.body),t.call(this,n,i)}return n.prototype.bind=function(e,t,n){var i=this,r=!1;e.call(this,t,n),t.on("open",function(){i._showDropdown(),i._attachPositioningHandler(t),r||(r=!0,t.on("results:all",function(){i._positionDropdown(),i._resizeDropdown()}),t.on("results:append",function(){i._positionDropdown(),i._resizeDropdown()}))}),t.on("close",function(){i._hideDropdown(),i._detachPositioningHandler(t)}),this.$dropdownContainer.on("mousedown",function(e){e.stopPropagation()})},n.prototype.destroy=function(e){e.call(this),this.$dropdownContainer.remove()},n.prototype.position=function(e,t,n){t.attr("class",n.attr("class")),t.removeClass("select2"),t.addClass("select2-container--open"),t.css({position:"absolute",top:-999999}),this.$container=n},n.prototype.render=function(t){var n=e("<span></span>"),i=t.call(this);return n.append(i),this.$dropdownContainer=n,n},n.prototype._hideDropdown=function(e){this.$dropdownContainer.detach()},n.prototype._attachPositioningHandler=function(n,i){var r=this,o="scroll.select2."+i.id,a="resize.select2."+i.id,s="orientationchange.select2."+i.id,l=this.$container.parents().filter(t.hasScroll);l.each(function(){e(this).data("select2-scroll-position",{x:e(this).scrollLeft(),y:e(this).scrollTop()})}),l.on(o,function(t){var n=e(this).data("select2-scroll-position");e(this).scrollTop(n.y)}),e(window).on(o+" "+a+" "+s,function(e){r._positionDropdown(),r._resizeDropdown()})},n.prototype._detachPositioningHandler=function(n,i){var r="scroll.select2."+i.id,o="resize.select2."+i.id,a="orientationchange.select2."+i.id,s=this.$container.parents().filter(t.hasScroll);s.off(r),e(window).off(r+" "+o+" "+a)},n.prototype._positionDropdown=function(){var t=e(window),n=this.$dropdown.hasClass("select2-dropdown--above"),i=this.$dropdown.hasClass("select2-dropdown--below"),r=null,o=this.$container.offset();o.bottom=o.top+this.$container.outerHeight(!1);var a={height:this.$container.outerHeight(!1)};a.top=o.top,a.bottom=o.top+a.height;var s={height:this.$dropdown.outerHeight(!1)},l={top:t.scrollTop(),bottom:t.scrollTop()+t.height()},u=l.top<o.top-s.height,c=l.bottom>o.bottom+s.height,d={left:o.left,top:a.bottom},p=this.$dropdownParent;"static"===p.css("position")&&(p=p.offsetParent());var h=p.offset();d.top-=h.top,d.left-=h.left,n||i||(r="below"),c||!u||n?!u&&c&&n&&(r="below"):r="above",("above"==r||n&&"below"!==r)&&(d.top=a.top-h.top-s.height),null!=r&&(this.$dropdown.removeClass("select2-dropdown--below select2-dropdown--above").addClass("select2-dropdown--"+r),this.$container.removeClass("select2-container--below select2-container--above").addClass("select2-container--"+r)),this.$dropdownContainer.css(d)},n.prototype._resizeDropdown=function(){var e={width:this.$container.outerWidth(!1)+"px"};this.options.get("dropdownAutoWidth")&&(e.minWidth=e.width,e.position="relative",e.width="auto"),this.$dropdown.css(e)},n.prototype._showDropdown=function(e){this.$dropdownContainer.appendTo(this.$dropdownParent),this._positionDropdown(),this._resizeDropdown()},n}),t.define("select2/dropdown/minimumResultsForSearch",[],function(){function e(t){for(var n=0,i=0;i<t.length;i++){var r=t[i];r.children?n+=e(r.children):n++}return n}function t(e,t,n,i){this.minimumResultsForSearch=n.get("minimumResultsForSearch"),this.minimumResultsForSearch<0&&(this.minimumResultsForSearch=1/0),e.call(this,t,n,i)}return t.prototype.showSearch=function(t,n){return e(n.data.results)<this.minimumResultsForSearch?!1:t.call(this,n)},t}),t.define("select2/dropdown/selectOnClose",[],function(){function e(){}return e.prototype.bind=function(e,t,n){var i=this;e.call(this,t,n),t.on("close",function(e){i._handleSelectOnClose(e)})},e.prototype._handleSelectOnClose=function(e,t){if(t&&null!=t.originalSelect2Event){var n=t.originalSelect2Event;if("select"===n._type||"unselect"===n._type)return}var i=this.getHighlightedResults();if(!(i.length<1)){var r=i.data("data");null!=r.element&&r.element.selected||null==r.element&&r.selected||this.trigger("select",{data:r})}},e}),t.define("select2/dropdown/closeOnSelect",[],function(){function e(){}return e.prototype.bind=function(e,t,n){var i=this;e.call(this,t,n),t.on("select",function(e){i._selectTriggered(e)}),t.on("unselect",function(e){i._selectTriggered(e)})},e.prototype._selectTriggered=function(e,t){var n=t.originalEvent;n&&n.ctrlKey||this.trigger("close",{originalEvent:n,originalSelect2Event:t})},e}),t.define("select2/i18n/en",[],function(){return{errorLoading:function(){return"The results could not be loaded."},inputTooLong:function(e){var t=e.input.length-e.maximum,n="Please delete "+t+" character";return 1!=t&&(n+="s"),n},inputTooShort:function(e){var t=e.minimum-e.input.length,n="Please enter "+t+" or more characters";return n},loadingMore:function(){return"Loading more results…"},maximumSelected:function(e){var t="You can only select "+e.maximum+" item";return 1!=e.maximum&&(t+="s"),t},noResults:function(){return"No results found"},searching:function(){return"Searching…"}}}),t.define("select2/defaults",["jquery","require","./results","./selection/single","./selection/multiple","./selection/placeholder","./selection/allowClear","./selection/search","./selection/eventRelay","./utils","./translation","./diacritics","./data/select","./data/array","./data/ajax","./data/tags","./data/tokenizer","./data/minimumInputLength","./data/maximumInputLength","./data/maximumSelectionLength","./dropdown","./dropdown/search","./dropdown/hidePlaceholder","./dropdown/infiniteScroll","./dropdown/attachBody","./dropdown/minimumResultsForSearch","./dropdown/selectOnClose","./dropdown/closeOnSelect","./i18n/en"],function(e,t,n,i,r,o,a,s,l,u,c,d,p,h,f,g,v,m,y,b,w,x,_,k,C,T,D,S,E){function A(){this.reset()}A.prototype.apply=function(d){if(d=e.extend(!0,{},this.defaults,d),null==d.dataAdapter){if(null!=d.ajax?d.dataAdapter=f:null!=d.data?d.dataAdapter=h:d.dataAdapter=p,d.minimumInputLength>0&&(d.dataAdapter=u.Decorate(d.dataAdapter,m)),d.maximumInputLength>0&&(d.dataAdapter=u.Decorate(d.dataAdapter,y)),d.maximumSelectionLength>0&&(d.dataAdapter=u.Decorate(d.dataAdapter,b)),d.tags&&(d.dataAdapter=u.Decorate(d.dataAdapter,g)),null==d.tokenSeparators&&null==d.tokenizer||(d.dataAdapter=u.Decorate(d.dataAdapter,v)),null!=d.query){var E=t(d.amdBase+"compat/query");d.dataAdapter=u.Decorate(d.dataAdapter,E)}if(null!=d.initSelection){var A=t(d.amdBase+"compat/initSelection");d.dataAdapter=u.Decorate(d.dataAdapter,A)}}if(null==d.resultsAdapter&&(d.resultsAdapter=n,null!=d.ajax&&(d.resultsAdapter=u.Decorate(d.resultsAdapter,k)),null!=d.placeholder&&(d.resultsAdapter=u.Decorate(d.resultsAdapter,_)),d.selectOnClose&&(d.resultsAdapter=u.Decorate(d.resultsAdapter,D))),null==d.dropdownAdapter){if(d.multiple)d.dropdownAdapter=w;else{var M=u.Decorate(w,x);d.dropdownAdapter=M}if(0!==d.minimumResultsForSearch&&(d.dropdownAdapter=u.Decorate(d.dropdownAdapter,T)),d.closeOnSelect&&(d.dropdownAdapter=u.Decorate(d.dropdownAdapter,S)),null!=d.dropdownCssClass||null!=d.dropdownCss||null!=d.adaptDropdownCssClass){var O=t(d.amdBase+"compat/dropdownCss");d.dropdownAdapter=u.Decorate(d.dropdownAdapter,O)}d.dropdownAdapter=u.Decorate(d.dropdownAdapter,C)}if(null==d.selectionAdapter){if(d.multiple?d.selectionAdapter=r:d.selectionAdapter=i,null!=d.placeholder&&(d.selectionAdapter=u.Decorate(d.selectionAdapter,o)),d.allowClear&&(d.selectionAdapter=u.Decorate(d.selectionAdapter,a)),d.multiple&&(d.selectionAdapter=u.Decorate(d.selectionAdapter,s)),null!=d.containerCssClass||null!=d.containerCss||null!=d.adaptContainerCssClass){var I=t(d.amdBase+"compat/containerCss");d.selectionAdapter=u.Decorate(d.selectionAdapter,I)}d.selectionAdapter=u.Decorate(d.selectionAdapter,l)}if("string"==typeof d.language)if(d.language.indexOf("-")>0){var N=d.language.split("-"),F=N[0];d.language=[d.language,F]}else d.language=[d.language];if(e.isArray(d.language)){var P=new c;d.language.push("en");for(var $=d.language,L=0;L<$.length;L++){var q=$[L],j={};try{j=c.loadPath(q)}catch(R){try{q=this.defaults.amdLanguageBase+q,j=c.loadPath(q)}catch(z){d.debug&&window.console&&console.warn&&console.warn('Select2: The language file for "'+q+'" could not be automatically loaded. A fallback will be used instead.');continue}}P.extend(j)}d.translations=P}else{var H=c.loadPath(this.defaults.amdLanguageBase+"en"),W=new c(d.language);W.extend(H),d.translations=W}return d},A.prototype.reset=function(){function t(e){function t(e){return d[e]||e}return e.replace(/[^\u0000-\u007E]/g,t)}function n(i,r){if(""===e.trim(i.term))return r;if(r.children&&r.children.length>0){for(var o=e.extend(!0,{},r),a=r.children.length-1;a>=0;a--){var s=r.children[a],l=n(i,s);null==l&&o.children.splice(a,1)}return o.children.length>0?o:n(i,o)}var u=t(r.text).toUpperCase(),c=t(i.term).toUpperCase();return u.indexOf(c)>-1?r:null}this.defaults={amdBase:"./",amdLanguageBase:"./i18n/",closeOnSelect:!0,debug:!1,dropdownAutoWidth:!1,escapeMarkup:u.escapeMarkup,language:E,matcher:n,minimumInputLength:0,maximumInputLength:0,maximumSelectionLength:0,minimumResultsForSearch:0,selectOnClose:!1,sorter:function(e){return e},templateResult:function(e){return e.text},templateSelection:function(e){return e.text},theme:"default",width:"resolve"}},A.prototype.set=function(t,n){var i=e.camelCase(t),r={};r[i]=n;var o=u._convertData(r);e.extend(this.defaults,o)};var M=new A;return M}),t.define("select2/options",["require","jquery","./defaults","./utils"],function(e,t,n,i){function r(t,r){if(this.options=t,null!=r&&this.fromElement(r),this.options=n.apply(this.options),r&&r.is("input")){var o=e(this.get("amdBase")+"compat/inputData");this.options.dataAdapter=i.Decorate(this.options.dataAdapter,o)}}return r.prototype.fromElement=function(e){var n=["select2"];null==this.options.multiple&&(this.options.multiple=e.prop("multiple")),null==this.options.disabled&&(this.options.disabled=e.prop("disabled")),null==this.options.language&&(e.prop("lang")?this.options.language=e.prop("lang").toLowerCase():e.closest("[lang]").prop("lang")&&(this.options.language=e.closest("[lang]").prop("lang"))),null==this.options.dir&&(e.prop("dir")?this.options.dir=e.prop("dir"):e.closest("[dir]").prop("dir")?this.options.dir=e.closest("[dir]").prop("dir"):this.options.dir="ltr"),e.prop("disabled",this.options.disabled),e.prop("multiple",this.options.multiple),e.data("select2Tags")&&(this.options.debug&&window.console&&console.warn&&console.warn('Select2: The `data-select2-tags` attribute has been changed to use the `data-data` and `data-tags="true"` attributes and will be removed in future versions of Select2.'),e.data("data",e.data("select2Tags")),e.data("tags",!0)),e.data("ajaxUrl")&&(this.options.debug&&window.console&&console.warn&&console.warn("Select2: The `data-ajax-url` attribute has been changed to `data-ajax--url` and support for the old attribute will be removed in future versions of Select2."),e.attr("ajax--url",e.data("ajaxUrl")),e.data("ajax--url",e.data("ajaxUrl")));var r={};r=t.fn.jquery&&"1."==t.fn.jquery.substr(0,2)&&e[0].dataset?t.extend(!0,{},e[0].dataset,e.data()):e.data();var o=t.extend(!0,{},r);o=i._convertData(o);for(var a in o)t.inArray(a,n)>-1||(t.isPlainObject(this.options[a])?t.extend(this.options[a],o[a]):this.options[a]=o[a]);return this},r.prototype.get=function(e){return this.options[e]},r.prototype.set=function(e,t){this.options[e]=t},r}),t.define("select2/core",["jquery","./options","./utils","./keys"],function(e,t,n,i){var r=function(e,n){null!=e.data("select2")&&e.data("select2").destroy(),this.$element=e,this.id=this._generateId(e),n=n||{},this.options=new t(n,e),r.__super__.constructor.call(this);var i=e.attr("tabindex")||0;e.data("old-tabindex",i),e.attr("tabindex","-1");var o=this.options.get("dataAdapter");this.dataAdapter=new o(e,this.options);var a=this.render();this._placeContainer(a);var s=this.options.get("selectionAdapter");this.selection=new s(e,this.options),this.$selection=this.selection.render(),this.selection.position(this.$selection,a);var l=this.options.get("dropdownAdapter");this.dropdown=new l(e,this.options),this.$dropdown=this.dropdown.render(),this.dropdown.position(this.$dropdown,a);var u=this.options.get("resultsAdapter");this.results=new u(e,this.options,this.dataAdapter),this.$results=this.results.render(),this.results.position(this.$results,this.$dropdown);var c=this;this._bindAdapters(),this._registerDomEvents(),this._registerDataEvents(),this._registerSelectionEvents(),this._registerDropdownEvents(),this._registerResultsEvents(),this._registerEvents(),this.dataAdapter.current(function(e){c.trigger("selection:update",{data:e})}),e.addClass("select2-hidden-accessible"),e.attr("aria-hidden","true"),this._syncAttributes(),e.data("select2",this)};return n.Extend(r,n.Observable),r.prototype._generateId=function(e){var t="";return t=null!=e.attr("id")?e.attr("id"):null!=e.attr("name")?e.attr("name")+"-"+n.generateChars(2):n.generateChars(4),t=t.replace(/(:|\.|\[|\]|,)/g,""),t="select2-"+t},r.prototype._placeContainer=function(e){e.insertAfter(this.$element);var t=this._resolveWidth(this.$element,this.options.get("width"));null!=t&&e.css("width",t)},r.prototype._resolveWidth=function(e,t){var n=/^width:(([-+]?([0-9]*\.)?[0-9]+)(px|em|ex|%|in|cm|mm|pt|pc))/i;if("resolve"==t){var i=this._resolveWidth(e,"style");return null!=i?i:this._resolveWidth(e,"element")}if("element"==t){var r=e.outerWidth(!1);return 0>=r?"auto":r+"px"}if("style"==t){var o=e.attr("style");if("string"!=typeof o)return null;for(var a=o.split(";"),s=0,l=a.length;l>s;s+=1){var u=a[s].replace(/\s/g,""),c=u.match(n);if(null!==c&&c.length>=1)return c[1]}return null}return t},r.prototype._bindAdapters=function(){this.dataAdapter.bind(this,this.$container),this.selection.bind(this,this.$container),this.dropdown.bind(this,this.$container),this.results.bind(this,this.$container)},r.prototype._registerDomEvents=function(){var t=this;this.$element.on("change.select2",function(){t.dataAdapter.current(function(e){t.trigger("selection:update",{data:e})})}),this.$element.on("focus.select2",function(e){t.trigger("focus",e)}),this._syncA=n.bind(this._syncAttributes,this),this._syncS=n.bind(this._syncSubtree,this),this.$element[0].attachEvent&&this.$element[0].attachEvent("onpropertychange",this._syncA);var i=window.MutationObserver||window.WebKitMutationObserver||window.MozMutationObserver;null!=i?(this._observer=new i(function(n){e.each(n,t._syncA),e.each(n,t._syncS)}),this._observer.observe(this.$element[0],{attributes:!0,childList:!0,subtree:!1})):this.$element[0].addEventListener&&(this.$element[0].addEventListener("DOMAttrModified",t._syncA,!1),this.$element[0].addEventListener("DOMNodeInserted",t._syncS,!1),this.$element[0].addEventListener("DOMNodeRemoved",t._syncS,!1))},r.prototype._registerDataEvents=function(){var e=this;this.dataAdapter.on("*",function(t,n){e.trigger(t,n)})},r.prototype._registerSelectionEvents=function(){var t=this,n=["toggle","focus"];this.selection.on("toggle",function(){t.toggleDropdown()}),this.selection.on("focus",function(e){t.focus(e)}),this.selection.on("*",function(i,r){-1===e.inArray(i,n)&&t.trigger(i,r)})},r.prototype._registerDropdownEvents=function(){var e=this;this.dropdown.on("*",function(t,n){e.trigger(t,n)})},r.prototype._registerResultsEvents=function(){var e=this;this.results.on("*",function(t,n){e.trigger(t,n)})},r.prototype._registerEvents=function(){var e=this;this.on("open",function(){e.$container.addClass("select2-container--open")}),this.on("close",function(){e.$container.removeClass("select2-container--open")}),this.on("enable",function(){e.$container.removeClass("select2-container--disabled")}),this.on("disable",function(){e.$container.addClass("select2-container--disabled")}),this.on("blur",function(){e.$container.removeClass("select2-container--focus")}),this.on("query",function(t){e.isOpen()||e.trigger("open",{}),this.dataAdapter.query(t,function(n){e.trigger("results:all",{data:n,query:t})})}),this.on("query:append",function(t){this.dataAdapter.query(t,function(n){e.trigger("results:append",{data:n,query:t})})}),this.on("keypress",function(t){var n=t.which;e.isOpen()?n===i.ESC||n===i.TAB||n===i.UP&&t.altKey?(e.close(),t.preventDefault()):n===i.ENTER?(e.trigger("results:select",{}),t.preventDefault()):n===i.SPACE&&t.ctrlKey?(e.trigger("results:toggle",{}),t.preventDefault()):n===i.UP?(e.trigger("results:previous",{}),t.preventDefault()):n===i.DOWN&&(e.trigger("results:next",{}),t.preventDefault()):(n===i.ENTER||n===i.SPACE||n===i.DOWN&&t.altKey)&&(e.open(),t.preventDefault())})},r.prototype._syncAttributes=function(){this.options.set("disabled",this.$element.prop("disabled")),this.options.get("disabled")?(this.isOpen()&&this.close(),this.trigger("disable",{})):this.trigger("enable",{})},r.prototype._syncSubtree=function(e,t){var n=!1,i=this;if(!e||!e.target||"OPTION"===e.target.nodeName||"OPTGROUP"===e.target.nodeName){if(t)if(t.addedNodes&&t.addedNodes.length>0)for(var r=0;r<t.addedNodes.length;r++){var o=t.addedNodes[r];o.selected&&(n=!0)}else t.removedNodes&&t.removedNodes.length>0&&(n=!0);else n=!0;n&&this.dataAdapter.current(function(e){i.trigger("selection:update",{data:e})})}},r.prototype.trigger=function(e,t){var n=r.__super__.trigger,i={open:"opening",close:"closing",select:"selecting",unselect:"unselecting"};if(void 0===t&&(t={}),e in i){var o=i[e],a={prevented:!1,name:e,args:t};if(n.call(this,o,a),a.prevented)return void(t.prevented=!0)}n.call(this,e,t)},r.prototype.toggleDropdown=function(){this.options.get("disabled")||(this.isOpen()?this.close():this.open())},r.prototype.open=function(){this.isOpen()||this.trigger("query",{})},r.prototype.close=function(){this.isOpen()&&this.trigger("close",{})},r.prototype.isOpen=function(){return this.$container.hasClass("select2-container--open")},r.prototype.hasFocus=function(){return this.$container.hasClass("select2-container--focus")},r.prototype.focus=function(e){this.hasFocus()||(this.$container.addClass("select2-container--focus"),this.trigger("focus",{}))},r.prototype.enable=function(e){this.options.get("debug")&&window.console&&console.warn&&console.warn('Select2: The `select2("enable")` method has been deprecated and will be removed in later Select2 versions. Use $element.prop("disabled") instead.'),null!=e&&0!==e.length||(e=[!0]);var t=!e[0];this.$element.prop("disabled",t)},r.prototype.data=function(){this.options.get("debug")&&arguments.length>0&&window.console&&console.warn&&console.warn('Select2: Data can no longer be set using `select2("data")`. You should consider setting the value instead using `$element.val()`.');var e=[];return this.dataAdapter.current(function(t){e=t}),e},r.prototype.val=function(t){if(this.options.get("debug")&&window.console&&console.warn&&console.warn('Select2: The `select2("val")` method has been deprecated and will be removed in later Select2 versions. Use $element.val() instead.'),null==t||0===t.length)return this.$element.val();var n=t[0];e.isArray(n)&&(n=e.map(n,function(e){return e.toString()})),this.$element.val(n).trigger("change")},r.prototype.destroy=function(){this.$container.remove(),this.$element[0].detachEvent&&this.$element[0].detachEvent("onpropertychange",this._syncA),null!=this._observer?(this._observer.disconnect(),this._observer=null):this.$element[0].removeEventListener&&(this.$element[0].removeEventListener("DOMAttrModified",this._syncA,!1),this.$element[0].removeEventListener("DOMNodeInserted",this._syncS,!1),this.$element[0].removeEventListener("DOMNodeRemoved",this._syncS,!1)),this._syncA=null,this._syncS=null,this.$element.off(".select2"),this.$element.attr("tabindex",this.$element.data("old-tabindex")),this.$element.removeClass("select2-hidden-accessible"),this.$element.attr("aria-hidden","false"),this.$element.removeData("select2"),this.dataAdapter.destroy(),this.selection.destroy(),this.dropdown.destroy(),this.results.destroy(),this.dataAdapter=null,this.selection=null,this.dropdown=null,this.results=null},r.prototype.render=function(){var t=e('<span class="select2 select2-container"><span class="selection"></span><span class="dropdown-wrapper" aria-hidden="true"></span></span>');return t.attr("dir",this.options.get("dir")),this.$container=t,this.$container.addClass("select2-container--"+this.options.get("theme")),
t.data("element",this.$element),t},r}),t.define("jquery-mousewheel",["jquery"],function(e){return e}),t.define("jquery.select2",["jquery","jquery-mousewheel","./select2/core","./select2/defaults"],function(e,t,n,i){if(null==e.fn.select2){var r=["open","close","destroy"];e.fn.select2=function(t){if(t=t||{},"object"==typeof t)return this.each(function(){var i=e.extend(!0,{},t);new n(e(this),i)}),this;if("string"==typeof t){var i,o=Array.prototype.slice.call(arguments,1);return this.each(function(){var n=e(this).data("select2");null==n&&window.console&&console.error&&console.error("The select2('"+t+"') method was called on an element that is not using Select2."),i=n[t].apply(n,o)}),e.inArray(t,r)>-1?this:i}throw new Error("Invalid arguments for Select2: "+t)}}return null==e.fn.select2.defaults&&(e.fn.select2.defaults=i),n}),{define:t.define,require:t.require}}(),n=t.require("jquery.select2");return e.fn.select2.amd=t,n})}).call(t,n(1))}]);